/* Tabs bar  */

@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

:root {
	--space-above-tabbar: 0 !important;
}

#TabsToolbar {
	--toolbarbutton-inner-padding: 0 !important;
}

#TabsToolbar:not([inFullscreen]) #tabbrowser-tabs {
	margin-bottom: -1px !important;
}

/* Tabs bar height */
#tabbrowser-tabs,
#tabbrowser-tabs arrowscrollbox {
	height: auto !important;
	min-height: auto !important;
}
/* Extra margin for the first and last tabs */
.tabbrowser-tab[first-tab]:not([pinned=true]) {
	margin-left: 0 !important;
}
.tabbrowser-tab[last-tab]:not([pinned=true]) {
	margin-right: 0 !important;
}

/* Remove hover effects on tab bar buttons */
#TabsToolbar {
	--toolbarbutton-active-background: transparent !important;
	--toolbarbutton-hover-background: transparent !important;
	padding: 0 3px !important;
}

/* New hover effect */
#TabsToolbar toolbarbutton {
	fill-opacity: .6 !important;
}
#TabsToolbar toolbarbutton:not([disabled]):hover,
#TabsToolbar toolbarbutton[open=true] {
	fill-opacity: 1 !important;
}

#TabsToolbar .toolbarbutton-1 {
	margin: 3px !important;
	padding: 0 6px !important;
}

/* Remove shadow next to tab scroll buttons */
.arrowscrollbox-overflow-start-indicator,
.arrowscrollbox-overflow-end-indicator {
	display: none;
}

/* Remove tab separators */
.tabbrowser-tab::after,
.tabbrowser-tab::before {
	border-color: transparent !important;
	border-image: none !important;
}

/* Space between tabs */
.tabbrowser-tab:not([pinned=true]) {
	margin: 0 0 !important;
}

/* Tab labels */
tab {
	color: var(--gnome-tabbar-tab-color) !important;
	font-family: Cantarell, inherit;
	font-weight: normal;
	font-size: 1em;
}
tab:hover {
	color: var(--gnome-tabbar-tab-hover-color) !important;
}
tab[selected] {
	color: var(--gnome-tabbar-tab-active-color) !important;
	font-weight: bold;
}
tab:-moz-window-inactive {
	color: var(--gnome-inactive-tabbar-tab-color) !important;
}
tab[selected]:-moz-window-inactive {
	color: var(--gnome-inactive-tabbar-tab-active-color) !important;
}

/* Center all inside tab */
.tab-content {
	display: flex !important;
	justify-content: center !important;
	align-items: center !important;
	min-width: 100% !important;
	padding: 0 10px !important;
}

/* Prevent tab icons size breaking */
.tab-icon-image, .tab-icon-sound, .tab-throbber, .tab-throbber-fallback, .tab-close-button {
	min-width: 16px;
	transition: all .2s ease !important;
}

/* Center tab text */
.tab-label {
	margin-inline: 0 !important;
}

/* Adjust tab label width */
.tab-label-container {
	min-width: 0 !important;
}

.tabbrowser-tab:not([pinned]) .tab-label-container {
	max-width: min-content !important;
}

/* Put tab close button and icon sound to the right */
.tab-icon-sound[soundplaying="true"], .tab-icon-sound[muted="true"],
.tab-icon-sound[activemedia-blocked="true"] {
	margin-left: auto !important;
}

.tab-throbber:not([pinned]), .tab-icon-pending:not([pinned]), .tab-icon-image:not([pinned]), .tab-sharing-icon-overlay:not([pinned]), .tab-icon-overlay:not([pinned]) {
	margin-inline-end: 0 !important;
}

.tabbrowser-tab:not([soundplaying], [muted], [activemedia-blocked], [crashed]) .tab-icon-stack {
	padding: 6px;
}

/* Hide favicon when mute icon is present */
.tabbrowser-tab:not([pinned]):is([soundplaying], [muted], [activemedia-blocked], [crashed]) .tab-icon-image:not([sharing]),
.tabbrowser-tab:not([pinned]):is([soundplaying], [muted], [activemedia-blocked], [crashed])[selected] .tab-icon-image {
	display: none;
}

/* Hide secondary label about muting */
.tabbrowser-tab:is([soundplaying], [muted], [activemedia-blocked], [crashed]) .tab-secondary-label {
	display: none;
}

.tab-icon-sound {
	margin-right: 6px;
}

/* Force tab favicon to the center */
.tab-throbber, .tab-throbber-fallback,
.tabbrowser-tab:not([busy]) .tab-icon-image,
.tabbrowser-tab:not([class*="identity-color-"]) .tab-icon-stack {
	margin-left: auto !important;
}

/* separate class for multi-tab alignment*/
.tabbrowser-tab[class*="identity-color-"]>.tab-stack>.tab-content>.tab-icon-stack {
	margin-left: auto !important;
}

/* If tab favicon is not present, force tab label to the center */
.tabbrowser-tab .tab-label-container {
	margin-left: 0 !important;
	margin-right: auto !important;
}

.tabbrowser-tab:not([image]):not([busy]):not([progress]) .tab-label-container {
	margin-left: auto !important;
}

/* Fix website with no favicon centred text */
.tabbrowser-tab:not([image]) .tab-icon-overlay:not([pinned], [sharing], [crashed]) .tab-icon-stack {
	margin-left: 0 !important
}

.tabbrowser-tab:not([image], [busy]) .tab-icon-stack {
	margin-left: 0 !important
}

.tabbrowser-tab[selected="true"]>.tab-stack>.tab-background {
	margin-left: 0px !important;
	margin-right: 0px !important;
}

/* centre text when audio is playing */
.tabbrowser-tab:is([soundplaying]) .tab-label-container {
	margin-left: 0 !important;
	margin-right: auto !important
}

/* Remove tab icons */
/* tab:not([pinned=true]) .tab-icon-image {
	display: none;
} */

/* Close tab button */
:root {
	--gnome-fill-icon: red !important;
}

.close-icon {
	height: 16px !important;
	padding: 0 !important;
	width: 16px !important;
}

.tab-close-button {
	-moz-appearance: none !important;
	border: none !important;
	box-sizing: content-box; /* Avoid deformation on flexbox */
	border-radius: 100px;
	list-style-image: url("../icons/window-close-alt-symbolic.svg") !important;
	height: 16px !important;
	opacity: .3;
	padding: 2px !important;
	margin: 0 2px !important;
	width: 16px !important;
}

@media (prefers-color-scheme: dark) {
	.tab-close-button {
		list-style-image: url("../icons/window-close-alt-symbolic-light.svg") !important;
	}
}
:root:-moz-window-inactive .tab-close-button:not(#hack) {
	opacity: .18 !important;
}
:root:not(:-moz-window-inactive) .tab-close-button:hover {
	background: var(--gnome-flat-button-hover-background) !important;
	border-radius: 100px !important;
	opacity: 1;
}
:root:not(:-moz-window-inactive) .tab-close-button:active {
	border-radius: 100px !important;
	background: var(--gnome-flat-button-active-background) !important;
}

.tab-close-button:active:not(:hover) {
	border-radius: 100px !important;
	background-image: none !important;
	box-shadow: none !important;
}

/* Tab close button etc. positioning */
.tab-throbber, .tab-icon-image, .tab-sharing-icon-overlay, .tab-icon-sound, .tab-close-button {
	margin-top: 0 !important;
}

/* Remove blue line above tabs */
.tab-line {
	display: none;
}

/* Firefox v89 beta tab fix */
.tab-background {
	margin-block: 0 !important;
	border-radius: 0 !important;
	padding: 0 12px !important;
	transition: all 200ms ease !important;
	box-shadow: inset 0 -3px transparent !important;
	border: none !important;
	outline: none !important;
}

/*Align personal bookmarks v89 */
#personal-bookmarks {
	-moz-box-align: center !important;
}

/* fix misc spacing between tabs */
.tabbrowser-tab {
	padding-inline: 0 !important;
}

/* Active tab */
.tab-background[selected=true] {
	background-color: var(--gnome-tabbar-tab-active-background) !important;
	background-image: none !important;
	border: none !important;
	border-image: none !important;
	box-shadow: inset 0 -3px var(--gnome-tabbar-tab-active-border-bottom-color) !important;
}
.tab-background[selected=true]:-moz-window-inactive {
	background-color: var(--gnome-inactive-tabbar-tab-active-background) !important;
	border-bottom-color: var(--gnome-inactive-tabbar-tab-active-border-bottom-color) !important;
}

/* Tab hover */
:root:not(:-moz-window-inactive) .tabbrowser-tab:hover > .tab-stack > .tab-background[selected=true] {
	background-color: var(--gnome-tabbar-tab-active-hover-background) !important;
}
.tabbrowser-tab:hover > .tab-stack > .tab-background:not([selected=true]),
#TabsToolbar[brighttext] > #tabbrowser-tabs > .tabbrowser-tab:hover > .tab-stack > .tab-background:not([selected=true]),
#TabsToolbar[brighttext] > #tabbrowser-tabs > .tabbrowser-tab:hover > .tab-stack > .tab-background > .tab-line:not([selected=true]) {
	background-color: transparent !important;
}
:root:not(:-moz-window-inactive) .tabbrowser-tab:hover > .tab-stack > .tab-background:not([selected=true]) {
	background-color: var(--gnome-tabbar-tab-hover-background) !important;
	border-image: none !important;
	box-shadow: inset 0 -3px var(--gnome-tabbar-tab-hover-border-bottom-color) !important;
}

/* Tabs scroll buttons hover */
#TabsToolbar .scrollbutton-up:not([disabled]):hover, #TabsToolbar .scrollbutton-down:not([disabled]):hover {
	background-color: var(--gnome-tabbar-tab-active-hover-background) !important;
}

/* Full width tabs */
.tabbrowser-tab:not([style^="max-width"]):not([pinned]),
.tabbrowser-tab[style^="max-width: 100px !important;"]:not([pinned]) {
	max-width: 100% !important;
}

.tabbrowser-tab:not([style^="max-width"]):not([pinned]):not([fadein]),
.tabbrowser-tab[style^="max-width: 100px !important;"]:not([pinned]):not([fadein]) {
	max-width: .1px !important;
}

/* Remove blank spaces on tabs start and end */
#TabsToolbar .titlebar-spacer {
	display: none !important;
}

/* Remove container bottom line indicator */
.tabbrowser-tab[usercontextid] > .tab-stack > .tab-background > .tab-bottom-line {
	display: none;
}

/* Create new container tab indicator */
.tabbrowser-tab[class*="identity-color-"] .tab-content::before {
	content: "";
	display: block;
	background-image: var(#userContext-icons:--identity-icon);
	background: var( --identity-tab-color);
	-moz-context-properties: fill;
	fill: var(--identity-icon-color);
	background-size: contain;
	background-repeat: no-repeat;
	background-position: center center;
	min-width: 10px;
	height: 10px;
	margin-right: 5px;
	margin-left: auto !important;
	border-radius: 100%;
}

.tabbrowser-tab[class*="identity-color-"][pinned] .tab-content::before,
.tabbrowser-tab[class*="identity-color-"][image] .tab-content::before,
.tabbrowser-tab[class*="identity-color-"][busy] .tab-content::before,
.tabbrowser-tab[class*="identity-color-"][progress] .tab-content::before {
	right: -10px;
	top: -8px;
	position: relative;
	margin-right: -10px;
}
