/* Header bar */
@import "headerbar-urlbar.css";
@import "headerbar-private-window.css";
@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

/* Headerbar */
#nav-bar {
	min-height: 0 !important;
	padding: 6px !important;
	color: var(--gnome-headerbar-color) !important;
	background: var(--gnome-headerbar-background) !important;
}

#nav-bar-customization-target {
	min-height: 0 !important;
}

/* Headerbar CSD colors */
:root[tabsintitlebar] #nav-bar {
	background: var(--gnome-headerbar-background) !important;
	border: none !important;
	border-bottom: 1px solid var(--gnome-headerbar-border-color) !important;
	box-shadow: var(--gnome-headerbar-box-shadow) !important;
}
:root[tabsintitlebar] #nav-bar:-moz-window-inactive {
	background: var(--gnome-inactive-headerbar-background) !important;
	border-bottom-color: var(--gnome-inactive-headerbar-border-color) !important;
	box-shadow: var(--gnome-inactive-headerbar-box-shadow) !important;
}

#nav-bar toolbarbutton:not(#urlbar-zoom-button):not(.subviewbutton) {
	fill: var(--gnome-headerbar-color) !important;
	color: var(--gnome-headerbar-color) !important;
	background: transparent !important;
	box-shadow: none !important;
	border: none !important;
}

#nav-bar toolbarbutton:not(#urlbar-zoom-button):not(.subviewbutton):not([open]):not([disabled]):not([checked]):hover {
	fill: var(--gnome-headerbar-color) !important;
	color: var(--gnome-headerbar-color) !important;
	background: var(--gnome-header-button-hover-background) !important;
}
