@namespace xul url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/* Variables that start with --gnome- are added by me and are assigned
 * to elements somewhere in this code. The rest of the variables are
 * built-in in Firefox, so you need to add an !important if you wanna
 * override them. */
@media (prefers-color-scheme: dark) {
	:root {
		--gnome-selected-color: #ffffff;
		--gnome-selected-background: #2eb398;

		/* Browser area before a page starts loading */
		--gnome-browser-before-load-background: #303b3e;

		/* Toolbars */
		--gnome-toolbar-background: #1b2224;
		--gnome-toolbar-color: #ccd7d4;
		--gnome-toolbar-border-color: #0b0e0f;
		--gnome-inactive-toolbar-background: #1b2224;
		--gnome-inactive-toolbar-border-color: #0b0e0f;

		/* Sidebar */
		--gnome-sidebar-background: #303b3e;
		--gnome-inactive-sidebar-background: #303b3e;

		/* Popups */
		--gnome-menu-background: #222b2e;
		--gnome-menu-border-color: #0b0e0f;
		--gnome-popover-background: #222b2e;
		--gnome-popover-border-color: #0b0e0f;
		--gnome-popover-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
		--gnome-popover-button-hover-background: #353f43;
		--gnome-popover-separator-color: rgba(0, 0, 0, 0.1);

		/* Header bar */
		--gnome-headerbar-color: #ccd7d4;
		--gnome-headerbar-background: #141A1B;
		--gnome-headerbar-border-color: #0e1112;
		--gnome-headerbar-box-shadow: inset 0 1px rgba(238, 238, 236, 0.07);
		--gnome-inactive-headerbar-background: #1b2224;
		--gnome-inactive-headerbar-border-color: #0b0e0f;
		--gnome-inactive-headerbar-box-shadow: inset 0 1px rgba(238, 238, 236, 0.07);

		/* Buttons */
		--gnome-button-background: #263034;
		--gnome-button-border-color: #0b0e0f;
		--gnome-button-border-accent-color: #0b0e0f;
		--gnome-button-box-shadow: inset 0 1px rgba(255, 255, 255, 0.02), 0 1px 2px rgba(0, 0, 0, 0.07);
		--gnome-button-hover-background: rgba(255, 255, 255, 0.1);
		--gnome-button-active-background: #2eb398;
		--gnome-button-active-border-color: #2eb398;
		--gnome-button-active-border-accent-color: #0b0e0f;
		--gnome-button-active-box-shadow: inset 0 1px rgba(255, 255, 255, 0);
		--gnome-button-disabled-background: #20292C;
		--gnome-button-disabled-border-color: #1c2326;
		--gnome-button-disabled-box-shadow: inset 0 1px rgba(255, 255, 255, 0);
		--gnome-inactive-button-background: #20292C;
		--gnome-inactive-button-border-color: #1c2326;
		--gnome-inactive-button-box-shadow: inset 0 1px rgba(255, 255, 255, 0);
		--gnome-flat-button-hover-background: rgba(255, 255, 255, 0.1);
		--gnome-flat-button-active-background: rgba(255, 255, 255, 0.2);
		--gnome-header-button-hover-background: rgba(255, 255, 255, 0.1);
		--gnome-header-button-active-background: #2eb398;
		--gnome-button-suggested-action-background: linear-gradient(to top, #155099 2px, #15539e);
		--gnome-button-suggested-action-border-color: #0f3b71;
		--gnome-button-suggested-action-border-accent-color: #092444;
		--gnome-button-suggested-action-box-shadow: inset 0 1px rgba(255, 255, 255, 0.02), 0 1px 2px rgba(0, 0, 0, 0.07);
		--gnome-button-suggested-action-hover-background: linear-gradient(to top, #155099, #1655a2 1px);
		--gnome-button-suggested-action-active-background: #103e75;
		--gnome-button-suggested-action-active-border-color: #0f3b71;
		--gnome-button-suggested-action-active-box-shadow: inset 0 1px rgba(255, 255, 255, 0);
		--gnome-button-destructive-action-background: linear-gradient(to top, #ae151c 2px, #b2161d);
		--gnome-button-destructive-action-border-color: #851015;
		--gnome-button-destructive-action-border-accent-color: #570b0e;
		--gnome-button-destructive-action-box-shadow: inset 0 1px rgba(255, 255, 255, 0.02), 0 1px 2px rgba(0, 0, 0, 0.07);
		--gnome-button-destructive-action-hover-background: linear-gradient(to top, #ae151c, #b7161d 1px);
		--gnome-button-destructive-action-active-background: #8a1116;
		--gnome-button-destructive-action-active-border-color: #851015;
		--gnome-button-destructive-action-active-box-shadow: inset 0 1px rgba(255, 255, 255, 0);

		/* TitleButtons */
		--gnome-titlebutton-min-hover-background: rgba(255, 255, 255, 0.1);
		--gnome-titlebutton-max-hover-background: rgba(255, 255, 255, 0.1);
		--gnome-titlebutton-close-hover-background: transparent;
		--gnome-titlebutton-min-active-background: #2eb398;
		--gnome-titlebutton-max-active-background: #2eb398;
		--gnome-titlebutton-close-active-background: transparent;

		/* Entries */
		--gnome-entry-background: #222B2E;
		--gnome-entry-border-color: #0b0e0f;
		--gnome-entry-box-shadow: none;
		--gnome-entry-color: #D3DAE3;
		--gnome-inactive-entry-background: #1E2629;
		--gnome-inactive-entry-border-color: #0b0e0f;
		--gnome-inactive-entry-box-shadow: none;
		--gnome-inactive-entry-color: #d6d6d6;
		--gnome-focused-urlbar-border-color: #2eb398;
		--gnome-private-urlbar-background: #25003e;

		--gnome-header-entry-color: #D3DAE3;
		--gnome-header-entry-background: #273135;
		--gnome-header-entry-border-color: #0b0e0f;
		--gnome-header-inactive-entry-color: #d6d6d6;
		--gnome-header-inactive-entry-background: #1E2629;
		--gnome-header-inactive-entry-border-color: #14191B;

		/* Switch */
		--gnome-switch-background: #282828;
		--gnome-switch-border-color: #1b1b1b;
		--gnome-switch-slider-background: linear-gradient(to bottom, #3c3c3c 20%, #353535 90%);
		--gnome-switch-slider-border-color: #111111;
		--gnome-switch-slider-box-shadow: inset 0 1px rgba(255, 255, 255, 0.02), 0 1px rgba(0, 0, 0, 0.1), 0 1px 2px rgba(0, 0, 0, 0.07);
		--gnome-switch-active-background: #15539e;
		--gnome-switch-active-border-color: #030c17;
		--gnome-switch-active-slider-border-color: #030c17;

		/* Tabs */
		--gnome-tabbar-tab-color: #D3DAE3;
		--gnome-tabbar-tab-hover-background: transparent;
		--gnome-tabbar-tab-hover-border-bottom-color: #226356;
		--gnome-tabbar-tab-hover-color: #D3DAE3;
		--gnome-tabbar-tab-active-background: transparent;
		--gnome-tabbar-tab-active-background-contrast: transparent;
		--gnome-tabbar-tab-active-border-bottom-color: #2eb398;
		--gnome-tabbar-tab-active-border-bottom-color-contrast: #2eb398;
		--gnome-tabbar-tab-active-color: #abb9b6;
		--gnome-tabbar-tab-active-hover-background: transparent;
		--gnome-inactive-tabbar-tab-color: #808690;
		--gnome-inactive-tabbar-tab-active-background: transparent;
		--gnome-inactive-tabbar-tab-active-border-bottom-color: var(--gnome-tabbar-tab-active-border-bottom-color);
		--gnome-inactive-tabbar-tab-active-color: var(--gnome-inactive-tabbar-tab-color);
	}
}
