/* OVERVIEW */

.controls-manager, .secondary-monitor-workspaces {
  spacing: $base_spacing * 2;
}

#overviewGroup {
  background-color: $system_bg_color;
}

.overview-controls {
  padding-bottom: 32px;
}
