// Decorations
UnityDecoration {
  -UnityDecoration-extents: 28px 1 1 1;
  -UnityDecoration-input-extents: 10px;

  -UnityDecoration-shadow-offset-x: 0px;
  -UnityDecoration-shadow-offset-y: 3px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.2);
  -UnityDecoration-active-shadow-radius: 12px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.07);
  -UnityDecoration-inactive-shadow-radius: 7px;

  -UnityDecoration-glow-size: 10px;
  -UnityDecoration-glow-color: $selected_bg_color;

  -UnityDecoration-title-indent: 10px;
  -UnityDecoration-title-fade: 35px;
  -UnityDecoration-title-alignment: 0.0;

  .top {
    border: 1px solid if($variant == 'dark', darken($header_bg, 7%), rgba(black, 0.1));
    border-bottom-width: 0;
    border-radius: 4px 4px 0 0;
    padding: 1px 6px 0 6px;

    background-image: _solid(opacify($header_bg, 1));
    color: $header_fg;                         // The foreground color will be used to paint the text

    box-shadow: inset 0  1px lighten($header_bg, 3%);

    &:backdrop {
      border-bottom-width: 0;
      //background-image: _solid(opacify($header_bg_backdrop, 1));
      color: rgba($header_fg, 0.7);
    }
  }
  .left, .right, .bottom,
  .left:backdrop, .right:backdrop, .bottom:backdrop {
    background-color: transparent;
    background-image: _solid(if($variant == 'dark', darken($header_bg, 7%), rgba(black, 0.1)));
  }
}

// Panel Style
UnityPanelWidget,
.unity-panel {
  background-image: _solid(#1b2224);
  color: lighten($panel_fg, 20%);
  box-shadow: none;

  &:backdrop { color: lighten($panel_fg, 1%); }
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
  border-radius: 0;
  color: $selected_fg_color;
  background-image: _solid($selected_bg_color);
  border-bottom: none;
}

// Unity Greeter
.lightdm.menu {
  background-image: none;
  background-color: rgba(black, 0.45);
  border-color: rgba(white, 0.8);
  border-radius: 4px;
  padding: 1px;
  color: white;
}

.lightdm-combo .menu {
  background-color: lighten($header_bg, 8);
  border-radius: 0px;
  padding: 0px;
  color: white;
}

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
  color: white;
}

.lightdm.menubar {
  color: rgba(white, 0.8);
  background-image: none;
  background-color: rgba(black, 0.5);

  & > .menuitem {
    padding: 2px 6px;
  }
}

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.button,
.lightdm.entry {
  background-image: none;
  background-color: rgba(black, 0.3);
  border-color: rgba(white, 0.45);
  border-radius: 10px;
  padding: 7px;
  color: white;
  text-shadow: none;
}

.lightdm.button,
.lightdm.button:hover,
.lightdm.button:active,
.lightdm.button:active:focus,
.lightdm.entry,
.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focus {
  background-image: none;
  border-image: none;
}

.lightdm.button:focus,
.lightdm.entry:focus {
  border-color: rgba(white, 0.1);
  border-width: 1px;
  border-style: solid;
  color: white;
}

.lightdm.entry:selected {
  background-color: rgba(white, 0.8);
}

.lightdm.entry:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: dashentry_spinner 1s infinite linear;
}

.lightdm.option-button {
  padding: 2px;
  background: none;
  border: 0;
}

.lightdm.toggle-button {
  background: none;
  border-width: 0;

  &.selected {
    background-color: rgba(black, 0.7);
    border-width: 1px;
  }
}

@keyframes dashentry_spinner {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}
