$variant: 'light';
$color: 'sea';
$trans: 'true';
$header: 'light';

@import '../sass/colors';
@import '../sass/drawing';
@import '../sass/common-4.0';
@import '../sass/libadwaita';
@import '../sass/apps-4.0';
// @import '../sass/transparent-widgets';
@import '../sass/colors-public';
