/* Search */

// search overview container
#searchResults {
  margin: 0 $base_margin;
}

#searchResultsContent {
  max-width: 1044px;
}

// search results sections "the boxes"
.search-section {
  // This should be equal to #searchResultsContent spacing
  spacing: $base_padding * 3;

  // separator (unstyled)
  .search-section-separator {
    height: $base_margin * 2; // use it as a spacer
    background-color: transparent;
  }
}

// content
.search-section-content {
  background-color: $system_overlay_bg_color;
  color: $system_fg_color;
  border-radius: $modal_radius * 1.5;
  padding: $base_padding * 2;
  margin:0 $base_margin * 3;
  border: 2px solid transparent;
}

%search_section_content_item {
  @include tile_button($bg:$system_overlay_bg_color);
  border-radius: $base_border_radius * 1.65;
}

// "no results" text
.search-statustext {
  @extend %title_1;
  color: transparentize($system_fg_color, .2);
}

.grid-search-results {
  spacing: $base_padding * 5;
  margin:0 $base_margin * 3;
}

// Search results with icons
.grid-search-result {
  @extend .overview-tile;
}

// search result provider
.search-provider-icon {
  @extend %search_section_content_item;
  &:ltr {margin-right: $base_margin;}
  &:rtl {margin-left: $base_margin;}

  // content
  .list-search-provider-content {
    spacing: $base_padding * 2;

    // provider labels
    .list-search-provider-details {
      width: 120px;
      color: $system_fg_color;
    }
  }
}

// search results list
.list-search-results {
  spacing: $base_padding;
}

// search result listitem
.list-search-result {
  @extend %search_section_content_item;

  // content
  .list-search-result-content {
    spacing: $base_padding;
  }

  // list item title (with leading icon)
  .list-search-result-title {
    spacing: $base_padding * 2;
  }

  // list item description
  .list-search-result-description {
    color: $system_insensitive_fg_color;
  }
}
