/* Scrollbars */

StScrollView {
  &.vfade { -st-vfade-offset: 68px; }
  &.hfade { -st-hfade-offset: 68px; }
}

StScrollBar {
  padding: 0;
  margin: $base_spacing;

  StScrollView & {
    min-width: 6px;
    min-height: 6px;
  }

  StBin#trough {
    border-radius: 8px;
    background-color: rgba($fg_color, 0.1);
  }

  StButton#vhandle, StButton#hhandle {
    border-radius: 8px;
    background-color: mix($fg_color, $bg_color, 60%);
    border: 3px solid transparent; //would be nice to margin or at least to transparent

    &:hover { background-color: mix($fg_color, $bg_color, 80%); }
    &:active { background-color: $selected_bg_color; }
  }
}

#overviewGroup {
  StScrollBar {
    StBin#trough {
      background-color: rgba($osd_fg_color, 0.1);
    }

    StButton#vhandle, StButton#hhandle {
      background-color: mix($osd_fg_color, $osd_bg_color, 60%);

      &:hover { background-color: mix($osd_fg_color, $osd_bg_color, 80%); }
      &:active { background-color: $selected_bg_color; }
    }
  }
}
