$variant: 'light';
$laptop: 'true';
$topbar: 'light';
$color: 'azul';

@import "../sass/3.28/colors";
@import "../sass/3.28/drawing";
@import "../sass/3.28/common";
@import "../sass/3.28/extensions";
