/* Check Boxes */

// these are equal to the size of the SVG assets
$check_height: 24px;
$check_width: 24px;

.check-box {
  StBoxLayout { spacing: .8em; }
  StBin {
    width: $check_width;
    height: $check_height;
    background-image: url("assets/checkbox-off.svg");
  }
  &:focus StBin {
    background-image: url("assets/checkbox-off.svg");
  }
  &:checked StBin {
    background-image: url("assets/checkbox.svg");
  }
  &:focus:checked StBin {
    background-image: url("assets/checkbox.svg");
  }
}
