// IBus Candidate Popup

.candidate-popup-boxpointer {
  @extend .popup-menu-boxpointer;
}

.candidate-popup-content {
  @extend .popup-menu-content;
  padding: 0.5em;
  spacing: 0.3em;
}

.candidate-index {
  padding: 0 0.5em 0 0;
  color: $alt_fg_color;

  .candidate-box:selected & { color: $selected_fg_color; }
}

.candidate-box {
  padding: 0.3em 0.5em 0.3em 0.5em;
  border-radius: $base_border_radius;
  margin-right: 2px;

  &:last-child { margin-right: 0; }

  &:hover {
    background-color: rgba($fg_color, 0.1);
    color: $fg_color;
  }

  &:active {
    background-color: rgba($fg_color, 0.15);
    color: $fg_color;
  }

  &:selected {
    background-color: $selected_bg_color;
    color: $selected_fg_color;
  }
}

.candidate-page-button-box {
  height: 2em;
  .vertical & { padding-top: 0.5em; }
  .horizontal & { padding-left: 0.5em; }
}

.candidate-page-button {
  padding: 4px;
}

.candidate-page-button-previous { border-radius: $base_border_radius 0px 0px $base_border_radius; border-right-width: 0; }
.candidate-page-button-next { border-radius: 0px $base_border_radius $base_border_radius 0px;  }
.candidate-page-button-icon { icon-size: 1em; }
