/* This stylesheet is generated, DO NOT EDIT */
stage {
  font-size: 9.75pt;
  font-weight: 400;
  color: rgba(0, 0, 0, 0.8);
}

.button {
  min-height: 32px;
  padding: 0 16px;
  border-width: 0;
  border-radius: 2px;
  font-size: 9.75pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.6);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: none;
  color: #F0544C;
}

StEntry {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 0;
  border-width: 0;
  color: rgba(0, 0, 0, 0.8);
  caret-color: rgba(0, 0, 0, 0.8);
  selection-background-color: #F0544C;
  selected-color: #FFFFFF;
  font-size: 11.25pt;
  font-weight: 400;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
  box-shadow: none;
  text-shadow: none;
}

StEntry:focus {
  border-color: transparent;
  border: 1px solid #F0544C;
  box-shadow: none;
  text-shadow: none;
}

StEntry:insensitive {
  color: rgba(0, 0, 0, 0.28);
  border-color: rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
}

StEntry StIcon.capslock-warning {
  icon-size: 16px;
  warning-color: #FF6D00;
  padding: 0 0;
}

StEntry StIcon.peek-password {
  icon-size: 16px;
  padding: 0 4px;
}

StEntry StLabel.hint-text {
  margin-left: 2px;
  color: rgba(0, 0, 0, 0.5);
}

StScrollView.vfade {
  -st-vfade-offset: 32px;
}

StScrollView.hfade {
  -st-hfade-offset: 32px;
}

StScrollBar {
  padding: 0;
}

StScrollView StScrollBar {
  min-width: 5px;
  min-height: 5px;
}

StScrollBar StBin#trough {
  margin: 4px;
  border-radius: 100px;
  background-color: rgba(0, 0, 0, 0.084);
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  border-radius: 100px;
  background-color: rgba(0, 0, 0, 0.48);
  margin: 4px;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: rgba(0, 0, 0, 0.6);
}

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active {
  background-color: #F0544C;
}

#screenShieldNotifications StScrollBar StBin#trough, #overview StScrollBar StBin#trough {
  background-color: rgba(255, 255, 255, 0.105);
}

#screenShieldNotifications StScrollBar StButton#vhandle, #overview StScrollBar StButton#vhandle, #screenShieldNotifications StScrollBar StButton#hhandle, #overview StScrollBar StButton#hhandle {
  background-color: rgba(255, 255, 255, 0.6);
}

#screenShieldNotifications StScrollBar StButton#vhandle:hover, #overview StScrollBar StButton#vhandle:hover, #screenShieldNotifications StScrollBar StButton#hhandle:hover, #overview StScrollBar StButton#hhandle:hover {
  background-color: rgba(255, 255, 255, 0.75);
}

#screenShieldNotifications StScrollBar StButton#vhandle:active, #overview StScrollBar StButton#vhandle:active, #screenShieldNotifications StScrollBar StButton#hhandle:active, #overview StScrollBar StButton#hhandle:active {
  background-color: #FFFFFF;
}

.slider {
  height: 20px;
  color: #f4817b;
  -slider-height: 2px;
  -slider-background-color: rgba(0, 0, 0, 0.24);
  -slider-border-color: transparent;
  -slider-active-background-color: #f4817b;
  -slider-active-border-color: transparent;
  -slider-border-width: 0;
  -slider-handle-radius: 7px;
  -slider-handle-border-width: 1px;
  -slider-handle-border-color: rgba(0, 0, 0, 0.1);
  -barlevel-height: 2px;
  -barlevel-background-color: rgba(0, 0, 0, 0.24);
  -barlevel-border-color: transparent;
  -barlevel-active-background-color: #f4817b;
  -barlevel-active-border-color: transparent;
  -barlevel-overdrive-color: #FF5252;
  -barlevel-overdrive-border-color: transparent;
  -barlevel-overdrive-separator-width: 2px;
  -barlevel-border-width: 0;
}

.popup-menu-item.selected .slider {
  color: #FFFFFF;
  -slider-background-color: rgba(0, 0, 0, 0.2);
  -slider-active-background-color: #FFFFFF;
  -barlevel-background-color: rgba(0, 0, 0, 0.2);
  -barlevel-active-background-color: #FFFFFF;
}

.check-box * {
  min-height: 16px;
  padding: 8px 0;
}

.check-box StBoxLayout {
  spacing: 8px;
}

.check-box StBin {
  width: 24px;
  height: 24px;
  padding: 4px;
  border-radius: 100px;
  background-image: url("assets/checkbox-off.svg");
}

.check-box:focus StBin {
  background-image: url("assets/checkbox-off.svg");
}

.check-box:hover StBin {
  background-color: rgba(0, 0, 0, 0.12);
}

.check-box:active StBin {
  background-color: rgba(0, 0, 0, 0.24);
}

.check-box:checked StBin {
  background-image: url("assets/checkbox.svg");
}

.check-box:focus:checked StBin {
  background-image: url("assets/checkbox.svg");
}

.check-box:hover:checked StBin {
  background-color: rgba(244, 129, 123, 0.15);
}

.check-box:active:checked StBin {
  background-color: rgba(244, 129, 123, 0.3);
}

.toggle-switch {
  width: 52px;
  height: 24px;
  background-size: contain;
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch:checked {
  background-image: url("assets/toggle-on.svg");
}

.popup-menu-item.selected .toggle-switch {
  background-image: url("assets/toggle-off.svg");
}

.popup-menu-item.selected .toggle-switch:checked {
  background-image: url("assets/toggle-on.svg");
}

.toggle-switch-us {
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch-us:checked {
  background-image: url("assets/toggle-on.svg");
}

.toggle-switch-intl {
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch-intl:checked {
  background-image: url("assets/toggle-on.svg");
}

.shell-link {
  border-radius: 2px;
  color: #F0544C;
}

.shell-link:hover {
  color: #F0544C;
  background-color: rgba(240, 84, 76, 0.15);
}

.shell-link:active {
  color: #F0544C;
  background-color: rgba(240, 84, 76, 0.3);
}

.lowres-icon {
  icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
}

.icon-dropshadow {
  icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.4);
}

.headline {
  font-size: 15pt;
  font-weight: 500;
}

.lightbox {
  background-color: black;
}

.flashspot {
  background-color: white;
}

.modal-dialog {
  border-radius: 2px;
  color: rgba(0, 0, 0, 0.8);
  margin: 10px;
  background-color: #ffffff;
  box-shadow: none;
  border: 0 solid rgba(0, 0, 0, 0.6);
  border-width: 0;
}

.modal-dialog .modal-dialog-content-box {
  margin: 32px 40px;
  spacing: 32px;
  max-width: 28em;
}

.modal-dialog .modal-dialog-linked-button {
  min-height: 40px;
  padding: 0 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.1) !important;
  border-right-width: 0;
  font-size: 9.75pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.6);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: none;
  color: #F0544C;
}

.modal-dialog .modal-dialog-linked-button:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:first-child {
  border-radius: 0px 0px 0px 2px;
}

.modal-dialog .modal-dialog-linked-button:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 0px;
}

.modal-dialog .modal-dialog-linked-button:first-child:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 2px;
}

.modal-dialog .run-dialog-entry {
  width: 20em;
  margin-bottom: 6px;
}

.modal-dialog .run-dialog-error-box {
  padding-top: 16px;
  spacing: 6px;
}

.modal-dialog .run-dialog-button-box {
  padding-top: 1em;
}

.modal-dialog .run-dialog-label {
  font-size: 1em;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.48);
  padding-bottom: .4em;
}

.message-dialog-main-layout {
  padding: 12px 20px 0;
  spacing: 12px;
}

.message-dialog-content {
  spacing: 20px;
}

.message-dialog-content .message-dialog-title {
  text-align: center;
  font-size: 18pt;
  font-weight: 800;
}

.message-dialog-content .message-dialog-title.leightweight {
  font-size: 13pt;
  font-weight: 800;
}

.message-dialog-content .message-dialog-description {
  text-align: center;
}

.dialog-list {
  spacing: 18px;
}

.dialog-list .dialog-list-title {
  text-align: center;
  font-weight: bold;
}

.dialog-list .dialog-list-scrollview {
  max-height: 200px;
}

.dialog-list .dialog-list-box {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-title {
  font-weight: bold;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-description {
  color: rgba(0, 0, 0, 0.6);
  font-size: 15pt;
  font-weight: 500;
}

.run-dialog .modal-dialog-content-box {
  margin-top: 24px;
  margin-bottom: 14px;
}

.run-dialog .run-dialog-entry {
  width: 20em;
}

.run-dialog .run-dialog-description {
  text-align: center;
  color: rgba(0, 0, 0, 0.6);
  font-size: 15pt;
  font-weight: 500;
}

.end-session-dialog {
  width: 30em;
}

.end-session-dialog .end-session-dialog-battery-warning,
.end-session-dialog .dialog-list-title {
  color: #FF6D00;
}

.shell-mount-operation-icon {
  icon-size: 48px;
}

.show-processes-dialog,
.mount-question-dialog {
  spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
}

.mount-question-dialog-subject {
  max-width: 500px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
  padding-left: 17px;
  width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
  padding-right: 17px;
}

.show-processes-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.show-processes-dialog-app-list-item {
  color: rgba(0, 0, 0, 0.8);
}

.show-processes-dialog-app-list-item:hover {
  color: rgba(0, 0, 0, 0.8);
}

.show-processes-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
  font-size: 1em;
}

.mount-dialog {
  spacing: 24px;
}

.mount-dialog .message-dialog-title {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
  max-width: 34em;
}

.mount-dialog .message-dialog-title:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog .message-dialog-body {
  padding-left: 17px;
  width: 28em;
}

.mount-dialog .message-dialog-body:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.mount-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.mount-dialog-app-list-item {
  color: rgba(0, 0, 0, 0.8);
}

.mount-dialog-app-list-item:hover {
  color: rgba(0, 0, 0, 0.48);
}

.mount-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.mount-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.mount-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.mount-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.mount-dialog-app-list-item-name {
  font-size: 10pt;
}

.prompt-dialog {
  width: 28em;
}

.prompt-dialog .modal-dialog-content-box {
  margin-bottom: 24px;
}

.prompt-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.prompt-dialog .message-dialog-content {
  spacing: 16px;
}

.prompt-dialog .message-dialog-title {
  font-size: 15pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.8);
}

.prompt-dialog-password-grid {
  spacing-rows: 8px;
  spacing-columns: 4px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry {
  width: auto;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:ltr {
  margin-left: 20px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:rtl {
  margin-right: 20px;
}

.prompt-dialog-password-layout {
  spacing: 8px;
}

.prompt-dialog-password-entry {
  width: 20em;
}

.prompt-dialog-error-label,
.prompt-dialog-info-label,
.prompt-dialog-null-label {
  text-align: center;
  font-size: 15pt;
  font-weight: 500;
  margin: 6px;
}

.prompt-dialog-error-label {
  color: #FF6D00;
}

.prompt-dialog-description:rtl {
  text-align: right;
}

.prompt-dialog-password-box {
  spacing: 1em;
  padding-bottom: 1em;
}

.prompt-dialog-error-label {
  font-size: 1em;
  color: #DD2C00;
  padding-bottom: 8px;
}

.prompt-dialog-info-label {
  font-size: 1em;
  padding-bottom: 8px;
  color: rgba(0, 0, 0, 0.48);
}

.hidden {
  color: rgba(0, 0, 0, 0);
}

.prompt-dialog-null-label {
  font-size: 1em;
  padding-bottom: 8px;
  color: rgba(0, 0, 0, 0.48);
}

.polkit-dialog-user-layout {
  text-align: center;
  spacing: 8px;
  margin-bottom: 6px;
}

.polkit-dialog-user-layout .polkit-dialog-user-root-label {
  color: #FF6D00;
}

.polkit-dialog-user-layout .polkit-dialog-user-icon {
  border-radius: 5px;
  background-size: contain;
  width: 48px;
  height: 48px;
  margin: 6px;
}

.audio-device-selection-dialog .modal-dialog-content-box {
  margin-bottom: 28px;
}

.audio-device-selection-dialog .audio-selection-box {
  spacing: 20px;
}

.audio-selection-device {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
}

.audio-selection-device:active, .audio-selection-device:hover, .audio-selection-device:focus {
  background-color: #F0544C;
  color: #FFFFFF;
}

.audio-selection-device-box {
  padding: 20px;
  spacing: 20px;
}

.audio-selection-device-icon {
  icon-size: 64px;
}

.access-dialog {
  spacing: 30px;
}

.access-dialog-main-layout {
  padding: 12px 20px 0;
  spacing: 12px;
}

.access-dialog-content {
  max-width: 28em;
  spacing: 20px;
}

.access-dialog-icon {
  min-width: 48px;
  icon-size: 48px;
}

.access-dialog-title {
  font-weight: bold;
}

.access-dialog-subtitle {
  color: rgba(0, 0, 0, 0.48);
  font-weight: bold;
}

.geolocation-dialog {
  spacing: 30px;
}

.geolocation-dialog-main-layout {
  spacing: 12px;
}

.geolocation-dialog-content {
  spacing: 20px;
}

.geolocation-dialog-icon {
  icon-size: 48px;
}

.geolocation-dialog-title {
  font-weight: bold;
}

.geolocation-dialog-reason {
  color: rgba(0, 0, 0, 0.48);
  font-weight: bold;
}

.extension-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.extension-dialog .message-dialog-title {
  font-weight: normal;
  color: rgba(0, 0, 0, 0.48);
}

.inhibit-shortcuts-dialog {
  spacing: 30px;
}

.network-dialog-secret-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.keyring-dialog-control-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.candidate-popup-content, .popup-menu .popup-menu-content {
  background-color: #ffffff;
  border-radius: 3px;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.25);
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 0;
}

.popup-menu {
  min-width: 15em;
  color: rgba(0, 0, 0, 0.6);
  padding: 0 0;
  background: none;
  border-image: none;
}

.popup-menu .popup-menu-content {
  padding: 6px 0;
  margin: 0 6px;
  color: rgba(0, 0, 0, 0.6);
}

.popup-menu .popup-menu-item {
  spacing: 12px;
  padding: 6px;
  margin: 0;
  border-radius: 0;
  color: rgba(0, 0, 0, 0.6);
}

.popup-menu .popup-menu-item:ltr {
  padding-right: 1.75em;
  padding-left: 0;
}

.popup-menu .popup-menu-item:rtl {
  padding-right: 0;
  padding-left: 1.75em;
}

.popup-menu .popup-menu-item:checked {
  color: rgba(0, 0, 0, 0.6);
  font-weight: normal;
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.1);
  border: none;
  border-image: none;
  background-color: rgba(0, 0, 0, 0.05);
}

.popup-menu .popup-menu-item:active, .popup-menu .popup-menu-item.selected {
  color: #FFFFFF;
  background-color: #F0544C;
  border-image: none;
}

.popup-menu .popup-menu-item:insensitive {
  color: rgba(0, 0, 0, 0.28);
}

.popup-menu .popup-sub-menu {
  background-color: rgba(0, 0, 0, 0.05);
  border-image: none;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1);
  border: none;
  border-radius: 0;
  margin: 0;
}

.popup-menu .popup-inactive-menu-item {
  color: rgba(0, 0, 0, 0.6);
}

.popup-menu .popup-inactive-menu-item:insensitive {
  color: rgba(0, 0, 0, 0.28);
}

.popup-menu.panel-menu {
  -boxpointer-gap: 4px;
  margin-bottom: 1.75em;
}

.popup-menu-ornament {
  text-align: right;
  width: 16px;
  height: 16px;
}

.popup-menu-boxpointer {
  -arrow-border-radius: 2px;
  -arrow-background-color: transparent;
  -arrow-border-width: 1px;
  -arrow-border-color: transparent;
  -arrow-base: 0;
  -arrow-rise: 0;
  border: 0 none transparent;
}

.popup-menu-boxpointer StEntry, .popup-menu-boxpointer .search-entry, .popup-menu-boxpointer .app-folder-dialog .folder-name-container .folder-name-entry, .app-folder-dialog .folder-name-container .popup-menu-boxpointer .folder-name-entry {
  caret-color: rgba(0, 0, 0, 0.8);
}

.popup-separator-menu-item {
  background: none;
  border: none;
  padding: 0;
}

.popup-separator-menu-item .popup-separator-menu-item-separator {
  height: 1px;
  background-color: rgba(0, 0, 0, 0.1);
  padding: 0 0;
  margin: 0 40px;
}

.popup-sub-menu .popup-separator-menu-item .popup-separator-menu-item-separator {
  padding: 0 0;
  margin: 0 40px 0 0;
}

.system-switch-user-submenu-icon.user-icon {
  icon-size: 20px;
  padding: 0 2px;
}

.system-switch-user-submenu-icon.default-icon {
  icon-size: 16px;
  padding: 0 4px;
}

#appMenu {
  spinner-image: url("process-working.svg");
  spacing: 4px;
}

#appMenu .label-shadow {
  color: transparent;
}

.aggregate-menu {
  min-width: 21em;
}

.aggregate-menu .popup-menu-icon {
  padding: 0;
  margin: 0 4px;
  -st-icon-style: symbolic;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:ltr {
  /* 12px spacing + 2*4px padding */
  padding-left: 24px;
  margin-left: 1em;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:rtl {
  /* 12px spacing + 2*4px padding */
  padding-right: 24px;
  margin-right: 1em;
}

.system-menu-action {
  color: rgba(0, 0, 0, 0.6);
  border-radius: 100px;
  /* wish we could do 50% */
  padding: 14px;
  border: none;
  -st-icon-style: symbolic;
}

.system-menu-action:hover, .system-menu-action:focus {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.8);
  border: none;
  padding: 14px;
}

.system-menu-action:active {
  background-color: rgba(0, 0, 0, 0.24);
  color: rgba(0, 0, 0, 0.8);
}

.system-menu-action > StIcon {
  icon-size: 16px;
}

.system-action-icon {
  background-color: rgba(0, 0, 0, 0.24);
  color: rgba(0, 0, 0, 0.8);
  border-radius: 99px;
  icon-size: 48px;
}

.background-menu {
  -boxpointer-gap: 4px;
  -arrow-rise: 0;
}

.select-area-rubberband {
  background-color: rgba(240, 84, 76, 0.3);
  border: 1px solid #F0544C;
}

.user-icon {
  background-size: contain;
  color: rgba(255, 255, 255, 0.75);
  border-radius: 99px;
}

.user-icon:hover {
  color: rgba(255, 255, 255, 0.75);
}

.user-icon StIcon {
  background-color: rgba(255, 255, 255, 0);
  border-radius: 99px;
}

.user-widget.vertical .user-icon {
  icon-size: 128px;
}

.user-widget.vertical .user-icon StIcon {
  padding: 20px;
  padding-top: 18px;
  padding-bottom: 22px;
  width: 88px;
  height: 88px;
}

.user-widget.horizontal .user-icon {
  icon-size: 64px;
}

.user-widget.horizontal .user-icon StIcon {
  padding: 12px;
  width: 40;
  height: 40px;
}

.osd-window {
  text-align: center;
  font-weight: bold;
  spacing: 1em;
  margin: 32px;
  min-width: 64px;
  min-height: 64px;
}

.osd-window .osd-monitor-label {
  font-size: 45px;
  font-weight: 400;
}

.osd-window .level {
  height: 4px;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.24);
  color: #F0544C;
  -barlevel-height: 3px;
  -barlevel-background-color: rgba(0, 0, 0, 0.15);
  -barlevel-active-background-color: #F0544C;
  -barlevel-overdrive-color: #FF5252;
  -barlevel-overdrive-separator-width: 3px;
  -barlevel-border-width: 0;
}

.osd-window .level-bar {
  background-color: #F0544C;
  border-radius: 3px;
}

.pad-osd-window {
  padding: 32px;
  background-color: rgba(0, 0, 0, 0.8);
}

.pad-osd-window .pad-osd-title-box {
  spacing: 12px;
}

.pad-osd-window .pad-osd-title-menu-box {
  spacing: 6px;
}

.combo-box-label {
  width: 15em;
}

.switcher-popup {
  padding: 8px;
  spacing: 16px;
}

.switcher-list-item-container {
  spacing: 8px;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 2px;
}

.switcher-list .item-box:outlined {
  padding: 8px;
  border: none;
  background-color: rgba(0, 0, 0, 0.084);
}

.switcher-list .item-box:selected {
  background-color: #F0544C;
  color: #FFFFFF;
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 4px;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .separator {
  width: 1px;
  background: rgba(0, 0, 0, 0.1);
}

.switcher-arrow {
  border-color: rgba(0, 0, 0, 0);
  color: rgba(0, 0, 0, 0.48);
}

.switcher-arrow:highlighted {
  color: rgba(0, 0, 0, 0.8);
}

.input-source-switcher-symbol {
  font-size: 45px;
  font-weight: 400;
  width: 96px;
  height: 96px;
}

.cycler-highlight {
  border: 5px solid #F0544C;
}

.workspace-switcher-group {
  padding: 8px;
}

.workspace-switcher {
  background: transparent;
  border: 0px;
  border-radius: 0px;
  padding: 0px;
  spacing: 8px;
}

.ws-switcher-active-up, .ws-switcher-active-down {
  height: 48px;
  background-color: #F0544C;
  color: #FFFFFF;
  background-size: 32px;
  border-radius: 2px;
}

.ws-switcher-box {
  height: 48px;
  border: none;
  background: rgba(0, 0, 0, 0.084);
  border-radius: 2px;
}

.osd-window,
.resize-popup,
.switcher-list, .workspace-switcher-container {
  color: rgba(0, 0, 0, 0.8);
  background-color: #ffffff;
  border: none;
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.5), 0 10px 5px rgba(0, 0, 0, 0.44);
  border-radius: 2px;
  padding: 12px;
}

.tile-preview {
  background-color: rgba(242, 106, 100, 0.3);
  border: 1px solid #f26a64;
}

.tile-preview-left.on-primary {
  border-radius: 0 0 0 0;
}

.tile-preview-right.on-primary {
  border-radius: 0 0 0 0;
}

.tile-preview-left.tile-preview-right.on-primary {
  border-radius: 0 0 0 0;
}

#panel {
  background-color: #222222;
  font-weight: bold;
  height: 28px;
  box-shadow: none;
}

#panel:overview, #panel.unlock-screen, #panel.login-screen, #panel.lock-screen {
  background-color: transparent;
}

#panel:overview .panel-corner, #panel.unlock-screen .panel-corner, #panel.login-screen .panel-corner, #panel.lock-screen .panel-corner {
  -panel-corner-radius: 0;
  -panel-corner-background-color: transparent;
  -panel-corner-border-color: transparent;
}

#panel #panelLeft, #panel #panelCenter {
  spacing: 0;
}

#panel .panel-corner {
  -panel-corner-radius: 0;
  -panel-corner-background-color: rgba(0, 0, 0, 0.6);
  -panel-corner-border-width: 2px;
  -panel-corner-border-color: transparent;
}

#panel .panel-corner:active, #panel .panel-corner:overview, #panel .panel-corner:focus {
  -panel-corner-border-color: #FFFFFF;
}

#panel .panel-corner.lock-screen, #panel .panel-corner.login-screen, #panel .panel-corner.unlock-screen {
  -panel-corner-radius: 0;
  -panel-corner-background-color: transparent;
  -panel-corner-border-color: transparent;
}

#panel .panel-button {
  -natural-hpadding: 8px;
  -minimum-hpadding: 8px;
  font-weight: bold;
  color: #F0F0F0;
  transition-duration: 0.2s;
  border-radius: 0;
  border: none !important;
}

#panel .panel-button .app-menu-icon {
  -st-icon-style: symbolic;
  margin-left: 0;
  margin-right: 0;
  icon-size: 16px;
}

#panel .panel-button .app-menu-icon > StIcon {
  padding-left: 4px;
  padding-right: 6px;
}

#panel .panel-button .popup-menu-arrow {
  width: 0;
  height: 0;
}

#panel .panel-button:hover {
  color: rgba(255, 255, 255, 0.8);
  background-color: rgba(255, 255, 255, 0.08);
  box-shadow: none;
}

#panel .panel-button:active, #panel .panel-button:overview, #panel .panel-button:focus, #panel .panel-button:checked {
  background-color: rgba(255, 255, 255, 0.15);
  box-shadow: inset 0 -2px #F0544C;
  color: rgba(255, 255, 255, 0.8);
  border-image: none;
}

#panel .panel-button:active > .system-status-icon, #panel .panel-button:overview > .system-status-icon, #panel .panel-button:focus > .system-status-icon, #panel .panel-button:checked > .system-status-icon {
  icon-shadow: none;
}

#panel .panel-button.clock-display {
  border-radius: 0;
}

#panel .panel-button.clock-display:hover .clock, #panel .panel-button.clock-display:active .clock, #panel .panel-button.clock-display:overview .clock, #panel .panel-button.clock-display:focus .clock, #panel .panel-button.clock-display:checked .clock {
  background-color: transparent;
  box-shadow: none;
}

#panel .panel-button .system-status-icon {
  icon-size: 1.2307692308em;
  padding: 0 4px;
}

.unlock-screen #panel .panel-button, .login-screen #panel .panel-button, .lock-screen #panel .panel-button {
  color: rgba(255, 255, 255, 0.75);
}

.unlock-screen #panel .panel-button:focus, .unlock-screen #panel .panel-button:hover, .unlock-screen #panel .panel-button:active, .login-screen #panel .panel-button:focus, .login-screen #panel .panel-button:hover, .login-screen #panel .panel-button:active, .lock-screen #panel .panel-button:focus, .lock-screen #panel .panel-button:hover, .lock-screen #panel .panel-button:active {
  color: #FFFFFF;
}

#panel .panel-status-indicators-box,
#panel .panel-status-menu-box {
  spacing: 2px;
}

#panel .power-status.panel-status-indicators-box {
  spacing: 0;
}

#panel .screencast-indicator {
  color: #DD2C00;
}

#panel .remote-access-indicator {
  color: #FF6D00;
}

#panel.solid {
  background-color: #222222;
  /* transition from transparent to solid */
  transition-duration: 250ms;
  background-gradient-direction: none;
  text-shadow: none;
}

#panel.solid:overview {
  background-color: transparent;
}

#panel.solid .panel-corner {
  -panel-corner-background-color: #222222;
}

#panel.solid .panel-button {
  color: #F0F0F0;
  text-shadow: none;
}

#panel.solid .panel-button:hover, #panel.solid .panel-button:active, #panel.solid .panel-button:overview, #panel.solid .panel-button:focus, #panel.solid .panel-button:checked {
  color: rgba(255, 255, 255, 0.8);
}

.clock-display-box {
  spacing: 3px;
}

.clock-display-box .clock {
  padding-left: 6px;
  padding-right: 6px;
}

#calendarArea {
  padding: 10px 0;
}

.datemenu-today-button {
  padding: 8px;
  box-shadow: none;
  background: none;
  text-shadow: none;
  border: none;
  border-radius: 3px;
}

.datemenu-today-button .day-label {
  font-size: 15pt;
  font-weight: 500;
  font-weight: bold;
}

.datemenu-today-button .date-label {
  font-size: 18pt;
  font-weight: 400;
}

.datemenu-today-button:hover, .datemenu-today-button:focus {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
}

.datemenu-today-button:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
}

.calendar {
  border: none;
  box-shadow: none;
  background: none;
  padding: 6px;
  margin: 0;
  text-shadow: none;
}

.datemenu-calendar-column {
  spacing: 6px;
  border: 0 solid rgba(0, 0, 0, 0.1);
  padding: 0 12px;
}

.datemenu-calendar-column:ltr {
  margin-right: 8px;
  border-left-width: 1px;
}

.datemenu-calendar-column:rtl {
  margin-left: 8px;
  border-right-width: 1px;
}

.datemenu-calendar-column .datemenu-displays-box {
  spacing: 6px;
}

.calendar-month-label {
  height: 20px;
  margin: 2px;
  padding: 6px;
  border-radius: 3px;
  color: rgba(0, 0, 0, 0.8);
  font-weight: bold;
  text-align: center;
  text-shadow: none;
}

.pager-button {
  width: 28px;
  height: 28px;
  margin: 2px;
  border-radius: 1000px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.8);
}

.pager-button:hover, .pager-button:focus {
  background-color: rgba(0, 0, 0, 0.12);
}

.pager-button:active {
  background-color: rgba(0, 0, 0, 0.24);
}

.calendar-change-month-back {
  padding: 0 2px;
  background-image: url("assets/calendar-arrow-left.svg");
}

.calendar-change-month-back:rtl {
  background-image: url("assets/calendar-arrow-right.svg");
}

.calendar-change-month-forward {
  padding: 0 2px;
  background-image: url("assets/calendar-arrow-right.svg");
}

.calendar-change-month-forward:rtl {
  background-image: url("assets/calendar-arrow-left.svg");
}

.calendar-change-month-back StIcon,
.calendar-change-month-forward StIcon {
  icon-size: 16px;
}

.calendar-day-base {
  font-size: 9pt;
  font-weight: 400;
  text-align: center;
  text-shadow: none;
  width: 28px;
  height: 28px;
  padding: 0 0;
  margin: 4px;
  border-radius: 100px;
  color: rgba(0, 0, 0, 0.6);
  border: none;
  font-feature-settings: "tnum";
}

.calendar-day-base:hover, .calendar-day-base:focus {
  background-color: rgba(0, 0, 0, 0.12);
}

.calendar-day-base:active, .calendar-day-base:selected {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
  border-color: transparent;
}

.calendar-day-base.calendar-day-heading {
  margin-top: 1em;
  border-radius: 1000px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.48);
  font-size: 9pt;
  font-weight: 400;
  font-weight: bold;
  text-align: center;
  text-shadow: none;
}

.calendar-day {
  border-width: 0;
}

.calendar-day-top {
  border-top-width: 0;
}

.calendar-day-left {
  border-left-width: 0;
}

.calendar-nonwork-day {
  color: rgba(0, 0, 0, 0.8);
}

.calendar-today {
  font-weight: bold;
  color: #FFFFFF;
  background-color: #F0544C;
  border: none;
}

.calendar-today:hover, .calendar-today:focus {
  background-color: #f1615a;
  color: #FFFFFF;
}

.calendar-today:active, .calendar-today:selected {
  background-color: #F0544C;
  color: #FFFFFF;
}

.calendar-today:active:hover, .calendar-today:active:focus, .calendar-today:selected:hover, .calendar-today:selected:focus {
  background-color: #f1615a;
  color: #FFFFFF;
}

.calendar-day-with-events {
  background-image: url("assets/calendar-today.svg");
}

.calendar-day-with-events.calendar-work-day {
  color: rgba(0, 0, 0, 0.48);
  font-weight: bold;
}

.calendar-other-month-day {
  color: rgba(0, 0, 0, 0.28);
  opacity: 0.5;
  text-shadow: none;
}

.calendar-week-number {
  height: 1.8em;
  width: 2.6em;
  border-radius: 3px;
  margin: 6px 6px 6px 0;
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.48);
  font-size: 7pt;
  font-size: inherit;
  font-weight: bold;
  text-align: center;
  text-shadow: none;
}

.world-clocks-button,
.weather-button,
.events-button {
  padding: 12px;
  margin: 2px 0;
  border-radius: 3px;
  border: none;
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.6);
  text-shadow: none;
}

.world-clocks-button:hover, .world-clocks-button:focus,
.weather-button:hover,
.weather-button:focus,
.events-button:hover,
.events-button:focus {
  background-color: rgba(0, 0, 0, 0.12);
  text-shadow: none;
}

.world-clocks-button:active,
.weather-button:active,
.events-button:active {
  background-color: rgba(0, 0, 0, 0.24);
}

.world-clocks-header,
.weather-header,
.message-list-section-title,
.events-section-title,
.events-title {
  color: rgba(0, 0, 0, 0.48);
  font-weight: bold;
  text-shadow: none;
}

.weather-grid,
.world-clocks-grid {
  spacing-rows: 8px;
  spacing-columns: 16px;
}

.world-clocks-button .world-clocks-city {
  color: rgba(0, 0, 0, 0.48);
  font-weight: normal;
  font-size: 11pt;
}

.world-clocks-button .world-clocks-time {
  color: rgba(0, 0, 0, 0.48);
  font-feature-settings: "tnum";
  font-weight: bold;
  font-size: 11pt;
}

.world-clocks-button .world-clocks-time:ltr {
  text-align: right;
}

.world-clocks-button .world-clocks-time:rtl {
  text-align: left;
}

.world-clocks-button .world-clocks-timezone {
  color: rgba(0, 0, 0, 0.48);
  font-feature-settings: "tnum";
  font-size: 10pt;
}

.weather-button .weather-box {
  spacing: 12px;
}

.weather-button .weather-header-box {
  spacing: 8px;
}

.weather-button .weather-header.location {
  font-size: 10pt;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.48);
}

.weather-button .weather-forecast-time {
  color: rgba(0, 0, 0, 0.48);
  font-feature-settings: "tnum";
  font-weight: normal;
  font-size: 9pt;
  padding-top: 0.2em;
  padding-bottom: 0.4em;
}

.weather-button .weather-forecast-icon {
  icon-size: 32px;
}

.weather-button .weather-forecast-temp {
  font-weight: bold;
}

.events-button .events-box {
  spacing: 6px;
}

.events-button .events-list {
  spacing: 12px;
  text-shadow: none;
}

.events-button .events-title {
  margin-bottom: 4px;
}

.events-button .event-time {
  color: rgba(0, 0, 0, 0.28);
  font-feature-settings: "tnum";
  font-size: 10pt;
}

.message-list {
  width: 31.5em;
  padding: 0 8px;
}

.message-list .message-list-placeholder {
  spacing: 12px;
}

.message-list-sections {
  spacing: 6px;
  margin: 0 16px;
}

.message-list-section-list {
  spacing: 6px;
}

.message-list-section-close > StIcon {
  icon-size: 16px;
  border-radius: 16px;
  padding: 6px;
  color: rgba(0, 0, 0, 0.6);
  background-color: transparent;
}

.message-list-section-close:hover > StIcon,
.message-list-section-close:focus > StIcon {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
}

.message-list-section-close:active > StIcon {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
}

.message-list-controls {
  margin: 8px 16px 0;
  padding: 4px;
  spacing: 16px;
}

.message {
  min-height: 56px;
  margin: 4px;
  background-color: rgba(0, 0, 0, 0.04);
  border: none;
  border-radius: 3px;
  color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
  text-shadow: none;
}

.message:hover, .message:focus {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
}

.message:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
}

.message .message-icon-bin {
  margin: 8px 0;
  padding: 8px 0px 8px 8px;
}

.message .message-icon-bin:rtl {
  padding: 8px 8px 8px 0px;
}

.message .message-icon-bin > StIcon {
  icon-size: 32px;
  -st-icon-style: symbolic;
}

.message .message-icon-bin > .fallback-app-icon,
.message .message-icon-bin > .fallback-window-icon {
  width: 16px;
  height: 16px;
}

.message .message-secondary-bin {
  color: rgba(0, 0, 0, 0.48);
  padding: 0 8px;
  text-shadow: none;
}

.message .message-secondary-bin > .event-time {
  color: rgba(0, 0, 0, 0.28);
  font-size: 0.7em;
  /* HACK: the label should be baseline-aligned with a 1em label,
               fake this with some bottom padding */
  padding-bottom: 0.13em;
  text-shadow: none;
}

.message .message-secondary-bin > StIcon {
  icon-size: 16px;
}

.message .message-close-button {
  color: rgba(0, 0, 0, 0.6);
}

.message .message-close-button:hover, .message .message-close-button:active {
  color: rgba(0, 0, 0, 0.8);
}

.message .message-body {
  color: rgba(0, 0, 0, 0.6);
}

.message .message-title {
  min-height: 18px;
  padding-top: 2px;
  color: rgba(0, 0, 0, 0.8);
  font-weight: bold;
  font-size: 1em;
  text-shadow: none;
}

.message .message-content {
  padding: 12px;
  color: rgba(0, 0, 0, 0.6);
  font-size: 1em;
  spacing: 4px;
  text-shadow: none;
}

.message .message-content * > StIcon {
  icon-size: 16px;
  border-radius: 16px;
  padding: 2px;
  color: rgba(0, 0, 0, 0.6);
}

.message .message-content *:hover > StIcon,
.message .message-content *:focus > StIcon {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
}

.message .message-content *:active > StIcon {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
}

.message-media-control {
  margin: 18px 3px;
  padding: 8px;
  border-radius: 100px;
  color: rgba(0, 0, 0, 0.6);
}

.message-media-control:hover, .message-media-control:focus {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
}

.message-media-control:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
}

.message-media-control:insensitive {
  color: rgba(0, 0, 0, 0.21);
}

.message-media-control:last-child:ltr {
  margin-right: 16px;
  padding-right: 8px;
}

.message-media-control:last-child:rtl {
  margin-left: 16px;
  padding-left: 8px;
}

.media-message-cover-icon {
  icon-size: 32px !important;
}

.media-message-cover-icon.fallback {
  icon-size: 32px !important;
  border: none;
  border-radius: 5px;
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.48);
}

.ripple-box {
  width: 48px;
  height: 48px;
  border-radius: 0 0 48px 0;
  background-color: rgba(240, 84, 76, 0.35);
  background-image: none;
  background-size: auto;
}

.ripple-box:rtl {
  border-radius: 0 0 0 48px;
  background-image: none;
}

.ripple-pointer-location {
  width: 50px;
  height: 50px;
  border-radius: 25px;
  background-color: rgba(252, 219, 217, 0.3);
  box-shadow: 0 0 2px 2px #f8aeaa;
}

.pie-timer {
  width: 60px;
  height: 60px;
  -pie-border-width: 3px;
  -pie-border-color: #F0544C;
  -pie-background-color: rgba(255, 255, 255, 0.3);
}

.popup-menu-arrow {
  width: 16px;
  height: 16px;
}

.popup-menu-icon {
  icon-size: 1.2307692308em;
}

.window-close {
  background-size: 26px;
  height: 26px;
  width: 26px;
  -shell-close-overlap: 10px;
  border-radius: 100px;
  border: 0 none transparent;
  background-color: transparent;
  color: transparent;
  box-shadow: none;
  background-image: url("assets/window-close.svg");
}

.window-close StIcon {
  icon-size: 26px;
}

.window-close:hover {
  background-size: 26px;
  height: 26px;
  width: 26px;
  background-image: url("assets/window-close-hover.svg");
}

.window-close:active {
  background-size: 26px;
  height: 26px;
  width: 26px;
  background-image: url("assets/window-close-active.svg");
}

.nm-dialog {
  max-height: 500px;
  min-height: 450px;
  min-width: 470px;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 24px;
}

.nm-dialog-header-hbox {
  spacing: 10px;
}

.nm-dialog-airplane-box {
  spacing: 12px;
}

.nm-dialog-airplane-headline {
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text {
  color: rgba(0, 0, 0, 0.8);
}

.nm-dialog-header-icon {
  icon-size: 32px;
}

.nm-dialog-scroll-view {
  border: 1px solid rgba(0, 0, 0, 0.1);
  padding: 0;
  background-color: #f7f7f7;
  border-radius: 2px;
}

.nm-dialog-header {
  font-size: 15pt;
  font-weight: 500;
}

.nm-dialog-item {
  font-size: 1em;
  border-bottom: none;
  border-radius: 2px;
  padding: 12px;
  spacing: 20px;
}

.nm-dialog-item:hover, .nm-dialog-item:focus {
  background-color: rgba(0, 0, 0, 0.12);
}

.nm-dialog-item:active {
  background-color: rgba(0, 0, 0, 0.24);
}

.nm-dialog-item:selected {
  background-color: #F0544C;
  color: #FFFFFF;
}

.nm-dialog-icons {
  spacing: .5em;
}

.nm-dialog-icon {
  icon-size: 16px;
}

.no-networks-label {
  color: rgba(0, 0, 0, 0.48);
}

.no-networks-box {
  spacing: 12px;
}

#overview {
  spacing: 24px;
}

#overview .app-view-controls {
  width: 320px;
  padding-bottom: 32px;
}

#overview .app-view-control {
  padding: 0 16px;
  margin: 0;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.1);
  border: 1px solid rgba(0, 0, 0, 0.8);
}

#overview .app-view-control:hover {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.15);
  box-shadow: none;
}

#overview .app-view-control:active {
  color: #FFFFFF;
  background-color: #F0544C;
  border: 1px solid rgba(0, 0, 0, 0.8);
  box-shadow: none;
}

#overview .app-view-control:checked {
  color: #FFFFFF;
  background-color: #F0544C;
  border: 1px solid rgba(0, 0, 0, 0.8);
  box-shadow: none;
}

#overview .app-view-control:first-child {
  border-right-width: 0;
  border-radius: 2px 0 0 2px;
}

#overview .app-view-control:first-child:checked {
  border-radius: 2px 0 0 2px;
}

#overview .app-view-control:last-child {
  border-left-width: 0;
  border-radius: 0 2px 2px 0;
}

#overview .app-view-control:last-child:checked {
  border-radius: 0 2px 2px 0;
}

.overview-controls {
  padding-bottom: 32px;
}

.window-picker {
  -horizontal-spacing: 32px;
  -vertical-spacing: 32px;
  padding-left: 32px;
  padding-right: 32px;
  padding-bottom: 48px;
}

.window-picker.external-monitor {
  padding: 32px;
}

.window-clone-border {
  border: 4px solid rgba(240, 84, 76, 0.7);
  border-radius: 2px;
  box-shadow: inset 0 0 0 1px rgba(240, 84, 76, 0.7);
}

.window-caption {
  spacing: 25px;
  color: #FFFFFF;
  background-color: rgba(0, 0, 0, 0.5);
  border-radius: 2px;
  padding: 4px 8px;
  -shell-caption-spacing: 12px;
  border: none;
  font-weight: normal;
}

.window-caption:hover {
  background-color: rgba(240, 84, 76, 0.8);
  color: #FFFFFF;
}

.search-entry, .app-folder-dialog .folder-name-container .folder-name-entry {
  width: 320px;
  padding: 0 8px;
  border-radius: 1000px;
  color: #FAFAFA;
  caret-color: #FAFAFA;
  background-color: rgba(255, 255, 255, 0.1);
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.8);
  text-shadow: none;
}

.search-entry:hover, .app-folder-dialog .folder-name-container .folder-name-entry:hover {
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.15);
}

.search-entry:hover .search-entry-icon, .app-folder-dialog .folder-name-container .folder-name-entry:hover .search-entry-icon {
  color: #FFFFFF;
}

.search-entry:focus, .app-folder-dialog .folder-name-container .folder-name-entry:focus {
  padding: 0 8px;
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.1);
  box-shadow: none;
  border: 1px solid #F0544C;
}

.search-entry:insensitive, .app-folder-dialog .folder-name-container .folder-name-entry:insensitive {
  color: rgba(255, 255, 255, 0.2625);
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.45);
}

.search-entry:insensitive StLabel.hint-text, .app-folder-dialog .folder-name-container .folder-name-entry:insensitive StLabel.hint-text,
.search-entry:insensitive .search-entry-icon,
.app-folder-dialog .folder-name-container .folder-name-entry:insensitive .search-entry-icon {
  color: rgba(255, 255, 255, 0.2625);
}

.search-entry StLabel.hint-text, .app-folder-dialog .folder-name-container .folder-name-entry StLabel.hint-text {
  margin-left: 2px;
  color: rgba(250, 250, 250, 0.7);
}

.search-entry .search-entry-icon, .app-folder-dialog .folder-name-container .folder-name-entry .search-entry-icon {
  icon-size: 16px;
  padding: 0 0;
  color: #FAFAFA;
}

#searchResultsContent {
  max-width: 1024px;
  spacing: 8px;
}

.list-search-results {
  spacing: 3px;
}

.search-section-separator {
  height: 0;
  background-color: transparent;
}

.search-provider-icon-more {
  width: 16px;
  height: 16px;
  background-image: url("assets/more-results.svg");
}

.search-section {
  spacing: 16px;
}

.search-section .search-section-separator {
  height: 0;
  background-color: transparent;
}

.search-section-content {
  background-color: rgba(255, 255, 255, 0.1);
  border-radius: 3px;
  border: none;
  box-shadow: none;
  text-shadow: none;
  color: #FFFFFF;
  padding: 18px;
  spacing: 8px;
}

.list-search-result, .search-provider-icon {
  transition-duration: 0ms;
}

.list-search-result:focus, .search-provider-icon:focus, .list-search-result:hover, .search-provider-icon:hover, .list-search-result:selected, .search-provider-icon:selected {
  background-color: #FFFFFF;
  transition-duration: 200ms;
}

.list-search-result:active, .search-provider-icon:active, .list-search-result:checked, .search-provider-icon:checked {
  background-color: rgba(255, 255, 255, 0.1);
}

.grid-search-results {
  spacing: 36px;
}

.search-provider-icon .list-search-provider-content {
  spacing: 12px;
}

.search-provider-icon .list-search-provider-content .list-search-provider-details {
  width: 120px;
  margin-top: 0;
  color: #ebebeb;
}

.list-search-results {
  spacing: 6px;
}

.list-search-result .list-search-result-content {
  spacing: 6px;
}

.list-search-result .list-search-result-title {
  spacing: 8px;
  font-weight: bold;
  font-size: 1em;
}

.list-search-result .list-search-result-description {
  color: rgba(255, 255, 255, 0.75);
}

#dash {
  font-size: 1em;
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.1);
  padding: 3px 0;
  border: none;
  border-left: 0px;
  border-radius: 0px 2px 2px 0px;
}

#dash:rtl {
  border-radius: 2px 0 0 2px;
}

#dash .placeholder {
  background-image: url("assets/dash-placeholder.svg");
  background-size: contain;
  height: 24px;
}

#dash .empty-dash-drop-target {
  width: 24px;
  height: 24px;
}

.dash-item-container > StWidget {
  padding: 3px 6px;
}

.dash-label {
  border-radius: 3px;
  padding: 6px 10px;
  color: white;
  background-color: rgba(0, 0, 0, 0.75);
  box-shadow: none;
  text-align: center;
  -x-offset: 8px;
}

.icon-grid {
  row-spacing: 36px;
  column-spacing: 36px;
  max-row-spacing: 72px;
  max-column-spacing: 72px;
}

.search-provider-icon:focus, .search-provider-icon:selected, .search-provider-icon:hover,
.list-search-result:focus,
.list-search-result:selected,
.list-search-result:hover {
  background-color: rgba(255, 255, 255, 0.15);
  transition-duration: 0s;
}

.search-provider-icon:active, .search-provider-icon:checked,
.list-search-result:active,
.list-search-result:checked {
  background-color: rgba(255, 255, 255, 0.3);
  transition-duration: 0.2s;
}

.app-well-app:hover .overview-icon, .app-well-app:focus .overview-icon, .app-well-app:selected .overview-icon,
.show-apps:hover .overview-icon,
.show-apps:focus .overview-icon,
.show-apps:selected .overview-icon,
.grid-search-result:hover .overview-icon,
.grid-search-result:focus .overview-icon,
.grid-search-result:selected .overview-icon {
  background-color: rgba(255, 255, 255, 0.15);
  transition-duration: 0s;
  border-image: none;
  background-image: none;
}

.app-well-app:active .overview-icon, .app-well-app:checked .overview-icon,
.show-apps:active .overview-icon,
.show-apps:checked .overview-icon,
.grid-search-result:active .overview-icon,
.grid-search-result:checked .overview-icon {
  background-color: rgba(255, 255, 255, 0.3);
  box-shadow: 0 0 transparent;
  transition-duration: 0.2s;
}

.app-well-app-running-dot {
  width: 16px;
  height: 2px;
  background-color: rgba(255, 255, 255, 0.3);
  margin-bottom: 0;
  border-radius: 0;
}

StWidget.focused .app-well-app-running-dot {
  width: 24px;
  background-color: #F0544C;
}

.search-provider-icon, .list-search-result, .app-well-app .overview-icon,
.show-apps .overview-icon,
.grid-search-result .overview-icon {
  color: #FFFFFF;
  border-radius: 3px;
  padding: 6px;
  border: none;
  transition-duration: 100ms;
  text-align: center;
}

.app-well-app.app-folder > .overview-icon {
  background-color: rgba(255, 255, 255, 0.1);
}

.show-apps .show-apps-icon {
  color: rgba(255, 255, 255, 0.75);
}

.show-apps:hover .show-apps-icon,
.show-apps:active .show-apps-icon,
.show-apps:checked .show-apps-icon,
.show-apps:focus .show-apps-icon {
  color: #FFFFFF;
  transition-duration: 0.2s;
}

.app-folder-popup {
  -arrow-border-radius: 2px;
  -arrow-background-color: rgba(255, 255, 255, 0.1);
  -arrow-base: 24px;
  -arrow-rise: 12px;
}

.app-folder-popup-bin {
  padding: 5px;
}

.app-folder-icon {
  padding: 6px;
  spacing-rows: 6px;
  spacing-columns: 6px;
}

.page-indicator {
  padding: 15px 20px;
}

.page-indicator .page-indicator-icon {
  width: 12px;
  height: 12px;
  border-radius: 12px;
  margin: 0;
  padding: 0;
  background-image: none;
  color: transparent;
  border: none;
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.3);
}

.page-indicator:hover .page-indicator-icon {
  margin: 0;
  padding: 0;
  background-image: none;
  color: transparent;
  border: none;
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.6);
}

.page-indicator:active .page-indicator-icon, .page-indicator:checked .page-indicator-icon {
  margin: 0;
  padding: 0;
  background-image: none;
  color: transparent;
  border: none;
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.6);
  transition-duration: 0s;
}

.page-indicator:checked:active {
  background-image: none;
}

.app-well-app .overview-icon.overview-icon-with-label,
.grid-search-result .overview-icon.overview-icon-with-label {
  padding: 10px 8px 5px 8px;
}

.app-well-app .overview-icon.overview-icon-with-label > StBoxLayout,
.grid-search-result .overview-icon.overview-icon-with-label > StBoxLayout {
  spacing: 6px;
}

.app-folder {
  background: none;
}

.app-folder .overview-icon {
  background-color: rgba(255, 255, 255, 0.15);
  border-radius: 3px;
}

.app-folder:hover .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
}

.app-folder-dialog {
  border-radius: 12px;
  border: none;
  spacing: 6px;
  padding: 0;
  background-color: rgba(34, 34, 34, 0.95);
  border: 2px solid rgba(255, 255, 255, 0.15);
}

.app-folder-dialog .folder-name-container {
  padding: 24px 36px 0;
  spacing: 12px;
  /* FIXME: this is to keep the label in sync with the entry */
}

.app-folder-dialog .folder-name-container .folder-name-label, .app-folder-dialog .folder-name-container .folder-name-entry {
  font-size: 18pt;
  font-weight: bold;
}

.app-folder-dialog .folder-name-container .folder-name-label {
  padding: 5px 7px;
  color: #FFFFFF;
}

.app-folder-dialog .folder-name-container .edit-folder-button {
  background-color: rgba(255, 255, 255, 0.1);
  color: #FFFFFF;
  border: none;
  background-image: none;
  padding: 0;
  width: 36px;
  height: 36px;
  border-radius: 1000px;
}

.app-folder-dialog .folder-name-container .edit-folder-button > StIcon {
  icon-size: 16px;
}

.app-folder-dialog .folder-name-container .edit-folder-button:hover {
  background-color: rgba(255, 255, 255, 0.15);
  background-image: none;
}

.app-folder-dialog .folder-name-container .edit-folder-button:checked, .app-folder-dialog .folder-name-container .edit-folder-button:active {
  background-color: rgba(255, 255, 255, 0.25);
  background-image: none;
}

.app-folder-dialog .icon-grid {
  row-spacing: 12px;
  column-spacing: 30px;
}

.app-folder-dialog .page-indicators {
  margin-bottom: 18px;
}

.app-folder-dialog .page-indicators .page-indicator {
  padding: 15px 12px;
}

.app-folder-dialog StButton#vhandle, .app-folder-dialog StButton#vhandle:hover, .app-folder-dialog StButton#vhandle:active {
  background-color: transparent;
}

.app-folder-dialog-container {
  padding: 6px;
  width: 600px;
  height: 600px;
}

.rename-folder-popup .rename-folder-popup-item {
  spacing: 6px;
}

.rename-folder-popup .rename-folder-popup-item:ltr, .rename-folder-popup .rename-folder-popup-item:rtl {
  padding: 0 12px;
}

.app-menu,
.app-well-menu {
  max-width: 27.25em;
}

.workspace-thumbnails {
  visible-width: 32px;
  spacing: 12px;
  padding: 12px;
  border-radius: 2px 0 0 2px;
}

.workspace-thumbnails:rtl {
  border-radius: 0 2px 2px 0;
}

.workspace-thumbnail-indicator {
  border: 0 solid #F0544C;
  border-left-width: 2px;
  padding: 6px;
  border-radius: 0;
}

.workspace-thumbnails {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.1);
  border: none;
}

.search-statustext, .no-frequent-applications-label {
  font-size: 2em;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.6);
}

.url-highlighter {
  link-color: #F0544C;
}

.notification-banner {
  font-size: 1em;
  width: 34em;
  min-height: 56px;
  margin: 5px;
  border-radius: 2px;
  color: rgba(0, 0, 0, 0.8);
  background-color: #ffffff;
  border: none;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

.notification-banner:hover {
  background-color: #ffffff;
}

.notification-banner:focus {
  background-color: #ffffff;
}

.notification-banner .notification-icon {
  padding: 5px;
}

.notification-banner .notification-content {
  padding: 5px;
  spacing: 5px;
}

.notification-banner .secondary-icon {
  icon-size: em(16px);
}

.notification-banner .notification-actions {
  background-color: transparent;
  padding-top: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  spacing: 1px;
}

.notification-banner .notification-button {
  min-height: 40px;
  padding: 0 16px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
  border-width: 0;
}

.notification-banner .notification-button:first-child {
  border-radius: 0 0 0 2px;
}

.notification-banner .notification-button:last-child {
  border-radius: 0 0 2px 0;
}

.notification-banner .notification-button:hover, .notification-banner .notification-button:focus:hover {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.8);
}

.notification-banner .notification-button:focus {
  background-color: transparent;
  box-shadow: none;
}

.notification-banner .notification-button:active {
  background-color: rgba(0, 0, 0, 0.24);
  color: rgba(0, 0, 0, 0.8);
}

.summary-source-counter {
  font-size: 1em;
  font-weight: bold;
  height: 1.6em;
  width: 1.6em;
  -shell-counter-overlap-x: 3px;
  -shell-counter-overlap-y: 3px;
  background-color: #F0544C;
  color: #FFFFFF;
  border: 2px solid #FFFFFF;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.5);
  border-radius: 0.9em;
}

.secondary-icon {
  icon-size: 1.2307692308em;
}

.chat-body {
  spacing: 5px;
}

.chat-response {
  margin: 5px;
}

.chat-log-message {
  color: rgba(0, 0, 0, 0.8);
}

.chat-new-group {
  padding-top: 1em;
}

.chat-received {
  padding-left: 4px;
}

.chat-received:rtl {
  padding-left: 0px;
  padding-right: 4px;
}

.chat-sent {
  padding-left: 18pt;
  color: rgba(0, 0, 0, 0.6);
}

.chat-sent:rtl {
  padding-left: 0;
  padding-right: 18pt;
}

.chat-meta-message {
  padding-left: 4px;
  font-size: 9pt;
  font-weight: 400;
  color: rgba(0, 0, 0, 0.48);
}

.chat-meta-message:rtl {
  padding-left: 0;
  padding-right: 4px;
}

.hotplug-transient-box {
  spacing: 6px;
  padding: 2px 72px 2px 12px;
}

.hotplug-notification-item {
  padding: 2px 10px;
}

.hotplug-notification-item:focus {
  padding: 1px 71px 1px 11px;
}

.hotplug-notification-item-icon {
  icon-size: 24px;
  padding: 2px 5px;
}

.hotplug-resident-box {
  spacing: 8px;
}

.hotplug-resident-mount {
  spacing: 8px;
  border-radius: 2px;
}

.hotplug-resident-mount:hover {
  background-color: rgba(0, 0, 0, 0.12);
}

.hotplug-resident-mount:active {
  background-color: rgba(0, 0, 0, 0.24);
}

.hotplug-resident-mount-label {
  color: inherit;
  padding-left: 6px;
}

.hotplug-resident-mount-icon {
  icon-size: 24px;
  padding-left: 6px;
}

.hotplug-resident-eject-icon {
  icon-size: 16px;
}

.hotplug-resident-eject-button {
  padding: 7px;
  border-radius: 2px;
  color: rgba(0, 0, 0, 0.8);
}

.legacy-tray {
  background-color: rgba(0, 0, 0, 0.6);
  color: #FFFFFF;
  border: none;
  border-bottom-width: 0;
}

.legacy-tray:ltr {
  border-radius: 0 2px 0 0;
  border-left-width: 0;
}

.legacy-tray:rtl {
  border-radius: 2px 0 0 0;
  border-right-width: 0;
}

.legacy-tray-handle,
.legacy-tray-icon {
  padding: 6px;
}

.legacy-tray-handle StIcon,
.legacy-tray-icon StIcon {
  icon-size: 24px;
}

.legacy-tray-handle:hover, .legacy-tray-handle:focus,
.legacy-tray-icon:hover,
.legacy-tray-icon:focus {
  background-color: rgba(255, 255, 255, 0.15);
}

.legacy-tray-handle:active,
.legacy-tray-icon:active {
  background-color: rgba(255, 255, 255, 0.3);
}

.legacy-tray-icon-box {
  spacing: 12px;
}

.legacy-tray-icon-box:ltr {
  padding-left: 12px;
}

.legacy-tray-icon-box:rtl {
  padding-right: 12px;
}

.legacy-tray-icon-box StButton {
  width: 24px;
  height: 24px;
}

.magnifier-zoom-region {
  border: 2px solid #F0544C;
}

.magnifier-zoom-region.full-screen {
  border-width: 0;
}

.word-suggestions {
  font-size: 14pt;
  spacing: 12px;
  min-height: 20pt;
}

#keyboard {
  background-color: rgba(16, 16, 16, 0.95);
  box-shadow: none;
}

#keyboard .page-indicator {
  padding: 6px;
}

#keyboard .page-indicator .page-indicator-icon {
  width: 8px;
  height: 8px;
}

.key-container,
.keyboard-layout {
  padding: 4px;
  spacing: 4px;
}

.keyboard-key {
  min-height: 2em;
  min-width: 2em;
  font-size: 14pt;
  font-weight: bold;
  border-radius: 3px;
  border: none;
  color: #FFFFFF;
  background-color: #484848;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.75);
}

.keyboard-key:focus, .keyboard-key:hover {
  color: #FFFFFF;
  background-color: #f4817b;
}

.keyboard-key:checked, .keyboard-key:active {
  color: #FFFFFF;
  background-color: #f2665f;
}

.keyboard-key:grayed {
  background-color: #484848;
  color: #FFFFFF;
}

.keyboard-key.default-key, .keyboard-key.enter-key, .keyboard-key.shift-key-lowercase, .keyboard-key.shift-key-uppercase, .keyboard-key.hide-key, .keyboard-key.layout-key {
  background-color: #2f2f2f;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.75);
}

.keyboard-key.default-key:focus, .keyboard-key.default-key:hover, .keyboard-key.enter-key:focus, .keyboard-key.enter-key:hover, .keyboard-key.shift-key-lowercase:focus, .keyboard-key.shift-key-lowercase:hover, .keyboard-key.shift-key-uppercase:focus, .keyboard-key.shift-key-uppercase:hover, .keyboard-key.hide-key:focus, .keyboard-key.hide-key:hover, .keyboard-key.layout-key:focus, .keyboard-key.layout-key:hover {
  color: #FFFFFF;
  background-color: #484848;
}

.keyboard-key.default-key:checked, .keyboard-key.default-key:active, .keyboard-key.enter-key:checked, .keyboard-key.enter-key:active, .keyboard-key.shift-key-lowercase:checked, .keyboard-key.shift-key-lowercase:active, .keyboard-key.shift-key-uppercase:checked, .keyboard-key.shift-key-uppercase:active, .keyboard-key.hide-key:checked, .keyboard-key.hide-key:active, .keyboard-key.layout-key:checked, .keyboard-key.layout-key:active {
  color: #FFFFFF;
  background-color: #393939;
}

.keyboard-key.enter-key {
  background-color: #F0544C;
}

.keyboard-key.enter-key:focus, .keyboard-key.enter-key:hover {
  color: #FFFFFF;
  background-color: #f26a64;
}

.keyboard-key.enter-key:checked, .keyboard-key.enter-key:active {
  color: #FFFFFF;
  background-color: #ec271d;
}

.keyboard-key StIcon {
  icon-size: 1.125em;
}

.keyboard-subkeys {
  color: inherit;
  -arrow-border-radius: 3px;
  -arrow-background-color: rgba(0, 0, 0, 0.75);
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 20px;
  -arrow-rise: 10px;
  -boxpointer-gap: 5px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.35);
}

.emoji-page .keyboard-key {
  background-color: transparent;
  border: none;
  color: initial;
}

.emoji-panel .keyboard-key:latched {
  border-color: #f26a64;
  background-color: #F0544C;
}

.word-suggestions {
  spacing: 12px;
  min-height: 20pt;
}

.candidate-popup-boxpointer {
  -arrow-border-radius: 2px;
  -arrow-background-color: transparent;
  -arrow-border-width: 1px;
  -arrow-border-color: transparent;
  -arrow-base: 64px;
  -arrow-rise: 6px;
  border: none;
  border-image: none;
}

.candidate-popup-content {
  padding: 6px;
  spacing: 6px;
  margin: 12px 6px;
  color: rgba(0, 0, 0, 0.6);
}

.candidate-index {
  padding-top: 3px;
  spacing: 6px;
  color: rgba(0, 0, 0, 0.48);
  font-weight: bold;
}

.candidate-box:selected .candidate-index {
  color: rgba(255, 255, 255, 0.6);
}

.candidate-box {
  transition-duration: 0s;
  min-height: 28px;
  padding: 2px 8px;
  spacing: 0;
  border-radius: 2px;
  margin: 2px;
}

.candidate-box StLabel {
  margin: 3px 0;
}

.candidate-box:hover {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.8);
}

.candidate-box:active {
  background-color: rgba(0, 0, 0, 0.24);
  color: rgba(0, 0, 0, 0.8);
}

.candidate-box:selected {
  background-color: #F0544C;
  color: #FFFFFF;
}

.vertical .candidate-page-button-box {
  padding-top: 0;
}

.horizontal .candidate-page-button-box {
  padding-left: 0;
}

.candidate-page-button {
  padding: 2px 8px;
  margin: 2px;
}

.candidate-page-button-previous {
  border-radius: 2px;
}

.candidate-page-button-next {
  border-radius: 2px;
}

.candidate-page-button-icon {
  icon-size: 1.2307692308em;
}

/* Auth Dialogs & Screen Shield */
.framed-user-icon {
  background-size: contain;
  border: none;
  color: #FFFFFF;
  border-radius: 2px;
}

.framed-user-icon:hover {
  border-color: #FFFFFF;
  color: #FFFFFF;
}

.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 23em;
}

.login-dialog,
.unlock-dialog {
  background-color: transparent;
}

.login-dialog StEntry,
.unlock-dialog StEntry {
  color: #FFFFFF;
  caret-color: #FFFFFF;
  selection-background-color: #F0544C;
  selected-color: #FFFFFF;
  border: 1px solid rgba(255, 255, 255, 0.2);
  background-color: rgba(255, 255, 255, 0.1);
}

.login-dialog StEntry:focus,
.unlock-dialog StEntry:focus {
  border: 1px solid #F0544C;
  background-color: rgba(255, 255, 255, 0.1);
  selection-background-color: #F0544C;
  selected-color: #FFFFFF;
}

.login-dialog StEntry:insensitive,
.unlock-dialog StEntry:insensitive {
  color: rgba(0, 0, 0, 0.28);
  border-color: rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  color: rgba(255, 255, 255, 0.35);
}

.login-dialog .modal-dialog-button-box,
.unlock-dialog .modal-dialog-button-box {
  spacing: 3px;
}

.login-dialog .modal-dialog-button,
.unlock-dialog .modal-dialog-button {
  padding: 4px 18px;
  color: rgba(0, 0, 0, 0.6);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:hover,
.unlock-dialog .modal-dialog-button:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.1);
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:focus,
.unlock-dialog .modal-dialog-button:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: inset 0px 0px 0px 2px rgba(0, 0, 0, 0.24);
}

.login-dialog .modal-dialog-button:active,
.unlock-dialog .modal-dialog-button:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:insensitive,
.unlock-dialog .modal-dialog-button:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default,
.unlock-dialog .modal-dialog-button:default {
  color: rgba(0, 0, 0, 0.6);
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:hover,
.unlock-dialog .modal-dialog-button:default:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.1);
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:focus,
.unlock-dialog .modal-dialog-button:default:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: inset 0px 0px 0px 2px rgba(0, 0, 0, 0.24);
}

.login-dialog .modal-dialog-button:default:active,
.unlock-dialog .modal-dialog-button:default:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(198, 198, 198, 0.94);
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:insensitive,
.unlock-dialog .modal-dialog-button:default:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: rgba(0, 0, 0, 0.084);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .cancel-button,
.login-dialog .switch-user-button,
.login-dialog .login-dialog-session-list-button,
.unlock-dialog .cancel-button,
.unlock-dialog .switch-user-button,
.unlock-dialog .login-dialog-session-list-button {
  padding: 0;
  border-radius: 100px;
  width: 32px;
  height: 32px;
  border: 0 solid transparent;
  background-color: rgba(0, 0, 0, 0);
}

.login-dialog .cancel-button, .login-dialog .cancel-button:hover, .login-dialog .cancel-button:active, .login-dialog .cancel-button:focus,
.login-dialog .switch-user-button,
.login-dialog .switch-user-button:hover,
.login-dialog .switch-user-button:active,
.login-dialog .switch-user-button:focus,
.login-dialog .login-dialog-session-list-button,
.login-dialog .login-dialog-session-list-button:hover,
.login-dialog .login-dialog-session-list-button:active,
.login-dialog .login-dialog-session-list-button:focus,
.unlock-dialog .cancel-button,
.unlock-dialog .cancel-button:hover,
.unlock-dialog .cancel-button:active,
.unlock-dialog .cancel-button:focus,
.unlock-dialog .switch-user-button,
.unlock-dialog .switch-user-button:hover,
.unlock-dialog .switch-user-button:active,
.unlock-dialog .switch-user-button:focus,
.unlock-dialog .login-dialog-session-list-button,
.unlock-dialog .login-dialog-session-list-button:hover,
.unlock-dialog .login-dialog-session-list-button:active,
.unlock-dialog .login-dialog-session-list-button:focus {
  border-width: 0;
}

.login-dialog .cancel-button StIcon,
.login-dialog .switch-user-button StIcon,
.login-dialog .login-dialog-session-list-button StIcon,
.unlock-dialog .cancel-button StIcon,
.unlock-dialog .switch-user-button StIcon,
.unlock-dialog .login-dialog-session-list-button StIcon {
  icon-size: 16px;
}

.login-dialog .login-dialog-message-warning,
.unlock-dialog .login-dialog-message-warning {
  color: #FF6D00;
}

.caps-lock-warning-label {
  text-align: center;
  padding-bottom: 8px;
  color: #FF6D00;
}

.login-dialog-logo-bin {
  padding: 24px 0px;
}

.login-dialog-banner {
  color: rgba(255, 255, 255, 0.75);
}

.login-dialog-button-box {
  width: 23em;
  spacing: 5px;
}

.login-dialog-message {
  text-align: center;
}

.login-dialog-message-warning {
  color: #FF6D00;
}

.login-dialog-message-hint {
  padding-top: 0;
  padding-bottom: 20px;
}

.login-dialog-user-selection-box {
  padding: 100px 0px;
}

.login-dialog-not-listed-label {
  padding-left: 2px;
}

.login-dialog-not-listed-button:focus .login-dialog-not-listed-label, .login-dialog-not-listed-button:hover .login-dialog-not-listed-label {
  color: #FFFFFF;
}

.login-dialog-not-listed-label {
  font-size: 1em;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.75);
  padding-top: 1em;
}

.login-dialog-not-listed-label:hover {
  color: #FFFFFF;
}

.login-dialog-not-listed-label:focus {
  background-color: rgba(255, 255, 255, 0.15);
}

.login-dialog-user-list-view {
  -st-vfade-offset: 1em;
}

.login-dialog-user-list {
  spacing: 12px;
  width: 23em;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:focus {
  background-color: rgba(255, 255, 255, 0.15);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:hover {
  background-color: rgba(255, 255, 255, 0.15);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:active {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in {
  border-right: 2px solid #FFFFFF;
}

.login-dialog-user-list-item {
  border-radius: 3px;
  padding: 6px;
  color: rgba(255, 255, 255, 0.75);
}

.login-dialog-user-list-item:ltr .user-widget {
  padding-right: 1em;
}

.login-dialog-user-list-item:rtl .user-widget {
  padding-left: 1em;
}

.login-dialog-user-list-item:hover {
  background-color: rgba(255, 255, 255, 0.15);
  color: #FFFFFF;
}

.login-dialog-user-list-item:active {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

.login-dialog-user-list-item .login-dialog-timed-login-indicator {
  height: 2px;
  margin-top: 6px;
  background-color: #FFFFFF;
}

.login-dialog-user-list-item:focus .login-dialog-timed-login-indicator {
  background-color: #FFFFFF;
}

.user-widget-label {
  color: #FFFFFF;
}

.user-widget.horizontal .user-widget-label {
  font-weight: bold;
  text-align: left;
  padding-left: 15px;
}

.user-widget.horizontal .user-widget-label:ltr {
  padding-left: 14px;
}

.user-widget.horizontal .user-widget-label:rtl {
  padding-right: 14px;
}

.user-widget.vertical .user-widget-label {
  text-align: center;
  font-weight: normal;
  padding-top: 16px;
}

.login-dialog-prompt-entry {
  height: 1.5em;
}

.login-dialog-prompt-layout {
  padding-top: 24px;
  padding-bottom: 12px;
  spacing: 8px;
  width: 23em;
}

.login-dialog-prompt-label {
  color: rgba(255, 255, 255, 0.6);
  font-size: 1em;
  padding-top: 1em;
}

.screen-shield-arrows {
  padding-bottom: 3em;
}

.screen-shield-arrows Gjs_Arrow {
  color: white;
  width: 80px;
  height: 48px;
  -arrow-thickness: 12px;
  -arrow-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
}

.screen-shield-clock {
  color: white;
  text-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
  font-weight: normal;
  text-align: center;
  padding-bottom: 1.5em;
}

.screen-shield-clock-time {
  font-size: 112px;
  font-weight: 300;
  text-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
}

.screen-shield-clock-date {
  font-size: 45px;
  font-weight: 400;
}

.screen-shield-notifications-container {
  spacing: 6px;
  width: 30em;
  background-color: transparent;
  max-height: 500px;
}

.screen-shield-notifications-container .summary-notification-stack-scrollview {
  padding-top: 0;
  padding-bottom: 0;
}

.screen-shield-notifications-container .notification,
.screen-shield-notifications-container .screen-shield-notification-source {
  padding: 8px;
  border: none;
  background-color: rgba(0, 0, 0, 0.3);
  color: #FFFFFF;
  border-radius: 2px;
}

.screen-shield-notifications-container .notification {
  margin-right: 16px;
}

.screen-shield-notification-label {
  min-height: 18px;
  padding: 2px 0px 0px 16px;
  font-weight: bold;
}

.screen-shield-notification-count-text {
  min-height: 18px;
  padding: 2px 0px 0px 16px;
  color: rgba(255, 255, 255, 0.75);
}

#panel.lock-screen {
  background-color: rgba(0, 0, 0, 0.3);
}

.screen-shield-background {
  background: black;
  box-shadow: 0 19px 19px rgba(0, 0, 0, 0.6), 0 15px 6px rgba(0, 0, 0, 0.44);
}

.unlock-dialog-clock {
  color: white;
  font-weight: 300;
  text-align: center;
  spacing: 24px;
  padding-bottom: 2.5em;
}

.unlock-dialog-clock-time {
  font-size: 64pt;
  padding-top: 42px;
  font-feature-settings: "tnum";
}

.unlock-dialog-clock-date {
  font-size: 16pt;
  font-weight: normal;
}

.unlock-dialog-clock-hint {
  font-weight: normal;
  padding-top: 48px;
}

.unlock-dialog-notifications-container {
  margin: 12px 0;
  spacing: 6px;
  width: 23em;
  background-color: transparent;
}

.unlock-dialog-notifications-container .summary-notification-stack-scrollview {
  padding-top: 0;
  padding-bottom: 0;
}

.unlock-dialog-notifications-container .notification,
.unlock-dialog-notifications-container .unlock-dialog-notification-source {
  padding: 12px 6px;
  border: none;
  background-color: rgba(0, 0, 0, 0);
  color: rgba(255, 255, 255, 0.75);
  border-radius: 3px;
}

.unlock-dialog-notifications-container .notification.critical,
.unlock-dialog-notifications-container .unlock-dialog-notification-source.critical {
  background-color: rgba(0, 0, 0, 0.2);
}

.unlock-dialog-notification-label {
  padding: 0px 0px 0px 12px;
}

.unlock-dialog-notification-count-text {
  weight: bold;
  padding: 0 6px;
  color: rgba(0, 0, 0, 0.3);
  background-color: rgba(255, 255, 255, 0.05);
  border-radius: 99px;
  margin-right: 12px;
}

#lockDialogGroup {
  background: #3c3c3c url("assets/noise-texture.png");
  background-repeat: repeat;
}

#screenShieldNotifications StButton#vhandle, #screenShieldNotifications StButton#hhandle {
  background-color: rgba(0, 0, 0, 0);
}

#screenShieldNotifications StButton#vhandle:hover, #screenShieldNotifications StButton#vhandle:focus, #screenShieldNotifications StButton#hhandle:hover, #screenShieldNotifications StButton#hhandle:focus {
  background-color: rgba(0, 0, 0, 0.1);
}

#screenShieldNotifications StButton#vhandle:active, #screenShieldNotifications StButton#hhandle:active {
  background-color: rgba(240, 84, 76, 0.5);
}

#LookingGlassDialog {
  color: rgba(0, 0, 0, 0.6);
  background-color: rgba(255, 255, 255, 0.95);
  spacing: 4px;
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.5), 0 10px 5px rgba(0, 0, 0, 0.44);
}

#LookingGlassDialog > #Toolbar {
  padding: 0 8px;
  border: none;
  border-radius: 0;
  background-color: rgba(255, 255, 255, 0.01);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}

#LookingGlassDialog .labels {
  spacing: 0;
}

#LookingGlassDialog .notebook-tab {
  -natural-hpadding: 12px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.48);
  transition-duration: 0.2s;
  padding-left: 16px;
  padding-right: 16px;
  min-height: 32px;
  padding: 0 32px;
  border-bottom-width: 2px;
}

#LookingGlassDialog .notebook-tab:hover {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  box-shadow: inset 0 -2px rgba(0, 0, 0, 0.24);
}

#LookingGlassDialog .notebook-tab:selected {
  border-bottom-width: 2px;
  border-color: transparent;
  background-color: rgba(255, 255, 255, 0.01);
  box-shadow: inset 0 -2px #F0544C;
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
}

#LookingGlassDialog StBoxLayout#EvalBox {
  padding: 4px;
  spacing: 4px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
  spacing: 4px;
}

.lg-dialog StEntry {
  selection-background-color: #F0544C;
  selected-color: #FFFFFF;
}

.lg-dialog .shell-link {
  color: #F0544C;
}

.lg-dialog .shell-link:hover {
  color: #F0544C;
}

.lg-completions-text {
  font-size: 1em;
  font-style: italic;
}

.lg-obj-inspector-title {
  spacing: 4px;
}

.lg-obj-inspector-button {
  min-height: 32px;
  padding: 0 16px;
  border: none;
  border-radius: 2px;
  font-size: 9.75pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.6);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
  border: none;
}

.lg-obj-inspector-button:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.24);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: none;
  color: #F0544C;
}

#lookingGlassExtensions {
  padding: 4px;
}

.lg-extensions-list {
  padding: 4px;
  spacing: 6px;
}

.lg-extension {
  border: none;
  border-radius: 3px;
  padding: 4px;
  background-color: rgba(0, 0, 0, 0.06);
}

.lg-extension-name {
  font-size: 18pt;
  font-weight: 400;
}

.lg-extension-meta {
  spacing: 6px;
}

#LookingGlassPropertyInspector {
  background: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
  padding: 6px;
  box-shadow: none;
}

#dashtodockContainer {
  background: transparent;
}

#dashtodockContainer #dash, #dashtodockContainer:overview #dash, #dashtodockContainer.extended #dash, #dashtodockContainer.extended:overview #dash {
  padding: 0;
  border: none;
  margin: 0;
}

#dashtodockContainer.top #dash, #dashtodockContainer.top:overview #dash {
  border-radius: 0 0 3px 3px;
}

#dashtodockContainer.top.extended #dash, #dashtodockContainer.top.extended:overview #dash {
  border-radius: 0 0 3px 3px;
}

#dashtodockContainer.bottom #dash, #dashtodockContainer.bottom:overview #dash {
  border-radius: 3px 3px 0 0;
}

#dashtodockContainer.bottom.extended #dash, #dashtodockContainer.bottom.extended:overview #dash {
  border-radius: 3px 3px 0 0;
}

#dashtodockContainer.left #dash, #dashtodockContainer.left:overview #dash {
  border-radius: 0 3px 3px 0;
}

#dashtodockContainer.left.extended #dash, #dashtodockContainer.left.extended:overview #dash {
  border-radius: 0 3px 3px 0;
}

#dashtodockContainer.right #dash, #dashtodockContainer.right:overview #dash {
  border-radius: 3px 0 0 3px;
}

#dashtodockContainer.right.extended #dash, #dashtodockContainer.right.extended:overview #dash {
  border-radius: 3px 0 0 3px;
}

#dashtodockContainer #dash {
  background-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

#dashtodockContainer.opaque #dash {
  background-color: #222222;
}

#dashtodockContainer.transparent #dash {
  background-color: rgba(0, 0, 0, 0.3);
}

#dashtodockContainer:overview #dash {
  background-color: rgba(255, 255, 255, 0.1);
}

#dashtodockContainer.opaque:overview #dash, #dashtodockContainer.transparent:overview #dash {
  background-color: transparent !important;
  box-shadow: none !important;
}

#dashtodockContainer.extended:overview #dash, #dashtodockContainer.opaque.extended:overview #dash, #dashtodockContainer.transparent.extended:overview #dash {
  background-color: #222222;
}

#dashtodockContainer .app-well-app .overview-icon,
#dashtodockContainer .show-apps .overview-icon {
  padding: 8px;
  background-size: contain;
}

#dash:desktop {
  background-color: rgba(0, 0, 0, 0.6);
}

.openweather-button, .openweather-button-action, .openweather-menu-button-container, .openweather-button-box {
  border: 1px solid transparent;
  background: none;
}

.openweather-provider {
  padding: 0 16px;
  font-weight: 500;
  border: 1px solid transparent;
  color: rgba(0, 0, 0, 0.6);
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-provider:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(0, 0, 0, 0.1);
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-provider:focus {
  color: rgba(0, 0, 0, 0.8);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0px 0px 0px 2px rgba(240, 84, 76, 0.35);
  box-shadow: inset 0px 0px 0px 2px rgba(0, 0, 0, 0.24);
}

.openweather-provider:active {
  color: rgba(0, 0, 0, 0.8);
  background-color: rgba(198, 198, 198, 0.94);
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-provider:insensitive {
  color: rgba(0, 0, 0, 0.21);
  background-color: rgba(0, 0, 0, 0.084);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-current-icon, .openweather-current-summary, .openweather-current-summarybox {
  background: none;
  color: rgba(0, 0, 0, 0.8);
  -st-icon-style: symbolic;
}

.openweather-current-databox-values {
  background: none;
  color: rgba(0, 0, 0, 0.6);
}

.openweather-current-databox-captions {
  background: none;
  color: rgba(0, 0, 0, 0.48);
}

.openweather-forecast-icon, .openweather-forecast-summary {
  background: none;
  color: rgba(0, 0, 0, 0.6);
  -st-icon-style: symbolic;
}

.openweather-forecast-day {
  background: none;
  color: rgba(0, 0, 0, 0.8);
}

.openweather-forecast-temperature {
  background: none;
  color: rgba(0, 0, 0, 0.6);
}

.openweather-sunrise-icon, .openweather-sunset-icon, .openweather-build-icon {
  color: rgba(0, 0, 0, 0.6);
  -st-icon-style: symbolic;
}

.popup-menu .search-entry, .popup-menu .app-folder-dialog .folder-name-container .folder-name-entry, .app-folder-dialog .folder-name-container .popup-menu .folder-name-entry {
  color: rgba(0, 0, 0, 0.8);
  selection-background-color: #F0544C;
  selected-color: #FFFFFF;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
  box-shadow: none;
  text-shadow: none;
  border-image: none;
}

.popup-menu .search-entry:focus, .popup-menu .app-folder-dialog .folder-name-container .folder-name-entry:focus, .app-folder-dialog .folder-name-container .popup-menu .folder-name-entry:focus {
  border-color: transparent;
  border: 1px solid #F0544C;
  box-shadow: none;
  text-shadow: none;
  color: rgba(0, 0, 0, 0.8);
}

.popup-menu .search-entry .search-entry-icon, .popup-menu .app-folder-dialog .folder-name-container .folder-name-entry .search-entry-icon, .app-folder-dialog .folder-name-container .popup-menu .folder-name-entry .search-entry-icon {
  color: rgba(0, 0, 0, 0.48);
}

.popup-menu .search-entry:hover .search-entry-icon, .popup-menu .app-folder-dialog .folder-name-container .folder-name-entry:hover .search-entry-icon, .app-folder-dialog .folder-name-container .popup-menu .folder-name-entry:hover .search-entry-icon, .popup-menu .search-entry:focus .search-entry-icon, .popup-menu .app-folder-dialog .folder-name-container .folder-name-entry:focus .search-entry-icon, .app-folder-dialog .folder-name-container .popup-menu .folder-name-entry:focus .search-entry-icon {
  color: rgba(0, 0, 0, 0.8);
}
