// Dash to Dock

#dashtodockContainer {
  background: transparent;

  #dash,
  &:overview #dash,
  &.extended #dash,
  &.extended:overview #dash {
    padding: 0;
    border: none;
    margin: 0;
  }

  @each $_dock, $_radius in (top, 0 0 3px 3px),
                            (bottom, 3px 3px 0 0),
                            (left, 0 3px 3px 0),
                            (right, 3px 0 0 3px) {
    &.#{$_dock} #dash,
    &.#{$_dock}:overview #dash { border-radius: #{$_radius}; }

    &.#{$_dock}.extended #dash,
    &.#{$_dock}.extended:overview #dash { border-radius: #{$_radius}; }
  }

  #dash { // default-mode
    background-color: $bg_color;
    box-shadow: none;
  }

  &.opaque #dash { // solid-mode
    background-color: $topbar_color;
  }

  &.transparent #dash { // translucent-mode
    background-color: $osd_bg_color; // does not work
  }

  &:overview #dash { // overview-mode #1
    background-color: $overview_bg_color;
  }

  &.opaque:overview,
  &.transparent:overview { // overview-mode #2
    #dash {
      background-color: transparent !important;
      box-shadow: none !important;
    }
  }

  &.extended:overview, // overview-mode #3
  &.opaque.extended:overview,
  &.transparent.extended:overview {
    #dash {
      background-color: $topbar_color;
    }
  }

  .app-well-app,
  .show-apps {
    .overview-icon {
      padding: 8px;
      background-size: contain;
    }
  }
}

// Simple Dock

#dash:desktop {
  background-color: $bg_color;
}

//  OpenWeather Extension

.openweather {
  &-button,
  &-button-action,
  &-menu-button-container,
  &-button-box {
    border: 1px solid transparent;
    background: none;
  }

  &-provider {
    // generic text buttons are allocated with y-expand-ed
    padding: 0 16px;
    font-weight: 500;
    border: 1px solid transparent;
    @include button(normal);
    &:hover { @include button(hover); }
    &:focus { @include button(focus); }
    &:active { @include button(active); }
    &:insensitive { @include button(insensitive); }
  }

  &-current {
    &-icon,
    &-summary,
    &-summarybox {
      background: none;
      color: $fg_color;
      -st-icon-style: symbolic;
    }

    &-databox-values {
      background: none;
      color: $secondary_fg_color;
    }

    &-databox-captions {
      background: none;
      color: $tertiary_fg_color;
    }
  }

  &-forecast {
    &-icon,
    &-summary {
      background: none;
      color: $secondary_fg_color;
      -st-icon-style: symbolic;
    }

    &-day {
      background: none;
      color: $fg_color;
    }

    &-temperature {
      background: none;
      color: $secondary_fg_color;
    }
  }

  &-sunrise-icon,
  &-sunset-icon,
  &-build-icon {
    color: $secondary_fg_color;
    -st-icon-style: symbolic;
  }
}

// GPaste

.popup-menu {
  .search-entry {
    color: $fg_color;
    selection-background-color: $selected_bg_color;
    selected-color: $selected_fg_color;
    @include entry(normal);
    border-image: none;

    &:focus {
      @include entry(focus);
      color: $fg_color;
    }

    .search-entry-icon { color: $tertiary_fg_color; }

    &:hover, &:focus {
      .search-entry-icon { color: $fg_color; }
    }
  }
}
