/* Workspace pager */

// thumbnails in overview
.workspace-thumbnails {
  visible-width: 32px; //amount visible before hover
  spacing: $base_spacing;
  padding: $base_padding;

  .workspace-thumbnail {
    @extend %overview_panel;
    border-radius: $base_border_radius;
  }

  // drag and drop indicator
  .placeholder {
    background-image: url("resource:///org/gnome/shell/theme/dash-placeholder.svg");
    background-size: contain;
    width: 18px;
  }
}

// selected indicator
.workspace-thumbnail-indicator {
  border: 3px solid $selected_bg_color;
  border-radius: $base_border_radius;
  padding: 0px;
  // background-color: transparentize($selected_bg_color, 0.9);
}
