$variant: 'light';
$color: 'aliz';
$trans: 'true';
$header: 'light';

@import '../sass/colors';
@import '../sass/drawing';
@import '../sass/common-3.0';
@import '../sass/apps-3.0';
@import '../sass/granite';
@import '../sass/transparent-widgets';
@import '../sass/colors-public';
