@import "parts/buttons.css";
@import "parts/entries.css";
@import "parts/toolbox.css";
@import "parts/headerbar.css";
@import "parts/csd.css";
@import "parts/tabsbar.css";
@import "parts/findbar.css";
@import "parts/sidebar.css";
@import "parts/popups.css";
@import "parts/remove-white-flash.css";
@import "parts/icons.css";
@import "colors/light.css";
@import "colors/dark.css";
@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

/* Set theme version text in customization panel */
#customization-footer::before {
	content: "Firefox Qogir theme";
	padding: 9px;
}
