/* Window Picker */

$window_picker_spacing: $base_spacing; // 6px
$window_picker_padding: $base_padding * 2; // 12px

$window_thumbnail_label_color: transparentize($osd_bg_color, 0.4);

$window_close_button_size: 30px;
$window_close_button_padding: 3px;

// Window picker
.window-picker {
  // Space between window thumbnails
  spacing: $window_picker_spacing;
}

// Window titles
.window-caption {
  color: $osd_fg_color;
  background-color: $osd_bg_color;
  border-radius: $base_border_radius;
  padding: $base_padding $base_padding * 2;
}

// Close button
.window-close {
  background-color: $osd_bg_color;
  color: $osd_fg_color;
  border-radius: 1000px;
  padding: $window_close_button_padding;
  height: $window_close_button_size;
  width: $window_close_button_size;
  box-shadow: -1px 1px 5px 0px rgba(0,0,0,0.5);
  transition-duration: 300ms;
  background-image: url("assets/window-close-symbolic.svg");

  StIcon {
    color: white;
    icon-size: 1px; // Can't set to 0
  }

  &:hover {
    background-color: lighten($osd_bg_color, 15%);
  }

  &:active {
    color: transparentize($osd_fg_color, 0.2);
    background-color: darken($osd_bg_color, 5%);
  }
}

.workspace-background {
  // keep in sync with BACKGROUND_CORNER_RADIUS_PIXELS in workspace.js
  border-radius: 30px; // Don't change this !
  background-color: $osd_bg_color;
  box-shadow: 0 4px 16px 4px transparentize(darken($osd_bg_color, 30%), 0.7);
}
