/* GNOME CSD styles for headerbar on Firefox [tabsintitlebar] */

@namespace xul url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

#main-window {
	-moz-appearance: -moz-window-titlebar !important;
}

/* Headerbar top border corners rounded */
:root[tabsintitlebar]:not([inFullscreen]):not([sizemode="maximized"]) #nav-bar {
	border-radius: 2px 2px 0 0 !important;
}

/* Window buttons box */
:root[tabsintitlebar] #titlebar .titlebar-buttonbox-container,
:root[tabsintitlebar] #titlebar-buttonbox-container,
:root[tabsintitlebar][inFullscreen] #window-controls {
	-moz-appearance: none !important;
	padding: 0 6px;
	position: absolute !important;
	right: 0;
	top: 0;
	display: block !important;
}

:root[tabsintitlebar] #titlebar .titlebar-buttonbox {
	-moz-appearance: none !important;
}

/* Window buttons: at least 1 button */
@media (-moz-gtk-csd-minimize-button), (-moz-gtk-csd-maximize-button), (-moz-gtk-csd-close-button) {
	:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
		padding-right: 40px !important;
	}
}
/* Window buttons: at least 2 buttons */
@media (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-maximize-button),
       (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-close-button),
       (-moz-gtk-csd-maximize-button) and (-moz-gtk-csd-close-button) {
	:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
		padding-right: 80px !important;
	}
}
/* Window buttons: 3 buttons */
@media (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-maximize-button) and (-moz-gtk-csd-close-button) {
	:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
		padding-right: 120px !important;
	}
}

/* Left window buttons */
@media (-moz-gtk-csd-reversed-placement) {
	:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
		padding-right: 0 !important;
	}

	/* Window buttons box */
	:root[tabsintitlebar] #titlebar .titlebar-buttonbox-container {
		left: 0;
		right: auto;
	}

	/* Window controls: at least 1 button */
	@media (-moz-gtk-csd-minimize-button), (-moz-gtk-csd-maximize-button), (-moz-gtk-csd-close-button) {
		:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
			padding-left: 50px !important;
		}
	}
	/* Window controls: at least 2 buttons */
	@media (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-maximize-button),
				 (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-close-button),
				 (-moz-gtk-csd-maximize-button) and (-moz-gtk-csd-close-button) {
		:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
			padding-left: 90px !important;
		}
	}
	/* Window controls: 3 buttons */
	@media (-moz-gtk-csd-minimize-button) and (-moz-gtk-csd-maximize-button) and (-moz-gtk-csd-close-button) {
		:root[tabsintitlebar]:not([inFullscreen]) #nav-bar {
			padding-left: 130px !important;
		}
	}
}

/* Fullscreen headerbar padding for 1 button */
:root[tabsintitlebar][inFullscreen] #nav-bar {
	padding-right: 50px !important;
}

/* Remove close and minimize buttons from fullscreen buttons */
:root[tabsintitlebar][inFullscreen] #window-controls #close-button,
:root[tabsintitlebar][inFullscreen] #window-controls #minimize-button,
:root[tabsintitlebar][inFullscreen] #titlebar .titlebar-buttonbox-container {
	display: none !important;
}

/* Remove tabsbar titlebar blank spaces */
:root[tabsintitlebar] #TabsToolbar .titlebar-placeholder {
	display: none !important;
}

/* Prevent menubar from breaking */
:root[tabsintitlebar] #toolbar-menubar:not([inactive=true]) {
	height: 28px !important;
	margin-bottom: 3px;
}

/* Remove default style of titlebar */
:root[tabsintitlebar] #titlebar {
	-moz-appearance: none !important;
}

/* Fix the issue when dragging tabs */
:root[tabsintitlebar] #navigator-toolbox[movingtab] #TabsToolbar {
	padding-bottom: 0 !important;
}

/* Window buttons style */
:root[tabsintitlebar] #titlebar .titlebar-button,
:root[tabsintitlebar][inFullscreen] #window-controls toolbarbutton {
	-moz-appearance: none !important;
	border: none !important;
	border-radius: 100% !important;
	padding: 0 0 !important;
	transition: all .2s ease;
}

:root[tabsintitlebar] #titlebar .titlebar-button {
	height: 22px !important;
	width: 22px !important;
	margin: 8px 6px !important;
}

:root[tabsintitlebar] #titlebar .titlebar-min:hover,
:root[tabsintitlebar] #titlebar #titlebar-min:hover {
	background: var(--gnome-titlebutton-min-hover-background) !important;
}

:root[tabsintitlebar] #titlebar .titlebar-min:active,
:root[tabsintitlebar] #titlebar #titlebar-min:active {
	background: var(--gnome-titlebutton-min-active-background) !important;
}

:root[tabsintitlebar] #titlebar .titlebar-restore:hover,
:root[tabsintitlebar] #titlebar .titlebar-max:hover,
:root[tabsintitlebar] #titlebar #titlebar-max:hover {
	background: var(--gnome-titlebutton-max-hover-background) !important;
}

:root[tabsintitlebar] #titlebar .titlebar-restore:active,
:root[tabsintitlebar] #titlebar .titlebar-max:active,
:root[tabsintitlebar] #titlebar #titlebar-max:active {
	background: var(--gnome-titlebutton-max-active-background) !important;
}

:root[tabsintitlebar] #titlebar .titlebar-close:hover,
:root[tabsintitlebar] #titlebar #titlebar-close:hover {
	background: var(--gnome-titlebutton-close-hover-background) !important;
}

:root[tabsintitlebar] #titlebar .titlebar-close:active,
:root[tabsintitlebar] #titlebar #titlebar-close:active {
	background: var(--gnome-titlebutton-close-active-background) !important;
}

:root[tabsintitlebar] #titlebar:-moz-window-inactive .titlebar-button {
	opacity: .4 !important;
}

:root[tabsintitlebar][inFullscreen] #window-controls toolbarbutton {
	height: 28px !important;
	width: 28px !important;
	margin: 6px 6px !important;
}
