$variant: 'light';
$laptop: 'true';
$topbar: 'light';
$color: 'azul';

@import "../sass/40.0/colors";
@import "../sass/40.0/drawing";
@import "../sass/40.0/common";
@import "../sass/40.0/widgets-47";
@import "../sass/40.0/extensions";
