/* Looking Glass */

$text_fg_color: #ccc;

// Dialog
#LookingGlassDialog {
  background-color: $osd_bg_color;
  spacing: $base_spacing;
  padding: 4px;
  border: 1px solid transparentize($osd_fg_color, 0.8);
  border-radius: $base_border_radius;
  color: $osd_fg_color;

  & > #Toolbar {
    border: none;
    border-radius: $base_border_radius;
    background-color: $osd_bg_color;
  }

  .labels { spacing: $base_spacing; }
  .notebook-tab {
    -natural-hpadding: $base_padding * 2;
    -minimum-hpadding: 6px;
    font-weight: bold;
    color: darken($osd_fg_color, 15%);
    transition-duration: 100ms;
    padding-left: .3em;
    padding-right: .3em;
    border-bottom-width: 2px;
    &:hover {
      color: $osd_fg_color;
    }
    &:selected {
      border-bottom-width: 2px;
      box-shadow: inset 0 -2px 0 0 lighten($selected_bg_color, 5%);
      color: $osd_fg_color;
    }
  }
  StBoxLayout#EvalBox { padding: 4px; spacing: $base_spacing; }
  StBoxLayout#ResultsArea { spacing: $base_spacing; }
}

.lg-dialog {
  StEntry {
    background-color: transparentize(lighten($osd_bg_color, 5%), 0.4);
    color: $osd_fg_color;
    border-color: transparentize($osd_fg_color, 0.8);
    min-height: 22px;
    selection-background-color: $selected_bg_color;
    selected-color: $selected_fg_color;
  }
  .shell-link {
    color: $link_color;
    &:hover { color: lighten($link_color, 10%); }
    &:active { color: darken($link_color, 10%); }
   }
  .actor-link {
    color: $text_fg_color;
    &:hover { color: lighten($text_fg_color, 20%); }
    &:active { color: darken($text_fg_color, 20%); }
   }
}

.lg-completions-text {
    font-size: .9em;
    font-style: italic;
}

.lg-obj-inspector-title {
    spacing: $base_spacing;
}

.lg-obj-inspector-button {
    border: 1px solid $osd_borders_color;
    padding: 4px;
    border-radius: $base_border_radius;
    &:hover { border: 1px solid #ffffff; }
}

// Extensions
#lookingGlassExtensions { padding: 4px; }

.lg-extensions-list {
    padding: 4px;
    spacing: 6px;
}

.lg-extension {
    border: 1px solid lighten($osd_borders_color, 5%);
    background-color: lighten($osd_bg_color, 5%);
    border-radius: $base_border_radius;
    padding: 4px;
}

.lg-extension-name {
    font-weight: bold;
}

.lg-extension-meta {
    spacing: 6px;
}

// Inspector
#LookingGlassPropertyInspector {
  background: $osd_bg_color;
  border: 1px solid $osd_borders_color;
  border-radius: $base_border_radius;
  padding: 6px;
}
