@keyframes header_ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, #141a1b 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, #141a1b 100%, transparent 0%);
  }
}

@keyframes ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 100%, transparent 0%);
  }
}

.background {
  color: #ccd7d4;
  background-color: #1b2224;
}

.background.csd {
  border-radius: 2px;
}

.background:backdrop {
  text-shadow: none;
  -gtk-icon-shadow: none;
}

#desktopwindow.background {
  background-color: transparent;
  border: none;
}

dnd {
  color: #ccd7d4;
}

.normal-icons {
  -gtk-icon-size: 16px;
}

.large-icons {
  -gtk-icon-size: 32px;
}

spinner:disabled,
arrow:disabled,
scrollbar:disabled,
check:disabled,
radio:disabled,
treeview.expander:disabled {
  -gtk-icon-filter: opacity(0.5);
}

.view, iconview, textview > text {
  color: #abb9b6;
  background-color: #222b2e;
}

.view:hover, iconview:hover, textview > text:hover {
  color: #ccd7d4;
}

.view:selected:focus, .view:selected, iconview:selected:focus, textview > text:selected:focus, iconview:selected, textview > text:selected {
  border-radius: 2px;
}

.view:selected:hover, iconview:selected:hover, textview > text:selected:hover {
  background-color: rgba(63, 63, 63, 0.163);
}

textview:drop(active) {
  caret-color: #F08437;
}

textview border {
  background-color: #1f2729;
}

iconview {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

iconview:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

iconview:hover, iconview:active, iconview:selected {
  border-radius: 2px;
}

iconview:drop(active) {
  box-shadow: none;
}

iconview > dndtarget:drop(active) {
  border-style: solid;
  border-width: 1px;
  border-color: #196253;
}

rubberband, .content-view > rubberband, columnview.view > rubberband,
treeview.view > rubberband, gridview > rubberband, flowbox > rubberband {
  border: 1px solid #248a76;
  background-color: rgba(36, 138, 118, 0.2);
}

flowbox > flowboxchild {
  padding: 3px;
  border-radius: 2px;
}

flowbox > flowboxchild {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

flowbox > flowboxchild:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

flowbox > flowboxchild:selected {
  outline-color: rgba(255, 255, 255, 0.3);
}

gridview > child {
  padding: 3px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

gridview > child {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

gridview > child:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

gridview > child:selected {
  outline-color: rgba(255, 255, 255, 0.3);
}

gridview > child box {
  border-spacing: 8px;
  margin: 12px;
}

coverflow cover {
  color: #abb9b6;
  background-color: #222b2e;
  border: 1px solid black;
}

label {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

label:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

label > selection {
  color: #ffffff;
  background-color: #2eb398;
}

label:disabled {
  color: rgba(204, 215, 212, 0.45);
}

button label:disabled, entry label:disabled,
label:disabled row,
label:disabled headerbar {
  color: inherit;
}

label:disabled selection {
  color: #97d9cc;
}

label.error {
  color: #FC4138;
}

label.error:disabled {
  color: rgba(252, 65, 56, 0.5);
}

.dim-label, row label.subtitle, popover.background label.separator, headerbar .subtitle, spinbutton.vertical > text > text > placeholder, spinbutton:not(.vertical) > text > placeholder,
entry > text > placeholder, label.separator {
  opacity: 0.55;
  text-shadow: none;
}

window.assistant .sidebar {
  padding: 3px;
  background-color: #222b2e;
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

window.assistant.csd .sidebar {
  border-top-style: none;
}

window.assistant .sidebar > label {
  padding: 6px 12px;
}

window.assistant .sidebar > label.highlight {
  background-color: #2eb398;
  color: #ffffff;
  border-radius: 2px;
}

window.aboutdialog image.large-icons {
  -gtk-icon-size: 128px;
}

.osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents, .osd {
  color: #abb9b6;
  background-color: rgba(34, 43, 46, 0.95);
  border-radius: 3px;
}

.osd {
  border: none;
  padding: 6px;
  margin: 6px;
  box-shadow: 0 3px 8px rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.25);
}

.osd.circular {
  border-radius: 100%;
}

@keyframes spin {
  to {
    transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

.large-title {
  font-weight: 300;
  font-size: 24pt;
}

.title-1 {
  font-weight: 800;
  font-size: 20pt;
}

.title-2 {
  font-weight: 800;
  font-size: 15pt;
}

.title-3 {
  font-weight: 700;
  font-size: 15pt;
}

.title-4 {
  font-weight: 700;
  font-size: 13pt;
}

.heading, row.button .title, listview > header {
  font-weight: 700;
  font-size: 11pt;
}

.body {
  font-weight: 400;
  font-size: 11pt;
}

.caption-heading {
  font-weight: 700;
  font-size: 9pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
}

spinbutton.vertical > text, spinbutton:not(.vertical),
entry {
  min-height: 22px;
  border: 1px solid;
  padding: 2px 8px;
  caret-color: currentColor;
  border-radius: 3px;
  border-spacing: 3px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  background-clip: padding-box;
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #222b2e;
  outline: none;
}

spinbutton.vertical > text.search, spinbutton.search:not(.vertical),
entry.search {
  border-radius: 1000px;
}

spinbutton.vertical > text > image, spinbutton:not(.vertical) > image,
entry > image {
  color: #aab5b3;
}

spinbutton.vertical > text > image.left, spinbutton:not(.vertical) > image.left,
entry > image.left {
  margin-right: 6px;
}

spinbutton.vertical > text > image.right, spinbutton:not(.vertical) > image.right,
entry > image.right {
  margin-left: 6px;
}

spinbutton.vertical > text.flat, spinbutton.flat:not(.vertical),
entry.flat {
  min-height: 0;
  padding: 2px;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

spinbutton.vertical > text:focus-within, spinbutton:focus-within:not(.vertical),
entry:focus-within {
  background-clip: padding-box;
  color: #abb9b6;
  border-color: #2eb398;
  background-color: #222b2e;
  outline: none;
}

spinbutton.vertical > text:focus-within > placeholder, spinbutton:focus-within:not(.vertical) > placeholder,
entry:focus-within > placeholder {
  opacity: 0;
  /* We hide placeholders on focus */
}

spinbutton.vertical > text:disabled, spinbutton:disabled:not(.vertical),
entry:disabled {
  color: rgba(204, 215, 212, 0.45);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(34, 43, 46, 0.55);
}

spinbutton.vertical > text.warning, spinbutton.warning:not(.vertical),
entry.warning {
  color: white;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #9f5932;
}

spinbutton.vertical > text.warning, spinbutton.warning:not(.vertical),
entry.warning {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton.vertical > text.warning:focus-within, spinbutton.warning:focus-within:not(.vertical),
entry.warning:focus-within {
  outline-color: rgba(242, 120, 53, 0.5);
  outline-width: 2px;
  outline-offset: -2px;
}

spinbutton.vertical > text.warning > image, spinbutton.warning:not(.vertical) > image,
entry.warning > image {
  color: white;
}

spinbutton.vertical > text.warning:focus-within, spinbutton.warning:focus-within:not(.vertical),
entry.warning:focus-within {
  color: white;
  background-color: #F27835;
  box-shadow: none;
}

spinbutton.vertical > text.warning > selection, spinbutton.warning:not(.vertical) > selection,
entry.warning > selection {
  background-color: white;
  color: #F27835;
}

spinbutton.vertical > text.error, spinbutton.error:not(.vertical),
entry.error {
  color: white;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #a53834;
}

spinbutton.vertical > text.error, spinbutton.error:not(.vertical),
entry.error {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton.vertical > text.error:focus-within, spinbutton.error:focus-within:not(.vertical),
entry.error:focus-within {
  outline-color: rgba(252, 65, 56, 0.5);
  outline-width: 2px;
  outline-offset: -2px;
}

spinbutton.vertical > text.error > image, spinbutton.error:not(.vertical) > image,
entry.error > image {
  color: white;
}

spinbutton.vertical > text.error:focus-within, spinbutton.error:focus-within:not(.vertical),
entry.error:focus-within {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

spinbutton.vertical > text.error > selection, spinbutton.error:not(.vertical) > selection,
entry.error > selection {
  background-color: white;
  color: #FC4138;
}

spinbutton.vertical > text.success, spinbutton.success:not(.vertical),
entry.success {
  color: white;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #297d6e;
}

spinbutton.vertical > text.success, spinbutton.success:not(.vertical),
entry.success {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton.vertical > text.success:focus-within, spinbutton.success:focus-within:not(.vertical),
entry.success:focus-within {
  outline-color: rgba(46, 179, 152, 0.5);
  outline-width: 2px;
  outline-offset: -2px;
}

spinbutton.vertical > text.success > image, spinbutton.success:not(.vertical) > image,
entry.success > image {
  color: white;
}

spinbutton.vertical > text.success:focus-within, spinbutton.success:focus-within:not(.vertical),
entry.success:focus-within {
  color: white;
  background-color: #2eb398;
  box-shadow: none;
}

spinbutton.vertical > text.success > selection, spinbutton.success:not(.vertical) > selection,
entry.success > selection {
  background-color: white;
  color: #2eb398;
}

spinbutton.vertical > text.search-missing, spinbutton.search-missing:not(.vertical),
entry.search-missing {
  color: white;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #a53834;
}

spinbutton.vertical > text.search-missing, spinbutton.search-missing:not(.vertical),
entry.search-missing {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

spinbutton.vertical > text.search-missing:focus-within, spinbutton.search-missing:focus-within:not(.vertical),
entry.search-missing:focus-within {
  outline-color: rgba(252, 65, 56, 0.5);
  outline-width: 2px;
  outline-offset: -2px;
}

spinbutton.vertical > text.search-missing > image, spinbutton.search-missing:not(.vertical) > image,
entry.search-missing > image {
  color: white;
}

spinbutton.vertical > text.search-missing:focus-within, spinbutton.search-missing:focus-within:not(.vertical),
entry.search-missing:focus-within {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

spinbutton.vertical > text.search-missing > selection, spinbutton.search-missing:not(.vertical) > selection,
entry.search-missing > selection {
  background-color: white;
  color: #FC4138;
}

spinbutton.vertical > text > image, spinbutton:not(.vertical) > image,
entry > image {
  color: #aab5b3;
}

spinbutton.vertical > text > image:hover, spinbutton:not(.vertical) > image:hover,
entry > image:hover {
  color: #ccd7d4;
}

spinbutton.vertical > text > image:active, spinbutton:not(.vertical) > image:active,
entry > image:active {
  color: #2eb398;
}

spinbutton.vertical > text.password image.caps-lock-indicator, spinbutton.password:not(.vertical) image.caps-lock-indicator,
entry.password image.caps-lock-indicator {
  color: rgba(125, 135, 135, 0.56);
}

spinbutton.vertical > text:drop(active), spinbutton:drop(active):not(.vertical),
entry:drop(active):focus-within,
entry:drop(active) {
  border-color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
}

.osd spinbutton.vertical > text, .osd spinbutton:not(.vertical), .osd entry {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.95);
}

.osd spinbutton.vertical > text image, .osd spinbutton:not(.vertical) image, .osd entry image {
  color: inherit;
}

.osd spinbutton.vertical > text:focus-within, .osd spinbutton:focus-within:not(.vertical), .osd entry:focus-within {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

.osd spinbutton.vertical > text:disabled, .osd spinbutton:disabled:not(.vertical), .osd entry:disabled {
  color: rgba(171, 185, 182, 0.55);
  background-color: rgba(41, 51, 55, 0.85);
}

spinbutton.vertical > text > progress, spinbutton:not(.vertical) > progress,
entry > progress {
  margin-bottom: 2px;
}

spinbutton.vertical > text progress > trough > progress, spinbutton:not(.vertical) progress > trough > progress,
entry progress > trough > progress {
  background-color: transparent;
  background-image: none;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #2eb398;
  border-style: solid;
  box-shadow: none;
}

spinbutton.vertical.linked:not(.vertical) > text:drop(active) + text, spinbutton.vertical.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + text, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), spinbutton.vertical.linked:not(.vertical) > text:drop(active) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + menubutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + menubutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + dropdown > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + dropdown > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + colorbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + colorbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + fontbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + fontbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + filechooserbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + filechooserbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + entry, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + entry, .linked:not(.vertical) > entry:drop(active) + button, .linked:not(.vertical) > entry:drop(active) + menubutton > button, .linked:not(.vertical) > entry:drop(active) + dropdown > button, .linked:not(.vertical) > entry:drop(active) + colorbutton > button, .linked:not(.vertical) > entry:drop(active) + fontbutton > button, .linked:not(.vertical) > entry:drop(active) + filechooserbutton > button, .linked:not(.vertical) > entry:drop(active) + combobox > box > button.combo, spinbutton.vertical.linked:not(.vertical) > entry:drop(active) + text, .linked:not(.vertical) > entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > entry:drop(active) + entry {
  border-left-color: #F08437;
}

spinbutton.vertical.linked > text:not(:disabled) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), spinbutton.vertical.linked > text:not(:disabled) + text:not(:disabled), spinbutton.vertical.linked > spinbutton:not(:disabled):not(.vertical) + text:not(:disabled), spinbutton.vertical.linked > text:not(:disabled) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled), spinbutton.vertical.linked > entry:not(:disabled) + text:not(:disabled), .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) {
  border-top-color: rgba(32, 41, 43, 0.775);
}

spinbutton.vertical.linked > text:disabled + text:disabled, spinbutton.vertical.linked > spinbutton:disabled:not(.vertical) + text:disabled, spinbutton.vertical.linked > text:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), spinbutton.vertical.linked > text:disabled + entry:disabled, .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, spinbutton.vertical.linked > entry:disabled + text:disabled, .linked.vertical > entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > entry:disabled + entry:disabled {
  border-top-color: rgba(32, 41, 43, 0.775);
}

spinbutton.vertical.linked > text + text:drop(active):not(:only-child), spinbutton.vertical.linked > spinbutton:not(.vertical) + text:drop(active):not(:only-child), spinbutton.vertical.linked > text + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical),
spinbutton.vertical.linked > text + entry:drop(active):not(:only-child),
.linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), spinbutton.vertical.linked > entry + text:drop(active):not(:only-child), .linked.vertical > entry + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical > entry + entry:drop(active):not(:only-child) {
  border-top-color: #F08437;
}

spinbutton.vertical.linked > text:drop(active):not(:only-child) + text, spinbutton.vertical.linked > spinbutton:drop(active):not(:only-child):not(.vertical) + text, spinbutton.vertical.linked > text:drop(active):not(:only-child) + spinbutton:not(.vertical), .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical),
spinbutton.vertical.linked > text:drop(active):not(:only-child) + entry,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + menubutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + menubutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + dropdown > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + dropdown > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + colorbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + colorbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + fontbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + fontbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + filechooserbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + filechooserbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + combobox > box > button.combo,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, spinbutton.vertical.linked > entry:drop(active):not(:only-child) + text, .linked.vertical > entry:drop(active):not(:only-child) + spinbutton:not(.vertical),
.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + menubutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + dropdown > button,
.linked.vertical > entry:drop(active):not(:only-child) + colorbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + fontbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + filechooserbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #F08437;
}

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) {
  background-color: #222b2e;
  transition-property: color, background;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #222b2e;
}

treeview entry.flat:focus-within, treeview entry:focus-within {
  border-color: #2eb398;
}

editablelabel > stack > text {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #222b2e;
  outline: none;
}

@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #59d4bb 0%, rgba(89, 212, 187, 0) 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #59d4bb 95%, rgba(89, 212, 187, 0));
  }
}

button {
  border-width: 1px;
  border-style: solid;
  color: #ccd7d4;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #263034;
}

button {
  background-clip: padding-box;
}

button:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

button:active, button.keyboard-activating, button:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

button:disabled {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(38, 48, 52, 0.55);
}

button:disabled label, button:disabled {
  color: rgba(204, 215, 212, 0.45);
}

button:disabled:active, button:disabled:checked {
  border-color: rgba(46, 179, 152, 0.75);
  background-color: rgba(46, 179, 152, 0.75);
  opacity: 0.6;
}

button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

toggle-group > toggle, splitbutton.flat > button,
splitbutton.flat > menubutton > button, menubutton.flat > button, placessidebar .navigation-sidebar > row button.sidebar-button, button.flat {
  border-width: 1px;
  border-style: solid;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

toggle-group > toggle, splitbutton.flat > button,
splitbutton.flat > menubutton > button, menubutton.flat > button, placessidebar .navigation-sidebar > row button.sidebar-button, button.flat {
  background-clip: padding-box;
}

toggle-group > toggle:hover, splitbutton.flat > button:hover,
splitbutton.flat > menubutton > button:hover, menubutton.flat > button:hover, placessidebar .navigation-sidebar > row button.sidebar-button:hover, button.flat:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

toggle-group > toggle:active, splitbutton.flat > button:active,
splitbutton.flat > menubutton > button:active, menubutton.flat > button:active, placessidebar .navigation-sidebar > row button.sidebar-button:active, button.flat:active, toggle-group > toggle:checked, splitbutton.flat > button:checked,
splitbutton.flat > menubutton > button:checked, menubutton.flat > button:checked, placessidebar .navigation-sidebar > row button.sidebar-button:checked, button.flat:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

toggle-group > toggle:disabled, splitbutton.flat > button:disabled,
splitbutton.flat > menubutton > button:disabled, menubutton.flat > button:disabled, placessidebar .navigation-sidebar > row button.sidebar-button:disabled, button.flat:disabled {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(38, 48, 52, 0.55);
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

toggle-group > toggle:disabled label, splitbutton.flat > button:disabled label, menubutton.flat > button:disabled label, placessidebar .navigation-sidebar > row button.sidebar-button:disabled label, button.flat:disabled label, toggle-group > toggle:disabled, splitbutton.flat > button:disabled,
splitbutton.flat > menubutton > button:disabled, menubutton.flat > button:disabled, placessidebar .navigation-sidebar > row button.sidebar-button:disabled, button.flat:disabled {
  color: rgba(204, 215, 212, 0.45);
}

button {
  min-height: 22px;
  min-width: 20px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-radius: 3px;
  padding: 2px 6px;
}

button {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

button:hover {
  -gtk-icon-filter: brightness(1.2);
}

button:active, button:checked {
  transition-duration: 50ms;
}

button:active:not(:disabled) label:disabled, button:checked:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

button.flat {
  transition: none;
}

button.flat:hover, button.flat:active, button.flat:checked {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button.flat:hover {
  transition-duration: 350ms;
}

button.image-button {
  min-width: 24px;
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

button.text-button.image-button {
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button.image-button label:first-child {
  padding-left: 8px;
  padding-right: 2px;
}

button.text-button.image-button label:last-child {
  padding-right: 8px;
  padding-left: 2px;
}

button.text-button.image-button label:only-child {
  padding-left: 8px;
  padding-right: 8px;
}

button.text-button.image-button.popup {
  padding-right: 8px;
  padding-left: 8px;
}

dropdown:drop(active) button.combo,
combobox:drop(active) button.combo, button:drop(active) {
  color: #F08437;
  border-color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
}

button.osd {
  color: #abb9b6;
  background-color: rgba(34, 43, 46, 0.95);
  border-color: rgba(17, 21, 23, 0.95);
  box-shadow: none;
}

button.osd.image-button {
  padding: 0;
  min-height: 36px;
  min-width: 36px;
}

button.osd:hover {
  color: #2eb398;
}

button.osd:active, button.osd:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

button.osd:disabled {
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.85);
}

menubutton.osd > button, popover.background.touch-selection button, popover.background.magnifier button, .osd button {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.95);
  box-shadow: none;
}

popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .osd button:hover {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(171, 185, 182, 0.1);
}

popover.background.touch-selection button:active, popover.background.magnifier button:active, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .osd button:active, .osd button:checked {
  background-clip: padding-box;
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .osd button:disabled {
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.85);
}

popover.background.touch-selection button.flat, popover.background.magnifier button.flat, .osd button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover, .osd button.flat:hover {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(171, 185, 182, 0.1);
}

popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled, .osd button.flat:disabled {
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.85);
  background-image: none;
}

popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked, .osd button.flat:active, .osd button.flat:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child), .osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
  box-shadow: none;
}

button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #2eb398;
  border-color: #2eb398;
}

button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #2eb398;
}

button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #33c7a9;
  border-color: #33c7a9;
}

button.suggested-action:active, button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #45cfb3;
  border-color: #45cfb3;
}

button.suggested-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(204, 215, 212, 0.45);
}

button.suggested-action:disabled {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(38, 48, 52, 0.55);
}

button.suggested-action:disabled label, button.suggested-action:disabled {
  color: rgba(204, 215, 212, 0.45);
}

button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #db5b5b;
}

button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #e07070;
  border-color: #e07070;
}

button.destructive-action:active, button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #e48585;
  border-color: #e48585;
}

button.destructive-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(204, 215, 212, 0.45);
}

button.destructive-action:disabled {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(38, 48, 52, 0.55);
}

button.destructive-action:disabled label, button.destructive-action:disabled {
  color: rgba(204, 215, 212, 0.45);
}

stackswitcher > button {
  outline-offset: -3px;
}

stackswitcher > button > label {
  padding-left: 6px;
  padding-right: 6px;
}

stackswitcher > button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px;
}

stackswitcher > button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

stackswitcher > button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

stackswitcher > button.needs-attention:active > label, stackswitcher > button.needs-attention:active > image, stackswitcher > button.needs-attention:checked > label, stackswitcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button.font separator, button.file separator {
  background-color: transparent;
}

button.font > box, button.file > box {
  border-spacing: 6px;
}

button.font > box > box > label, button.file > box > box > label {
  font-weight: bold;
}

menubutton.circular > button,
button.circular {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
  border-radius: 1000px;
}

menubutton.circular > button label,
button.circular label {
  padding: 0;
}

stacksidebar row.needs-attention > label, stackswitcher > button.needs-attention > label, stackswitcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #59d4bb 96%, rgba(89, 212, 187, 0));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 2px;
}

stacksidebar row.needs-attention > label:backdrop, stackswitcher > button.needs-attention > label:backdrop, stackswitcher > button.needs-attention > image:backdrop {
  background-size: 6px 6px, 0 0;
}

stacksidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px, left 2px;
}

.linked:not(.vertical) > button:dir(ltr):not(:first-child), .linked:not(.vertical) > button:dir(rtl):not(:last-child) {
  margin-left: 0;
}

.linked.vertical button:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > menubutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > menubutton:dir(rtl):not(:last-child) > button {
  margin-left: 0;
}

.linked.vertical menubutton:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > dropdown:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > dropdown:dir(rtl):not(:last-child) > button {
  margin-left: 0;
}

.linked.vertical dropdown:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > colorbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > colorbutton:dir(rtl):not(:last-child) > button {
  margin-left: 0;
}

.linked.vertical colorbutton:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > fontbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > fontbutton:dir(rtl):not(:last-child) > button {
  margin-left: 0;
}

.linked.vertical fontbutton:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > tabbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > tabbutton:dir(rtl):not(:last-child) > button {
  margin-left: 0;
}

.linked.vertical tabbutton:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical) > entry:dir(ltr):not(:first-child), .linked:not(.vertical) > entry:dir(rtl):not(:last-child) {
  margin-left: 0;
}

.linked.vertical entry:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  margin-top: 0;
}

.linked:not(.vertical):not(.path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > entry.error + entry,
.linked:not(.vertical):not(.path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar) > entry.warning + entry,
.linked:not(.vertical):not(.path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar) > entry.error + entry.warning,
.linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:last-child {
  border-left-color: #2eb398;
}

.linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #2eb398;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > button:active + entry,
.linked:not(.vertical):not(.path-bar) > button:checked + entry {
  border-left-color: #2eb398;
}

.linked:not(.vertical):not(.path-bar) > button + button {
  border-left-style: none;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.linked:not(.vertical):not(.path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked:not(.vertical):not(.path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button + button {
  border-left-style: none;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
  box-shadow: none;
}

.osd .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
  margin-left: 0;
}

.osd .linked:not(.vertical) > entry.error + entry,
.osd .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.warning + entry,
.osd .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.error + entry.warning,
.osd .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.osd .linked:not(.vertical) > entry + entry:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry:focus-within:last-child {
  border-left-color: #2eb398;
}

.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #2eb398;
  margin-left: 0;
}

.osd .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.osd .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
  margin-left: 0;
}

.osd .linked:not(.vertical) > entry + entry.warning:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
  margin-left: 0;
}

.osd .linked:not(.vertical) > entry + entry.error:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
  margin-left: 0;
}

.osd .linked:not(.vertical) > button:active + entry,
.osd .linked:not(.vertical) > button:checked + entry {
  border-left-color: #2eb398;
}

.osd .linked:not(.vertical) > button + button {
  border-left-style: none;
  margin-left: 0;
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

.linked.vertical > entry + entry {
  border-top-color: rgba(0, 0, 0, 0.3);
  margin-left: 0;
}

.linked.vertical > entry.error + entry,
.linked.vertical > entry + entry.error {
  border-top-color: #FC4138;
}

.linked.vertical > entry.warning + entry,
.linked.vertical > entry + entry.warning {
  border-top-color: #F27835;
}

.linked.vertical > entry.error + entry.warning,
.linked.vertical > entry.warning + entry.error {
  border-top-color: #f75d37;
}

.linked.vertical > entry + entry:focus-within:not(:last-child),
.linked.vertical > entry + entry:focus-within:last-child {
  border-top-color: #2eb398;
}

.linked.vertical > entry:focus-within:not(:only-child) + entry,
.linked.vertical > entry:focus-within:not(:only-child) + button,
.linked.vertical > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #2eb398;
  margin-left: 0;
}

.linked.vertical > entry + entry:drop(active):not(:last-child),
.linked.vertical > entry + entry:drop(active):last-child {
  border-top-color: #F08437;
}

.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #F08437;
  margin-left: 0;
}

.linked.vertical > entry + entry.warning:focus-within:not(:last-child),
.linked.vertical > entry + entry.warning:focus-within:last-child {
  border-top-color: #F27835;
}

.linked.vertical > entry.warning:focus-within:not(:only-child) + entry,
.linked.vertical > entry.warning:focus-within:not(:only-child) + button,
.linked.vertical > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #F27835;
  margin-left: 0;
}

.linked.vertical > entry + entry.error:focus-within:not(:last-child),
.linked.vertical > entry + entry.error:focus-within:last-child {
  border-top-color: #FC4138;
}

.linked.vertical > entry.error:focus-within:not(:only-child) + entry,
.linked.vertical > entry.error:focus-within:not(:only-child) + button,
.linked.vertical > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #FC4138;
  margin-left: 0;
}

.linked.vertical > button:active + entry,
.linked.vertical > button:checked + entry {
  border-top-color: #2eb398;
}

.linked.vertical > button + button {
  border-top-style: none;
  margin-left: 0;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.25);
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.25);
}

.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry,
headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry,
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error,
headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry,
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error, .titlebar .linked:not(.vertical):not(.path-bar) > entry + entry,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.error + entry,
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.error,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.warning + entry,
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.warning,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:last-child, .titlebar .linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry:focus-within:last-child {
  border-left-color: #2eb398;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child, .titlebar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:last-child, .titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:last-child, .titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > button:active + entry,
headerbar .linked:not(.vertical):not(.path-bar) > button:checked + entry, .titlebar .linked:not(.vertical):not(.path-bar) > button:active + entry,
.titlebar .linked:not(.vertical):not(.path-bar) > button:checked + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > button + button, .titlebar .linked:not(.vertical):not(.path-bar) > button + button {
  border-left-style: solid;
}

headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action), .titlebar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.titlebar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover), .titlebar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.titlebar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: none;
}

.linked:not(.vertical) > dropdown > box > button.combo:dir(ltr), .linked:not(.vertical) > dropdown > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl), spinbutton.vertical.linked:not(.vertical) > text, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .linked:not(.vertical) > button {
  border-radius: 0;
  border-right-style: none;
  background-clip: padding-box;
}

spinbutton.vertical.linked:not(.vertical) > text:first-child, .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, .linked:not(.vertical) > button:first-child {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

spinbutton.vertical.linked:not(.vertical) > text:last-child, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, .linked:not(.vertical) > button:last-child {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

spinbutton.vertical.linked:not(.vertical) > text:only-child, .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .linked:not(.vertical) > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

spinbutton.vertical.linked > text, .linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .linked.vertical > button {
  border-radius: 0;
  border-bottom-style: none;
}

spinbutton.vertical.linked > text:first-child, .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .linked.vertical > button:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

spinbutton.vertical.linked > text:last-child, .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .linked.vertical > button:last-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

spinbutton.vertical.linked > text:only-child, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .linked.vertical > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

tabbar tab button.image-button:active,
dnd tab button.image-button:active, tabbar tab button.image-button:hover,
dnd tab button.image-button:hover, .app-notification button.flat, notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover, notebook > header > tabs > tab button.flat:hover, button.link, button.link:hover, button.link:active, button.link:checked, popover.menu box.circular-buttons button.circular.image-button.model,
list > row button.image-button:not(.flat), modelbutton.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.linked:not(.vertical) > filechooserbutton > combobox:dir(rtl):not(:last-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(rtl):not(:last-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(rtl):not(:last-child) > box > button.combo, .linked:not(.vertical) > filechooserbutton > combobox:dir(ltr):not(:first-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(ltr):not(:first-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(ltr):not(:first-child) > box > button.combo, .linked:not(.vertical) > menubutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > dropdown:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > colorbutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > fontbutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(rtl):not(:last-child) > button, .linked:not(.vertical) > menubutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > dropdown:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > colorbutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > fontbutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(ltr):not(:first-child) > button {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.linked:not(.vertical) > filechooserbutton > combobox:dir(rtl):not(:first-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(rtl):not(:first-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(rtl):not(:first-child) > box > button.combo, .linked:not(.vertical) > filechooserbutton > combobox:dir(ltr):not(:last-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(ltr):not(:last-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(ltr):not(:last-child) > box > button.combo, .linked:not(.vertical) > menubutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > dropdown:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > colorbutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > fontbutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(rtl):not(:first-child) > button, .linked:not(.vertical) > menubutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > dropdown:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > colorbutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > fontbutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(ltr):not(:last-child) > button {
  border-right-style: none;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.linked.vertical > filechooserbutton > combobox:not(:first-child) > box > button.combo,
.linked.vertical > appchooserbutton > combobox:not(:first-child) > box > button.combo,
.linked.vertical > combobox:not(:first-child) > box > button.combo, .linked.vertical > menubutton:not(:first-child) > button,
.linked.vertical > dropdown:not(:first-child) > button,
.linked.vertical > colorbutton:not(:first-child) > button,
.linked.vertical > fontbutton:not(:first-child) > button,
.linked.vertical > filechooserbutton:not(:first-child) > button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.linked.vertical > filechooserbutton > combobox:not(:last-child) > box > button.combo,
.linked.vertical > appchooserbutton > combobox:not(:last-child) > box > button.combo,
.linked.vertical > combobox:not(:last-child) > box > button.combo, .linked.vertical > menubutton:not(:last-child) > button,
.linked.vertical > dropdown:not(:last-child) > button,
.linked.vertical > colorbutton:not(:last-child) > button,
.linked.vertical > fontbutton:not(:last-child) > button,
.linked.vertical > filechooserbutton:not(:last-child) > button {
  border-bottom-style: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

modelbutton.flat {
  min-height: 24px;
  padding-left: 6px;
  padding-right: 6px;
  outline-offset: -3px;
  border-radius: 2px;
}

modelbutton.flat:hover {
  background-color: rgba(255, 255, 255, 0.07);
  color: #ccd7d4;
}

modelbutton.flat:active {
  color: #ccd7d4;
  background-color: rgba(255, 255, 255, 0.12);
}

modelbutton.flat:disabled {
  color: rgba(204, 215, 212, 0.45);
}

modelbutton.flat arrow {
  background: none;
  min-width: 16px;
  min-height: 16px;
  opacity: 0.3;
}

modelbutton.flat arrow:hover, modelbutton.flat arrow:selected, modelbutton.flat arrow:focus {
  background: none;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("go-previous-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("go-next-symbolic");
}

/* list buttons */
/* tone down as per new designs, see issue #1473 */
popover.menu box.circular-buttons button.circular.image-button.model,
list > row button.image-button:not(.flat) {
  border: 1px solid rgba(0, 0, 0, 0);
}

popover.menu box.circular-buttons button.circular.image-button.model:hover,
list > row button.image-button:not(.flat):hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

popover.menu box.circular-buttons button.circular.image-button.model:active, popover.menu box.circular-buttons button.circular.image-button.model:checked,
list > row button.image-button:not(.flat):active,
list > row button.image-button:not(.flat):checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

popover.menu box.circular-buttons button.suggested-action.circular.image-button.model,
list > row button.image-button:not(.flat).suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #2eb398;
  border-color: #2eb398;
}

popover.menu box.circular-buttons button.suggested-action.circular.image-button.model,
list > row button.image-button:not(.flat).suggested-action {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

popover.menu box.circular-buttons button.suggested-action.circular.image-button.model:focus:focus-visible,
list > row button.image-button:not(.flat).suggested-action:focus:focus-visible {
  outline-color: rgba(255, 255, 255, 0.3);
  outline-width: 2px;
  outline-offset: -2px;
}

popover.menu box.circular-buttons button.destructive-action.circular.image-button.model,
list > row button.image-button:not(.flat).destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

popover.menu box.circular-buttons button.destructive-action.circular.image-button.model,
list > row button.image-button:not(.flat).destructive-action {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

popover.menu box.circular-buttons button.destructive-action.circular.image-button.model:focus:focus-visible,
list > row button.image-button:not(.flat).destructive-action:focus:focus-visible {
  outline-color: rgba(255, 255, 255, 0.3);
  outline-width: 2px;
  outline-offset: -2px;
}

infobar.info > revealer > box *:link, infobar.info:hover > revealer > box *:link, infobar.info:backdrop > revealer > box *:link, infobar.question > revealer > box *:link, infobar.question:hover > revealer > box *:link, infobar.question:backdrop > revealer > box *:link, infobar.warning > revealer > box *:link, infobar.warning:hover > revealer > box *:link, infobar.warning:backdrop > revealer > box *:link, infobar.error > revealer > box *:link, infobar.error:hover > revealer > box *:link, infobar.error:backdrop > revealer > box *:link, headerbar.selection-mode .subtitle:link, link:selected, *:selected link, button.link:selected, *:selected button.link {
  color: #d5f0ea;
}

link, button.link {
  color: #6ddac4;
  text-decoration: underline;
}

link:visited, button.link:visited {
  color: #c7d0ce;
}

*:selected link:visited, *:selected button.link:visited {
  color: #abe1d6;
}

link:hover, button.link:hover {
  color: #96e4d4;
}

*:selected link:hover, *:selected button.link:hover {
  color: #eaf7f5;
}

link:active, button.link:active {
  color: #6ddac4;
}

*:selected link:active, *:selected button.link:active {
  color: #d5f0ea;
}

link {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

link:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

button.link, button.link:hover, button.link:active, button.link:checked {
  text-shadow: none;
}

button.link > label {
  text-decoration: underline;
}

.osd spinbutton:not(.vertical) > text, spinbutton:not(.vertical) > text {
  min-width: 28px;
  background: none;
  border: none;
  box-shadow: none;
  border-radius: 0;
  padding: 6px;
  margin: 0;
}

spinbutton {
  font-feature-settings: "tnum";
}

spinbutton:not(.vertical) {
  padding: 0;
  border-spacing: 0;
  outline: none;
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat),
spinbutton:not(.vertical) > button.image-button.down:not(.flat) {
  min-height: 16px;
  margin: 0;
  padding-bottom: 0;
  padding-top: 0;
  color: #bbc6c3;
  background-image: none;
  border-style: none none none solid;
  border-color: rgba(0, 0, 0, 0.25);
  border-radius: 0;
  box-shadow: none;
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl),
spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl) {
  border-style: none solid none none;
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):hover,
spinbutton:not(.vertical) > button.image-button.down:not(.flat):hover {
  color: #ccd7d4;
  background-color: rgba(204, 215, 212, 0.1);
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):disabled,
spinbutton:not(.vertical) > button.image-button.down:not(.flat):disabled {
  color: rgba(204, 215, 212, 0);
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.15);
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):active,
spinbutton:not(.vertical) > button.image-button.down:not(.flat):active {
  background-color: rgba(204, 215, 212, 0.2);
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(ltr):last-child,
spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(ltr):last-child {
  border-radius: 0 2px 2px 0;
}

spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl):first-child,
spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl):first-child {
  border-radius: 2px 0 0 2px;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat),
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat) {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #abb9b6;
  border-style: none none none solid;
  border-color: rgba(0, 0, 0, 0);
  border-radius: 0;
  box-shadow: none;
  -gtk-icon-shadow: 0 1px black;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl),
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl) {
  border-style: none solid none none;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):hover,
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):hover {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.5);
  background-color: rgba(12, 16, 17, 0.95);
  -gtk-icon-shadow: 0 1px black;
  box-shadow: none;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):disabled,
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.5);
  -gtk-icon-shadow: none;
  box-shadow: none;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(ltr):last-child,
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(ltr):last-child {
  border-radius: 0 2px 2px 0;
}

.osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl):first-child,
.osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl):first-child {
  border-radius: 2px 0 0 2px;
}

spinbutton.vertical {
  outline: none;
}

spinbutton.vertical:disabled {
  color: rgba(204, 215, 212, 0.45);
}

spinbutton.vertical:drop(active) {
  border-color: transparent;
  box-shadow: none;
}

spinbutton.vertical > text {
  min-height: 32px;
  min-width: 32px;
  padding: 0;
  border-radius: 0;
}

spinbutton.vertical > text > block-cursor {
  color: #222b2e;
  background-color: #abb9b6;
}

spinbutton.vertical > button {
  min-height: 32px;
  min-width: 32px;
  padding: 0;
}

spinbutton.vertical > button.up {
  border-bottom-style: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

spinbutton.vertical > button.down {
  border-top-style: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.osd spinbutton.vertical > button:first-child {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.95);
}

.osd spinbutton.vertical > button:first-child:hover {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(171, 185, 182, 0.1);
}

.osd spinbutton.vertical > button:first-child:active {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

.osd spinbutton.vertical > button:first-child:disabled {
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.85);
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) > text {
  min-height: 0;
  padding: 1px 2px;
}

dropdown > popover.menu.background > contents {
  padding: 0;
}

dropdown > button > box {
  border-spacing: 6px;
}

dropdown button.combo,
combobox button.combo {
  min-width: 0;
  padding-left: 8px;
  padding-right: 8px;
}

dropdown arrow,
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

dropdown > popover.menu > contents modelbutton,
combobox > popover.menu > contents modelbutton {
  padding-left: 9px;
  padding-right: 9px;
}

dropdown:drop(active),
combobox:drop(active) {
  box-shadow: none;
}

dropdown popover,
combobox popover {
  margin-top: 4px;
  padding: 0;
}

dropdown popover listview,
combobox popover listview {
  margin: 0;
  padding: 0;
}

dropdown popover listview > row,
combobox popover listview > row {
  padding: 6px;
  border-radius: 2px;
}

dropdown popover listview > row + row,
combobox popover listview > row + row {
  margin-top: 2px;
}

dropdown popover listview > row:selected,
combobox popover listview > row:selected {
  outline: none;
  color: #abb9b6;
  background-color: rgba(255, 255, 255, 0.07);
}

dropdown popover .dropdown-searchbar,
combobox popover .dropdown-searchbar {
  padding: 6px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

.linked:not(.vertical) > dropdown:first-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.linked:not(.vertical) > dropdown:last-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.linked:not(.vertical) > dropdown:only-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

.linked.vertical > dropdown:first-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

.linked.vertical > dropdown:last-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

.linked.vertical > dropdown:only-child > box > button.combo, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

toolbar {
  padding: 6px;
  border-spacing: 6px;
  background-color: #1b2224;
  color: #abb9b6;
  border-radius: 3px;
}

toolbar separator {
  background: none;
}

toolbar.horizontal separator {
  margin: 0 6px;
}

toolbar.vertical separator {
  margin: 6px 0;
}

.osd toolbar {
  background-color: transparent;
}

toolbar.osd {
  padding: 8px;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 3px;
  background-color: rgba(34, 43, 46, 0.9);
  background-clip: padding-box;
}

toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom {
  border-radius: 0;
}

toolbar.osd.top {
  border-width: 0 0 1px 0;
}

toolbar.osd.bottom {
  border-width: 1px 0 0 0;
}

toolbar.osd.left {
  border-width: 0 1px 0 0;
}

toolbar.osd.right {
  border-width: 0 0 0 1px;
}

searchbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-style: solid;
  border-color: #141a1b;
  background-color: #1b2224;
  border-width: 0 0 1px;
  box-shadow: none;
  color: #abb9b6;
}

actionbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.25);
  background-color: #141a1b;
  box-shadow: none;
  color: #abb9b6;
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: #c6cdcb;
  border-radius: 0;
  box-shadow: none;
  border: none;
  margin: 0 0 0 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #2eb398 0%, transparent 0%) 0 0 0/0 0 0;
}

.titlebar.windowhandle viewswitcher button:checked:not(.titlebutton):not(.suggested-action):not(.destructive-action), .titlebar.windowhandle viewswitcher button:active:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.15);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #2eb398 100%, transparent 0%) 0 0 3/0 0 3px;
}

.titlebar.windowhandle viewswitcher button:disabled:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: rgba(198, 205, 203, 0.4);
}

.titlebar.windowhandle viewswitcher button:checked:disabled:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: rgba(198, 205, 203, 0.4);
  background-color: rgba(198, 205, 203, 0.05);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(46, 179, 152, 0.4) 100%, transparent 0%) 0 0 3/0 0 3px;
}

.titlebar {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

.titlebar, .titlebar headerbar {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.tiled .titlebar, .maximized .titlebar, .fullscreen .titlebar, .tiled .titlebar headerbar, .maximized .titlebar headerbar, .fullscreen .titlebar headerbar {
  box-shadow: none;
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  border-radius: 0;
  margin-top: 0;
  margin-bottom: 0;
}

.sidebar-pane entry, headerbar entry {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.42);
  background-color: rgba(69, 86, 91, 0.42);
}

.sidebar-pane entry image, headerbar entry image, headerbar entry image:hover {
  color: inherit;
}

.sidebar-pane entry:backdrop, headerbar entry:backdrop {
  opacity: 0.85;
}

.sidebar-pane entry:focus-within, headerbar entry:focus-within {
  color: #fcfdfd;
  border-color: #2eb398;
  background-color: rgba(55, 70, 74, 0.42);
  background-clip: padding-box;
}

.sidebar-pane entry:focus-within image, headerbar entry:focus-within image {
  color: #2eb398;
}

.sidebar-pane entry:disabled, headerbar entry:disabled {
  color: rgba(198, 205, 203, 0.55);
  border-color: rgba(0, 0, 0, 0.42);
  background-color: rgba(69, 86, 91, 0.85);
}

.sidebar-pane entry selection:focus-within, headerbar entry selection:focus-within {
  background-color: #ffffff;
  color: #2eb398;
}

.sidebar-pane button, headerbar button {
  color: #c6cdcb;
  outline-offset: -3px;
  background-color: transparent;
  border-color: transparent;
  border-width: 0;
}

.sidebar-pane button:backdrop, headerbar button:backdrop {
  opacity: 0.8;
}

.sidebar-pane button:hover, headerbar button:hover {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(198, 205, 203, 0.18);
}

.sidebar-pane button:active, headerbar button:active, .sidebar-pane button:checked, headerbar button:checked {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #ffffff;
  border-color: transparent;
  background-color: #2eb398;
  background-clip: padding-box;
}

.sidebar-pane button:disabled, headerbar button:disabled {
  color: rgba(198, 205, 203, 0.45);
  background-color: transparent;
  border-color: transparent;
}

.sidebar-pane button:disabled:active, headerbar button:disabled:active, .sidebar-pane button:disabled:checked, headerbar button:disabled:checked {
  color: rgba(255, 255, 255, 0.5);
  border-color: rgba(46, 179, 152, 0.75);
  background-color: rgba(46, 179, 152, 0.75);
}

.sidebar-pane .linked.raised > button:not(:last-child):not(:only-child), headerbar .linked.raised > button:not(:last-child):not(:only-child) {
  margin-left: 1px;
}

.sidebar-pane .linked.raised > button, headerbar .linked.raised > button {
  border-radius: 3px;
  border-style: solid;
  border-width: 0;
  box-shadow: none;
}

.sidebar-pane .linked.raised > button:last-child, headerbar .linked.raised > button:last-child {
  border-left-style: solid;
  border-left-width: 0;
  border-color: transparent;
}

.sidebar-pane .linked.raised > button:last-child:hover, headerbar .linked.raised > button:last-child:hover, .sidebar-pane .linked.raised > button:last-child:active, headerbar .linked.raised > button:last-child:active {
  border-color: rgba(0, 0, 0, 0.25);
}

headerbar popover > contents entry {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #222b2e;
  outline: none;
}

headerbar popover > contents entry:focus-within {
  color: #abb9b6;
  border-color: #2eb398;
  background-color: #222b2e;
  outline: none;
}

headerbar popover > contents entry:disabled {
  color: rgba(204, 215, 212, 0.45);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(34, 43, 46, 0.55);
}

headerbar popover > contents button {
  color: #ccd7d4;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #263034;
  border-width: 1px;
}

headerbar popover > contents button:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

headerbar popover > contents button:active, headerbar popover > contents button:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

headerbar popover > contents button:disabled {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(38, 48, 52, 0.55);
}

headerbar popover > contents button:disabled label, headerbar popover > contents button:disabled {
  color: rgba(204, 215, 212, 0.45);
}

headerbar popover > contents button:disabled:active, headerbar popover > contents button:disabled:checked {
  border-color: rgba(46, 179, 152, 0.75);
  background-color: rgba(46, 179, 152, 0.75);
  opacity: 0.6;
}

headerbar popover > contents button:disabled:active label, headerbar popover > contents button:disabled:active, headerbar popover > contents button:disabled:checked label, headerbar popover > contents button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

headerbar {
  min-height: 42px;
  padding: 0;
  margin: 0;
  color: #c6cdcb;
  border: none;
  background-color: #141a1b;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.25), inset 0 1px rgba(255, 255, 255, 0.1);
}

headerbar:backdrop {
  transition: 200ms ease-out;
  color: rgba(198, 205, 203, 0.7);
  background-color: #1f282a;
}

headerbar > windowhandle > box {
  padding: 6px;
}

headerbar > windowhandle > box,
headerbar > windowhandle > box > box.start,
headerbar > windowhandle > box > box.end {
  border-spacing: 6px;
}

headerbar .title {
  padding-left: 12px;
  padding-right: 12px;
  font-weight: bold;
}

headerbar .subtitle {
  font-size: smaller;
  padding-left: 12px;
  padding-right: 12px;
}

headerbar.flat {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

headerbar entry progress {
  border-color: #2eb398;
  background-image: none;
  background-color: transparent;
}

headerbar entry.warning {
  color: white;
  border-color: rgba(0, 0, 0, 0.42);
  background-color: #99522b;
}

headerbar entry.warning:focus-within {
  color: white;
  background-color: #F27835;
}

headerbar entry.warning selection, headerbar entry.warning selection:focus {
  background-color: white;
  color: #F27835;
}

headerbar entry.error {
  color: white;
  border-color: rgba(0, 0, 0, 0.42);
  background-color: #9f312d;
}

headerbar entry.error:focus-within {
  color: white;
  background-color: #FC4138;
}

headerbar entry.error selection, headerbar entry.error selection:focus {
  background-color: white;
  color: #FC4138;
}

headerbar.selection-mode button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

headerbar.selection-mode button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

headerbar.selection-mode button:hover {
  background-color: alpha(#ffffff,0.3);
}

headerbar.selection-mode button:active, headerbar.selection-mode button:checked {
  color: #2eb398;
  background-color: #ffffff;
  border-color: #ffffff;
}

headerbar.selection-mode button:disabled {
  color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:disabled label {
  color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:disabled:checked, headerbar.selection-mode button:disabled:active {
  color: #2eb398;
  background-color: rgba(255, 255, 255, 0.5);
  border-color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:backdrop {
  opacity: 0.7;
  background: none;
}

headerbar buttonbox.linked > button,
headerbar stackswitcher.linked > button {
  background-color: #2a3538;
  color: #c6cdcb;
  border-width: 0;
  border-color: rgba(0, 0, 0, 0.25);
}

headerbar buttonbox.linked > button:hover,
headerbar stackswitcher.linked > button:hover {
  background-color: #3a4447;
}

headerbar buttonbox.linked > button:active, headerbar buttonbox.linked > button:checked,
headerbar stackswitcher.linked > button:active,
headerbar stackswitcher.linked > button:checked {
  color: #ffffff;
  border-color: transparent;
  background-color: #2eb398;
}

headerbar buttonbox.linked > button:disabled,
headerbar stackswitcher.linked > button:disabled {
  color: rgba(198, 205, 203, 0.4);
}

headerbar buttonbox.linked > button:disabled label,
headerbar stackswitcher.linked > button:disabled label {
  color: rgba(198, 205, 203, 0.4);
}

headerbar stackswitcher.linked > button + button {
  border-left: none;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:focus-within {
  border-color: #2eb398;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry {
  border-left-color: rgba(0, 0, 0, 0.42);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
  border-left-color: #FC4138;
}

headerbar button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #2eb398;
  border-color: #2eb398;
}

headerbar button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #2eb398;
}

headerbar button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #33c7a9;
  border-color: #33c7a9;
}

headerbar button.suggested-action:active, headerbar button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #45cfb3;
  border-color: #45cfb3;
}

headerbar button.suggested-action.flat:disabled, headerbar button.suggested-action:disabled {
  color: rgba(198, 205, 203, 0.45);
  background-color: transparent;
  border-color: transparent;
}

headerbar button.suggested-action:backdrop,
headerbar button.suggested-action:backdrop {
  opacity: 0.8;
}

headerbar button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

headerbar button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #db5b5b;
}

headerbar button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #e07070;
  border-color: #e07070;
}

headerbar button.destructive-action:active, headerbar button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #e48585;
  border-color: #e48585;
}

headerbar button.destructive-action.flat:disabled, headerbar button.destructive-action:disabled {
  color: rgba(198, 205, 203, 0.45);
  background-color: transparent;
  border-color: transparent;
}

headerbar button.destructive-action:backdrop,
headerbar button.destructive-action:backdrop {
  opacity: 0.8;
}

headerbar spinbutton:not(.vertical):focus-within {
  color: #ffffff;
  caret-color: #ffffff;
}

headerbar spinbutton:not(.vertical) button, headerbar spinbutton:not(.vertical) button:disabled {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(198, 205, 203, 0.18);
}

headerbar spinbutton:not(.vertical) button:hover {
  background-color: rgba(101, 128, 135, 0.42);
}

headerbar spinbutton:not(.vertical) button:active, headerbar spinbutton:not(.vertical) button:checked {
  color: #ffffff;
  border-color: transparent;
  background-color: #2eb398;
}

headerbar spinbutton:not(.vertical) button:disabled {
  color: rgba(198, 205, 203, 0.42);
}

headerbar spinbutton:not(.vertical) > button + button {
  border-left-style: none;
}

headerbar spinbutton:not(.vertical) > button:hover:not(:active),
headerbar spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.42);
}

headerbar spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
headerbar spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.42);
}

headerbar spinbutton:not(.vertical) > button:first-child:hover:not(:active),
headerbar spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

headerbar spinbutton:not(.vertical) > entry:focus-within + button {
  border-left-color: #2eb398;
}

headerbar combobox:disabled {
  color: rgba(198, 205, 203, 0.42);
}

headerbar combobox > .linked > button.combo {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.42);
  background-color: rgba(69, 86, 91, 0.42);
}

headerbar combobox > .linked > button.combo image, headerbar combobox > .linked > button.combo image:hover {
  color: inherit;
}

headerbar combobox > .linked > button.combo:hover {
  color: #fcfdfd;
  border-color: #2eb398;
  background-color: rgba(55, 70, 74, 0.42);
  box-shadow: none;
}

headerbar combobox > .linked > button.combo:disabled {
  color: rgba(198, 205, 203, 0.55);
  border-color: rgba(0, 0, 0, 0.42);
  background-color: rgba(69, 86, 91, 0.85);
}

headerbar combobox > .linked > entry.combo:dir(ltr) {
  border-right-style: none;
}

headerbar combobox > .linked > entry.combo:dir(ltr):focus {
  box-shadow: 1px 0 #2eb398;
}

headerbar combobox > .linked > entry.combo:dir(rtl) {
  border-left-style: none;
}

headerbar combobox > .linked > entry.combo:dir(rtl):focus {
  box-shadow: -1px 0 #2eb398;
}

headerbar combobox > .linked > button.combo:dir(ltr), headerbar combobox > .linked > button.combo:dir(ltr):hover, headerbar combobox > .linked > button.combo:dir(ltr):active, headerbar combobox > .linked > button.combo:dir(ltr):checked, headerbar combobox > .linked > button.combo:dir(ltr):disabled {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

headerbar combobox > .linked > button.combo:dir(rtl), headerbar combobox > .linked > button.combo:dir(rtl):hover, headerbar combobox > .linked > button.combo:dir(rtl):active, headerbar combobox > .linked > button.combo:dir(rtl):checked, headerbar combobox > .linked > button.combo:dir(rtl):disabled {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

headerbar switch:backdrop {
  opacity: 0.75;
}

headerbar progressbar trough {
  background-color: rgba(0, 0, 0, 0.42);
}

headerbar progressbar:backdrop {
  opacity: 0.75;
}

headerbar scale:backdrop {
  opacity: 0.75;
}

headerbar scale slider {
  background-color: #2a3538;
  border-color: rgba(0, 0, 0, 0.72);
}

headerbar scale slider:hover {
  background-color: #354347;
  border-color: rgba(0, 0, 0, 0.72);
}

headerbar scale slider:active {
  background-color: #2eb398;
  border-color: #2eb398;
}

headerbar scale slider:disabled {
  background-color: #242d30;
  border-color: rgba(0, 0, 0, 0.72);
}

headerbar scale trough {
  background-color: rgba(0, 0, 0, 0.42);
}

headerbar scale trough:disabled {
  background-color: rgba(0, 0, 0, 0.9);
}

headerbar.titlebar headerbar:not(.titlebar) {
  background: none;
  box-shadow: none;
}

headerbar.selection-mode {
  color: #ffffff;
  background-color: rgba(46, 179, 152, 0.95);
  border-color: rgba(42, 163, 138, 0.95);
  box-shadow: none;
}

headerbar.selection-mode:backdrop {
  background-color: rgba(46, 179, 152, 0.95);
  color: rgba(255, 255, 255, 0.6);
}

headerbar.selection-mode .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized headerbar.selection-mode {
  background-color: #2eb398;
}

.maximized headerbar {
  background-color: #141a1b;
  box-shadow: none;
}

.maximized headerbar:backdrop {
  background-color: #1f282a;
}

headerbar.default-decoration {
  min-height: 28px;
  padding: 0;
  background-color: #141a1b;
}

.tiled headerbar.default-decoration, .maximized headerbar.default-decoration, .fullscreen headerbar.default-decoration {
  box-shadow: none;
}

headerbar.default-decoration > windowhandle > box {
  padding: 0 6px;
}

.solid-csd headerbar:backdrop:dir(rtl), .solid-csd headerbar:backdrop:dir(ltr), .solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) {
  margin-left: -1px;
  margin-right: -1px;
  margin-top: -1px;
  border-radius: 0;
  box-shadow: none;
}

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop, window.csd > .titlebar:not(headerbar), window.csd > .titlebar:not(headerbar):backdrop {
  padding: 0;
  background: none;
  border: none;
}

.titlebar:not(headerbar) > separator {
  background-image: linear-gradient(to bottom, #141a1b, #141a1b);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.titlebar:not(headerbar) > separator:backdrop {
  transition: 200ms ease-out;
  background-image: linear-gradient(to bottom, #1f282a, #1f282a);
  box-shadow: none;
}

headerbar separator.titlebutton {
  min-width: 0;
  min-height: 0;
  background: none;
  border-width: 0 0;
  border-image: linear-gradient(to bottom, rgba(198, 205, 203, 0) 25%, rgba(198, 205, 203, 0.35) 25%, rgba(198, 205, 203, 0.35) 75%, rgba(198, 205, 203, 0) 75%) 0 1/0 0 stretch;
}

headerbar separator.titlebutton:backdrop {
  opacity: 0.6;
}

window.devel headerbar.titlebar {
  background: #1b2224 cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(46, 179, 152, 0.1)), linear-gradient(to top, #0c0f10 3px, #101415);
}

window.devel headerbar.titlebar:backdrop {
  background: #1b2224 cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#1b2224);
  /* background-color would flash */
}

.path-bar > button:hover {
  background-color: rgba(204, 215, 212, 0.06);
}

.path-bar > button:checked, .path-bar > button:active {
  background-color: #2eb398;
  border-color: #2eb398;
}

.path-bar > button:checked:hover, .path-bar > button:active:hover {
  background-color: #33c7a9;
  border-color: #33c7a9;
}

.path-bar > button.text-button, .path-bar > button.image-button, .path-bar > button {
  padding-left: 6px;
  padding-right: 6px;
}

.path-bar > button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.path-bar > button.text-button.image-button label:last-child, .path-bar > button label:last-child {
  padding-right: 10px;
}

.path-bar > button.text-button.image-button label:first-child, .path-bar > button label:first-child {
  padding-left: 10px;
}

.path-bar > button.slider-button, .path-bar > button:not(.image-button):not(.text-button) {
  padding-left: 1px;
  padding-right: 1px;
}

.path-bar > button image {
  padding-left: 4px;
  padding-right: 4px;
}

columnview.view,
treeview.view {
  border-left-color: #444d4f;
  border-top-color: #444d4f;
}

columnview.view,
treeview.view {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

columnview.view:focus:focus-visible,
treeview.view:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

columnview.view acceleditor > label,
treeview.view acceleditor > label {
  background-color: #2eb398;
}

columnview.view:selected,
treeview.view:selected {
  outline-color: rgba(255, 255, 255, 0.3);
}

columnview.view.separator,
treeview.view.separator {
  min-height: 2px;
  color: rgba(0, 0, 0, 0.1);
}

columnview.view:drop(active),
treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #7dc5b6;
}

columnview.view:drop(active).after,
treeview.view:drop(active).after {
  border-top-style: none;
}

columnview.view:drop(active).before,
treeview.view:drop(active).before {
  border-bottom-style: none;
}

columnview.view > dndtarget:drop(active),
treeview.view > dndtarget:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #196253;
}

columnview.view > dndtarget:drop(active).after,
treeview.view > dndtarget:drop(active).after {
  border-top-style: none;
}

columnview.view > dndtarget:drop(active).before,
treeview.view > dndtarget:drop(active).before {
  border-bottom-style: none;
}

columnview.view.expander,
treeview.view.expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: #919b9a;
}

columnview.view.expander:dir(rtl),
treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

columnview.view.expander:hover,
treeview.view.expander:hover {
  color: #ccd7d4;
}

columnview.view.expander:selected,
treeview.view.expander:selected {
  color: #abb9b6;
}

columnview.view.expander:selected:hover,
treeview.view.expander:selected:hover {
  color: #ccd7d4;
}

columnview.view.expander:checked,
treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view.progressbar,
treeview.view.progressbar {
  color: #ffffff;
  border-radius: 3px;
  background-color: #2eb398;
  background-image: image(#2eb398);
}

columnview.view.progressbar:selected, columnview.view.progressbar:selected:focus,
treeview.view.progressbar:selected,
treeview.view.progressbar:selected:focus {
  color: #2eb398;
  border-radius: 3px;
  box-shadow: none;
  background-color: #ffffff;
  background-image: image(#ffffff);
}

columnview.view.trough,
treeview.view.trough {
  color: #ccd7d4;
  background-color: rgba(0, 0, 0, 0.25);
  border-radius: 3px;
  border-width: 0;
}

columnview.view.trough:selected, columnview.view.trough:selected:focus,
treeview.view.trough:selected,
treeview.view.trough:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  border-width: 0;
}

columnview.view > header > button,
treeview.view > header > button {
  min-height: 0;
  min-width: 0;
  padding: 3px 6px;
  font-weight: bold;
  color: #aab5b3;
  background-color: #222b2e;
  background-image: none;
  border-style: none solid none none;
  border-radius: 0;
  border-image: linear-gradient(to bottom, #222b2e 20%, rgba(255, 255, 255, 0.12) 20%, rgba(255, 255, 255, 0.12) 80%, #222b2e 80%) 0 1 0 0/0 1px 0 0 stretch;
}

columnview.view > header > button:hover,
treeview.view > header > button:hover {
  color: #2eb398;
}

columnview.view > header > button:active,
treeview.view > header > button:active {
  color: #ccd7d4;
}

columnview.view > header > button:active, columnview.view > header > button:hover,
treeview.view > header > button:active,
treeview.view > header > button:hover {
  background-color: #222b2e;
}

columnview.view > header > button:active:hover,
treeview.view > header > button:active:hover {
  color: #ccd7d4;
}

columnview.view > header > button:disabled,
treeview.view > header > button:disabled {
  border-color: #1b2224;
  background-image: none;
}

columnview.view > header > button:last-child,
treeview.view > header > button:last-child {
  border-right-style: none;
  border-image: none;
}

columnview.view button.dnd, columnview.view button.dnd:selected, columnview.view button.dnd:hover, columnview.view button.dnd:active,
columnview.view header.button.dnd,
columnview.view header.button.dnd:selected,
columnview.view header.button.dnd:hover,
columnview.view header.button.dnd:active,
treeview.view button.dnd,
treeview.view button.dnd:selected,
treeview.view button.dnd:hover,
treeview.view button.dnd:active,
treeview.view header.button.dnd,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd:active {
  padding: 0 6px;
  transition: none;
  color: #ffffff;
  background-color: #2eb398;
  border-radius: 0;
  border-style: none;
}

menubar {
  padding: 0;
  background-color: #141a1b;
  color: #c6cdcb;
}

menubar:backdrop {
  color: rgba(198, 205, 203, 0.7);
}

menubar > item {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  padding: 6px 10px;
  border: none;
  border-radius: 0;
  min-height: 16px;
}

menubar > item:selected {
  background-color: #2eb398;
  color: #ffffff;
}

menubar > item:disabled {
  color: rgba(198, 205, 203, 0.45);
  border-color: transparent;
}

menubar > item popover.menu.background > contents {
  padding: 5px;
  border-radius: 0 0 3px 3px;
}

menubar > item popover.menu popover.menu {
  padding: 0 0 4px 0;
}

menubar > item popover.menu.background popover.menu.background > contents {
  margin: 0;
  border-radius: 3px;
}

popover.background {
  background-color: transparent;
  font: initial;
  padding: 0;
  color: #ccd7d4;
}

popover.background > arrow,
popover.background > contents {
  padding: 3px;
  border-radius: 3px;
  color: #ccd7d4;
  background-color: #1b2224;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.45);
  box-shadow: 0 2px 6px 0 rgba(0, 0, 0, 0.35);
}

popover.background:backdrop {
  background-color: transparent;
}

popover.background > contents > list,
popover.background > contents > .view,
popover.background > contents > toolbar {
  border-style: none;
  background-color: transparent;
}

popover.background > contents separator {
  background-color: rgba(20, 26, 27, 0.475);
  margin: 3px 0;
}

popover.background > contents list separator {
  margin: 0;
}

popover.background > contents > scrolledwindow > viewport > stack > box {
  padding: 0;
}

popover.background > contents listview {
  margin: 0;
  padding: 0;
}

popover.background > contents listview > row {
  padding: 6px;
  border-radius: 2px;
  margin: 0;
}

popover.background > contents listview > row + row {
  margin-top: 2px;
}

popover.background > contents listview > row:selected {
  outline: none;
  color: #abb9b6;
  background-color: rgba(255, 255, 255, 0.07);
}

popover.background label.separator {
  color: #ccd7d4;
}

popover.background > list,
popover.background > .view,
popover.background > toolbar,
popover.background > scrolledwindow > viewport > list {
  border-style: none;
  background-color: transparent;
}

popover.background > scrolledwindow > viewport > list {
  margin: 3px;
}

popover.background > scrolledwindow > viewport > list row {
  padding: 6px 12px;
  border-radius: 2px;
}

popover.background scale > trough > fill:disabled {
  background-color: transparent;
}

.osd popover.background, popover.background.touch-selection, popover.background.magnifier {
  background-color: transparent;
}

.osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents {
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.25);
}

magnifier {
  background-color: #222b2e;
}

popover.menu {
  padding: 0;
}

popover.menu box.inline-buttons {
  padding: 0 6px;
}

popover.menu box.inline-buttons button.image-button.model {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  min-height: 30px;
  min-width: 30px;
  padding: 0;
  border: none;
  outline: none;
  transition: none;
}

popover.menu box.inline-buttons button.image-button.model:selected {
  background-image: image(rgba(255, 255, 255, 0.07));
}

popover.menu box.circular-buttons {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model {
  padding: 10px;
  border: none;
}

popover.menu box.circular-buttons button.circular.image-button.model:focus {
  background-color: rgba(255, 255, 255, 0.07);
}

popover.menu box.circular-buttons button.circular.image-button.model:active:focus {
  color: #ccd7d4;
  background-color: rgba(255, 255, 255, 0.12);
}

popover.menu accelerator {
  color: alpha(currentColor,0.55);
}

popover.menu accelerator:dir(ltr) {
  margin-left: 6px;
}

popover.menu accelerator:dir(rtl) {
  margin-right: 6px;
}

popover.menu radio {
  border-color: rgba(0, 0, 0, 0.25);
}

popover.menu radio:active {
  border-color: rgba(0, 0, 0, 0);
}

popover.menu arrow.left,
popover.menu radio.left,
popover.menu check.left {
  margin-left: -2px;
  margin-right: 6px;
}

popover.menu arrow.right,
popover.menu radio.right,
popover.menu check.right {
  margin-left: 6px;
  margin-right: -2px;
}

popover.menu modelbutton {
  min-height: 30px;
  min-width: 40px;
  padding: 0 6px;
  border-radius: 2px;
}

popover.menu modelbutton:selected {
  color: #abb9b6;
  background-color: rgba(255, 255, 255, 0.07);
}

popover.menu modelbutton:selected:active {
  color: #ccd7d4;
  background-color: rgba(255, 255, 255, 0.12);
}

popover.menu label.title {
  font-weight: bold;
  padding: 4px 26px;
}

notebook {
  padding: 0;
}

notebook > header > tabs > tab:checked {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook:focus:focus-visible > header > tabs > tab:checked {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

notebook.frame {
  border: 1px solid rgba(0, 0, 0, 0.25);
}

notebook > stack:not(:only-child) {
  background-color: #222b2e;
}

notebook > header {
  padding: 0;
  background-color: #1b2224;
}

notebook > header.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

notebook > header.top > tabs > tab {
  padding: 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-bottom: none;
}

notebook > header.top > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.top > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -2px alpha(#2eb398,0.6), 0 1px alpha(#2eb398,0.6);
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -2px #2eb398, 0 1px #2eb398;
}

notebook > header.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

notebook > header.bottom > tabs > tab {
  padding: 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-top: none;
}

notebook > header.bottom > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.bottom > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 2px alpha(#2eb398,0.6), 0 -1px alpha(#2eb398,0.6);
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 2px #2eb398, 0 -1px #2eb398;
}

notebook > header.right {
  border-left: 1px solid rgba(0, 0, 0, 0.25);
}

notebook > header.right > tabs > tab {
  padding: 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-left: none;
}

notebook > header.right > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.right > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 2px 0 alpha(#2eb398,0.6), -1px 0 alpha(#2eb398,0.6);
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 2px 0 #2eb398, -1px 0 #2eb398;
}

notebook > header.left {
  border-right: 1px solid rgba(0, 0, 0, 0.25);
}

notebook > header.left > tabs > tab {
  padding: 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-right: none;
}

notebook > header.left > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.left > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -2px 0 alpha(#2eb398,0.6), 1px 0 alpha(#2eb398,0.6);
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -2px 0 #2eb398, 1px 0 #2eb398;
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
  margin-left: 2px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
  margin-right: 2px;
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
  margin-top: 2px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
  margin-bottom: 2px;
}

notebook > header > tabs > arrow {
  color: rgba(204, 215, 212, 0.45);
}

notebook > header > tabs > arrow:hover {
  color: rgba(204, 215, 212, 0.725);
}

notebook > header > tabs > arrow:active {
  color: #ccd7d4;
}

notebook > header > tabs > arrow:disabled {
  color: rgba(204, 215, 212, 0.7);
}

notebook > header > tabs {
  margin: 0;
  padding: 0;
}

notebook > header > tabs > tab {
  color: rgba(204, 215, 212, 0.45);
  background-color: rgba(27, 34, 36, 0);
}

notebook > header > tabs > tab:hover:not(:checked) {
  color: rgba(204, 215, 212, 0.725);
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab:checked {
  color: #ccd7d4;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab button.flat {
  border-radius: 100%;
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  margin: 4px 0;
  color: #8e9896;
}

notebook > header > tabs > tab button.flat:hover {
  color: #ff4d4d;
  background-color: #101415;
}

notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover {
  color: #2eb398;
  background-color: #0a0c0d;
}

notebook > header button {
  margin: 2px;
}

scrollbar {
  background-color: #20282b;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.25);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.25);
}

scrollbar button {
  border: none;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-right-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-left-symbolic");
}

scrollbar > range > trough {
  background-color: transparent;
  padding: 0;
  margin: 0;
  border: none;
  outline: none;
  border-radius: 0;
}

scrollbar > range > trough > slider {
  min-width: 6px;
  min-height: 6px;
  margin: -1px;
  padding: 0;
  border: 4px solid transparent;
  border-radius: 8px;
  background-clip: padding-box;
  background-color: #626a6a;
  box-shadow: none;
  outline: none;
}

scrollbar > range > trough > slider:hover {
  background-color: #505859;
}

scrollbar > range > trough > slider:hover:active {
  background-color: #2eb398;
}

scrollbar > range > trough > slider:disabled {
  background-color: transparent;
}

scrollbar > range.fine-tune > trough > slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar > range.fine-tune.horizontal > trough > slider {
  border-width: 5px 4px;
}

scrollbar > range.fine-tune.vertical > trough > slider {
  border-width: 4px 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  opacity: 0.4;
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough > slider {
  margin: 0;
  min-width: 4px;
  min-height: 4px;
  background-color: #97a19f;
  border: 1px solid rgba(0, 0, 0, 0.3);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal > range > trough > slider {
  margin: 0 2px;
  min-width: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical > range > trough > slider {
  margin: 2px 0;
  min-height: 40px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 0.8;
}

scrollbar.horizontal > range > trough > slider {
  min-width: 40px;
}

scrollbar.vertical > range > trough > slider {
  min-height: 40px;
}

treeview ~ scrollbar.vertical {
  border-top: 1px solid rgba(0, 0, 0, 0.25);
  margin-top: -1px;
}

switch {
  font-size: 0;
  min-width: 52px;
  min-height: 24px;
  background-size: 52px 24px;
  background-repeat: no-repeat;
  background-position: center center;
  transition: all 350ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

switch > slider {
  min-width: 0;
  min-height: 0;
  background-image: none;
}

switch, switch > slider {
  padding: 0;
  margin: 0;
  background-color: transparent;
  outline: none;
  color: transparent;
  border: none;
  box-shadow: none;
}

switch {
  background-image: -gtk-scaled(url("assets/switch-dark.png"), url("assets/switch-dark@2.png"));
}

row:selected switch,
infobar switch {
  background-image: -gtk-scaled(url("assets/switch-selected.png"), url("assets/switch-selected@2.png"));
}

headerbar switch {
  background-image: -gtk-scaled(url("assets/switch-header-dark.png"), url("assets/switch-header-dark@2.png"));
}

switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-dark.png"), url("assets/switch-active-dark@2.png"));
}

row:selected switch:checked,
infobar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-selected.png"), url("assets/switch-active-selected@2.png"));
}

headerbar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-header-dark.png"), url("assets/switch-active-header-dark@2.png"));
}

switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover-dark.png"), url("assets/switch-hover-dark@2.png"));
}

row:selected switch:hover,
infobar switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover-selected.png"), url("assets/switch-hover-selected@2.png"));
}

headerbar switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover-header-dark.png"), url("assets/switch-hover-header-dark@2.png"));
}

switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover-dark.png"), url("assets/switch-active-hover-dark@2.png"));
}

row:selected switch:checked:hover,
infobar switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover-selected.png"), url("assets/switch-active-hover-selected@2.png"));
}

headerbar switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover-header-dark.png"), url("assets/switch-active-hover-header-dark@2.png"));
}

switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-dark.png"), url("assets/switch-insensitive-dark@2.png"));
}

row:selected switch:disabled,
infobar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-selected.png"), url("assets/switch-insensitive-selected@2.png"));
}

headerbar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-header-dark.png"), url("assets/switch-insensitive-header-dark@2.png"));
}

switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-dark.png"), url("assets/switch-active-insensitive-dark@2.png"));
}

row:selected switch:checked:disabled,
infobar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-selected.png"), url("assets/switch-active-insensitive-selected@2.png"));
}

headerbar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-header-dark.png"), url("assets/switch-active-insensitive-header-dark@2.png"));
}

check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
}

.osd check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
}

.view check:selected,
row:selected check,
infobar check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-selected.png"), url("assets/checkbox-unchecked-selected@2.png"));
}

check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
}

.osd check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
}

.view check:disabled:selected,
row:selected check:disabled,
infobar check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-selected.png"), url("assets/checkbox-unchecked-insensitive-selected@2.png"));
}

check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
}

.osd check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
}

.view check:indeterminate:selected,
row:selected check:indeterminate,
infobar check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-selected.png"), url("assets/checkbox-mixed-selected@2.png"));
}

check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
}

.osd check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
}

.view check:indeterminate:disabled:selected,
row:selected check:indeterminate:disabled,
infobar check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-selected.png"), url("assets/checkbox-mixed-insensitive-selected@2.png"));
}

check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
}

.osd check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
}

.view check:checked:selected,
row:selected check:checked,
infobar check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selected.png"), url("assets/checkbox-checked-selected@2.png"));
}

check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
}

.osd check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
}

.view check:checked:disabled:selected,
row:selected check:checked:disabled,
infobar check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-selected.png"), url("assets/checkbox-checked-insensitive-selected@2.png"));
}

radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
}

.osd radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
}

.view radio:selected,
row:selected radio,
infobar radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-selected.png"), url("assets/radio-unchecked-selected@2.png"));
}

radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
}

.osd radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
}

.view radio:disabled:selected,
row:selected radio:disabled,
infobar radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-selected.png"), url("assets/radio-unchecked-insensitive-selected@2.png"));
}

radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
}

.osd radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
}

.view radio:indeterminate:selected,
row:selected radio:indeterminate,
infobar radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-selected.png"), url("assets/radio-mixed-selected@2.png"));
}

radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
}

.osd radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
}

.view radio:indeterminate:disabled:selected,
row:selected radio:indeterminate:disabled,
infobar radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-selected.png"), url("assets/radio-mixed-insensitive-selected@2.png"));
}

radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
}

.osd radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
}

.view radio:checked:selected,
row:selected radio:checked,
infobar radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-selected.png"), url("assets/radio-checked-selected@2.png"));
}

radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
}

.osd radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
}

.view radio:checked:disabled:selected,
row:selected radio:checked:disabled,
infobar radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-selected.png"), url("assets/radio-checked-insensitive-selected@2.png"));
}

.view.content-view.check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode-dark.png"), url("assets/checkbox-selectionmode-dark@2.png"));
  background-color: transparent;
}

.view.content-view.check:checked:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode-dark.png"), url("assets/checkbox-checked-selectionmode-dark@2.png"));
  background-color: transparent;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button:hover, radiobutton.text-button:hover {
  color: #a1b5b0;
}

checkbutton.text-button:disabled, radiobutton.text-button:disabled {
  color: rgba(204, 215, 212, 0.45);
}

checkbutton label:not(:only-child):first-child, radiobutton label:not(:only-child):first-child {
  margin-left: 4px;
}

checkbutton label:not(:only-child):last-child, radiobutton label:not(:only-child):last-child {
  margin-right: 4px;
}

check,
radio {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-size: 16px;
  margin: 0 2px;
  padding: 0;
}

check:only-child,
radio:only-child {
  margin: 0;
}

scale > trough > fill, scale > trough, popover.background scale > trough, popover.background scale > trough > fill {
  border: none;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.25);
}

scale > trough > fill:disabled, scale > trough:disabled, popover.background scale > trough:disabled, popover.background scale > trough > fill:disabled {
  background-color: rgba(0, 0, 0, 0.15);
}

.osd scale > trough > fill, .osd scale > trough, .osd popover.background scale > trough, popover.background .osd scale > trough, .osd popover.background scale > trough > fill, popover.background .osd scale > trough > fill {
  background-color: rgba(0, 0, 0, 0.25);
}

.osd scale > trough > fill:disabled, .osd scale > trough:disabled, .osd popover.background scale > trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

scale > trough > highlight, popover.background scale > trough > highlight {
  border: none;
  border-radius: 3px;
  background-color: #2eb398;
}

scale > trough > highlight:disabled, popover.background scale > trough > highlight:disabled {
  background-color: rgba(46, 179, 152, 0.5);
}

scale {
  min-height: 15px;
  min-width: 15px;
  padding: 3px;
}

scale.horizontal trough {
  padding: 0 4px;
}

scale.horizontal highlight, scale.horizontal fill {
  margin: 0 -4px;
}

scale.vertical trough {
  padding: 4px 0;
}

scale.vertical highlight, scale.vertical fill {
  margin: -4px 0;
}

scale.fine-tune slider {
  margin: -4px;
}

scale.fine-tune fill,
scale.fine-tune highlight,
scale.fine-tune trough {
  border-radius: 5px;
}

scale > trough > fill:disabled {
  background-color: transparent;
}

scale > trough > slider {
  min-height: 15px;
  min-width: 15px;
  margin: -6px;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 100%;
  box-shadow: none;
  background-clip: padding-box;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border;
}

scale > trough > slider:hover {
  background-clip: border-box;
  background-color: #2eb398;
  border-color: #2ba78e;
}

scale > trough > slider:active {
  background-clip: border-box;
  background-color: #2ba78e;
  border-color: #289b83;
}

scale > trough > slider:disabled {
  background-color: #e6e6e6;
  border-color: rgba(0, 0, 0, 0.25);
}

scale > value {
  color: alpha(currentColor,0.45);
  font-feature-settings: "tnum";
}

scale > marks {
  color: alpha(currentColor,0.45);
}

scale > marks.top {
  margin-bottom: 1px;
  margin-top: -4px;
}

scale > marks.bottom {
  margin-top: 1px;
  margin-bottom: -4px;
}

scale > marks.top {
  margin-right: 1px;
  margin-left: -4px;
}

scale > marks.bottom {
  margin-left: 1px;
  margin-right: -4px;
}

scale.fine-tune > marks.top {
  margin-bottom: 0px;
  margin-top: -2px;
}

scale.fine-tune > marks.bottom {
  margin-top: 0px;
  margin-bottom: -2px;
}

scale.fine-tune > marks.top {
  margin-right: 0px;
  margin-left: -2px;
}

scale.fine-tune > marks.bottom {
  margin-left: 0px;
  margin-right: -2px;
}

scale.horizontal indicator {
  min-height: 3px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 2px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 3px;
}

scale.vertical.fine-tune indicator {
  min-width: 2px;
}

infobar.info trough, infobar.question trough, infobar.warning trough, infobar.error trough, scale:selected trough {
  background-color: rgba(0, 0, 0, 0.2);
}

infobar.info trough highlight, infobar.question trough highlight, infobar.warning trough highlight, infobar.error trough highlight, scale:selected trough highlight {
  background-color: #35cbac;
}

infobar.info trough highlight:disabled, infobar.question trough highlight:disabled, infobar.warning trough highlight:disabled, infobar.error trough highlight:disabled, scale:selected trough highlight:disabled {
  background-color: #a1ddd1;
}

infobar.info trough:disabled, infobar.question trough:disabled, infobar.warning trough:disabled, infobar.error trough:disabled, scale:selected trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

progressbar {
  font-size: smaller;
  color: rgba(204, 215, 212, 0.7);
  font-feature-settings: "tnum";
}

progressbar.horizontal > trough {
  min-width: 150px;
}

progressbar.horizontal > trough, progressbar.horizontal > trough > progress {
  min-height: 4px;
  border-radius: 2px;
}

progressbar.vertical > trough {
  min-height: 80px;
}

progressbar.vertical > trough, progressbar.vertical > trough > progress {
  min-width: 4px;
  border-radius: 2px;
}

progressbar.horizontal > trough > progress {
  margin: 0 -1px;
}

progressbar.vertical > trough > progress {
  margin: -1px 0;
}

progressbar.osd {
  min-width: 4px;
  min-height: 4px;
  background-color: transparent;
  margin: 0;
  box-shadow: none;
  padding: 0;
  border-radius: 0;
}

progressbar.osd > trough {
  border-style: none;
  background-color: transparent;
  box-shadow: none;
}

progressbar.osd > progress {
  border-style: none;
  border-radius: 0;
}

progressbar > trough > progress {
  background-color: #2eb398;
  border: none;
  border-radius: 3px;
  box-shadow: none;
  border-radius: 1.5px;
}

row:selected progressbar > trough > progress, infobar progressbar > trough > progress {
  background-color: #ffffff;
}

progressbar > trough > progress:disabled {
  background-color: rgba(204, 215, 212, 0.45);
  border-color: rgba(204, 215, 212, 0.45);
}

progressbar > trough > progress.left {
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}

progressbar > trough > progress.right {
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
}

progressbar > trough > progress.top {
  border-top-right-radius: 5px;
  border-top-left-radius: 5px;
}

progressbar > trough > progress.bottom {
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px;
}

progressbar > trough {
  border: none;
  border-radius: 3px;
  background-color: #101415;
}

row:selected progressbar > trough, infobar progressbar > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

/*************
 * Level Bar *
 *************/
levelbar.horizontal trough > block {
  min-height: 4px;
  border-radius: 3px;
}

levelbar.horizontal trough > block:dir(rtl) {
  border-radius: 0 3px 3px 0;
}

levelbar.horizontal trough > block:dir(ltr) {
  border-radius: 3px 0 0 3px;
}

levelbar.horizontal trough > block.empty, levelbar.horizontal trough > block.full {
  border-radius: 3px;
}

levelbar.horizontal.discrete trough > block {
  min-height: 2px;
  margin: 1px;
  min-width: 24px;
  border-radius: 0;
}

levelbar.horizontal.discrete trough > block:first-child {
  border-radius: 2px 0 0 2px;
}

levelbar.horizontal.discrete trough > block:last-child {
  border-radius: 0 2px 2px 0;
}

levelbar.vertical trough > block {
  min-width: 4px;
  border-radius: 3px;
}

levelbar.vertical.discrete > trough > block {
  min-width: 4px;
  margin: 1px 0;
  min-height: 32px;
}

levelbar > trough {
  padding: 0;
}

levelbar > trough > block {
  border: 1px solid;
}

levelbar > trough > block.low {
  border-color: #F27835;
  background-color: #F27835;
}

levelbar > trough > block.high, levelbar > trough > block:not(.empty) {
  border-color: #2eb398;
  background-color: #2eb398;
}

levelbar > trough > block.full {
  border-color: #2eb398;
  background-color: #2eb398;
}

levelbar > trough > block.empty {
  background-color: #101415;
  border-color: #101415;
}

window.dialog.print drawing {
  color: #ccd7d4;
  background: none;
  border: none;
  padding: 0;
}

window.dialog.print drawing paper {
  border: 1px solid rgba(0, 0, 0, 0.25);
  background: #222b2e;
  padding: 0;
}

window.dialog.print .dialog-action-box {
  margin: 12px;
}

frame,
.frame {
  border: 1px solid rgba(0, 0, 0, 0.25);
}

frame {
  border-radius: 2px;
}

frame > label {
  margin: 4px;
}

scrolledwindow > overshoot.top {
  background-image: radial-gradient(farthest-side at top, rgba(0, 0, 0, 0.25) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at top, rgba(204, 215, 212, 0.07), rgba(204, 215, 212, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, rgba(0, 0, 0, 0.25) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at bottom, rgba(204, 215, 212, 0.07), rgba(204, 215, 212, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.left {
  background-image: radial-gradient(farthest-side at left, rgba(0, 0, 0, 0.25) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at left, rgba(204, 215, 212, 0.07), rgba(204, 215, 212, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.right {
  background-image: radial-gradient(farthest-side at right, rgba(0, 0, 0, 0.25) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at right, rgba(204, 215, 212, 0.07), rgba(204, 215, 212, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > undershoot.top > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

scrolledwindow > undershoot.bottom > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

scrolledwindow > undershoot.left > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

scrolledwindow > undershoot.right > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

scrolledwindow > junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.25) 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: #20282b;
}

scrolledwindow > junction:dir(rtl) {
  border-image-slice: 0 1 0 0;
}

separator {
  background-color: rgba(0, 0, 0, 0.25);
  min-width: 1px;
  min-height: 1px;
  border: none;
}

separator.spacer {
  background-color: transparent;
}

listview,
list {
  background-color: #222b2e;
  border-color: rgba(0, 0, 0, 0.25);
  border-radius: 2px;
  box-shadow: none;
  color: #ccd7d4;
}

.content-pane listview, .content-pane list {
  background-color: #1b2224;
  background-clip: border-box;
}

listview > row.expander,
list > row.expander {
  padding: 0px;
}

listview > row.expander .row-header,
list > row.expander .row-header {
  padding: 2px;
}

listview.separators.horizontal,
list.separators.horizontal {
  border-left: none;
}

listview.separators:not(.horizontal),
list.separators:not(.horizontal) {
  border-bottom: none;
}

listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator),
list.horizontal row.separator,
list.separators.horizontal > row:not(.separator) {
  border-left: 1px solid rgba(0, 0, 0, 0.25);
}

listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator),
list:not(.horizontal) row.separator,
list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

listview > header {
  padding: 2px;
  padding-top: 18px;
  padding-bottom: 6px;
}

row {
  color: #abb9b6;
  outline: none;
  box-shadow: none;
}

row:hover, row.has-open-popup {
  background-color: rgba(255, 255, 255, 0.04);
  color: #ccd7d4;
}

row:active {
  background-color: rgba(255, 255, 255, 0.12);
  color: #ccd7d4;
}

row:disabled {
  background-color: transparent;
  color: rgba(204, 215, 212, 0.45);
}

row:disabled image {
  color: inherit;
}

row:selected {
  background-color: #2eb398;
  color: #ffffff;
  outline: none;
}

row:selected:hover, row:selected.has-open-popup {
  background-color: #35cbac;
  color: #ffffff;
}

row {
  transition: none;
}

row listview, row row, row:hover listview, row:hover row, row:active listview, row:active row, row:checked listview, row:checked row, row:selected listview, row:selected row, row:backdrop listview, row:backdrop row, row:disabled listview, row:disabled row {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  transition: none;
  animation: none;
  outline: none;
}

columnview > listview > row {
  padding: 0;
}

columnview > listview > row > cell {
  padding: 8px 6px;
}

columnview > listview > row > cell:not(:first-child) {
  border-left: 1px solid transparent;
}

columnview.column-separators > listview > row > cell {
  border-left-color: rgba(0, 0, 0, 0.25);
}

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px;
}

treeexpander {
  border-spacing: 4px;
}

/********************************************************
 * Data Tables                                          *
 * treeview like tables with individual focusable cells *
 * https://gitlab.gnome.org/GNOME/gtk/-/issues/2929     *
 ********************************************************/
columnview row:not(:selected) cell editablelabel:not(.editing):focus-within {
  outline: 2px solid rgba(46, 179, 152, 0.7);
}

columnview row:not(:selected) cell editablelabel.editing:focus-within {
  outline: 2px solid #2eb398;
}

columnview row:not(:selected) cell editablelabel.editing text selection {
  color: #ffffff;
  background-color: #2eb398;
}

.rich-list {
  /* rich lists usually containing other widgets than just labels/text */
}

.rich-list > row {
  padding: 8px 12px;
  min-height: 32px;
  /* should be tall even when only containing a label */
}

.rich-list > row > box {
  border-spacing: 12px;
}

.rich-list > header {
  padding-left: 12px;
  padding-right: 12px;
}

row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 50px;
}

row > box.header > .icon:disabled {
  filter: Opacity(0.45);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
  padding: 0;
}

row > box.header > box.title,
row > box.header > box.title > .title,
row > box.header > box.title > .subtitle {
  padding: 0;
  font-weight: inherit;
}

row > box.header > .prefixes,
row > box.header > .suffixes {
  border-spacing: 6px;
}

row > box.header > .prefixes > .suffixes,
row > box.header > .suffixes > .suffixes {
  border-spacing: 6px;
}

row > box.header > .icon:dir(ltr),
row > box.header > .prefixes:dir(ltr) {
  margin-right: 6px;
}

row > box.header > .icon:dir(rtl),
row > box.header > .prefixes:dir(rtl) {
  margin-left: 6px;
}

row.property > box.header > box.title > .title {
  font-size: smaller;
}

row.property > box.header > box.title > .subtitle {
  font-size: inherit;
  opacity: 1;
}

row.property.monospace, row.expander.property > box > list > row.monospace {
  font-family: inherit;
  font-size: inherit;
}

row.entry:disabled text {
  opacity: 0.45;
}

row.entry:disabled .dimmed, row.entry:disabled row.expander image.expander-row-arrow, row.expander row.entry:disabled image.expander-row-arrow, row.entry:disabled row.property > box.header > box.title > .title, row.entry:disabled .dim-label, row.entry:disabled label.separator,
row.entry:disabled entry > text > placeholder, row.entry:disabled spinbutton:not(.vertical) > text > placeholder, row.entry:disabled spinbutton.vertical > text > text > placeholder, row.entry:disabled .subtitle {
  opacity: 1;
}

row.entry > box.header {
  border-spacing: 0;
  margin-left: 6px;
  margin-right: 6px;
}

row.entry > box.header > .editable-area {
  padding: 0 6px;
}

row.entry > box.header > .editable-area > .edit-icon, row.entry > box.header > .editable-area > .indicator {
  min-width: 24px;
  min-height: 24px;
  padding: 5px;
}

row.entry > box.header > .editable-area > .edit-icon:dir(ltr), row.entry > box.header > .editable-area > .indicator:dir(ltr), row.entry > box.header > .editable-area > .apply-button:dir(ltr) {
  margin-left: 6px;
}

row.entry > box.header > .editable-area > .edit-icon:dir(rtl), row.entry > box.header > .editable-area > .indicator:dir(rtl), row.entry > box.header > .editable-area > .apply-button:dir(rtl) {
  margin-right: 6px;
}

row.entry > box.header > .editable-area > .edit-icon:disabled {
  opacity: 0.55;
}

row.entry > box.header > .editable-area > .indicator {
  opacity: 0.65;
}

row.entry > box.header > .prefixes:dir(ltr) {
  margin-left: 6px;
}

row.entry > box.header > .prefixes:dir(rtl) {
  margin-right: 6px;
}

row.entry > box.header > .suffixes:dir(ltr) {
  margin-right: 6px;
}

row.entry > box.header > .suffixes:dir(rtl) {
  margin-left: 6px;
}

row.entry.monospace {
  font-family: inherit;
  font-size: inherit;
}

row.spin spinbutton {
  border-spacing: 0;
}

row.spin spinbutton, row.spin spinbutton:focus {
  outline: none;
}

row.entry,
row.spin {
  outline: 0 solid transparent;
  outline-offset: 5px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.entry:focus:focus-visible,
row.spin:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -1px;
}

row.entry.activatable.focused,
row.spin.activatable.focused {
  outline-offset: -1px;
}

row.entry:not(:selected).activatable.focused:hover, row.entry:not(:selected).activatable.focused:active,
row.spin:not(:selected).activatable.focused:hover,
row.spin:not(:selected).activatable.focused:active {
  background-color: transparent;
}

row.entry.error,
row.spin.error {
  color: #FC4138;
}

row.entry.error .dimmed, row.entry.error row.expander image.expander-row-arrow, row.expander row.entry.error image.expander-row-arrow, row.entry.error row.property > box.header > box.title > .title, row.entry.error .dim-label, row.entry.error label.separator,
row.entry.error entry > text > placeholder, row.entry.error spinbutton:not(.vertical) > text > placeholder, row.entry.error spinbutton.vertical > text > text > placeholder, row.entry.error .subtitle,
row.spin.error .dimmed,
row.spin.error row.expander image.expander-row-arrow,
row.expander row.spin.error image.expander-row-arrow,
row.spin.error row.property > box.header > box.title > .title,
row.spin.error .dim-label,
row.spin.error label.separator,
row.spin.error entry > text > placeholder,
row.spin.error spinbutton:not(.vertical) > text > placeholder,
row.spin.error spinbutton.vertical > text > text > placeholder,
row.spin.error .subtitle {
  opacity: 1;
}

row.entry.warning,
row.spin.warning {
  color: #F27835;
}

row.entry.warning .dimmed, row.entry.warning row.expander image.expander-row-arrow, row.expander row.entry.warning image.expander-row-arrow, row.entry.warning row.property > box.header > box.title > .title, row.entry.warning .dim-label, row.entry.warning label.separator,
row.entry.warning entry > text > placeholder, row.entry.warning spinbutton:not(.vertical) > text > placeholder, row.entry.warning spinbutton.vertical > text > text > placeholder, row.entry.warning .subtitle,
row.spin.warning .dimmed,
row.spin.warning row.expander image.expander-row-arrow,
row.expander row.spin.warning image.expander-row-arrow,
row.spin.warning row.property > box.header > box.title > .title,
row.spin.warning .dim-label,
row.spin.warning label.separator,
row.spin.warning entry > text > placeholder,
row.spin.warning spinbutton:not(.vertical) > text > placeholder,
row.spin.warning spinbutton.vertical > text > text > placeholder,
row.spin.warning .subtitle {
  opacity: 1;
}

row.entry.success,
row.spin.success {
  color: #2eb398;
}

row.entry.success .dimmed, row.entry.success row.expander image.expander-row-arrow, row.expander row.entry.success image.expander-row-arrow, row.entry.success row.property > box.header > box.title > .title, row.entry.success .dim-label, row.entry.success label.separator,
row.entry.success entry > text > placeholder, row.entry.success spinbutton:not(.vertical) > text > placeholder, row.entry.success spinbutton.vertical > text > text > placeholder, row.entry.success .subtitle,
row.spin.success .dimmed,
row.spin.success row.expander image.expander-row-arrow,
row.expander row.spin.success image.expander-row-arrow,
row.spin.success row.property > box.header > box.title > .title,
row.spin.success .dim-label,
row.spin.success label.separator,
row.spin.success entry > text > placeholder,
row.spin.success spinbutton:not(.vertical) > text > placeholder,
row.spin.success spinbutton.vertical > text > text > placeholder,
row.spin.success .subtitle {
  opacity: 1;
}

row.combo image.dropdown-arrow:disabled {
  filter: Opacity(0.45);
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

row.combo popover > contents .combo-searchbar {
  margin: 6px;
}

row.combo popover > contents .combo-searchbar + scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

list.boxed-list-separate > row.expander row.header, list.boxed-list > row, list.boxed-list > row.expander row.header, row.expander list.nested > row {
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

list.boxed-list-separate > row.expander row.header, list.boxed-list > row, list.boxed-list > row.expander row.header, row.expander list.nested > row {
  outline: 0 solid transparent;
  outline-offset: 5px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

list.boxed-list-separate > row.expander row.header:focus:focus-visible, list.boxed-list > row:focus:focus-visible, list.boxed-list > row.expander row.header:focus:focus-visible, row.expander list.nested > row:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -1px;
}

list.boxed-list-separate > row.expander row.header:not(:selected).activatable:hover, list.boxed-list > row:not(:selected).activatable:hover, list.boxed-list > row.expander row.header:not(:selected).activatable:hover, row.expander list.nested > row:not(:selected).activatable:hover, list.boxed-list-separate > row.expander row.header:not(:selected).activatable.has-open-popup, list.boxed-list > row:not(:selected).activatable.has-open-popup, list.boxed-list > row.expander row.header:not(:selected).activatable.has-open-popup, row.expander list.nested > row:not(:selected).activatable.has-open-popup {
  background-color: rgba(255, 255, 255, 0.04);
}

list.boxed-list-separate > row.expander row.header:not(:selected).activatable:active, list.boxed-list > row:not(:selected).activatable:active, list.boxed-list > row.expander row.header:not(:selected).activatable:active, row.expander list.nested > row:not(:selected).activatable:active {
  background-color: rgba(255, 255, 255, 0.12);
}

list.boxed-list-separate > row, list.boxed-list {
  background-color: #222b2e;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 2px;
  box-shadow: none;
  color: #ccd7d4;
}

.content-pane list.boxed-list-separate > row, .content-pane list.boxed-list {
  background-color: #1b2224;
  background-clip: border-box;
}

list.boxed-list-separate > row.suggested-action, list.suggested-action.boxed-list {
  background-color: #2eb398;
  color: white;
}

list.boxed-list-separate > row.destructive-action, list.destructive-action.boxed-list {
  background-color: #db5b5b;
  color: white;
}

row.expander {
  background: none;
  padding: 0px;
}

row.expander > box > list {
  background: none;
  color: inherit;
}

row.expander list.nested {
  background-color: mix(#222b2e,#1b2224,0.5);
  color: inherit;
}

row.expander image.expander-row-arrow {
  transition: -gtk-icon-transform 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.expander image.expander-row-arrow:dir(ltr) {
  margin-left: 3px;
}

row.expander image.expander-row-arrow:dir(rtl) {
  margin-right: 3px;
}

row.expander image.expander-row-arrow:dir(ltr) {
  -gtk-icon-transform: rotate(0.5turn);
}

row.expander image.expander-row-arrow:dir(rtl) {
  -gtk-icon-transform: rotate(-0.5turn);
}

row.expander image.expander-row-arrow:disabled {
  filter: Opacity(0.45);
}

row.expander:checked image.expander-row-arrow {
  -gtk-icon-transform: rotate(0turn);
  opacity: 1;
}

row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: #2eb398;
}

.osd row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: inherit;
}

row.button > box {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 40px;
}

row.button > box > .icon:disabled {
  filter: Opacity(0.45);
}

row.button.suggested-action {
  background-color: #2eb398;
  color: white;
}

row.button.suggested-action {
  outline: 0 solid transparent;
  outline-offset: 5px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.button.suggested-action:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: 1px;
}

row.button.suggested-action:not(.expander):not(:selected).activatable:hover, row.button.suggested-action:not(.expander):not(:selected).activatable.has-open-popup {
  background-color: #45cfb3;
  background-image: none;
}

row.button.suggested-action:not(.expander):not(:selected).activatable:active {
  background-color: #2ba78e;
  background-image: none;
}

row.button.suggested-action:disabled {
  opacity: 0.45;
}

row.button.suggested-action:disabled > box > .icon:disabled,
row.button.suggested-action:disabled > box > label:disabled {
  filter: none;
}

row.button.destructive-action {
  background-color: #db5b5b;
  color: white;
}

row.button.destructive-action {
  outline: 0 solid transparent;
  outline-offset: 5px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.button.destructive-action:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: 1px;
}

row.button.destructive-action:not(.expander):not(:selected).activatable:hover, row.button.destructive-action:not(.expander):not(:selected).activatable.has-open-popup {
  background-color: #e48585;
  background-image: none;
}

row.button.destructive-action:not(.expander):not(:selected).activatable:active {
  background-color: #d84e4e;
  background-image: none;
}

row.button.destructive-action:disabled {
  opacity: 0.45;
}

row.button.destructive-action:disabled > box > .icon:disabled,
row.button.destructive-action:disabled > box > label:disabled {
  filter: none;
}

list.boxed-list > row.expander {
  border: none;
}

list.boxed-list > row:first-child, list.boxed-list > row:first-child.expander row.header {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

list.boxed-list > row:last-child, list.boxed-list > row:last-child.expander:not(:checked), list.boxed-list > row:last-child.expander:not(:checked) row.header, list.boxed-list > row:last-child.expander:checked list.nested, list.boxed-list > row:last-child.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-bottom-width: 0;
}

list.boxed-list-separate {
  background: none;
  border: none;
  box-shadow: none;
  color: #ccd7d4;
}

list.boxed-list-separate > row {
  margin-bottom: 12px;
}

list.boxed-list-separate > row:last-child {
  margin-bottom: 0;
}

list.boxed-list-separate > row {
  outline: 0 solid transparent;
  outline-offset: 5px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

list.boxed-list-separate > row:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -1px;
}

list.boxed-list-separate > row.expander row.header {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

list.boxed-list-separate > row.expander:not(:checked) row.header, list.boxed-list-separate > row.expander.expander:checked list.nested, list.boxed-list-separate > row.expander.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-bottom: none;
}

.app-notification {
  padding: 10px;
  color: #abb9b6;
  background-color: alpha(rgba(34, 43, 46, 0.95),0.9);
  background-clip: border-box;
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.25);
}

.app-notification border {
  border: none;
}

.app-notification button {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.95);
}

.app-notification button:hover {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(171, 185, 182, 0.1);
}

.app-notification button:active, .app-notification button:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
  background-clip: padding-box;
}

.app-notification button:disabled {
  color: #4b5657;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.85);
}

.app-notification button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
}

.app-notification .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > entry.error + entry,
.app-notification .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.app-notification .linked:not(.vertical) > entry.warning + entry,
.app-notification .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.app-notification .linked:not(.vertical) > entry.error + entry.warning,
.app-notification .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.app-notification .linked:not(.vertical) > entry + entry:focus-within:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry:focus-within:last-child {
  border-left-color: #2eb398;
}

.app-notification .linked:not(.vertical) > entry:focus-within:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry:focus-within:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #2eb398;
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > entry + entry.warning:focus-within:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

.app-notification .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > entry + entry.error:focus-within:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

.app-notification .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > button:active + entry,
.app-notification .linked:not(.vertical) > button:checked + entry {
  border-left-color: #2eb398;
}

.app-notification .linked:not(.vertical) > button + button {
  border-left-style: none;
  margin-left: 0;
}

.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

.app-notification .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.app-notification .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander:hover {
  color: white;
}

expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

expander-widget > box > title {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

expander-widget:focus:focus-visible > box > title {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

expander-widget > box > title {
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-radius: 2px;
}

expander-widget > box > title:hover > expander {
  color: white;
}

.navigation-sidebar:not(decoration):not(window):drop(active):focus, .navigation-sidebar:not(decoration):not(window):drop(active),
placessidebar:not(decoration):not(window):drop(active):focus,
placessidebar:not(decoration):not(window):drop(active),
stackswitcher:not(decoration):not(window):drop(active):focus,
stackswitcher:not(decoration):not(window):drop(active),
expander-widget:not(decoration):not(window):drop(active):focus,
expander-widget:not(decoration):not(window):drop(active) {
  box-shadow: none;
}

calendar {
  color: #ccd7d4;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 0;
  padding: 0;
}

calendar > header {
  color: #ccd7d4;
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

calendar > header > button {
  border: none;
  box-shadow: none;
  background: none;
  border-radius: 0;
}

calendar > header > button:hover {
  background-color: rgba(204, 215, 212, 0.1);
}

calendar > header > button:active {
  background-color: #2eb398;
}

calendar > header > button:backdrop {
  background: none;
}

calendar > grid > label.day-name,
calendar > grid > label.week-number {
  color: #abb9b6;
}

calendar > grid > label.today {
  background-color: rgba(204, 215, 212, 0.15);
  border-radius: 3px;
}

calendar > grid > label.today:selected {
  box-shadow: none;
}

calendar > grid > label:focus {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-offset: -2px;
  outline-width: 2px;
  outline-style: solid;
}

calendar > grid > label.day-number {
  padding: 4px;
}

calendar > grid > label.day-number:selected {
  border-radius: 3px;
}

calendar > grid > label.day-number.other-month {
  color: alpha(currentColor,0.3);
}

window.dialog.message .titlebar {
  min-height: 20px;
  background-color: #1b2224;
  border: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

window.dialog.message box.dialog-vbox.vertical {
  border-spacing: 10px;
}

window.dialog.message label.title {
  font-weight: 800;
  font-size: 15pt;
}

window.dialog.message .dialog-action-area:not(.vertical) > button {
  padding: 5px 10px;
  border-radius: 0;
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

window.dialog.message .dialog-action-area:not(.vertical) > button:active, window.dialog.message .dialog-action-area:not(.vertical) > button:checked {
  transition: background-color 0.00001s 0.2s;
  animation: ripple_effect 0.2s cubic-bezier(0, 0, 0.2, 1);
}

window.dialog.message .dialog-action-area:not(.vertical) > button, window.dialog.message .dialog-action-area:not(.vertical) > button:hover, window.dialog.message .dialog-action-area:not(.vertical) > button:active, window.dialog.message .dialog-action-area:not(.vertical) > button:checked, window.dialog.message .dialog-action-area:not(.vertical) > button:disabled {
  border-radius: 0;
}

window.dialog.message .dialog-action-area:not(.vertical) > button:first-child, window.dialog.message .dialog-action-area:not(.vertical) > button:hover:first-child, window.dialog.message .dialog-action-area:not(.vertical) > button:active:first-child, window.dialog.message .dialog-action-area:not(.vertical) > button:checked:first-child, window.dialog.message .dialog-action-area:not(.vertical) > button:disabled:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

window.dialog.message .dialog-action-area:not(.vertical) > button:last-child, window.dialog.message .dialog-action-area:not(.vertical) > button:hover:last-child, window.dialog.message .dialog-action-area:not(.vertical) > button:active:last-child, window.dialog.message .dialog-action-area:not(.vertical) > button:checked:last-child, window.dialog.message .dialog-action-area:not(.vertical) > button:disabled:last-child {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

window.dialog.message .dialog-action-area:not(.vertical) > button:only-child, window.dialog.message .dialog-action-area:not(.vertical) > button:hover:only-child, window.dialog.message .dialog-action-area:not(.vertical) > button:active:only-child, window.dialog.message .dialog-action-area:not(.vertical) > button:checked:only-child, window.dialog.message .dialog-action-area:not(.vertical) > button:disabled:only-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
}

window.dialog.message .dialog-action-area:not(.vertical) > button:not(.suggested-action):not(.destructive-action):hover {
  background-color: alpha(#ccd7d4,0.06);
}

window.dialog.message .dialog-action-area:not(.vertical) > button:not(.suggested-action):not(.destructive-action):active, window.dialog.message .dialog-action-area:not(.vertical) > button:not(.suggested-action):not(.destructive-action):checked {
  background-color: alpha(#ccd7d4,0.1);
  color: #ccd7d4;
}

window.dialog.message.csd.background {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border: none;
}

window.dialog.message.csd .dialog-action-area:not(.vertical) > button {
  padding: 6px 10px 8px 10px;
}

window.dialog.message.csd .dialog-action-area:not(.vertical) > button, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:hover, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:active, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:checked, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:disabled {
  border-radius: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.25);
  border-right: none;
  border-bottom: none;
}

window.dialog.message.csd .dialog-action-area:not(.vertical) > button:first-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:hover:first-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:active:first-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:checked:first-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:disabled:first-child {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 0;
  border-left: none;
  border-bottom: none;
}

window.dialog.message.csd .dialog-action-area:not(.vertical) > button:last-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:hover:last-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:active:last-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:checked:last-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:disabled:last-child {
  border-bottom-right-radius: 3px;
  border-top-right-radius: 0;
  border-right: none;
  border-bottom: none;
}

window.dialog.message.csd .dialog-action-area:not(.vertical) > button:only-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:hover:only-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:active:only-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:checked:only-child, window.dialog.message.csd .dialog-action-area:not(.vertical) > button:disabled:only-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-left: none;
  border-right: none;
  border-bottom: none;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.08);
}

filechooserbutton > button > box {
  border-spacing: 6px;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

.sidebar {
  border-style: none;
  background-color: #1b2224;
}

.sidebar:not(separator):dir(ltr), .sidebar:not(separator).left, .sidebar:not(separator).left:dir(rtl) {
  border-right: 1px solid rgba(0, 0, 0, 0.25);
  border-left-style: none;
}

.sidebar:not(separator):dir(rtl), .sidebar:not(separator).right {
  border-left: 1px solid rgba(0, 0, 0, 0.25);
  border-right-style: none;
}

.sidebar listview.view,
.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: none;
}

.sidebar-pane stacksidebar.sidebar {
  border: none;
}

stacksidebar row {
  border-radius: 3px;
  padding: 4px 6px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar row.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

stacksidebar row:focus:focus-visible {
  outline: none;
}

.navigation-sidebar {
  padding: 6px;
  border-radius: 0;
}

.navigation-sidebar > separator {
  margin: 3px 0;
}

.navigation-sidebar > row {
  min-height: 36px;
  padding: 0 8px;
  border-radius: 2px;
  margin: 0;
}

.navigation-sidebar > row + row {
  margin-top: 3px;
}

.navigation-sidebar > row:focus-visible:focus-within {
  background-color: rgba(255, 255, 255, 0.04);
}

.navigation-sidebar > row:selected:focus-visible:focus-within {
  outline: none;
  color: #ffffff;
  background-color: #2eb398;
}

.navigation-sidebar > row:selected:focus-visible:focus-within:hover {
  background-color: #35cbac;
}

placessidebar .navigation-sidebar > row button.sidebar-button {
  min-width: 22px;
  min-height: 22px;
  margin-top: 2px;
  margin-bottom: 2px;
  padding: 0;
  border-radius: 100%;
}

placessidebar .navigation-sidebar > row button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

placessidebar > viewport.frame {
  border-style: none;
}

placessidebar .navigation-sidebar {
  padding: 0;
}

placessidebar .navigation-sidebar > row {
  min-height: 28px;
  padding: 2px 2px 2px 10px;
  border-radius: 0;
}

placessidebar .navigation-sidebar > row > revealer {
  padding: 0 10px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar .navigation-sidebar > row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: linear-gradient(to bottom, #F08437, #F08437);
  background-clip: content-box;
}

placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row {
  color: #2eb398;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled) {
  color: #F08437;
  box-shadow: inset 0 1px #F08437, inset 0 -1px #F08437;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected {
  color: #ffffff;
  background-color: #F08437;
}

placesview .server-list-button > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > box {
  border-spacing: 6px;
}

paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.25), rgba(0, 0, 0, 0.25));
  background-size: 1px 1px;
}

paned > separator:selected {
  background-image: linear-gradient(to bottom, #2eb398, #2eb398);
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
  background-color: #1b2224;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.25), rgba(0, 0, 0, 0.25)), linear-gradient(to bottom, rgba(0, 0, 0, 0.25), rgba(0, 0, 0, 0.25));
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

video {
  background: black;
}

video image.osd {
  min-width: 64px;
  min-height: 64px;
  border-radius: 32px;
}

infobar {
  border-style: none;
}

infobar.info > revealer > box, infobar.info:backdrop > revealer > box {
  background-color: #2eb398;
}

infobar.info > revealer > box selection, infobar.info:backdrop > revealer > box selection {
  color: #2eb398;
}

infobar.question > revealer > box, infobar.question:backdrop > revealer > box {
  background-color: #2eb398;
}

infobar.question > revealer > box selection, infobar.question:backdrop > revealer > box selection {
  color: #2eb398;
}

infobar.warning > revealer > box, infobar.warning:backdrop > revealer > box {
  background-color: #F27835;
}

infobar.warning > revealer > box selection, infobar.warning:backdrop > revealer > box selection {
  color: #F27835;
}

infobar.error > revealer > box, infobar.error:backdrop > revealer > box {
  background-color: #FC4138;
}

infobar.error > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  color: #FC4138;
}

infobar.info > revealer > box, infobar.info:hover > revealer > box, infobar.info:backdrop > revealer > box, infobar.question > revealer > box, infobar.question:hover > revealer > box, infobar.question:backdrop > revealer > box, infobar.warning > revealer > box, infobar.warning:hover > revealer > box, infobar.warning:backdrop > revealer > box, infobar.error > revealer > box, infobar.error:hover > revealer > box, infobar.error:backdrop > revealer > box {
  color: #ffffff;
  caret-color: currentColor;
}

infobar.info > revealer > box > button, infobar.info:hover > revealer > box > button, infobar.info:backdrop > revealer > box > button, infobar.question > revealer > box > button, infobar.question:hover > revealer > box > button, infobar.question:backdrop > revealer > box > button, infobar.warning > revealer > box > button, infobar.warning:hover > revealer > box > button, infobar.warning:backdrop > revealer > box > button, infobar.error > revealer > box > button, infobar.error:hover > revealer > box > button, infobar.error:backdrop > revealer > box > button {
  min-height: 28px;
}

infobar.info > revealer > box selection, infobar.info:hover > revealer > box selection, infobar.info:backdrop > revealer > box selection, infobar.question > revealer > box selection, infobar.question:hover > revealer > box selection, infobar.question:backdrop > revealer > box selection, infobar.warning > revealer > box selection, infobar.warning:hover > revealer > box selection, infobar.warning:backdrop > revealer > box selection, infobar.error > revealer > box selection, infobar.error:hover > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  background-color: #ffffff;
}

infobar .close,
searchbar .close {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  border-radius: 1000px;
}

infobar .close:hover,
searchbar .close:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

windowcontrols {
  border-spacing: 6px;
}

windowcontrols:not(.empty).start:dir(ltr), windowcontrols:not(.empty).end:dir(rtl) {
  margin-right: 7px;
}

windowcontrols:not(.empty).start:dir(rtl), windowcontrols:not(.empty).end:dir(ltr) {
  margin-left: 7px;
}

windowcontrols button {
  margin: 0;
  padding: 0;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

windowcontrols button.close, windowcontrols button.close:hover, windowcontrols button.close:active, windowcontrols button.close:active:hover, windowcontrols button.maximize, windowcontrols button.maximize:hover, windowcontrols button.maximize:active, windowcontrols button.maximize:active:hover, windowcontrols button.minimize, windowcontrols button.minimize:hover, windowcontrols button.minimize:active, windowcontrols button.minimize:active:hover {
  min-width: 30px;
  min-height: 28px;
  margin: 0;
  padding: 0;
  color: transparent;
  background-color: transparent;
  background-position: center;
  background-repeat: no-repeat;
  border-width: 0;
}

windowcontrols button.close:backdrop, windowcontrols button.maximize:backdrop, windowcontrols button.minimize:backdrop {
  opacity: 1;
}

windowcontrols button.close {
  background-image: -gtk-scaled(url("assets/titlebutton-close-dark.png"), url("assets/titlebutton-close-dark@2.png"));
}

windowcontrols button.close:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop-dark.png"), url("assets/titlebutton-close-backdrop-dark@2.png"));
}

windowcontrols button.close:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-close-hover-dark.png"), url("assets/titlebutton-close-hover-dark@2.png"));
}

windowcontrols button.close:active {
  background-image: -gtk-scaled(url("assets/titlebutton-close-active-dark.png"), url("assets/titlebutton-close-active-dark@2.png"));
}

windowcontrols button.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-dark.png"), url("assets/titlebutton-maximize-dark@2.png"));
}

windowcontrols button.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop-dark.png"), url("assets/titlebutton-maximize-backdrop-dark@2.png"));
}

windowcontrols button.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover-dark.png"), url("assets/titlebutton-maximize-hover-dark@2.png"));
}

windowcontrols button.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-active-dark.png"), url("assets/titlebutton-maximize-active-dark@2.png"));
}

windowcontrols button.minimize {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-dark.png"), url("assets/titlebutton-minimize-dark@2.png"));
}

windowcontrols button.minimize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop-dark.png"), url("assets/titlebutton-minimize-backdrop-dark@2.png"));
}

windowcontrols button.minimize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover-dark.png"), url("assets/titlebutton-minimize-hover-dark@2.png"));
}

windowcontrols button.minimize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-active-dark.png"), url("assets/titlebutton-minimize-active-dark@2.png"));
}

.fullscreen windowcontrols button.maximize, .maximized windowcontrols button.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-dark.png"), url("assets/titlebutton-restore-dark@2.png"));
}

.fullscreen windowcontrols button.maximize:backdrop, .maximized windowcontrols button.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop-dark.png"), url("assets/titlebutton-restore-backdrop-dark@2.png"));
}

.fullscreen windowcontrols button.maximize:hover, .maximized windowcontrols button.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover-dark.png"), url("assets/titlebutton-restore-hover-dark@2.png"));
}

.fullscreen windowcontrols button.maximize:active, .maximized windowcontrols button.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active-dark.png"), url("assets/titlebutton-restore-active-dark@2.png"));
}

.nautilus-window .floating-bar button, row:selected button, infobar.info > revealer > box > button, infobar.info:hover > revealer > box > button, infobar.info:backdrop > revealer > box > button, infobar.question > revealer > box > button, infobar.question:hover > revealer > box > button, infobar.question:backdrop > revealer > box > button, infobar.warning > revealer > box > button, infobar.warning:hover > revealer > box > button, infobar.warning:backdrop > revealer > box > button, infobar.error > revealer > box > button, infobar.error:hover > revealer > box > button, infobar.error:backdrop > revealer > box > button {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.5);
}

.nautilus-window .floating-bar button.flat, row:selected button.flat, infobar.info > revealer > box > button.flat, infobar.question > revealer > box > button.flat, infobar.warning > revealer > box > button.flat, infobar.error > revealer > box > button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

.nautilus-window .floating-bar button.flat:disabled, row:selected button.flat:disabled, infobar.info > revealer > box > button.flat:disabled, infobar.question > revealer > box > button.flat:disabled, infobar.warning > revealer > box > button.flat:disabled, infobar.error > revealer > box > button.flat:disabled {
  color: rgba(255, 255, 255, 0.42);
}

.nautilus-window .floating-bar button.flat:disabled label, row:selected button.flat:disabled label, infobar.info > revealer > box > button.flat:disabled label, infobar.question > revealer > box > button.flat:disabled label, infobar.warning > revealer > box > button.flat:disabled label, infobar.error > revealer > box > button.flat:disabled label {
  color: rgba(255, 255, 255, 0.42);
}

.nautilus-window .floating-bar button:hover, row:selected button:hover, infobar.info > revealer > box > button:hover, infobar.question > revealer > box > button:hover, infobar.warning > revealer > box > button:hover, infobar.error > revealer > box > button:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.8);
}

.nautilus-window .floating-bar button:active, row:selected button:active, infobar.info > revealer > box > button:active, infobar.question > revealer > box > button:active, infobar.warning > revealer > box > button:active, infobar.error > revealer > box > button:active, .nautilus-window .floating-bar button:checked, row:selected button:checked, infobar.info > revealer > box > button:checked, infobar.question > revealer > box > button:checked, infobar.warning > revealer > box > button:checked, infobar.error > revealer > box > button:checked {
  color: #2eb398;
  background-color: #ffffff;
  border-color: #ffffff;
}

.nautilus-window .floating-bar button:disabled, row:selected button:disabled, infobar.info > revealer > box > button:disabled, infobar.question > revealer > box > button:disabled, infobar.warning > revealer > box > button:disabled, infobar.error > revealer > box > button:disabled {
  color: rgba(255, 255, 255, 0.5);
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.42);
}

.nautilus-window .floating-bar button:disabled label, row:selected button:disabled label, infobar.info > revealer > box > button:disabled label, infobar.question > revealer > box > button:disabled label, infobar.warning > revealer > box > button:disabled label, infobar.error > revealer > box > button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

.nautilus-window .floating-bar button:disabled:active, row:selected button:disabled:active, infobar.info > revealer > box > button:disabled:active, infobar.question > revealer > box > button:disabled:active, infobar.warning > revealer > box > button:disabled:active, infobar.error > revealer > box > button:disabled:active, .nautilus-window .floating-bar button:disabled:checked, row:selected button:disabled:checked, infobar.info > revealer > box > button:disabled:checked, infobar.question > revealer > box > button:disabled:checked, infobar.warning > revealer > box > button:disabled:checked, infobar.error > revealer > box > button:disabled:checked {
  color: #2eb398;
  background-color: rgba(255, 255, 255, 0.5);
  border-color: rgba(255, 255, 255, 0.42);
}

tooltip {
  padding: 6px 10px;
  border-radius: 2px;
  box-shadow: none;
}

tooltip.background {
  background-color: rgba(0, 0, 0, 0.75);
  background-clip: padding-box;
  border: none;
  color: white;
}

tooltip.csd {
  border-radius: 3px;
  box-shadow: none;
}

tooltip > box {
  border-spacing: 6px;
}

colorswatch, colorswatch:drop(active) {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 2.5px;
  border-top-right-radius: 2.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

colorswatch.bottom {
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 2.5px;
  border-bottom-left-radius: 2.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.dark overlay {
  color: rgba(255, 255, 255, 0.37);
}

colorswatch.dark overlay:hover {
  border-color: rgba(0, 0, 0, 0.25);
}

colorswatch.light overlay {
  color: rgba(0, 0, 0, 0.7);
}

colorswatch.light overlay:hover {
  border-color: rgba(0, 0, 0, 0.25);
}

colorswatch overlay {
  border: 1px solid rgba(0, 0, 0, 0.25);
}

colorswatch overlay:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  color: #ccd7d4;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #263034;
}

colorswatch#add-color-button:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

colorswatch#add-color-button overlay {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button.color {
  padding: 0;
}

button.color colorswatch:first-child:last-child, button.color colorswatch:first-child:last-child overlay {
  margin: 4px;
  border-radius: 0;
}

plane {
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

plane {
  outline: 0 solid transparent;
  outline-offset: 6px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

plane:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: 2px;
}

colorchooser .popover.osd {
  border-radius: 3px;
}

.content-view {
  background-color: #222b2e;
}

.content-view:hover {
  -gtk-icon-filter: brightness(1.2);
}

.content-view .tile {
  margin: 2px;
  background-color: black;
  border-radius: 0;
  padding: 0;
}

.content-view .tile:active, .content-view .tile:selected {
  background-color: #2eb398;
}

.content-view .tile:disabled {
  background-color: #1e2628;
}

.osd .scale-popup button.flat {
  border-style: none;
  border-radius: 3px;
}

.scale-popup button:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

.context-menu {
  font: initial;
}

.monospace {
  font-family: Monospace;
}

.keycap {
  min-width: 16px;
  min-height: 20px;
  padding: 3px 6px 4px 6px;
  color: #ccd7d4;
  background-color: #222b2e;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 2.5px;
  box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.15);
}

stackswitcher button.text-button {
  min-width: 80px;
}

stackswitcher button.circular {
  min-width: 0;
}

window {
  border: none;
  outline: none;
}

window.csd {
  margin: 0;
  border-radius: 3px;
  transition: none;
  box-shadow: 0 3px 5px rgba(0, 0, 0, 0.2), 0 5px 12px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.65);
}

window.csd:backdrop {
  box-shadow: 0 3px 5px rgba(0, 0, 0, 0.2), 0 5px 12px rgba(0, 0, 0, 0), 0 0 0 1px rgba(0, 0, 0, 0.65);
  transition: 200ms ease-out;
}

window.csd.maximized, window.csd.fullscreen, window.csd.tiled, window.csd.tiled-top, window.csd.tiled-left, window.csd.tiled-right, window.csd.tiled-bottom {
  border-radius: 0;
}

window.csd.maximized, window.csd.fullscreen {
  box-shadow: none;
}

window.solid-csd {
  border: 1px solid #141a1b;
  border-radius: 0;
  margin: 0;
  background-color: #141a1b;
  box-shadow: none;
}

cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
  min-width: 20px;
  min-height: 24px;
  padding-left: 20px;
  padding-right: 20px;
  padding-top: 24px;
  padding-bottom: 24px;
}

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-dark.png"), url("assets/text-select-start-dark@2.png"));
}

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-dark.png"), url("assets/text-select-end-dark@2.png"));
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-dark.png"), url("assets/slider-horz-scale-has-marks-above-dark@2.png"));
}

cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover-dark.png"), url("assets/text-select-start-hover-dark@2.png"));
}

cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover-dark.png"), url("assets/text-select-end-hover-dark@2.png"));
}

cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover-dark.png"), url("assets/slider-horz-scale-has-marks-above-hover-dark@2.png"));
}

cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active-dark.png"), url("assets/text-select-start-active-dark@2.png"));
}

cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active-dark.png"), url("assets/text-select-end-active-dark@2.png"));
}

cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) {
  -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active-dark.png"), url("assets/slider-horz-scale-has-marks-above-active-dark@2.png"));
}

shortcuts-section {
  margin: 20px;
}

.shortcuts-search-results {
  margin: 20px;
  border-spacing: 24px;
}

shortcut {
  border-spacing: 6px;
}

shortcut > .keycap {
  min-width: 20px;
  min-height: 25px;
  margin-top: 2px;
  padding-bottom: 3px;
  padding-left: 6px;
  padding-right: 6px;
  color: #ccd7d4;
  background-color: #222b2e;
  border: 1px solid;
  border-color: rgba(0, 0, 0, 0.25);
  border-radius: 5px;
  box-shadow: inset 0 -3px rgba(28, 35, 38, 0.55);
  font-size: smaller;
}

:not(decoration):not(window):drop(active):focus,
:not(decoration):not(window):drop(active) {
  border-color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
  caret-color: #F08437;
}

stackswitcher > button.text-button {
  min-width: 100px;
}

stackswitcher.circular {
  border-spacing: 12px;
}

stackswitcher.circular > button.circular,
stackswitcher.circular > button.text-button.circular {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
}

.lowres-icon {
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1);
}

.icon-dropshadow {
  -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1);
}

textview > text selection:focus, textview > text selection, flowbox > flowboxchild:selected, gridview > child:selected,
entry > text > selection, spinbutton:not(.vertical) > text > selection, spinbutton.vertical > text > text > selection, spinbutton.vertical > text > selection, calendar > grid > label.day-number:selected {
  background-color: #2eb398;
  color: #ffffff;
}

textview > text selection:disabled, flowbox > flowboxchild:disabled:selected, gridview > child:disabled:selected,
entry > text > selection:disabled, spinbutton:not(.vertical) > text > selection:disabled, spinbutton.vertical > text > text > selection:disabled, spinbutton.vertical > text > selection:disabled, calendar > grid > label.day-number:disabled:selected {
  color: #97d9cc;
}

.view:selected:focus, .view:selected, textview > text:selected:focus, textview > text:selected, iconview:selected:focus, iconview:selected, modelbutton.flat:selected {
  background-color: rgba(255, 255, 255, 0.07);
  color: #ccd7d4;
}

.view:disabled:selected, textview > text:disabled:selected:focus, textview > text:disabled:selected, iconview:disabled:selected:focus, iconview:disabled:selected, modelbutton.flat:disabled:selected {
  color: rgba(204, 215, 212, 0.45);
}

popover.emoji-picker > contents {
  padding: 0;
}

.emoji-searchbar {
  padding: 6px;
  border-spacing: 6px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.25);
}

.emoji-toolbar {
  padding: 6px;
  border-spacing: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.25);
}

button.emoji-section {
  border-color: transparent;
  border-width: 3px;
  border-style: solid none none;
  border-radius: 0;
  padding: 3px 0 0;
  min-width: 32px;
  min-height: 24px;
  /* reset props inherited from the button style */
  background: none;
  box-shadow: none;
  text-shadow: none;
}

button.emoji-section:hover {
  border-color: rgba(204, 215, 212, 0.1);
}

button.emoji-section:focus {
  background: none;
}

button.emoji-section:active {
  color: #ccd7d4;
}

button.emoji-section:checked {
  color: #ccd7d4;
  border-color: #2eb398;
}

popover.emoji-picker emoji {
  font-size: x-large;
  padding: 6px;
  border-radius: 6px;
}

popover.emoji-picker emoji:focus, popover.emoji-picker emoji:hover {
  background: #2eb398;
}

emoji-completion-row > box {
  border-spacing: 10px;
  padding: 2px 10px;
}

emoji-completion-row:focus,
emoji-completion-row:hover {
  background-color: #2eb398;
  color: #ffffff;
}

emoji-completion-row emoji:focus,
emoji-completion-row emoji:hover {
  background-color: rgba(255, 255, 255, 0.07);
}

popover.entry-completion > contents {
  padding: 0;
}

statusbar {
  padding: 6px 10px 6px 10px;
}

avatar {
  border-radius: 999px;
  font-weight: bold;
}

avatar.color1 {
  background-image: linear-gradient(#83b6ec, #337fdc);
  color: #cfe1f5;
}

avatar.color2 {
  background-image: linear-gradient(#7ad9f1, #0f9ac8);
  color: #caeaf2;
}

avatar.color3 {
  background-image: linear-gradient(#8de6b1, #29ae74);
  color: #cef8d8;
}

avatar.color4 {
  background-image: linear-gradient(#b5e98a, #6ab85b);
  color: #e6f9d7;
}

avatar.color5 {
  background-image: linear-gradient(#f8e359, #d29d09);
  color: #f9f4e1;
}

avatar.color6 {
  background-image: linear-gradient(#ffcb62, #d68400);
  color: #ffead1;
}

avatar.color7 {
  background-image: linear-gradient(#ffa95a, #ed5b00);
  color: #ffe5c5;
}

avatar.color8 {
  background-image: linear-gradient(#f78773, #e62d42);
  color: #f8d2ce;
}

avatar.color9 {
  background-image: linear-gradient(#e973ab, #e33b6a);
  color: #fac7de;
}

avatar.color10 {
  background-image: linear-gradient(#cb78d4, #9945b5);
  color: #e7c2e8;
}

avatar.color11 {
  background-image: linear-gradient(#9e91e8, #7a59ca);
  color: #d5d2f5;
}

avatar.color12 {
  background-image: linear-gradient(#e3cf9c, #b08952);
  color: #f2eade;
}

avatar.color13 {
  background-image: linear-gradient(#be916d, #785336);
  color: #e5d6ca;
}

avatar.color14 {
  background-image: linear-gradient(#c0bfbc, #6e6d71);
  color: #d8d7d3;
}

avatar.contrasted {
  color: white;
}

avatar.image {
  background: none;
}

button:disabled {
  filter: none;
}

button:disabled label {
  filter: none;
}

button.text-button.image-button > box,
button.text-button.image-button > box > box, button.image-text-button > box,
button.image-text-button > box > box {
  border-spacing: 4px;
}

button.text-button.image-button > box > label,
button.text-button.image-button > box > box > label, button.image-text-button > box > label,
button.image-text-button > box > box > label {
  padding-left: 2px;
  padding-right: 2px;
}

button.arrow-button > box {
  border-spacing: 4px;
}

button.arrow-button.text-button > box {
  border-spacing: 4px;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.destructive-action > button, splitbutton.destructive-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, menubutton.suggested-action > button, menubutton.destructive-action > button, menubutton.opaque > button, button.suggested-action, button.destructive-action, button.opaque {
  box-shadow: none;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.osd splitbutton.suggested-action > button:focus:focus-visible, .osd splitbutton.suggested-action > menubutton > button:focus:focus-visible, .osd splitbutton.destructive-action > button:focus:focus-visible, .osd splitbutton.destructive-action > menubutton > button:focus:focus-visible, .osd splitbutton.opaque > button:focus:focus-visible, .osd splitbutton.opaque > menubutton > button:focus:focus-visible, .osd menubutton.suggested-action > button:focus:focus-visible, .osd menubutton.destructive-action > button:focus:focus-visible, .osd menubutton.opaque > button:focus:focus-visible, .osd button.suggested-action:focus:focus-visible, .osd button.destructive-action:focus:focus-visible, .osd button.opaque:focus:focus-visible {
  outline: none;
}

splitbutton.suggested-action > button:hover, splitbutton.suggested-action > menubutton > button:hover, splitbutton.destructive-action > button:hover, splitbutton.destructive-action > menubutton > button:hover, splitbutton.opaque > button:hover, splitbutton.opaque > menubutton > button:hover, menubutton.suggested-action > button:hover, menubutton.destructive-action > button:hover, menubutton.opaque > button:hover, button.suggested-action:hover, button.destructive-action:hover, button.opaque:hover {
  background-image: image(alpha(currentColor,0.1));
}

splitbutton.suggested-action > button.keyboard-activating, splitbutton.suggested-action > menubutton > button.keyboard-activating, splitbutton.destructive-action > button.keyboard-activating, splitbutton.destructive-action > menubutton > button.keyboard-activating, splitbutton.opaque > button.keyboard-activating, splitbutton.opaque > menubutton > button.keyboard-activating, menubutton.suggested-action > button.keyboard-activating, menubutton.destructive-action > button.keyboard-activating, menubutton.opaque > button.keyboard-activating, button.keyboard-activating.suggested-action, button.keyboard-activating.destructive-action, button.keyboard-activating.opaque, splitbutton.suggested-action > button:active, splitbutton.suggested-action > menubutton > button:active, splitbutton.destructive-action > button:active, splitbutton.destructive-action > menubutton > button:active, splitbutton.opaque > button:active, splitbutton.opaque > menubutton > button:active, menubutton.suggested-action > button:active, menubutton.destructive-action > button:active, menubutton.opaque > button:active, button.suggested-action:active, button.destructive-action:active, button.opaque:active {
  background-image: image(rgba(0, 0, 0, 0.2));
}

splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button:checked, menubutton.suggested-action > button:checked, menubutton.destructive-action > button:checked, menubutton.opaque > button:checked, button.suggested-action:checked, button.destructive-action:checked, button.opaque:checked {
  background-image: image(rgba(0, 0, 0, 0.15));
}

splitbutton.suggested-action > button:checked:hover, splitbutton.suggested-action > menubutton > button:checked:hover, splitbutton.destructive-action > button:checked:hover, splitbutton.destructive-action > menubutton > button:checked:hover, splitbutton.opaque > button:checked:hover, splitbutton.opaque > menubutton > button:checked:hover, menubutton.suggested-action > button:checked:hover, menubutton.destructive-action > button:checked:hover, menubutton.opaque > button:checked:hover, button.suggested-action:checked:hover, button.destructive-action:checked:hover, button.opaque:checked:hover {
  background-image: image(rgba(0, 0, 0, 0.05));
}

splitbutton.suggested-action > button:checked.keyboard-activating, splitbutton.suggested-action > menubutton > button:checked.keyboard-activating, splitbutton.destructive-action > button:checked.keyboard-activating, splitbutton.destructive-action > menubutton > button:checked.keyboard-activating, splitbutton.opaque > button:checked.keyboard-activating, splitbutton.opaque > menubutton > button:checked.keyboard-activating, menubutton.suggested-action > button:checked.keyboard-activating, menubutton.destructive-action > button:checked.keyboard-activating, menubutton.opaque > button:checked.keyboard-activating, button.suggested-action:checked.keyboard-activating, button.destructive-action:checked.keyboard-activating, button.opaque:checked.keyboard-activating, splitbutton.suggested-action > button:checked:active, splitbutton.suggested-action > menubutton > button:checked:active, splitbutton.destructive-action > button:checked:active, splitbutton.destructive-action > menubutton > button:checked:active, splitbutton.opaque > button:checked:active, splitbutton.opaque > menubutton > button:checked:active, menubutton.suggested-action > button:checked:active, menubutton.destructive-action > button:checked:active, menubutton.opaque > button:checked:active, button.suggested-action:checked:active, button.destructive-action:checked:active, button.opaque:checked:active {
  background-image: image(rgba(0, 0, 0, 0.3));
}

button.opaque {
  background-color: #3c4547;
  color: #ccd7d4;
}

button.destructive-action {
  color: white;
}

button.destructive-action, button.destructive-action:checked {
  background-color: #db5b5b;
}

button.suggested-action {
  color: white;
}

button.suggested-action, button.suggested-action:checked {
  background-color: #2eb398;
}

button.font separator {
  background-color: transparent;
}

button.font > box {
  border-spacing: 6px;
}

button.font > box > box > label {
  font-weight: bold;
}

menubutton.pill > button, button.pill {
  min-height: 28px;
  min-width: 28px;
  padding: 6px 12px;
  border-radius: 999px;
}

button.card {
  background-clip: padding-box;
  font-weight: inherit;
  padding: 0;
  color: #ccd7d4;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #263034;
  box-shadow: none;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button.card:hover {
  color: #a1b5b0;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #38464b;
}

button.card.keyboard-activating, button.card:active {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

button.card:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #2eb398;
}

button.card:drop(active) {
  color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
}

menubutton.osd {
  background: none;
  color: inherit;
}

menubutton.suggested-action {
  background-color: #2eb398;
  color: white;
}

menubutton.destructive-action {
  background-color: #db5b5b;
  color: white;
}

menubutton.opaque {
  background-color: #3c4547;
  color: #ccd7d4;
}

menubutton.suggested-action, menubutton.destructive-action, menubutton.opaque {
  border-radius: 2px;
}

menubutton.suggested-action.circular, menubutton.suggested-action.pill, menubutton.destructive-action.circular, menubutton.destructive-action.pill, menubutton.opaque.circular, menubutton.opaque.pill {
  border-radius: 999px;
}

menubutton.suggested-action > button, menubutton.suggested-action > button:checked, menubutton.destructive-action > button, menubutton.destructive-action > button:checked, menubutton.opaque > button, menubutton.opaque > button:checked {
  background-color: transparent;
  color: inherit;
}

menubutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

menubutton arrow {
  min-height: 16px;
  min-width: 16px;
}

menubutton arrow.none {
  -gtk-icon-source: -gtk-icontheme("open-menu-symbolic");
}

menubutton arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menubutton arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menubutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menubutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

splitbutton {
  border-radius: 2px;
}

splitbutton, splitbutton > separator {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background;
}

splitbutton > separator {
  margin-top: 6px;
  margin-bottom: 6px;
  background: none;
}

splitbutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

splitbutton.text-button.image-button > button, splitbutton.image-text-button > button {
  padding-left: 9px;
  padding-right: 9px;
}

splitbutton.text-button.image-button > button > box, splitbutton.image-text-button > button > box {
  border-spacing: 6px;
}

splitbutton > button:dir(ltr),
splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: -1px;
}

splitbutton > button:dir(rtl),
splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin-left: -1px;
}

splitbutton.flat > separator {
  background: rgba(0, 0, 0, 0.25);
}

splitbutton.flat:hover, splitbutton.flat:active, splitbutton.flat:checked {
  background: alpha(currentColor,0.1);
  color: #ccd7d4;
}

splitbutton.flat:hover > separator, splitbutton.flat:active > separator, splitbutton.flat:checked > separator {
  background: none;
}

splitbutton.flat:focus-within:focus-visible > separator {
  background: none;
}

splitbutton.flat > button,
splitbutton.flat > menubutton > button {
  border-radius: 2px;
}

splitbutton.suggested-action {
  background-color: #2eb398;
  color: white;
}

splitbutton.destructive-action {
  background-color: #db5b5b;
  color: white;
}

splitbutton.opaque {
  background-color: #3c4547;
  color: #ccd7d4;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button, splitbutton.opaque > menubutton > button:checked {
  color: inherit;
  background-color: transparent;
}

splitbutton.suggested-action > menubutton > button:dir(ltr), splitbutton.destructive-action > menubutton > button:dir(ltr), splitbutton.opaque > menubutton > button:dir(ltr) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
}

splitbutton.suggested-action > menubutton > button:dir(rtl), splitbutton.destructive-action > menubutton > button:dir(rtl), splitbutton.opaque > menubutton > button:dir(rtl) {
  box-shadow: inset -1px 0 rgba(0, 0, 0, 0.25);
}

splitbutton > menubutton > button > arrow.none {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

buttoncontent {
  border-spacing: 6px;
}

buttoncontent > label {
  font-weight: bold;
}

buttoncontent > label:dir(ltr) {
  padding-right: 2px;
}

buttoncontent > label:dir(rtl) {
  padding-left: 2px;
}

.arrow-button > box > buttoncontent > label:dir(ltr), splitbutton > button > buttoncontent > label:dir(ltr) {
  padding-right: 0;
}

.arrow-button > box > buttoncontent > label:dir(rtl), splitbutton > button > buttoncontent > label:dir(rtl) {
  padding-left: 0;
}

tabbutton label {
  font-weight: 800;
  font-size: 8pt;
}

tabbutton label.small {
  font-size: 6pt;
}

tabbutton indicatorbin > indicator,
tabbutton indicatorbin > mask {
  transform: translate(-1px, 1px);
}

checkbutton {
  border-spacing: 4px;
  border-radius: 2px;
  padding: 3px;
}

.osd checkbutton:focus:focus-visible {
  outline: none;
}

checkbutton.text-button {
  padding: 4px;
}

check,
radio {
  box-shadow: none;
  border: none;
  outline: none;
}

check:not(:checked):not(:indeterminate):active,
radio:not(:checked):not(:indeterminate):active {
  background-color: transparent;
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  background-color: transparent;
  box-shadow: none;
}

check:checked:hover, check:indeterminate:hover,
radio:checked:hover,
radio:indeterminate:hover {
  background-image: none;
}

check:checked:active, check:indeterminate:active,
radio:checked:active,
radio:indeterminate:active {
  background-image: none;
}

check:disabled,
radio:disabled {
  filter: none;
}

.osd check:checked, .osd check:indeterminate, .osd radio:checked, .osd radio:indeterminate {
  background-color: transparent;
}

row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 50px;
}

row > box.header > .icon:disabled {
  filter: opacity(0.45);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
  padding: 0;
}

row > box.header > box.title,
row > box.header > box.title > .title,
row > box.header > box.title > .subtitle {
  padding: 0;
  font-weight: inherit;
}

row > box.header > .prefixes,
row > box.header > .suffixes {
  border-spacing: 6px;
}

row > box.header > .icon:dir(ltr),
row > box.header > .prefixes:dir(ltr) {
  margin-right: 6px;
}

row > box.header > .icon:dir(rtl),
row > box.header > .prefixes:dir(rtl) {
  margin-left: 6px;
}

row.entry {
  outline: 2px solid transparent;
  border-radius: 2px;
}

row.entry.activatable.focused {
  outline: 2px solid #2eb398;
}

row.entry:not(:selected).activatable.focused:hover, row.entry:not(:selected).activatable.focused:active {
  background-color: transparent;
}

row.entry:disabled text {
  opacity: 0.45;
}

row.entry:disabled .dim-label, row.entry:disabled label.separator,
row.entry:disabled entry > text > placeholder, row.entry:disabled spinbutton:not(.vertical) > text > placeholder, row.entry:disabled spinbutton.vertical > text > text > placeholder, row.entry:disabled .subtitle {
  opacity: 1;
}

row.entry .edit-icon, row.entry .indicator {
  min-width: 24px;
  min-height: 24px;
  padding: 5px;
}

row.entry .edit-icon:disabled {
  opacity: 0.5;
}

row.entry .indicator {
  opacity: 0.65;
}

row.entry.monospace {
  font-family: inherit;
}

row.entry.monospace text {
  font-family: monospace;
}

row.entry.error text > selection:focus-within {
  background-color: alpha(#FC4138,0.2);
}

row.entry.error text > cursor-handle > contents {
  background-color: currentColor;
}

row.entry.error .dim-label, row.entry.error label.separator,
row.entry.error entry > text > placeholder, row.entry.error spinbutton:not(.vertical) > text > placeholder, row.entry.error spinbutton.vertical > text > text > placeholder, row.entry.error .subtitle {
  opacity: 1;
}

row.entry.error .suggested-action {
  background-color: #FC4138;
  color: white;
}

row.entry.warning text > selection:focus-within {
  background-color: alpha(#F27835,0.2);
}

row.entry.warning text > cursor-handle > contents {
  background-color: currentColor;
}

row.entry.warning .dim-label, row.entry.warning label.separator,
row.entry.warning entry > text > placeholder, row.entry.warning spinbutton:not(.vertical) > text > placeholder, row.entry.warning spinbutton.vertical > text > text > placeholder, row.entry.warning .subtitle {
  opacity: 1;
}

row.entry.warning .suggested-action {
  background-color: #F27835;
  color: white;
}

row.entry.success text > selection:focus-within {
  background-color: alpha(#2eb398,0.2);
}

row.entry.success text > cursor-handle > contents {
  background-color: currentColor;
}

row.entry.success .dim-label, row.entry.success label.separator,
row.entry.success entry > text > placeholder, row.entry.success spinbutton:not(.vertical) > text > placeholder, row.entry.success spinbutton.vertical > text > text > placeholder, row.entry.success .subtitle {
  opacity: 1;
}

row.entry.success .suggested-action {
  background-color: #2eb398;
  color: white;
}

row.combo image.dropdown-arrow:disabled {
  filter: opacity(0.45);
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

toast {
  margin: 12px;
  margin-bottom: 24px;
  border-radius: 6px;
  border-spacing: 6px;
  padding: 6px;
  background-color: #222b2e;
  color: #abb9b6;
  box-shadow: 0 3px 8px rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.25);
}

toast:dir(ltr) {
  padding-left: 12px;
}

toast:dir(rtl) {
  padding-right: 12px;
}

toast > widget {
  margin: 0 6px;
}

window.about .main-page > viewport > clamp > box {
  margin: 12px;
  border-spacing: 6px;
}

window.about .main-page > viewport > clamp > box > box {
  margin-top: 18px;
  border-spacing: 18px;
  margin-bottom: 6px;
}

window.about .main-page .app-version {
  padding: 3px 18px;
  color: #2eb398;
  border-radius: 999px;
  margin-top: 3px;
}

window.about .subpage > viewport > clamp > box {
  margin: 18px 12px;
  border-spacing: 18px;
}

window.about .subpage > clamp > textview {
  background: none;
  color: inherit;
}

statuspage > scrolledwindow > viewport > box {
  margin: 36px 12px;
  border-spacing: 36px;
}

statuspage > scrolledwindow > viewport > box > clamp > box {
  border-spacing: 12px;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 128px;
  color: alpha(currentColor,0.45);
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:disabled {
  opacity: 0.45;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 24px;
}

statuspage.compact > scrolledwindow > viewport > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 96px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 12px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title {
  font-size: 18pt;
}

.card {
  color: #ccd7d4;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: #263034;
  border-radius: 2px;
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.25);
  background-clip: padding-box;
}

.osd .card, .card.osd {
  color: #abb9b6;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(41, 51, 55, 0.95);
}

.card.activatable {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.card.activatable:hover {
  background-image: image(alpha(currentColor,0.03));
}

.card.activatable:active {
  background-image: image(alpha(currentColor,0.08));
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 34px;
}

viewswitcher {
  margin: 0;
}

headerbar viewswitcher {
  margin: -6px 0;
}

viewswitcher button.toggle:hover {
  background-color: rgba(198, 205, 203, 0.06);
  color: #c6cdcb;
}

viewswitcher button.toggle:active {
  background-color: rgba(198, 205, 203, 0.16);
  color: #c6cdcb;
}

viewswitcher button.toggle:checked {
  background-color: rgba(198, 205, 203, 0.08);
  color: #c6cdcb;
  box-shadow: inset 0 -3px #2eb398;
}

viewswitcher.wide {
  border-spacing: 0;
}

viewswitcher.wide button.toggle {
  border-radius: 0;
  margin: 0;
  border: none;
}

viewswitcher.narrow button.toggle {
  border-radius: 0;
  margin: 0;
  border: none;
}

viewswitcher button.toggle {
  font-weight: bold;
  padding: 0;
  min-height: 0;
  border: none;
}

viewswitcher button.toggle > stack > box.narrow {
  font-size: 0.75rem;
  padding-top: 9px;
  padding-bottom: 3px;
  border-spacing: 3px;
}

viewswitcher button.toggle > stack > box.narrow > stack > label {
  padding-left: 8px;
  padding-right: 8px;
}

viewswitcher button.toggle > stack > box.wide {
  padding: 0 12px;
  border-spacing: 6px;
}

viewswitcherbar actionbar > revealer > box {
  padding: 0;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:hover {
  background-color: rgba(204, 215, 212, 0.06);
  color: #ccd7d4;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:active {
  background-color: rgba(204, 215, 212, 0.16);
  color: #ccd7d4;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:checked {
  background-color: rgba(204, 215, 212, 0.08);
  color: #ccd7d4;
  box-shadow: inset 0 3px #2eb398;
}

viewswitchertitle {
  margin-top: 0;
  margin-bottom: 0;
}

viewswitchertitle viewswitcher {
  margin-left: 12px;
  margin-right: 12px;
}

viewswitchertitle windowtitle {
  margin-top: 0;
  margin-bottom: 0;
}

indicatorbin > indicator, indicatorbin > mask {
  min-width: 6px;
  min-height: 6px;
  border-radius: 999px;
}

indicatorbin > indicator {
  margin: 1px;
  background: alpha(currentColor,0.4);
}

indicatorbin > indicator > label {
  font-size: 0.6rem;
  font-weight: bold;
  padding: 0 4px;
  color: white;
}

indicatorbin > mask {
  padding: 1px;
  background: black;
}

indicatorbin.needs-attention > indicator {
  background: #2eb398;
}

indicatorbin.needs-attention > indicator > label {
  color: #ffffff;
}

tabbar .box {
  min-height: 28px;
}

tabbar tabbox {
  padding: 0;
}

tabbar tabbox > tabboxchild {
  border-radius: 0;
  margin-bottom: 0;
  margin-top: 0;
}

tabbar tabbox > tabboxchild {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

tabbar tabbox > tabboxchild:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

tabbar tabbox > separator {
  margin-top: 9px;
  margin-bottom: 9px;
  transition: opacity 150ms ease-in-out;
}

tabbar tabbox > separator.hidden {
  opacity: 0;
}

tabbar tabbox > revealer > indicator {
  min-width: 2px;
  border-radius: 2px;
  margin: 9px 6px;
  background: alpha(#2eb398,0.5);
}

tabbar tab {
  transition: background 150ms ease-in-out;
}

tabbar tab:selected, tabbar tab:checked {
  background-color: transparent;
  box-shadow: inset 0 -3px #2eb398;
  color: #ccd7d4;
}

tabbar tab:hover:not(:selected):not(:checked) {
  box-shadow: inset 0 -3px #21665a;
}

tabbar .start-action,
tabbar .end-action {
  padding: 5px;
}

tabbar .start-action:dir(ltr),
tabbar .end-action:dir(rtl) {
  padding-right: 0;
}

tabbar .start-action:dir(rtl),
tabbar .end-action:dir(ltr) {
  padding-left: 0;
}

tabbar:not(.inline) .box {
  background-color: #1b2224;
  color: #abb9b6;
  padding-bottom: 0;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.25);
  border: none;
}

tabbar:not(.inline):backdrop .box {
  transition: 200ms ease-out;
}

tabbar:not(.inline):backdrop .box > scrolledwindow,
tabbar:not(.inline):backdrop .box > .start-action,
tabbar:not(.inline):backdrop .box > .end-action {
  filter: opacity(0.5);
  transition: 200ms ease-out;
}

dnd tab {
  background-color: #1b2224;
  color: #abb9b6;
  box-shadow: none;
  margin: 24px;
}

tabbar tab,
dnd tab {
  min-height: 28px;
  padding: 2px 6px 3px 6px;
  border-radius: 0;
}

tabbar tab button.image-button,
dnd tab button.image-button {
  padding: 0;
  margin: 0;
  min-width: 20px;
  min-height: 20px;
  border-radius: 999px;
  border: none;
}

tabbar tab button.image-button:hover,
dnd tab button.image-button:hover {
  color: #ff4d4d;
  background-color: #101415;
}

tabbar tab button.image-button:active,
dnd tab button.image-button:active {
  color: #2eb398;
  background-color: #0a0c0d;
}

tabbar tab indicator,
dnd tab indicator {
  min-height: 2px;
  border-radius: 2px;
  background: alpha(#2eb398,0.5);
}

tabgrid > tabgridchild .card {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

tabgrid > tabgridchild:focus:focus-visible .card {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: 0;
}

tabthumbnail {
  transition: box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

tabthumbnail, tabthumbnail > .card {
  border-radius: 3px;
}

tabthumbnail > box {
  margin: 6px;
}

tabthumbnail:drop(active) {
  box-shadow: inset 0 0 0 3px alpha(#F08437,0.4);
  background-color: alpha(#F08437,0.1);
}

tabthumbnail .needs-attention:dir(ltr) {
  transform: translate(8px, -8px);
}

tabthumbnail .needs-attention:dir(rtl) {
  transform: translate(-8px, -8px);
}

tabthumbnail .needs-attention > widget {
  background: #2eb398;
  min-width: 12px;
  min-height: 12px;
  border-radius: 8px;
  margin: 3px;
  box-shadow: 0 1px 2px alpha(#2eb398,0.4);
}

tabthumbnail .card {
  background: none;
  color: inherit;
}

tabthumbnail .card picture {
  outline: none;
  border-radius: 3px;
}

tabthumbnail.pinned .card {
  background-color: #222b2e;
  color: #abb9b6;
}

tabthumbnail .icon-title-box {
  border-spacing: 6px;
}

tabthumbnail .tab-unpin-icon {
  margin: 6px;
  min-width: 24px;
  min-height: 24px;
}

tabthumbnail button.circular {
  margin: 6px;
  background-color: alpha(#222b2e,0.75);
  min-width: 24px;
  min-height: 24px;
}

tabthumbnail button.circular:hover {
  background-color: alpha(mix(#222b2e,currentColor,0.1),0.75);
}

tabthumbnail button.circular:active {
  background-color: alpha(mix(#222b2e,currentColor,0.2),0.75);
}

taboverview > .overview .new-tab-button {
  margin: 18px;
}

tabview:drop(active),
tabbox:drop(active),
tabgrid:drop(active) {
  box-shadow: none;
}

.unfolded stacksidebar.sidebar {
  border: none;
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 28px;
}

preferencesgroup > box button.background-preview-button.toggle {
  padding: 0;
  background: none;
  box-shadow: none;
  outline-color: transparent;
  outline-width: 2px;
  outline-offset: 3px;
  outline-style: solid;
  border: none;
}

preferencesgroup > box button.background-preview-button.toggle, preferencesgroup > box button.background-preview-button.toggle > background-preview {
  border-radius: 2px;
}

preferencesgroup > box button.background-preview-button.toggle:hover {
  outline-color: rgba(204, 215, 212, 0.06);
}

preferencesgroup > box button.background-preview-button.toggle:active {
  outline-color: rgba(204, 215, 212, 0.2);
}

preferencesgroup > box button.background-preview-button.toggle:checked {
  outline-color: #2eb398;
}

flap > dimming,
leaflet > dimming,
navigation-view > dimming,
overlay-split-view > dimming {
  background: none;
}

flap > border,
leaflet > border,
navigation-view > border,
overlay-split-view > border {
  background: none;
}

flap > shadow,
leaflet > shadow,
navigation-view > shadow,
overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

flap > shadow.left,
leaflet > shadow.left,
navigation-view > shadow.left,
overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

flap > shadow.right,
leaflet > shadow.right,
navigation-view > shadow.right,
overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

flap > shadow.up,
leaflet > shadow.up,
navigation-view > shadow.up,
overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

flap > shadow.down,
leaflet > shadow.down,
navigation-view > shadow.down,
overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

toolbarview.undershoot-top scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.unfolded stacksidebar.sidebar {
  border: none;
}

.sidebar-pane .navigation-sidebar > row {
  color: #c6cdcb;
}

.sidebar-pane .navigation-sidebar > row .sidebar-icon {
  color: rgba(198, 205, 203, 0.6);
}

.sidebar-pane .navigation-sidebar > row:hover {
  color: #c6cdcb;
  background-color: rgba(255, 255, 255, 0.08);
}

.sidebar-pane .navigation-sidebar > row:active {
  color: #c6cdcb;
  background-color: rgba(255, 255, 255, 0.12);
}

.sidebar-pane .navigation-sidebar > row:selected {
  background-color: #2eb398;
  color: #ffffff;
}

.sidebar-pane .navigation-sidebar > row:selected:hover {
  background-color: #35cbac;
  color: #ffffff;
}

.sidebar-pane .navigation-sidebar > row:disabled {
  color: rgba(198, 205, 203, 0.45);
}

.sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button {
  color: #c6cdcb;
}

.sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:hover {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(198, 205, 203, 0.18);
}

.sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:active {
  color: #ffffff;
  border-color: transparent;
  background-color: #2eb398;
}

.sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

.sidebar-pane .navigation-sidebar > row:backdrop {
  opacity: 0.75;
}

.sidebar-pane .navigation-sidebar separator {
  background-color: transparent;
}

.sidebar-pane {
  background-color: rgba(48, 59, 62, 0.95);
  color: #c6cdcb;
}

.sidebar-pane:backdrop {
  background-color: #1b2224;
  color: rgba(198, 205, 203, 0.45);
}

.sidebar-pane .dim-label, .sidebar-pane label.separator,
.sidebar-pane entry > text > placeholder, .sidebar-pane spinbutton:not(.vertical) > text > placeholder, .sidebar-pane spinbutton.vertical > text > text > placeholder, .sidebar-pane headerbar .subtitle, headerbar .sidebar-pane .subtitle, .sidebar-pane popover.background label.separator, popover.background .sidebar-pane label.separator, .sidebar-pane row label.subtitle, row .sidebar-pane label.subtitle {
  color: rgba(198, 205, 203, 0.45);
}

.sidebar-pane .sidebar,
.sidebar-pane .toolbar,
.sidebar-pane .navigation-sidebar,
.sidebar-pane searchbar > revealer > box {
  background-color: transparent;
  box-shadow: none;
  border: none;
}

.sidebar-pane headerbar {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  border: none;
  border-top-right-radius: 0;
}

.sidebar-pane .toolbar {
  padding: 6px;
}

.sidebar-pane flap > dimming,
.sidebar-pane leaflet > dimming,
.sidebar-pane navigation-view > dimming,
.sidebar-pane overlay-split-view > dimming {
  background: none;
}

.sidebar-pane flap > border,
.sidebar-pane leaflet > border,
.sidebar-pane navigation-view > border,
.sidebar-pane overlay-split-view > border {
  background: none;
}

.sidebar-pane flap > shadow,
.sidebar-pane leaflet > shadow,
.sidebar-pane navigation-view > shadow,
.sidebar-pane overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

.sidebar-pane flap > shadow.left,
.sidebar-pane leaflet > shadow.left,
.sidebar-pane navigation-view > shadow.left,
.sidebar-pane overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(#171d1f,0.7), alpha(#171d1f,0.14) 40px, alpha(#171d1f,0) 56px), linear-gradient(to right, alpha(#171d1f,0.4), alpha(#171d1f,0.14) 7px, alpha(#171d1f,0) 24px);
}

.sidebar-pane flap > shadow.right,
.sidebar-pane leaflet > shadow.right,
.sidebar-pane navigation-view > shadow.right,
.sidebar-pane overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(#171d1f,0.7), alpha(#171d1f,0.14) 40px, alpha(#171d1f,0) 56px), linear-gradient(to left, alpha(#171d1f,0.4), alpha(#171d1f,0.14) 7px, alpha(#171d1f,0) 24px);
}

.sidebar-pane flap > shadow.up,
.sidebar-pane leaflet > shadow.up,
.sidebar-pane navigation-view > shadow.up,
.sidebar-pane overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(#171d1f,0.7), alpha(#171d1f,0.14) 40px, alpha(#171d1f,0) 56px), linear-gradient(to bottom, alpha(#171d1f,0.4), alpha(#171d1f,0.14) 7px, alpha(#171d1f,0) 24px);
}

.sidebar-pane flap > shadow.down,
.sidebar-pane leaflet > shadow.down,
.sidebar-pane navigation-view > shadow.down,
.sidebar-pane overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(#171d1f,0.7), alpha(#171d1f,0.14) 40px, alpha(#171d1f,0) 56px), linear-gradient(to top, alpha(#171d1f,0.4), alpha(#171d1f,0.14) 7px, alpha(#171d1f,0) 24px);
}

.sidebar-pane banner > revealer > widget {
  background-color: mix(#2eb398,rgba(48, 59, 62, 0.95),0.7);
  color: #c6cdcb;
}

.sidebar-pane banner > revealer > widget:backdrop {
  background-color: mix(#2eb398,rgba(48, 59, 62, 0.95),0.7);
}

.sidebar-pane:dir(ltr), .sidebar-pane:dir(ltr) banner > revealer > widget, .sidebar-pane.end:dir(rtl), .sidebar-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: 1px solid #171d1f;
}

.sidebar-pane:dir(rtl), .sidebar-pane:dir(rtl) banner > revealer > widget, .sidebar-pane.end:dir(ltr), .sidebar-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: 1px solid #171d1f;
}

/* Middle pane in three-pane setups */
.content-pane .sidebar-pane,
.sidebar-pane .content-pane {
  background-color: #222b2e;
  color: #abb9b6;
}

.content-pane .sidebar-pane:backdrop,
.sidebar-pane .content-pane:backdrop {
  background-color: #222b2e;
}

.content-pane .sidebar-pane flap > dimming,
.content-pane .sidebar-pane leaflet > dimming,
.content-pane .sidebar-pane navigation-view > dimming,
.content-pane .sidebar-pane overlay-split-view > dimming,
.sidebar-pane .content-pane flap > dimming,
.sidebar-pane .content-pane leaflet > dimming,
.sidebar-pane .content-pane navigation-view > dimming,
.sidebar-pane .content-pane overlay-split-view > dimming {
  background: none;
}

.content-pane .sidebar-pane flap > border,
.content-pane .sidebar-pane leaflet > border,
.content-pane .sidebar-pane navigation-view > border,
.content-pane .sidebar-pane overlay-split-view > border,
.sidebar-pane .content-pane flap > border,
.sidebar-pane .content-pane leaflet > border,
.sidebar-pane .content-pane navigation-view > border,
.sidebar-pane .content-pane overlay-split-view > border {
  background: none;
}

.content-pane .sidebar-pane flap > shadow,
.content-pane .sidebar-pane leaflet > shadow,
.content-pane .sidebar-pane navigation-view > shadow,
.content-pane .sidebar-pane overlay-split-view > shadow,
.sidebar-pane .content-pane flap > shadow,
.sidebar-pane .content-pane leaflet > shadow,
.sidebar-pane .content-pane navigation-view > shadow,
.sidebar-pane .content-pane overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

.content-pane .sidebar-pane flap > shadow.left,
.content-pane .sidebar-pane leaflet > shadow.left,
.content-pane .sidebar-pane navigation-view > shadow.left,
.content-pane .sidebar-pane overlay-split-view > shadow.left,
.sidebar-pane .content-pane flap > shadow.left,
.sidebar-pane .content-pane leaflet > shadow.left,
.sidebar-pane .content-pane navigation-view > shadow.left,
.sidebar-pane .content-pane overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

.content-pane .sidebar-pane flap > shadow.right,
.content-pane .sidebar-pane leaflet > shadow.right,
.content-pane .sidebar-pane navigation-view > shadow.right,
.content-pane .sidebar-pane overlay-split-view > shadow.right,
.sidebar-pane .content-pane flap > shadow.right,
.sidebar-pane .content-pane leaflet > shadow.right,
.sidebar-pane .content-pane navigation-view > shadow.right,
.sidebar-pane .content-pane overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

.content-pane .sidebar-pane flap > shadow.up,
.content-pane .sidebar-pane leaflet > shadow.up,
.content-pane .sidebar-pane navigation-view > shadow.up,
.content-pane .sidebar-pane overlay-split-view > shadow.up,
.sidebar-pane .content-pane flap > shadow.up,
.sidebar-pane .content-pane leaflet > shadow.up,
.sidebar-pane .content-pane navigation-view > shadow.up,
.sidebar-pane .content-pane overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

.content-pane .sidebar-pane flap > shadow.down,
.content-pane .sidebar-pane leaflet > shadow.down,
.content-pane .sidebar-pane navigation-view > shadow.down,
.content-pane .sidebar-pane overlay-split-view > shadow.down,
.sidebar-pane .content-pane flap > shadow.down,
.sidebar-pane .content-pane leaflet > shadow.down,
.sidebar-pane .content-pane navigation-view > shadow.down,
.sidebar-pane .content-pane overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.7), alpha(rgba(0, 0, 0, 0.25),0.14) 40px, alpha(rgba(0, 0, 0, 0.25),0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.4), alpha(rgba(0, 0, 0, 0.25),0.14) 7px, alpha(rgba(0, 0, 0, 0.25),0) 24px);
}

.content-pane .sidebar-pane banner > revealer > widget,
.sidebar-pane .content-pane banner > revealer > widget {
  background-color: mix(#2eb398,#222b2e,0.7);
  color: #abb9b6;
}

.content-pane .sidebar-pane banner > revealer > widget:backdrop,
.sidebar-pane .content-pane banner > revealer > widget:backdrop {
  background-color: mix(#2eb398,#222b2e,0.7);
}

.content-pane .sidebar-pane:dir(ltr), .content-pane .sidebar-pane:dir(ltr) banner > revealer > widget, .content-pane .sidebar-pane.end:dir(rtl), .content-pane .sidebar-pane.end:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane:dir(ltr),
.sidebar-pane .content-pane:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(rtl),
.sidebar-pane .content-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: 1px solid rgba(0, 0, 0, 0.25);
}

.content-pane .sidebar-pane:dir(rtl), .content-pane .sidebar-pane:dir(rtl) banner > revealer > widget, .content-pane .sidebar-pane.end:dir(ltr), .content-pane .sidebar-pane.end:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane:dir(rtl),
.sidebar-pane .content-pane:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(ltr),
.sidebar-pane .content-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: 1px solid rgba(0, 0, 0, 0.25);
}

.sidebar-pane toolbarview.undershoot-top scrolledwindow > undershoot.top,
.content-pane toolbarview.undershoot-top scrolledwindow > undershoot.top,
.content-pane .sidebar-pane toolbarview.undershoot-top scrolledwindow > undershoot.top,
.sidebar-pane .content-pane toolbarview.undershoot-top scrolledwindow > undershoot.top {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.25);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.content-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.content-pane .sidebar-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.sidebar-pane .content-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.25);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-top > undershoot.top,
.content-pane scrolledwindow.undershoot-top > undershoot.top,
.content-pane .sidebar-pane scrolledwindow.undershoot-top > undershoot.top,
.sidebar-pane .content-pane scrolledwindow.undershoot-top > undershoot.top {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.25);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.content-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.content-pane .sidebar-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.sidebar-pane .content-pane scrolledwindow.undershoot-bottom > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.25);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.content-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.content-pane .sidebar-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.sidebar-pane .content-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.content-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.content-pane .sidebar-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.sidebar-pane .content-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right {
  box-shadow: inset -1px 0 rgba(0, 0, 0, 0.25);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.content-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.content-pane .sidebar-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.sidebar-pane .content-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right {
  box-shadow: inset -1px 0 rgba(0, 0, 0, 0.25);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.content-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.content-pane .sidebar-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.sidebar-pane .content-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.25);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25),0.25), transparent 6px);
}

.sidebar-pane .sidebar-pane {
  background-color: transparent;
  color: inherit;
}

.content-pane {
  background-color: #222b2e;
}

.content-pane:backdrop {
  background-color: #1b2224;
}

.content-pane headerbar {
  border-top-left-radius: 0;
}

.content-pane headerbar, .content-pane headerbar:backdrop {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  border: none;
}

.content-pane toolbarview, .content-pane toolbarview.view {
  background-color: transparent;
}

.content-pane toolbarview > stack, .content-pane toolbarview > box > stack.view {
  background-color: transparent;
}

toolbarview > .top-bar searchbar > revealer > box,
toolbarview > .top-bar actionbar > revealer > box,
toolbarview > .bottom-bar searchbar > revealer > box,
toolbarview > .bottom-bar actionbar > revealer > box {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

toolbarview > .top-bar .toolbar,
toolbarview > .bottom-bar .toolbar {
  background-color: transparent;
}

toolbarview > .top-bar .collapse-spacing,
toolbarview > .bottom-bar .collapse-spacing {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing headerbar,
toolbarview > .bottom-bar .collapse-spacing headerbar {
  min-height: 42px;
}

toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar > windowhandle > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration {
  min-height: 28px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration > windowhandle > box {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .top-bar .collapse-spacing actionbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing actionbar > revealer > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing .toolbar,
toolbarview > .bottom-bar .collapse-spacing .toolbar {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing tabbar,
toolbarview > .bottom-bar .collapse-spacing tabbar {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar.raised,
toolbarview > .bottom-bar.raised {
  background-color: transparent;
  color: #c6cdcb;
}

toolbarview > .top-bar.raised:backdrop,
toolbarview > .bottom-bar.raised:backdrop {
  background-color: transparent;
}

toolbarview > .top-bar:backdrop > windowhandle,
toolbarview > .bottom-bar:backdrop > windowhandle {
  filter: none;
}

toolbarview > .bottom-bar {
  padding: 0;
  border-spacing: 0;
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.25);
  background-color: color-mix(in srgb, black 5%, #1b2224);
  color: #abb9b6;
}

toolbarview > .bottom-bar:backdrop {
  background-color: #1b2224;
  color: rgba(204, 215, 212, 0.45);
}

toolbarview > .bottom-bar actionbar > revealer > box {
  padding: 0;
}

toolbarview > .top-bar.raised {
  box-shadow: none;
}

toolbarview > .top-bar.raised.border {
  box-shadow: none;
}

toolbarview > .bottom-bar.raised {
  box-shadow: none;
}

toolbarview > .bottom-bar.raised.border {
  box-shadow: none;
}

banner > revealer > widget {
  /* There are 2 more instances in _sidebars.css, keep in sync with that */
  background-color: mix(#2eb398,#1b2224,0.7);
  color: #ccd7d4;
  padding: 6px;
}

banner > revealer > widget:backdrop {
  background-color: mix(#2eb398,#1b2224,0.85);
  transition: background-color 200ms ease-out;
}

banner > revealer > widget:backdrop > label, banner > revealer > widget:backdrop > button {
  filter: opacity(0.5);
  transition: filter 200ms ease-out;
}

toggle-group {
  background: #263034;
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 4px;
  padding: 2px;
  background-clip: padding-box;
}

toggle-group:disabled {
  background-color: alpha(#263034,0.45);
}

toggle-group > toggle {
  border-radius: 2px;
  font-weight: bold;
  min-width: 34px;
  min-height: 28px;
}

toggle-group > toggle.image-button > image:disabled {
  filter: opacity(0.55);
}

toggle-group > toggle.text-button {
  min-width: 24px;
  padding-left: 8px;
  padding-right: 8px;
}

toggle-group > toggle.text-button > label:disabled {
  filter: opacity(0.55);
}

toggle-group > toggle.image-text-button {
  min-width: 16px;
  padding-left: 8px;
  padding-right: 8px;
}

toggle-group > toggle.image-text-button > buttoncontent > box > label {
  padding: 0;
}

toggle-group > toggle.image-text-button > buttoncontent > box > image:disabled,
toggle-group > toggle.image-text-button > buttoncontent > box > label:disabled {
  filter: opacity(0.55);
}

toggle-group > toggle {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

toggle-group > toggle:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: 0;
}

toggle-group.vertical > toggle:not(.text-button):not(.image-text-button) {
  min-width: 28px;
}

toggle-group.osd, .osd toggle-group {
  padding: 2px;
}

toggle-group > separator {
  transition: opacity 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

toggle-group > separator.horizontal {
  margin: 3px 0;
}

toggle-group > separator.vertical {
  margin: 0 3px;
}

toggle-group > separator.hidden {
  opacity: 0;
}

toggle-group > separator:disabled {
  filter: Opacity(0.45);
}

toggle-group.round {
  border-radius: 999px;
}

toggle-group.round toggle {
  border-radius: 999px;
}

toggle-group.round toggle.text-button, toggle-group.round toggle.image-text-button {
  padding-left: 12px;
  padding-right: 12px;
}

toggle-group.round separator.horizontal {
  margin: 6px 0;
}

toggle-group.round separator.vertical {
  margin: 0 6px;
}

toggle-group.flat {
  background: none;
  color: inherit;
  box-shadow: none;
  border: none;
  padding: 0;
}

toggle-group.flat > toggle {
  outline: 0 solid transparent;
  outline-offset: 4px;
  transition: outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

toggle-group.flat > toggle:focus:focus-visible {
  outline-color: rgba(46, 179, 152, 0.7);
  outline-width: 2px;
  outline-offset: -2px;
}

toggle-group.flat > separator {
  background: none;
}

/*************************
 * AdwInlineViewSwitcher *
 *************************/
inline-view-switcher > toggle-group.icons > toggle {
  min-width: 34px;
}

inline-view-switcher > toggle-group.labels > toggle {
  min-width: 12px;
}

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin {
  padding-left: 8px;
  padding-right: 8px;
}

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > label {
  padding: 0 6px;
}

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > indicator, inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > mask {
  transform: translateY(2px);
}

inline-view-switcher > toggle-group.both > toggle {
  min-width: 16px;
}

inline-view-switcher > toggle-group.both > toggle > widget > box {
  padding-left: 12px;
  padding-right: 12px;
  border-spacing: 6px;
}

themeselector,
panelthemeselector {
  margin: 9px;
}

themeselector checkbutton,
panelthemeselector checkbutton {
  padding: 1px;
  min-height: 44px;
  min-width: 44px;
  background-clip: content-box;
  border-radius: 100%;
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.25);
}

themeselector checkbutton radio,
panelthemeselector checkbutton radio {
  min-height: 16px;
  min-width: 16px;
  transform: translate(27px, 14px);
  padding: 3px;
}

themeselector checkbutton radio, themeselector checkbutton radio:hover, themeselector checkbutton radio:disabled,
panelthemeselector checkbutton radio,
panelthemeselector checkbutton radio:hover,
panelthemeselector checkbutton radio:disabled {
  -gtk-icon-source: none;
  border: none;
  background: none;
  box-shadow: none;
}

themeselector checkbutton radio:checked, themeselector checkbutton radio:checked:hover, themeselector checkbutton radio:active, themeselector checkbutton radio:active:hover,
panelthemeselector checkbutton radio:checked,
panelthemeselector checkbutton radio:checked:hover,
panelthemeselector checkbutton radio:active,
panelthemeselector checkbutton radio:active:hover {
  -gtk-icon-source: -gtk-icontheme("object-select-symbolic");
  background-image: image(#2eb398);
  background-color: #2eb398;
  color: #ffffff;
}

themeselector checkbutton.follow:checked, themeselector checkbutton.light:checked, themeselector checkbutton.dark:checked,
panelthemeselector checkbutton.follow:checked,
panelthemeselector checkbutton.light:checked,
panelthemeselector checkbutton.dark:checked {
  box-shadow: inset 0 0 0 2px #2eb398;
}

themeselector checkbutton.light,
panelthemeselector checkbutton.light {
  background-color: #ffffff;
}

themeselector checkbutton.dark,
panelthemeselector checkbutton.dark {
  background-color: #202020;
}

themeselector checkbutton.follow,
panelthemeselector checkbutton.follow {
  background-image: linear-gradient(to bottom right, #fff 49.99%, #202020 50.01%);
}

themeswitcher {
  padding: 6px;
}

themeswitcher .check {
  min-height: 16px;
  min-width: 16px;
  background-color: #2eb398;
  color: #ffffff;
  padding: 2px;
  border-radius: 100%;
  margin: 3px;
  -gtk-icon-size: 20px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/check-symbolic.svg")), -gtk-recolor(url("assets/scalable/check-symbolic@2.svg")));
}

themeswitcher .check:hover {
  background-color: #45cfb3;
  color: #ffffff;
}

themeswitcher .check:active {
  background-color: #2eb398;
  color: #ffffff;
}

themeswitcher checkbutton radio {
  padding: 0;
  margin: 2px;
  min-height: 48px;
  min-width: 48px;
}

themeswitcher checkbutton radio, themeswitcher checkbutton radio:active, themeswitcher checkbutton radio:hover {
  outline-color: rgba(0, 0, 0, 0.25);
  outline-width: 1px;
  outline-offset: -1px;
  outline-style: solid;
  box-shadow: none;
}

themeswitcher checkbutton radio, themeswitcher checkbutton radio:hover, themeswitcher checkbutton radio:active, themeswitcher checkbutton radio:checked, themeswitcher checkbutton radio:checked:hover {
  -gtk-icon-source: none;
  transition: none;
  border: none;
}

themeswitcher checkbutton radio:checked, themeswitcher checkbutton radio:checked:hover, themeswitcher checkbutton radio:active, themeswitcher checkbutton radio:active:hover {
  box-shadow: inset 0 0 0 2px #2eb398;
}

themeswitcher checkbutton.system radio, themeswitcher checkbutton.system radio:hover, themeswitcher checkbutton.system radio:active, themeswitcher checkbutton.system radio:checked, themeswitcher checkbutton.system radio:checked:hover {
  background-image: linear-gradient(-45deg, #242424 49.99%, white 50.01%);
  background-color: transparent;
}

themeswitcher checkbutton.light radio, themeswitcher checkbutton.light radio:hover, themeswitcher checkbutton.light radio:active, themeswitcher checkbutton.light radio:checked, themeswitcher checkbutton.light radio:checked:hover {
  color: rgba(0, 0, 0, 0.8);
  background-color: white;
}

themeswitcher checkbutton.dark radio, themeswitcher checkbutton.dark radio:hover, themeswitcher checkbutton.dark radio:active, themeswitcher checkbutton.dark radio:checked, themeswitcher checkbutton.dark radio:checked:hover {
  color: white;
  background-image: image(#242424);
  background-color: transparent;
}

floating-sheet > dimming {
  background-color: rgba(0, 0, 0, 0.35);
}

floating-sheet > sheet {
  border-radius: 3px;
  outline: none;
  box-shadow: 0 3px 5px rgba(0, 0, 0, 0.2), 0 5px 12px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.65);
}

#NautilusPathBar > menubutton > button, #NautilusPathBar #NautilusPathButton, .nautilus-window headerbar splitbutton > button,
.nautilus-window headerbar splitbutton > menubutton > button {
  border-radius: 2px;
  border: none;
  min-height: 22px;
  min-width: 22px;
  padding: 0 6px;
}

#NautilusPathBar > menubutton > button:hover, #NautilusPathBar #NautilusPathButton:hover, .nautilus-window headerbar splitbutton > button:hover,
.nautilus-window headerbar splitbutton > menubutton > button:hover {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.1);
}

#NautilusPathBar > menubutton > button:active, #NautilusPathBar #NautilusPathButton:active, .nautilus-window headerbar splitbutton > button:active,
.nautilus-window headerbar splitbutton > menubutton > button:active {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.2);
}

#NautilusPathBar > menubutton > button:checked, #NautilusPathBar #NautilusPathButton:checked, .nautilus-window headerbar splitbutton > button:checked,
.nautilus-window headerbar splitbutton > menubutton > button:checked {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.15);
}

.sidebar-pane scrollbar {
  border-color: rgba(37, 45, 48, 0.95);
}

.sidebar-pane scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough > slider {
  background-color: #eff1f0;
  border: 1px solid rgba(0, 0, 0, 0.3);
}

.sidebar-pane scrollbar > range > trough {
  background-color: rgba(37, 45, 48, 0.95);
}

.sidebar-pane scrollbar > range > trough > slider {
  background-color: rgba(239, 241, 240, 0.7);
}

.sidebar-pane scrollbar > range > trough > slider:hover {
  background-color: #fcfdfd;
}

.sidebar-pane scrollbar > range > trough > slider:hover:active {
  background-color: #2eb398;
}

.sidebar-pane scrollbar > range > trough > slider:disabled {
  background-color: transparent;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row, .nautilus-window flap .navigation-sidebar > row {
  color: #c6cdcb;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row .sidebar-icon, .nautilus-window flap .navigation-sidebar > row .sidebar-icon {
  color: rgba(198, 205, 203, 0.75);
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:hover, .nautilus-window flap .navigation-sidebar > row:hover {
  background-color: rgba(255, 255, 255, 0.08);
  box-shadow: inset 3px 0 #45cfb3;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:active, .nautilus-window flap .navigation-sidebar > row:active {
  background-color: rgba(255, 255, 255, 0.12);
  box-shadow: inset 3px 0 #45cfb3;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:selected, .nautilus-window flap .navigation-sidebar > row:selected {
  background-color: #2eb398;
  color: #ffffff;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:selected:hover, .nautilus-window flap .navigation-sidebar > row:selected:hover {
  background-color: #35cbac;
  color: #ffffff;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:selected .sidebar-icon, .nautilus-window flap .navigation-sidebar > row:selected .sidebar-icon {
  color: rgba(255, 255, 255, 0.75);
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:disabled, .nautilus-window flap .navigation-sidebar > row:disabled {
  color: rgba(198, 205, 203, 0.45);
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button, .nautilus-window flap .navigation-sidebar > row:not(:selected) button.sidebar-button {
  color: #c6cdcb;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:hover, .nautilus-window flap .navigation-sidebar > row:not(:selected) button.sidebar-button:hover {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(198, 205, 203, 0.18);
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:active, .nautilus-window flap .navigation-sidebar > row:not(:selected) button.sidebar-button:active {
  color: #ffffff;
  border-color: transparent;
  background-color: #2eb398;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image, .nautilus-window flap .navigation-sidebar > row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row.sidebar-new-bookmark-row, .nautilus-window flap .navigation-sidebar > row.sidebar-new-bookmark-row {
  color: #2eb398;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row.sidebar-new-bookmark-row .sidebar-icon, .nautilus-window flap .navigation-sidebar > row.sidebar-new-bookmark-row .sidebar-icon {
  color: inherit;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:backdrop, .nautilus-window flap .navigation-sidebar > row:backdrop {
  opacity: 0.75;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:drop(active):not(:disabled), .nautilus-window flap .navigation-sidebar > row:drop(active):not(:disabled) {
  color: #F08437;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row:drop(active):not(:disabled):selected, .nautilus-window flap .navigation-sidebar > row:drop(active):not(:disabled):selected {
  color: #ffffff;
  background-color: #F08437;
}

.nautilus-window .sidebar-pane .navigation-sidebar separator, .nautilus-window flap .navigation-sidebar separator {
  background-color: transparent;
}

.nautilus-window headerbar splitbutton {
  border-radius: 2px;
  border: 1px solid transparent;
  padding: 2px;
  min-height: 22px;
  border-spacing: 2px;
}

.nautilus-window headerbar splitbutton, .nautilus-window headerbar splitbutton:hover {
  background-clip: padding-box;
}

.nautilus-window headerbar splitbutton:hover {
  color: #c6cdcb;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: rgba(198, 205, 203, 0.18);
}

.nautilus-window flap .navigation-sidebar {
  background-color: rgba(48, 59, 62, 0.95);
  color: #c6cdcb;
  padding: 0;
}

.nautilus-window flap .navigation-sidebar > row.sidebar-row {
  margin: 0;
  border: none;
  border-radius: 0;
}

.nautilus-window .sidebar-pane .navigation-sidebar {
  padding: 0;
}

.nautilus-window .sidebar-pane .navigation-sidebar > row.sidebar-row {
  margin: 0;
  border: none;
  border-radius: 0;
}

.nautilus-grid-view child.activatable {
  border-radius: 3px;
  border: 1px solid transparent;
  color: #ccd7d4;
}

.nautilus-grid-view child.activatable:hover {
  background-color: rgba(204, 215, 212, 0.08);
}

.nautilus-grid-view child.activatable:active {
  background-color: rgba(204, 215, 212, 0.16);
}

.nautilus-grid-view child.activatable:selected {
  background-color: rgba(46, 179, 152, 0.45);
  border-color: #2eb398;
  color: #7dc5b6;
}

.nautilus-list-view listview.view > row.activatable {
  border-radius: 2px;
  border: 1px solid transparent;
  color: #ccd7d4;
}

.nautilus-list-view listview.view > row.activatable:hover {
  background-color: rgba(204, 215, 212, 0.08);
}

.nautilus-list-view listview.view > row.activatable:active {
  background-color: rgba(204, 215, 212, 0.16);
}

.nautilus-list-view listview.view > row.activatable:selected {
  background-color: rgba(46, 179, 152, 0.45);
  border-color: #2eb398;
  color: #7dc5b6;
}

.content-pane .nautilus-grid-view, .content-pane .nautilus-grid-view .view,
.content-pane .nautilus-list-view,
.content-pane .nautilus-list-view .view {
  background-color: transparent;
}

#NautilusViewCell clamp box {
  margin: 0;
  border-spacing: 0;
}

#NautilusQueryEditor {
  border-spacing: 0;
}

#NautilusQueryEditor > * {
  margin: 0;
}

#NautilusQueryEditor #NautilusQueryEditorTag > button {
  margin: 0;
}

#NautilusQueryEditor > menubutton > button {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-size: 16px;
  margin: 0;
  padding: 3px;
  border-radius: 999px;
  border: none;
}

#NautilusQueryEditor > menubutton > button:hover {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.1);
}

#NautilusQueryEditor > menubutton > button:active {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.2);
}

#NautilusQueryEditor > menubutton > button:checked {
  color: #c6cdcb;
  background-color: rgba(198, 205, 203, 0.15);
}

#NautilusPathBar {
  min-height: 0;
  background-color: rgba(198, 205, 203, 0.1);
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.25);
  background-clip: padding-box;
  border-spacing: 2px;
}

#NautilusPathBar #NautilusPathButton label.dim-label {
  color: rgba(198, 205, 203, 0.75);
}

#NautilusPathBar #NautilusPathButton label.dim-label:hover, #NautilusPathBar #NautilusPathButton label.dim-label:active, #NautilusPathBar #NautilusPathButton label.dim-label:checked {
  color: #c6cdcb;
}

#NautilusPathBar #NautilusPathButton.current-dir {
  color: #c6cdcb;
}

#NautilusPathBar #NautilusPathButton.current-dir:hover, #NautilusPathBar #NautilusPathButton.current-dir:active {
  background: none;
  box-shadow: none;
}

#NautilusPathBar > menubutton {
  padding: 2px;
}

#NautilusPathBar > menubutton > button {
  border: none;
}

.nautilus-window .floating-bar {
  padding: 1px;
  background-color: #222b2e;
  color: #ccd7d4;
  border-radius: 2px 2px 0 0;
  border: 1px solid rgba(0, 0, 0, 0.25);
  box-shadow: none;
}

.nautilus-window .floating-bar.bottom.left {
  border-top-left-radius: 0;
  border-width: 1px 1px 0 0;
}

.nautilus-window .floating-bar.bottom.right {
  border-top-right-radius: 0;
  border-width: 1px 0 0 1px;
}

.nautilus-window .floating-bar button {
  border: none;
  border-radius: 100px;
  min-height: 0;
  min-width: 0;
  padding: 0;
  margin-right: 6px;
  -gtk-icon-shadow: none;
}

datechooser .current-week {
  background-color: rgba(204, 215, 212, 0.05);
}

datechooser label.weeknum {
  color: rgba(204, 215, 212, 0.75);
}

datechooser label.weekday {
  color: rgba(204, 215, 212, 0.45);
}

datechooser button.day {
  border: none;
}

datechooser button.day:selected {
  background-color: #2eb398;
  color: #ffffff;
}

datechooser navigator > button.flat {
  padding: 0;
  min-height: 32px;
  min-width: 32px;
}

agenda-view list.background {
  background-color: transparent;
}

menubutton.flat.popup.sources-button {
  margin: 0;
}

menubutton.flat.popup.sources-button > button {
  margin: 0;
  border-radius: 0;
  padding: 0 12px;
}

menubutton.flat.popup.sources-button > button .title {
  font-size: small;
  font-weight: normal;
}

menubutton.flat.popup.sources-button > button .title, menubutton.flat.popup.sources-button > button .subtitle {
  padding: 2px 0 2px 6px;
}

menubutton.flat.popup.sources-button > button image.calendar-color-image {
  -gtk-icon-size: 8px;
}

.sidebar-pane datechooser .current-week {
  background-color: rgba(198, 205, 203, 0.05);
}

.sidebar-pane datechooser label.weeknum {
  color: rgba(198, 205, 203, 0.75);
}

.sidebar-pane datechooser label.weekday {
  color: rgba(198, 205, 203, 0.45);
}

@define-color theme_fg_color #ccd7d4;
@define-color theme_text_color #abb9b6;
@define-color theme_bg_color #1b2224;
@define-color theme_base_color #222b2e;
@define-color theme_selected_bg_color #2eb398;
@define-color theme_selected_fg_color #ffffff;
@define-color fg_color #ccd7d4;
@define-color text_color #abb9b6;
@define-color bg_color #1b2224;
@define-color base_color #222b2e;
@define-color selected_bg_color #2eb398;
@define-color selected_fg_color #ffffff;
@define-color insensitive_bg_color #1f282a;
@define-color insensitive_fg_color alpha(rgba(204, 215, 212, 0.45), 0.5);
@define-color insensitive_base_color #222b2e;
@define-color theme_unfocused_fg_color #ccd7d4;
@define-color theme_unfocused_text_color #abb9b6;
@define-color theme_unfocused_bg_color #1b2224;
@define-color theme_unfocused_base_color #222b2e;
@define-color borders rgba(0, 0, 0, 0.25);
@define-color unfocused_borders rgba(0, 0, 0, 0.25);
@define-color warning_color #F27835;
@define-color error_color #FC4138;
@define-color success_color #2eb398;
@define-color placeholder_text_color #A8A8A8;
@define-color link_color #6ddac4;
@define-color content_view_bg #222b2e;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #151b1c;
@define-color wm_title alpha(#c6cdcb, 0.8);
@define-color wm_unfocused_title alpha(#c6cdcb, 0.5);
@define-color wm_bg #141a1b;
@define-color wm_bg_unfocused #1f282a;
@define-color wm_highlight #1b2224;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_button_close_bg #cc575d;
@define-color wm_button_close_hover_bg #d7787d;
@define-color wm_button_close_active_bg #be3841;
@define-color wm_icon_close_bg #141a1b;
@define-color wm_button_hover_bg #2a3538;
@define-color wm_button_active_bg #2eb398;
@define-color wm_button_hover_border rgba(0, 0, 0, 0.25);
@define-color wm_icon_bg #c6cdcb;
@define-color wm_icon_unfocused_bg #454f4c;
@define-color wm_icon_hover_bg #c6cdcb;
@define-color wm_icon_active_bg #ffffff;
@define-color budgie_tasklist_indicator_color #2eb398;
@define-color budgie_tasklist_indicator_color_active #2eb398;
@define-color budgie_tasklist_indicator_color_active_window #257063;
@define-color budgie_tasklist_indicator_color_attention #F27835;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
