@keyframes header_ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, #f2f2f2 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, #f2f2f2 100%, transparent 0%);
  }
}

@keyframes ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 100%, transparent 0%);
  }
}

* {
  background-clip: padding-box;
  -GtkToolButton-icon-spacing: 4;
  -GtkTextView-error-underline-color: #FC4138;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkToolItemGroup-expander-size: 11;
  -GtkWidget-text-handle-width: 20;
  -GtkWidget-text-handle-height: 20;
  -GtkDialog-button-spacing: 4;
  -GtkDialog-action-area-border: 0;
  outline-color: alpha(currentColor,0.3);
  outline-style: dashed;
  outline-offset: -3px;
  outline-width: 1px;
  -gtk-outline-radius: 2px;
}

.background {
  color: #2b2f3b;
  background-color: #f7f7f7;
}

.background.csd {
  border-radius: 0 0 2px 2px;
}

.background.csd.maximized {
  border-radius: 0;
}

.popup.background.csd {
  border-radius: 2px;
}

*:disabled {
  -gtk-icon-effect: dim;
}

.gtkstyle-fallback {
  background-color: #f7f7f7;
  color: #2b2f3b;
}

.gtkstyle-fallback:hover {
  background-color: white;
  color: #2b2f3b;
}

.gtkstyle-fallback:active {
  background-color: #dedede;
  color: #2b2f3b;
}

.gtkstyle-fallback:disabled {
  background-color: #fcfcfc;
  color: rgba(43, 47, 59, 0.55);
}

.gtkstyle-fallback:selected {
  background-color: #3498db;
  color: #ffffff;
}

button.gtkstyle-fallback:active, button.gtkstyle-fallback:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.view, iconview {
  color: #2e313d;
  background-color: #ffffff;
}

.view:hover, iconview:hover {
  color: #2b2f3b;
  background-color: #eeeeef;
}

.view:selected:hover, iconview:selected:hover {
  background-color: #2f89c5;
}

textview, textview.view {
  background-color: #ffffff;
}

textview text {
  background-color: #ffffff;
}

textview border {
  background-color: #fbfbfb;
}

iconview:hover, iconview:active, iconview:selected {
  border-radius: 2px;
}

rubberband, XfdesktopIconView.view .rubberband, .content-view rubberband, treeview.view rubberband, flowbox rubberband,
.rubberband {
  border: 1px solid #217dbb;
  background-color: rgba(33, 125, 187, 0.2);
}

flowbox flowboxchild {
  padding: 3px;
  border-radius: 2px;
}

flowbox flowboxchild:selected {
  outline-offset: -2px;
}

flowbox flowboxchild:focus {
  background-image: image(rgba(43, 47, 59, 0.05));
  background-clip: border-box;
}

label.separator {
  color: #2b2f3b;
}

label selection {
  color: #ffffff;
  background-color: #3498db;
}

label:disabled {
  color: rgba(43, 47, 59, 0.55);
}

label:disabled selection {
  color: #9acced;
}

.dim-label, .slate-notification .notification-body,
.budgie-notification .notification-body,
.budgie-switcher .notification-body, popover label.separator,
popover.background label.separator, headerbar .subtitle, label.separator {
  opacity: 0.55;
}

assistant .sidebar {
  background-color: #ffffff;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

assistant.csd .sidebar {
  border-top-style: none;
}

assistant .sidebar label {
  padding: 6px 12px;
}

assistant .sidebar label.highlight {
  background-color: #3498db;
  color: #ffffff;
}

.osd .scale-popup, popover.osd, popover.magnifier, .csd popover.osd, .csd popover.magnifier,
popover.background.osd,
popover.background.magnifier, .csd popover.background.osd, .csd popover.background.magnifier, .osd {
  color: #2e313d;
  border: none;
  background-color: rgba(255, 255, 255, 0.95);
  background-clip: padding-box;
  box-shadow: none;
}

@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

.large-title {
  font-weight: 300;
  font-size: 24pt;
}

.title-1 {
  font-weight: 800;
  font-size: 20pt;
}

.title-2 {
  font-weight: 800;
  font-size: 15pt;
}

.title-3 {
  font-weight: 700;
  font-size: 15pt;
}

.title-4 {
  font-weight: 700;
  font-size: 13pt;
}

.heading {
  font-weight: 700;
  font-size: 11pt;
}

.body {
  font-weight: 400;
  font-size: 11pt;
}

.caption-heading {
  font-weight: 700;
  font-size: 9pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
}

entry {
  min-height: 22px;
  border: 1px solid;
  padding: 2px 8px;
  caret-color: currentColor;
  border-radius: 3px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
  outline: none;
}

entry.search {
  border-radius: 50px;
}

entry image {
  color: #555962;
}

entry image.left {
  padding-left: 0;
  padding-right: 5px;
}

entry image.right {
  padding-right: 0;
  padding-left: 5px;
}

.raven .raven-background spinbutton:not(.vertical), .raven .raven-background spinbutton:focus:not(.vertical), entry.flat, entry.flat:focus {
  min-height: 0;
  padding: 2px;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

entry:focus {
  background-clip: border-box;
  color: #2e313d;
  border-color: #3498db;
  background-color: #ffffff;
  outline: none;
}

entry:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.55);
}

entry.warning {
  color: white;
  border-color: #F27835;
  background-color: #f7ae86;
}

entry.warning image {
  color: white;
}

entry.warning:focus {
  color: white;
  background-color: #F27835;
  box-shadow: none;
}

entry.warning selection, entry.warning selection:focus {
  background-color: white;
  color: #F27835;
}

entry.error {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.error image {
  color: white;
}

entry.error:focus {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.error selection, entry.error selection:focus {
  background-color: white;
  color: #FC4138;
}

entry.search-missing {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.search-missing image {
  color: white;
}

entry.search-missing:focus {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.search-missing selection, entry.search-missing selection:focus {
  background-color: white;
  color: #FC4138;
}

entry:drop(active):focus, entry:drop(active) {
  border-color: #F08437;
  box-shadow: none;
}

.osd entry {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.95);
}

.osd entry image, .osd entry image:hover {
  color: inherit;
}

.osd entry:focus {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #3498db;
}

.osd entry:disabled {
  color: rgba(46, 49, 61, 0.55);
  background-color: rgba(255, 255, 255, 0.85);
}

.osd entry selection:focus, .osd entry selection {
  color: #3498db;
  background-color: #ffffff;
}

entry progress {
  margin: 0 -6px;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #3498db;
  border-style: solid;
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #ffffff;
}

treeview entry.flat:focus, treeview entry:focus {
  border-color: #3498db;
}

@keyframes needs_attention {
  from {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#3498db), to(transparent));
  }
  to {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#3498db), to(transparent));
  }
}

button {
  min-height: 22px;
  min-width: 20px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border: 1px solid;
  border-radius: 3px;
  padding: 2px 6px;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

button separator {
  margin: 4px 1px;
}

#tasklist-button, .budgie-panel button.flat.launcher, button.budgie-menu-launcher, .budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable button, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button, tabbox > tab button, placessidebar row button.sidebar-button, button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  transition: none;
}

#tasklist-button:hover, .budgie-panel button.flat.launcher:hover, button.budgie-menu-launcher:hover, .budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable button:hover, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover, tabbox > tab button:hover, placessidebar row button.sidebar-button:hover, button.flat:hover {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 350ms;
}

#tasklist-button:hover:active, button.budgie-menu-launcher:hover:active, .budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable button:hover:active, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover:active, tabbox > tab button:hover:active, placessidebar row button.sidebar-button:hover:active, button.flat:hover:active {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

#tasklist-button:disabled, .budgie-panel button.flat.launcher:disabled, button.budgie-menu-launcher:disabled, .budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable button:disabled, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:disabled, tabbox > tab button:disabled, placessidebar row button.sidebar-button:disabled, button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
  -gtk-icon-effect: highlight;
}

button:active, button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
  background-clip: border-box;
  transition-duration: 50ms;
}

button:active:not(:disabled) label:disabled, button:checked:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

button:active {
  color: #2b2f3b;
}

button:active:hover, button:checked {
  color: #ffffff;
}

button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

button:disabled label, button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

button:disabled:active, button:disabled:checked {
  border-color: rgba(52, 152, 219, 0.75);
  background-color: rgba(52, 152, 219, 0.75);
  opacity: 0.6;
}

button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

button.image-button {
  min-width: 24px;
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

button.text-button.image-button {
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button.image-button label:first-child {
  padding-left: 8px;
  padding-right: 2px;
}

button.text-button.image-button label:last-child {
  padding-right: 8px;
  padding-left: 2px;
}

button.text-button.image-button label:only-child {
  padding-left: 8px;
  padding-right: 8px;
}

button.text-button.image-button.popup {
  padding-right: 8px;
  padding-left: 8px;
}

button:drop(active) {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

button.osd {
  color: #2e313d;
  background-color: rgba(255, 255, 255, 0.95);
  border-color: rgba(235, 235, 235, 0.95);
}

button.osd.image-button {
  padding: 0;
  min-height: 36px;
  min-width: 36px;
}

button.osd:hover {
  color: #3498db;
}

button.osd:active, button.osd:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

button.osd:disabled {
  color: #c0c1c5;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

.osd button {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.95);
}

.osd button:hover {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(46, 49, 61, 0.1);
}

.osd button:active, .osd button:checked {
  background-clip: padding-box;
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.osd button:disabled {
  color: #c0c1c5;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

.osd button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

.osd button.flat:hover {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(46, 49, 61, 0.1);
}

.osd button.flat:disabled {
  color: #c0c1c5;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
  background-image: none;
}

.osd button.flat:active, .osd button.flat:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child), .osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
  box-shadow: none;
}

button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #3498db;
  border-color: #3498db;
}

button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #3498db;
}

button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #4aa3df;
  border-color: #4aa3df;
}

button.suggested-action:active, button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #5faee3;
  border-color: #5faee3;
}

button.suggested-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(43, 47, 59, 0.55);
}

button.suggested-action:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

button.suggested-action:disabled label, button.suggested-action:disabled {
  color: rgba(43, 47, 59, 0.55);
}

button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #db5b5b;
}

button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #e07070;
  border-color: #e07070;
}

button.destructive-action:active, button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #e48585;
  border-color: #e48585;
}

button.destructive-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(43, 47, 59, 0.55);
}

button.destructive-action:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

button.destructive-action:disabled label, button.destructive-action:disabled {
  color: rgba(43, 47, 59, 0.55);
}

.stack-switcher > button {
  outline-offset: -3px;
}

.stack-switcher > button > label {
  padding-left: 6px;
  padding-right: 6px;
}

.stack-switcher > button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px;
}

.stack-switcher > button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

.stack-switcher > button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button stacksidebar row.needs-attention > label, stacksidebar button row.needs-attention > label, .stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#3498db), to(transparent));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 4px;
}

button stacksidebar row.needs-attention > label:dir(rtl), stacksidebar button row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px, left 4px;
}

button.font separator, button.file separator {
  background-color: transparent;
}

.inline-toolbar button, .inline-toolbar button:backdrop {
  border-radius: 2px;
  border-width: 1px;
}

.inline-toolbar toolbutton > button {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

.inline-toolbar toolbutton > button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.inline-toolbar toolbutton > button:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked {
  border-color: rgba(52, 152, 219, 0.75);
  background-color: rgba(52, 152, 219, 0.75);
  opacity: 0.6;
}

.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

toolbar.inline-toolbar toolbutton:first-child > button.flat, .inline-toolbar toolbutton:first-child > button.flat {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

toolbar.inline-toolbar toolbutton:last-child > button.flat, .inline-toolbar toolbutton:last-child > button.flat {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

toolbar.inline-toolbar toolbutton:only-child > button.flat, .inline-toolbar toolbutton:only-child > button.flat {
  border-radius: 3px;
  border-style: solid;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry.warning,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus:last-child {
  border-left-color: #3498db;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #3498db;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + entry {
  border-left-color: #3498db;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button + button {
  border-left-style: none;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button + button {
  border-left-style: none;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
  box-shadow: none;
}

.osd .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
}

.osd .linked:not(.vertical) > entry.error + entry,
.osd .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.warning + entry,
.osd .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.error + entry.warning,
.osd .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.osd .linked:not(.vertical) > entry + entry:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry:focus:last-child {
  border-left-color: #3498db;
}

.osd .linked:not(.vertical) > entry:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #3498db;
}

.osd .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.osd .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry + entry.warning:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry + entry.error:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > button:active + entry,
.osd .linked:not(.vertical) > button:checked + entry {
  border-left-color: #3498db;
}

.osd .linked:not(.vertical) > button + button {
  border-left-style: none;
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

.linked.vertical > entry + entry {
  border-top-color: rgba(0, 0, 0, 0.3);
}

.linked.vertical > entry.error + entry,
.linked.vertical > entry + entry.error {
  border-top-color: #FC4138;
}

.linked.vertical > entry.warning + entry,
.linked.vertical > entry + entry.warning {
  border-top-color: #F27835;
}

.linked.vertical > entry.error + entry.warning,
.linked.vertical > entry.warning + entry.error {
  border-top-color: #f75d37;
}

.linked.vertical > entry + entry:focus:not(:last-child),
.linked.vertical > entry + entry:focus:last-child {
  border-top-color: #3498db;
}

.linked.vertical > entry:focus:not(:only-child) + entry,
.linked.vertical > entry:focus:not(:only-child) + button,
.linked.vertical > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #3498db;
}

.linked.vertical > entry + entry:drop(active):not(:last-child),
.linked.vertical > entry + entry:drop(active):last-child {
  border-top-color: #F08437;
}

.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #F08437;
}

.linked.vertical > entry + entry.warning:focus:not(:last-child),
.linked.vertical > entry + entry.warning:focus:last-child {
  border-top-color: #F27835;
}

.linked.vertical > entry.warning:focus:not(:only-child) + entry,
.linked.vertical > entry.warning:focus:not(:only-child) + button,
.linked.vertical > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #F27835;
}

.linked.vertical > entry + entry.error:focus:not(:last-child),
.linked.vertical > entry + entry.error:focus:last-child {
  border-top-color: #FC4138;
}

.linked.vertical > entry.error:focus:not(:only-child) + entry,
.linked.vertical > entry.error:focus:not(:only-child) + button,
.linked.vertical > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #FC4138;
}

.linked.vertical > button:active + entry,
.linked.vertical > button:checked + entry {
  border-top-color: #3498db;
}

.linked.vertical > button + button {
  border-top-style: none;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.15);
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.15);
}

.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry.error, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry.warning,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry.error {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:last-child, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:last-child {
  border-left-color: #3498db;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):last-child, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:last-child, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:last-child, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:not(:last-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + entry, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:hover, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:hover,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + entry, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + entry,
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button + button, .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button + button {
  border-left-style: solid;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover), .titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: none;
}

.linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl), .budgie-settings-window buttonbox.inline-toolbar button, viewswitcher button, spinbutton:not(.vertical) button, spinbutton:not(.vertical) entry, .linked:not(.vertical) > entry, .linked:not(.vertical) > entry:focus, .inline-toolbar button, .inline-toolbar button:backdrop, .linked:not(.vertical) > button, .linked:not(.vertical) > button:hover, .linked:not(.vertical) > button:active, .linked:not(.vertical) > button:checked, toolbar.inline-toolbar toolbutton > button.flat, .inline-toolbar toolbutton > button.flat {
  border-radius: 0;
  border-right-style: none;
}

.budgie-settings-window buttonbox.inline-toolbar button:first-child, viewswitcher button:first-child, spinbutton:not(.vertical) button:first-child, spinbutton:not(.vertical) entry:first-child, .linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .inline-toolbar button:first-child:backdrop, .linked:not(.vertical) > button:first-child {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.budgie-settings-window buttonbox.inline-toolbar button:last-child, viewswitcher button:last-child, spinbutton:not(.vertical) button:last-child, spinbutton:not(.vertical) entry:last-child, .linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .inline-toolbar button:last-child:backdrop, .linked:not(.vertical) > button:last-child {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.budgie-settings-window buttonbox.inline-toolbar button:only-child, viewswitcher button:only-child, spinbutton:not(.vertical) button:only-child, spinbutton:not(.vertical) entry:only-child, .linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .inline-toolbar button:only-child:backdrop, .linked:not(.vertical) > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

spinbutton.vertical button, spinbutton.vertical entry, .linked.vertical > entry, .linked.vertical > entry:focus, .linked.vertical > button, .linked.vertical > button:hover, .linked.vertical > button:active, .linked.vertical > button:checked {
  border-radius: 0;
  border-bottom-style: none;
}

spinbutton.vertical button:first-child, spinbutton.vertical entry:first-child, .linked.vertical > entry:first-child, .linked.vertical > button:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

spinbutton.vertical button:last-child, spinbutton.vertical entry:last-child, .linked.vertical > entry:last-child, .linked.vertical > button:last-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

spinbutton.vertical button:only-child, spinbutton.vertical entry:only-child, .linked.vertical > entry:only-child, .linked.vertical > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

.drop-shadow button, .raven .raven-header:not(.top) button.image-button, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button), .nemo-window .floating-bar button, calendar.button, .app-notification button.flat, notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover, notebook > header > tabs > tab button.flat:hover, button:link:hover, button:link:active, button:link:checked, button:visited:hover, button:visited:active, button:visited:checked, button:link, button:visited, menuitem.button.flat,
modelbutton.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

menuitem.button.flat,
modelbutton.flat {
  transition: none;
  min-height: 24px;
  padding-left: 8px;
  padding-right: 8px;
  outline-offset: -3px;
  border-radius: 2px;
}

menuitem.button.flat:hover,
modelbutton.flat:hover {
  background-color: #ededee;
}

menuitem.button.flat:checked,
modelbutton.flat:checked {
  color: #2b2f3b;
}

menuitem.button.flat:disabled,
modelbutton.flat:disabled {
  color: rgba(43, 47, 59, 0.55);
}

menuitem.button.flat check:last-child,
menuitem.button.flat radio:last-child,
modelbutton.flat check:last-child,
modelbutton.flat radio:last-child {
  margin-left: 8px;
}

menuitem.button.flat check:first-child,
menuitem.button.flat radio:first-child,
modelbutton.flat check:first-child,
modelbutton.flat radio:first-child {
  margin-right: 8px;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

infobar.info > revealer > box *:link, infobar.info:hover > revealer > box *:link, infobar.info:backdrop > revealer > box *:link, infobar.question > revealer > box *:link, infobar.question:hover > revealer > box *:link, infobar.question:backdrop > revealer > box *:link, infobar.warning > revealer > box *:link, infobar.warning:hover > revealer > box *:link, infobar.warning:backdrop > revealer > box *:link, infobar.error > revealer > box *:link, infobar.error:hover > revealer > box *:link, infobar.error:backdrop > revealer > box *:link, headerbar.selection-mode .subtitle:link, *:link:selected, *:selected *:link, button:selected:link, button:selected:visited, *:selected button:link, *:selected button:visited {
  color: #d6eaf8;
}

*:link, button:link, button:visited {
  color: #217dbb;
}

*:link:visited, button:visited {
  color: #23252e;
}

*:selected *:link:visited, *:selected button:visited {
  color: #aed6f1;
}

*:link:hover, button:hover:link, button:hover:visited {
  color: #3498db;
}

*:selected *:link:hover, *:selected button:hover:link, *:selected button:hover:visited {
  color: #ebf5fb;
}

*:link:active, button:active:link, button:active:visited {
  color: #217dbb;
}

*:selected *:link:active, *:selected button:active:link, *:selected button:active:visited {
  color: #d6eaf8;
}

button:link > label, button:visited > label {
  text-decoration-line: underline;
}

spinbutton:drop(active) {
  box-shadow: none;
}

spinbutton button:active {
  color: #ffffff;
}

spinbutton:disabled {
  color: rgba(43, 47, 59, 0.55);
}

spinbutton:not(.vertical) entry {
  min-width: 28px;
}

spinbutton:not(.vertical):dir(ltr) entry, spinbutton:not(.vertical):dir(rtl) button.up {
  border-radius: 3px 0 0 3px;
}

spinbutton:not(.vertical) > button + button {
  border-left-style: none;
}

spinbutton:not(.vertical) > button:hover:not(:active),
spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.08);
}

spinbutton:not(.vertical) > button:first-child:hover:not(:active),
spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

spinbutton:not(.vertical) > entry:focus + button {
  border-left-color: #3498db;
}

spinbutton:not(.vertical) > entry:drop(active) + button {
  border-left-color: #F08437;
}

.osd spinbutton:not(.vertical) > button:hover:not(:active),
.osd spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.osd spinbutton:not(.vertical) > button:first-child:hover:not(:active),
.osd spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
.osd spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

.osd spinbutton:not(.vertical) > entry:focus + button {
  border-left-color: #3498db;
}

spinbutton.vertical button, spinbutton.vertical entry {
  padding-left: 4px;
  padding-right: 4px;
  min-width: 0;
}

spinbutton.vertical button.up {
  border-radius: 3px 3px 0 0;
}

spinbutton.vertical > entry:focus + button {
  border-top-color: #3498db;
}

spinbutton.vertical > entry:drop(active) + button {
  border-top-color: #F08437;
}

combobox button.combo {
  min-width: 0;
  padding-left: 8px;
  padding-right: 8px;
}

combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

combobox:drop(active) button.combo {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

.linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

.linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

.linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

.linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

toolbar, .inline-toolbar {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  background-color: #f7f7f7;
}

toolbar separator, .inline-toolbar separator {
  background: none;
}

toolbar.horizontal separator, .horizontal.inline-toolbar separator {
  margin: 0 6px;
}

toolbar.vertical separator, .vertical.inline-toolbar separator {
  margin: 6px 0;
}

.osd toolbar, .osd .inline-toolbar {
  background-color: transparent;
}

toolbar.osd, .osd.inline-toolbar {
  padding: 7px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  background-color: rgba(255, 255, 255, 0.9);
}

toolbar.osd.left, .osd.left.inline-toolbar, toolbar.osd.right, .osd.right.inline-toolbar, toolbar.osd.top, .osd.top.inline-toolbar, toolbar.osd.bottom, .osd.bottom.inline-toolbar {
  border-radius: 0;
}

toolbar.osd.top, .osd.top.inline-toolbar {
  border-width: 0 0 1px 0;
}

toolbar.osd.bottom, .osd.bottom.inline-toolbar {
  border-width: 1px 0 0 0;
}

toolbar.osd.left, .osd.left.inline-toolbar {
  border-width: 0 1px 0 0;
}

toolbar.osd.right, .osd.right.inline-toolbar {
  border-width: 0 0 0 1px;
}

toolbar:not(.inline-toolbar) switch, .inline-toolbar:not(.inline-toolbar) switch,
toolbar:not(.inline-toolbar) scale,
.inline-toolbar:not(.inline-toolbar) scale,
toolbar:not(.inline-toolbar) entry,
.inline-toolbar:not(.inline-toolbar) entry,
toolbar:not(.inline-toolbar) spinbutton,
.inline-toolbar:not(.inline-toolbar) spinbutton,
toolbar:not(.inline-toolbar) button,
.inline-toolbar:not(.inline-toolbar) button {
  margin-right: 1px;
  margin-bottom: 1px;
}

toolbar:not(.inline-toolbar) .linked > button, .inline-toolbar:not(.inline-toolbar) .linked > button,
toolbar:not(.inline-toolbar) .linked > entry,
.inline-toolbar:not(.inline-toolbar) .linked > entry {
  margin-right: 0;
}

.primary-toolbar:not(.libreoffice-toolbar) {
  color: #2e313d;
  background-color: transparent;
  box-shadow: none;
  border-width: 0 0 1px 0;
  border-style: solid;
  border-image: linear-gradient(to bottom, black, rgba(0, 0, 0, 0.15)) 1 0 1 0;
}

.inline-toolbar {
  background-color: #efefef;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
  border-width: 0 1px 1px;
  padding: 3px;
  border-radius: 0  0 3px 3px;
}

searchbar {
  padding: 0;
  margin: 0;
  border: none;
}

searchbar > revealer > box {
  padding: 6px;
  margin: -6px;
  border-style: solid;
  border-color: #d1d1d1;
  background-color: #f7f7f7;
  border-width: 0 0 1px;
}

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #efefef;
}

headerbar {
  min-height: 42px;
  padding: 0 6px;
  color: #2b2f3b;
  background-color: #f2f2f2;
}

headerbar:backdrop {
  transition: 200ms ease-out;
  color: rgba(43, 47, 59, 0.7);
  background-color: white;
}

headerbar .title {
  padding-left: 12px;
  padding-right: 12px;
}

headerbar .subtitle {
  font-size: smaller;
  padding-left: 12px;
  padding-right: 12px;
}

headerbar.selection-mode {
  color: #ffffff;
  background-color: rgba(52, 152, 219, 0.95);
  border-color: rgba(38, 143, 213, 0.95);
  box-shadow: none;
}

headerbar.selection-mode:backdrop {
  background-color: rgba(52, 152, 219, 0.95);
  color: rgba(255, 255, 255, 0.6);
}

headerbar.selection-mode .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

headerbar.selection-mode .selection-menu GtkArrow {
  -GtkArrow-arrow-scaling: 1;
}

headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized headerbar.selection-mode {
  background-color: #3498db;
}

.tiled headerbar, .tiled headerbar:backdrop, .maximized headerbar, .maximized headerbar:backdrop {
  border-radius: 0;
}

.maximized headerbar {
  background-color: #f2f2f2;
  border-color: black;
}

.maximized headerbar:backdrop {
  background-color: white;
}

headerbar.default-decoration {
  min-height: 28px;
  padding: 0 6px;
  background-color: #f2f2f2;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

.tiled headerbar.default-decoration, .maximized headerbar.default-decoration, .fullscreen headerbar.default-decoration {
  box-shadow: none;
}

headerbar.default-decoration button.titlebutton {
  border: none;
  min-height: 22px;
  min-width: 22px;
  margin: 0;
  padding: 0;
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: #2b2f3b;
  border-radius: 0;
  box-shadow: none;
  border: none;
  margin: 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 0%, transparent 0%) 0 0 0/0 0 0;
}

.titlebar.windowhandle viewswitcher button:checked:not(.titlebutton):not(.suggested-action):not(.destructive-action), .titlebar.windowhandle viewswitcher button:active:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.15);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 100%, transparent 0%) 0 0 2/0 0 2px;
}

.titlebar.windowhandle viewswitcher button:disabled:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: rgba(43, 47, 59, 0.4);
}

.titlebar.windowhandle viewswitcher button:checked:disabled:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  color: rgba(43, 47, 59, 0.4);
  background-color: rgba(43, 47, 59, 0.05);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(52, 152, 219, 0.4) 100%, transparent 0%) 0 0 2/0 0 2px;
}

.titlebar, .titlebar.background {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

.titlebar, .titlebar headerbar {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15), inset 0 1px rgba(255, 255, 255, 0.13);
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  border-radius: 0;
  min-width: 120px;
  padding: 0 0;
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) > stack > box {
  padding: 0 12px;
}

.titlebar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) > stack > box image {
  margin-top: 4px;
}

window.background > box.vertical > headerbar:not(.titlebar) {
  border-radius: 0 0 0 0;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

window.background > box.vertical > headerbar:not(.titlebar), window.background > box.vertical > headerbar:not(.titlebar):backdrop {
  background-color: #f2f2f2;
}

separator:first-child + window.background > box.vertical > headerbar:not(.titlebar), separator:first-child + window.background > box.vertical > headerbar:not(.titlebar):backdrop, window.background > box.vertical > headerbar:not(.titlebar):first-child, window.background > box.vertical > headerbar:not(.titlebar):first-child:backdrop {
  border-top-left-radius: 0;
}

window.background > box.vertical > headerbar:not(.titlebar):last-child, window.background > box.vertical > headerbar:not(.titlebar):last-child:backdrop {
  border-top-right-radius: 0;
}

window.thunar toolbar entry, window.thunar .inline-toolbar entry, .nemo-window .primary-toolbar entry, headerbar entry {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

window.thunar toolbar entry image, window.thunar .inline-toolbar entry image, .nemo-window .primary-toolbar entry image, headerbar entry image {
  color: inherit;
}

window.thunar toolbar entry:backdrop, window.thunar .inline-toolbar entry:backdrop, .nemo-window .primary-toolbar entry:backdrop, headerbar entry:backdrop {
  opacity: 0.85;
}

window.thunar toolbar entry:focus, window.thunar .inline-toolbar entry:focus, .nemo-window .primary-toolbar entry:focus, headerbar entry:focus {
  color: #565e76;
  border-color: #3498db;
  background-color: #ffffff;
  background-clip: border-box;
}

window.thunar toolbar entry:focus image, window.thunar .inline-toolbar entry:focus image, .nemo-window .primary-toolbar entry:focus image, headerbar entry:focus image {
  color: #3498db;
}

window.thunar toolbar entry:disabled, window.thunar .inline-toolbar entry:disabled, .nemo-window .primary-toolbar entry:disabled, headerbar entry:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

window.thunar toolbar entry selection, window.thunar .inline-toolbar entry selection, .nemo-window .primary-toolbar entry selection, headerbar entry selection {
  background-color: #ffffff;
  color: #3498db;
}

window.thunar toolbar button, window.thunar .inline-toolbar button, .caja-navigation-window toolbar#Toolbar.primary-toolbar button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button, .nemo-window .primary-toolbar button, headerbar button {
  color: #2b2f3b;
  outline-offset: -3px;
  background-color: transparent;
  border-color: transparent;
  border-width: 1px;
}

window.thunar toolbar button:backdrop, window.thunar .inline-toolbar button:backdrop, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:backdrop, .nemo-window .primary-toolbar button:backdrop, headerbar button:backdrop {
  opacity: 0.8;
}

window.thunar toolbar button:hover, window.thunar .inline-toolbar button:hover, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:hover, .nemo-window .primary-toolbar button:hover, headerbar button:hover {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.12);
}

window.thunar toolbar button:active, window.thunar .inline-toolbar button:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:active, .nemo-window .primary-toolbar button:active, headerbar button:active, window.thunar toolbar button:checked, window.thunar .inline-toolbar button:checked, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:checked, .nemo-window .primary-toolbar button:checked, headerbar button:checked {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
  background-clip: border-box;
}

window.thunar toolbar button:disabled, window.thunar .inline-toolbar button:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled, .nemo-window .primary-toolbar button:disabled, headerbar button:disabled {
  color: rgba(43, 47, 59, 0.45);
  background-color: transparent;
  border-color: transparent;
}

window.thunar toolbar button:disabled:active, window.thunar .inline-toolbar button:disabled:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled:active, .nemo-window .primary-toolbar button:disabled:active, headerbar button:disabled:active, window.thunar toolbar button:disabled:checked, window.thunar .inline-toolbar button:disabled:checked, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled:checked, .nemo-window .primary-toolbar button:disabled:checked, headerbar button:disabled:checked {
  color: rgba(255, 255, 255, 0.5);
  border-color: rgba(52, 152, 219, 0.75);
  background-color: rgba(52, 152, 219, 0.75);
}

.linked:not(.vertical):not(.path-bar):not(.stack-switcher) window.thunar toolbar button:not(:first-child):not(:only-child), window.thunar toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child), .linked:not(.vertical):not(.path-bar):not(.stack-switcher) window.thunar .inline-toolbar button:not(:first-child):not(:only-child), window.thunar .inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child), .linked:not(.vertical):not(.path-bar):not(.stack-switcher) .caja-navigation-window toolbar#Toolbar.primary-toolbar button:not(:first-child):not(:only-child), .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child), .linked:not(.vertical):not(.path-bar):not(.stack-switcher) .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:not(:first-child):not(:only-child), .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child), .linked:not(.vertical):not(.path-bar):not(.stack-switcher) .nemo-window .primary-toolbar button:not(:first-child):not(:only-child), .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child), .linked:not(.vertical):not(.path-bar):not(.stack-switcher) headerbar button:not(:first-child):not(:only-child), headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:first-child):not(:only-child) {
  margin-left: 1px;
}

window.thunar toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button, window.thunar .inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button, headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button {
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
}

window.thunar toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child, window.thunar .inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child, headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child {
  border-left-style: solid;
  border-left-width: 1px;
  border-color: transparent;
}

window.thunar toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, window.thunar .inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:hover, window.thunar toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active, window.thunar .inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active, headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:last-child:active {
  border-color: rgba(0, 0, 0, 0.15);
}

headerbar entry, headerbar button, headerbar separator {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar entry progress {
  border-color: #3498db;
  background-image: none;
  background-color: transparent;
}

headerbar entry.warning {
  color: white;
  border-color: #F27835;
  background-color: #f2a981;
}

headerbar entry.warning:focus {
  color: white;
  background-color: #F27835;
}

headerbar entry.warning selection, headerbar entry.warning selection:focus {
  background-color: white;
  color: #F27835;
}

headerbar entry.error {
  color: white;
  border-color: #FC4138;
  background-color: #f88882;
}

headerbar entry.error:focus {
  color: white;
  background-color: #FC4138;
}

headerbar entry.error selection, headerbar entry.error selection:focus {
  background-color: white;
  color: #FC4138;
}

headerbar.selection-mode button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

headerbar.selection-mode button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

headerbar.selection-mode button:hover {
  background-color: alpha(#ffffff,0.3);
}

headerbar.selection-mode button:active, headerbar.selection-mode button:checked {
  color: #3498db;
  background-color: #ffffff;
  border-color: #ffffff;
}

headerbar.selection-mode button:disabled {
  color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:disabled label {
  color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:disabled:checked, headerbar.selection-mode button:disabled:active {
  color: #3498db;
  background-color: rgba(255, 255, 255, 0.5);
  border-color: rgba(255, 255, 255, 0.42);
}

headerbar.selection-mode button:backdrop {
  opacity: 0.7;
  background: none;
}

headerbar .linked:not(.vertical).path-bar > button {
  padding-top: 3px;
  padding-bottom: 6px;
  margin: 1px 0 0 0;
  border: none;
  border-radius: 0;
  color: #2b2f3b;
}

headerbar .linked:not(.vertical).path-bar > button:hover {
  color: #2b2f3b;
  background-color: white;
}

headerbar .linked:not(.vertical).path-bar > button:active, headerbar .linked:not(.vertical).path-bar > button:checked {
  transition: background-color 0.00001s 0.3s;
  animation: header_ripple_effect 0.3s cubic-bezier(0, 0, 0.2, 1);
  color: #2b2f3b;
  background-color: #e5e5e5;
  box-shadow: inset 0 -3px #4ea5e0;
}

headerbar .linked:not(.vertical).path-bar > button:disabled {
  color: rgba(43, 47, 59, 0.4);
}

headerbar windowhandle .linked > button.toggle:not(.disclosure-button),
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button {
  background-color: white;
  color: #2b2f3b;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.15);
}

headerbar windowhandle .linked > button.toggle:not(.disclosure-button):hover,
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover {
  background-color: #eaeaeb;
}

headerbar windowhandle .linked > button.toggle:not(.disclosure-button):active, headerbar windowhandle .linked > button.toggle:not(.disclosure-button):checked,
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:active,
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

headerbar windowhandle .linked > button.toggle:not(.disclosure-button):disabled,
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled {
  color: rgba(43, 47, 59, 0.4);
}

headerbar windowhandle .linked > button.toggle:not(.disclosure-button):disabled label,
headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled label {
  color: rgba(43, 47, 59, 0.4);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry:focus {
  border-color: #3498db;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
  border-left-color: #FC4138;
}

headerbar button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #3498db;
  border-color: #3498db;
}

headerbar button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #3498db;
}

headerbar button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #4aa3df;
  border-color: #4aa3df;
}

headerbar button.suggested-action:active, headerbar button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #5faee3;
  border-color: #5faee3;
}

headerbar button.suggested-action.flat:disabled, headerbar button.suggested-action:disabled {
  color: rgba(43, 47, 59, 0.45);
  background-color: transparent;
  border-color: transparent;
}

headerbar button.suggested-action:backdrop,
headerbar button.suggested-action:backdrop {
  opacity: 0.8;
}

headerbar button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

headerbar button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #db5b5b;
}

headerbar button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #e07070;
  border-color: #e07070;
}

headerbar button.destructive-action:active, headerbar button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #e48585;
  border-color: #e48585;
}

headerbar button.destructive-action.flat:disabled, headerbar button.destructive-action:disabled {
  color: rgba(43, 47, 59, 0.45);
  background-color: transparent;
  border-color: transparent;
}

headerbar button.destructive-action:backdrop,
headerbar button.destructive-action:backdrop {
  opacity: 0.8;
}

headerbar spinbutton:not(.vertical):focus {
  color: #ffffff;
  caret-color: #ffffff;
}

headerbar spinbutton:not(.vertical) button, headerbar spinbutton:not(.vertical) button:disabled {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.12);
}

headerbar spinbutton:not(.vertical) button:hover {
  background-color: rgba(255, 255, 255, 0.9);
}

headerbar spinbutton:not(.vertical) button:active, headerbar spinbutton:not(.vertical) button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

headerbar spinbutton:not(.vertical) button:disabled {
  color: rgba(43, 47, 59, 0.42);
}

headerbar spinbutton:not(.vertical) > button + button {
  border-left-style: none;
}

headerbar spinbutton:not(.vertical) > button:hover:not(:active),
headerbar spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(242, 242, 242, 0.3);
}

headerbar spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
headerbar spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: inset 1px 0 rgba(242, 242, 242, 0.3);
}

headerbar spinbutton:not(.vertical) > button:first-child:hover:not(:active),
headerbar spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

headerbar spinbutton:not(.vertical) > entry:focus + button {
  border-left-color: #3498db;
}

headerbar combobox:disabled {
  color: rgba(43, 47, 59, 0.42);
}

headerbar combobox > .linked > button.combo {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

headerbar combobox > .linked > button.combo image, headerbar combobox > .linked > button.combo image:hover {
  color: inherit;
}

headerbar combobox > .linked > button.combo:hover {
  color: #565e76;
  border-color: #3498db;
  background-color: #ffffff;
  box-shadow: none;
}

headerbar combobox > .linked > button.combo:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

headerbar combobox > .linked > entry.combo:dir(ltr) {
  border-right-style: none;
}

headerbar combobox > .linked > entry.combo:dir(ltr):focus {
  box-shadow: 1px 0 #3498db;
}

headerbar combobox > .linked > entry.combo:dir(rtl) {
  border-left-style: none;
}

headerbar combobox > .linked > entry.combo:dir(rtl):focus {
  box-shadow: -1px 0 #3498db;
}

headerbar combobox > .linked > button.combo:dir(ltr), headerbar combobox > .linked > button.combo:dir(ltr):hover, headerbar combobox > .linked > button.combo:dir(ltr):active, headerbar combobox > .linked > button.combo:dir(ltr):checked, headerbar combobox > .linked > button.combo:dir(ltr):disabled {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

headerbar combobox > .linked > button.combo:dir(rtl), headerbar combobox > .linked > button.combo:dir(rtl):hover, headerbar combobox > .linked > button.combo:dir(rtl):active, headerbar combobox > .linked > button.combo:dir(rtl):checked, headerbar combobox > .linked > button.combo:dir(rtl):disabled {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

headerbar switch:backdrop {
  opacity: 0.75;
}

headerbar progressbar trough {
  background-color: #d9d9d9;
}

headerbar progressbar:backdrop {
  opacity: 0.75;
}

headerbar scale:backdrop {
  opacity: 0.75;
}

headerbar scale slider {
  background-color: #fcfcfc;
  border-color: rgba(242, 242, 242, 0.5);
}

headerbar scale slider:hover {
  background-color: white;
  border-color: rgba(242, 242, 242, 0.5);
}

headerbar scale slider:active {
  background-color: #3498db;
  border-color: #3498db;
}

headerbar scale slider:disabled {
  background-color: #f9f9f9;
  border-color: rgba(242, 242, 242, 0.5);
}

headerbar scale trough {
  background-color: #d9d9d9;
}

headerbar scale trough:disabled {
  background-color: rgba(217, 217, 217, 0.95);
}

separator:first-child + headerbar, separator:first-child + headerbar:backdrop, headerbar:first-child, headerbar:first-child:backdrop {
  border-top-left-radius: 2px;
}

headerbar:last-child, headerbar:last-child:backdrop {
  border-top-right-radius: 2px;
}

stack headerbar:first-child, stack headerbar:last-child {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

window.tiled headerbar, window.tiled headerbar:first-child, window.tiled headerbar:last-child, window.tiled headerbar:only-child, window.tiled-top headerbar, window.tiled-top headerbar:first-child, window.tiled-top headerbar:last-child, window.tiled-top headerbar:only-child, window.tiled-right headerbar, window.tiled-right headerbar:first-child, window.tiled-right headerbar:last-child, window.tiled-right headerbar:only-child, window.tiled-bottom headerbar, window.tiled-bottom headerbar:first-child, window.tiled-bottom headerbar:last-child, window.tiled-bottom headerbar:only-child, window.tiled-left headerbar, window.tiled-left headerbar:first-child, window.tiled-left headerbar:last-child, window.tiled-left headerbar:only-child, window.maximized headerbar, window.maximized headerbar:first-child, window.maximized headerbar:last-child, window.maximized headerbar:only-child, window.fullscreen headerbar, window.fullscreen headerbar:first-child, window.fullscreen headerbar:last-child, window.fullscreen headerbar:only-child, window.solid-csd headerbar, window.solid-csd headerbar:first-child, window.solid-csd headerbar:last-child, window.solid-csd headerbar:only-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop, window.csd > .titlebar:not(headerbar), window.csd > .titlebar:not(headerbar):backdrop {
  padding: 0;
  background: none;
  border: none;
}

.titlebar:not(headerbar) > separator {
  background-image: linear-gradient(to bottom, #f2f2f2, #f2f2f2);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

.titlebar:not(headerbar) > separator:backdrop {
  transition: 200ms ease-out;
  background-image: linear-gradient(to bottom, white, white);
  box-shadow: none;
}

.primary-toolbar:not(.libreoffice-toolbar) separator, headerbar separator.titlebutton {
  min-width: 0;
  min-height: 0;
  background: none;
  border-width: 0 0;
  border-image: linear-gradient(to bottom, rgba(43, 47, 59, 0) 25%, rgba(43, 47, 59, 0.35) 25%, rgba(43, 47, 59, 0.35) 75%, rgba(43, 47, 59, 0) 75%) 0 1/0 0 stretch;
}

.primary-toolbar:not(.libreoffice-toolbar) separator:backdrop, headerbar separator.titlebutton:backdrop {
  opacity: 0.6;
}

.path-bar button:hover {
  background-color: rgba(43, 47, 59, 0.06);
}

.path-bar button:checked, .path-bar button:active {
  background-color: #3498db;
  border-color: #3498db;
}

.path-bar button:checked:hover, .path-bar button:active:hover {
  background-color: #4aa3df;
  border-color: #4aa3df;
}

.path-bar button.text-button, .path-bar button.image-button, .path-bar button {
  padding-left: 6px;
  padding-right: 6px;
}

.path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
  padding-right: 10px;
}

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
  padding-left: 10px;
}

.path-bar button.slider-button, .path-bar button:not(.image-button):not(.text-button) {
  padding-left: 1px;
  padding-right: 1px;
}

.path-bar button image {
  padding-left: 4px;
  padding-right: 4px;
}

treeview.view {
  border-left-color: rgba(43, 47, 59, 0.15);
  border-top-color: rgba(0, 0, 0, 0.1);
}

* {
  -GtkTreeView-horizontal-separator: 4;
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
}

treeview.view acceleditor > label {
  background-color: #3498db;
}

treeview.view:selected, treeview.view:selected:focus {
  border-radius: 0;
  border-left-color: #9acced;
  border-top-color: rgba(43, 47, 59, 0.1);
}

treeview.view:disabled {
  color: rgba(43, 47, 59, 0.55);
}

treeview.view:disabled:selected {
  color: #85c1e9;
}

treeview.view.separator {
  min-height: 2px;
  color: rgba(0, 0, 0, 0.1);
}

treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #30648b;
}

treeview.view:drop(active).after {
  border-top-style: none;
}

treeview.view:drop(active).before {
  border-bottom-style: none;
}

treeview.view.expander {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: #95979d;
}

treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

treeview.view.expander:hover {
  color: #2b2f3b;
}

treeview.view.expander:selected {
  color: #c2e0f4;
}

treeview.view.expander:selected:hover {
  color: #ffffff;
}

treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

treeview.view.progressbar, treeview.view.progressbar:hover {
  color: #ffffff;
  border-radius: 3px;
  background-color: #3498db;
}

treeview.view.progressbar:selected, treeview.view.progressbar:selected:focus, treeview.view.progressbar:hover:selected, treeview.view.progressbar:hover:selected:focus {
  color: #3498db;
  border-radius: 3px;
  box-shadow: none;
  background-color: #ffffff;
}

treeview.view.trough, treeview.view.trough:hover {
  color: #2b2f3b;
  background-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  border-width: 0;
}

treeview.view.trough:selected, treeview.view.trough:selected:focus, treeview.view.trough:hover:selected, treeview.view.trough:hover:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  border-width: 0;
}

treeview.view header button {
  min-height: 0;
  min-width: 0;
  padding: 3px 6px;
  font-weight: bold;
  color: #555962;
  background-color: #ffffff;
  background-image: none;
  border-style: none solid none none;
  border-radius: 0;
  border-image: linear-gradient(to bottom, #ffffff 20%, rgba(0, 0, 0, 0.12) 20%, rgba(0, 0, 0, 0.12) 80%, #ffffff 80%) 0 1 0 0/0 1px 0 0 stretch;
}

treeview.view header button:hover {
  color: #3498db;
}

treeview.view header button:active {
  color: #2b2f3b;
}

treeview.view header button:active, treeview.view header button:hover {
  background-color: #ffffff;
}

treeview.view header button:active:hover {
  color: #2b2f3b;
}

treeview.view header button:disabled {
  border-color: #f7f7f7;
  background-image: none;
}

treeview.view header button:last-child {
  border-right-style: none;
  border-image: none;
}

treeview.view button.dnd, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd:active,
treeview.view header.button.dnd,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd:active {
  padding: 0 6px;
  transition: none;
  color: #ffffff;
  background-color: #3498db;
  border-radius: 0;
  border-style: none;
}

menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0 0 0 0;
  background-color: #f2f2f2;
  color: #2b2f3b;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

menubar:backdrop,
.menubar:backdrop {
  color: rgba(43, 47, 59, 0.7);
}

menubar > menuitem,
.menubar > menuitem {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  padding: 4px 8px;
  border: none;
  border-radius: 2px 2px 0 0;
}

menubar > menuitem:hover,
.menubar > menuitem:hover {
  background-color: #3498db;
  color: #ffffff;
}

menubar > menuitem:disabled,
.menubar > menuitem:disabled {
  color: rgba(43, 47, 59, 0.45);
  border-color: transparent;
}

menubar > menuitem label:disabled,
.menubar > menuitem label:disabled {
  color: rgba(43, 47, 59, 0.45);
}

menubar > menuitem > window.background.popup > menu,
.menubar > menuitem > window.background.popup > menu {
  border-radius: 0 0 2px 2px;
}

menu,
.menu {
  padding: 4px 0;
  border-radius: 0;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.csd menu, .csd .menu {
  padding: 4px 0;
  border-radius: 2px;
  border: none;
}

menu separator, .csd menu separator,
.menu separator, .csd .menu separator {
  margin: 2px 0;
  background-color: #ffffff;
}

menu .separator:not(label), .csd menu .separator:not(label),
.menu .separator:not(label), .csd .menu .separator:not(label) {
  color: #ffffff;
}

menu menuitem,
.menu menuitem {
  min-height: 16px;
  min-width: 40px;
  padding: 5px 8px;
  color: #2e313d;
}

menu menuitem:hover,
.menu menuitem:hover {
  color: #ffffff;
  background-color: #3498db;
}

menu menuitem:disabled,
.menu menuitem:disabled {
  color: rgba(43, 47, 59, 0.55);
}

menu menuitem label:disabled,
.menu menuitem label:disabled {
  color: rgba(43, 47, 59, 0.55);
}

menu menuitem arrow,
.menu menuitem arrow {
  min-height: 16px;
  min-width: 16px;
}

menu menuitem arrow:dir(ltr),
.menu menuitem arrow:dir(ltr) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  margin-left: 10px;
}

menu menuitem arrow:dir(rtl),
.menu menuitem arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
  margin-right: 10px;
}

menuitem accelerator {
  color: alpha(currentColor,0.55);
}

menuitem check, menuitem radio {
  min-height: 16px;
  min-width: 16px;
}

menuitem check:dir(ltr), menuitem radio:dir(ltr) {
  margin-right: 6px;
  margin-left: 2px;
}

menuitem check:dir(rtl), menuitem radio:dir(rtl) {
  margin-left: 6px;
  margin-right: 2px;
}

menu > arrow,
.menu > arrow {
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  background-color: #ffffff;
  border-radius: 0;
}

menu > arrow.top,
.menu > arrow.top {
  margin-top: -4px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menu > arrow.bottom,
.menu > arrow.bottom {
  margin-top: 8px;
  margin-bottom: -12px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menu > arrow:hover,
.menu > arrow:hover {
  background-color: #eaeaeb;
}

menu > arrow:disabled,
.menu > arrow:disabled {
  color: transparent;
  background-color: transparent;
  border-color: transparent;
}

popover,
popover.background {
  padding: 0;
  background-clip: border-box;
  background-color: #ffffff;
  box-shadow: 0 2px 6px 0 rgba(0, 0, 0, 0.07);
}

.csd popover, popover, .csd popover.background,
popover.background {
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 3px;
}

popover separator,
popover.background separator {
  background-color: #ffffff;
}

popover label.separator,
popover.background label.separator {
  color: #2b2f3b;
}

popover > list,
popover > .view,
popover > toolbar,
popover > .inline-toolbar,
popover > scrolledwindow > viewport > list,
popover.background > list,
popover.background > .view,
popover.background > toolbar,
popover.background > .inline-toolbar,
popover.background > scrolledwindow > viewport > list {
  border-style: none;
  background-color: transparent;
}

popover.combo > scrolledwindow > viewport > list,
popover.background.combo > scrolledwindow > viewport > list {
  margin: 6px;
}

popover.combo > scrolledwindow > viewport > list row,
popover.background.combo > scrolledwindow > viewport > list row {
  padding: 6px 12px;
  border-radius: 2px;
}

popover button:not(.suggested-action):not(.destructive-action):hover,
popover.background button:not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(0, 0, 0, 0.05);
  color: #2e313d;
}

popover button:not(.suggested-action):not(.destructive-action):checked, popover button:not(.suggested-action):not(.destructive-action):active,
popover.background button:not(.suggested-action):not(.destructive-action):checked,
popover.background button:not(.suggested-action):not(.destructive-action):active {
  background-color: #3498db;
  color: #ffffff;
}

cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
}

cursor-handle.top {
  -gtk-icon-source: -gtk-icontheme("selection-start-symbolic");
}

cursor-handle.bottom {
  -gtk-icon-source: -gtk-icontheme("selection-end-symbolic");
}

notebook {
  padding: 0;
}

notebook.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > stack:not(:only-child) {
  background-color: #ffffff;
}

notebook > header {
  padding: 0;
  background-color: #f7f7f7;
}

notebook > header.top {
  padding-bottom: 0;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.top > tabs > tab {
  padding: 3px 16px 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-bottom: none;
}

notebook > header.top > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.top > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -2px alpha(#3498db,0.6), 0 1px alpha(#3498db,0.6);
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -2px #3498db, 0 1px #3498db;
}

notebook > header.bottom {
  padding-top: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.bottom > tabs > tab {
  padding: 3px 16px 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-top: none;
}

notebook > header.bottom > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.bottom > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 2px alpha(#3498db,0.6), 0 -1px alpha(#3498db,0.6);
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 2px #3498db, 0 -1px #3498db;
}

notebook > header.right {
  padding-left: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.right > tabs > tab {
  padding: 3px 16px 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-left: none;
}

notebook > header.right > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.right > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 2px 0 alpha(#3498db,0.6), -1px 0 alpha(#3498db,0.6);
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 2px 0 #3498db, -1px 0 #3498db;
}

notebook > header.left {
  padding-right: 0;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.left > tabs > tab {
  padding: 3px 16px 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-right: none;
}

notebook > header.left > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.left > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -2px 0 alpha(#3498db,0.6), 1px 0 alpha(#3498db,0.6);
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -2px 0 #3498db, 1px 0 #3498db;
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
  margin-left: 2px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
  margin-right: 2px;
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
  margin-top: 2px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
  margin-bottom: 2px;
}

notebook > header > tabs > arrow {
  color: rgba(43, 47, 59, 0.55);
}

notebook > header > tabs > arrow:hover {
  color: rgba(43, 47, 59, 0.775);
}

notebook > header > tabs > arrow:active {
  color: #2b2f3b;
}

notebook > header > tabs > arrow:disabled {
  color: rgba(43, 47, 59, 0.7);
}

notebook > header > tabs > tab {
  color: rgba(43, 47, 59, 0.55);
  background-color: rgba(247, 247, 247, 0);
}

notebook > header > tabs > tab:hover:not(:checked) {
  color: rgba(43, 47, 59, 0.775);
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab:checked {
  color: #2b2f3b;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab button.flat {
  border-radius: 100%;
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  margin: 4px 0;
  color: #72757d;
}

notebook > header > tabs > tab button.flat:hover {
  color: #ff4d4d;
  background-color: #eaeaea;
}

notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover {
  color: #3498db;
  background-color: #e3e3e3;
}

notebook > header button {
  margin: 2px;
}

scrollbar {
  background-color: #fcfcfc;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

* {
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar button {
  border: none;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-right-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-left-symbolic");
}

scrollbar slider {
  min-width: 6px;
  min-height: 6px;
  margin: -1px;
  border: 4px solid transparent;
  border-radius: 8px;
  background-clip: padding-box;
  background-color: #a5a7ac;
}

scrollbar slider:hover {
  background-color: #babbbf;
}

scrollbar slider:hover:active {
  background-color: #3498db;
}

scrollbar slider:disabled {
  background-color: transparent;
}

scrollbar.fine-tune slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  border-width: 5px 4px;
}

scrollbar.fine-tune.vertical slider {
  border-width: 4px 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  opacity: 0.4;
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  margin: 0;
  min-width: 4px;
  min-height: 4px;
  background-color: #686b73;
  border: 1px solid rgba(255, 255, 255, 0.6);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
  margin: 0 2px;
  min-width: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
  margin: 2px 0;
  min-height: 40px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 0.99;
}

scrollbar.horizontal slider {
  min-width: 40px;
}

scrollbar.vertical slider {
  min-height: 40px;
}

switch {
  font-size: 0;
  min-width: 52px;
  min-height: 24px;
  background-size: 52px 24px;
  background-repeat: no-repeat;
  background-position: center center;
  transition: all 350ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

switch slider {
  min-width: 0;
  min-height: 0;
}

switch, switch slider {
  outline-color: transparent;
  color: transparent;
  border: none;
  box-shadow: none;
}

switch {
  background-image: -gtk-scaled(url("assets/switch.png"), url("assets/switch@2.png"));
}

menuitem:hover switch,
row:selected switch,
infobar switch {
  background-image: -gtk-scaled(url("assets/switch-selected.png"), url("assets/switch-selected@2.png"));
}

headerbar switch,
.primary-toolbar switch {
  background-image: -gtk-scaled(url("assets/switch-header.png"), url("assets/switch-header@2.png"));
}

switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active.png"), url("assets/switch-active@2.png"));
}

menuitem:hover switch:checked,
row:selected switch:checked,
infobar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-selected.png"), url("assets/switch-active-selected@2.png"));
}

headerbar switch:checked,
.primary-toolbar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-header.png"), url("assets/switch-active-header@2.png"));
}

switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover.png"), url("assets/switch-hover@2.png"));
}

menuitem:hover switch:hover,
row:selected switch:hover,
infobar switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover-selected.png"), url("assets/switch-hover-selected@2.png"));
}

headerbar switch:hover,
.primary-toolbar switch:hover {
  background-image: -gtk-scaled(url("assets/switch-hover-header.png"), url("assets/switch-hover-header@2.png"));
}

switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover.png"), url("assets/switch-active-hover@2.png"));
}

menuitem:hover switch:checked:hover,
row:selected switch:checked:hover,
infobar switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover-selected.png"), url("assets/switch-active-hover-selected@2.png"));
}

headerbar switch:checked:hover,
.primary-toolbar switch:checked:hover {
  background-image: -gtk-scaled(url("assets/switch-active-hover-header.png"), url("assets/switch-active-hover-header@2.png"));
}

switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive.png"), url("assets/switch-insensitive@2.png"));
}

menuitem:hover switch:disabled,
row:selected switch:disabled,
infobar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-selected.png"), url("assets/switch-insensitive-selected@2.png"));
}

headerbar switch:disabled,
.primary-toolbar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-header.png"), url("assets/switch-insensitive-header@2.png"));
}

switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive.png"), url("assets/switch-active-insensitive@2.png"));
}

menuitem:hover switch:checked:disabled,
row:selected switch:checked:disabled,
infobar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-selected.png"), url("assets/switch-active-insensitive-selected@2.png"));
}

headerbar switch:checked:disabled,
.primary-toolbar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-header.png"), url("assets/switch-active-insensitive-header@2.png"));
}

.check,
check,
treeview.check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked.png"), url("assets/checkbox-unchecked@2.png"));
}

.osd check,
filechooser actionbar check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
}

menuitem check:hover,
.view check:selected,
treeview.check:selected,
row:selected check,
infobar check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-selected.png"), url("assets/checkbox-unchecked-selected@2.png"));
}

.check:disabled,
check:disabled,
treeview.check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive.png"), url("assets/checkbox-unchecked-insensitive@2.png"));
}

.osd check:disabled,
filechooser actionbar check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
}

menuitem check:disabled:hover,
.view check:disabled:selected,
treeview.check:disabled:selected,
row:selected check:disabled,
infobar check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-selected.png"), url("assets/checkbox-unchecked-insensitive-selected@2.png"));
}

.check:indeterminate,
check:indeterminate,
treeview.check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed.png"), url("assets/checkbox-mixed@2.png"));
}

.osd check:indeterminate,
filechooser actionbar check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
}

menuitem check:indeterminate:hover,
.view check:indeterminate:selected,
treeview.check:indeterminate:selected,
row:selected check:indeterminate,
infobar check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-selected.png"), url("assets/checkbox-mixed-selected@2.png"));
}

.check:indeterminate:disabled,
check:indeterminate:disabled,
treeview.check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive.png"), url("assets/checkbox-mixed-insensitive@2.png"));
}

.osd check:indeterminate:disabled,
filechooser actionbar check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
}

menuitem check:indeterminate:disabled:hover,
.view check:indeterminate:disabled:selected,
treeview.check:indeterminate:disabled:selected,
row:selected check:indeterminate:disabled,
infobar check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-selected.png"), url("assets/checkbox-mixed-insensitive-selected@2.png"));
}

.check:checked,
check:checked,
treeview.check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked.png"), url("assets/checkbox-checked@2.png"));
}

.osd check:checked,
filechooser actionbar check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
}

menuitem check:checked:hover,
.view check:checked:selected,
treeview.check:checked:selected,
row:selected check:checked,
infobar check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selected.png"), url("assets/checkbox-checked-selected@2.png"));
}

.check:checked:disabled,
check:checked:disabled,
treeview.check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive.png"), url("assets/checkbox-checked-insensitive@2.png"));
}

.osd check:checked:disabled,
filechooser actionbar check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
}

menuitem check:checked:disabled:hover,
.view check:checked:disabled:selected,
treeview.check:checked:disabled:selected,
row:selected check:checked:disabled,
infobar check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-selected.png"), url("assets/checkbox-checked-insensitive-selected@2.png"));
}

.radio,
radio,
treeview.radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked.png"), url("assets/radio-unchecked@2.png"));
}

.osd radio,
filechooser actionbar radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
}

menuitem radio:hover,
.view radio:selected,
treeview.radio:selected,
row:selected radio,
infobar radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-selected.png"), url("assets/radio-unchecked-selected@2.png"));
}

.radio:disabled,
radio:disabled,
treeview.radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive.png"), url("assets/radio-unchecked-insensitive@2.png"));
}

.osd radio:disabled,
filechooser actionbar radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
}

menuitem radio:disabled:hover,
.view radio:disabled:selected,
treeview.radio:disabled:selected,
row:selected radio:disabled,
infobar radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-selected.png"), url("assets/radio-unchecked-insensitive-selected@2.png"));
}

.radio:indeterminate,
radio:indeterminate,
treeview.radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.png"), url("assets/radio-mixed@2.png"));
}

.osd radio:indeterminate,
filechooser actionbar radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
}

menuitem radio:indeterminate:hover,
.view radio:indeterminate:selected,
treeview.radio:indeterminate:selected,
row:selected radio:indeterminate,
infobar radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-selected.png"), url("assets/radio-mixed-selected@2.png"));
}

.radio:indeterminate:disabled,
radio:indeterminate:disabled,
treeview.radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive.png"), url("assets/radio-mixed-insensitive@2.png"));
}

.osd radio:indeterminate:disabled,
filechooser actionbar radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
}

menuitem radio:indeterminate:disabled:hover,
.view radio:indeterminate:disabled:selected,
treeview.radio:indeterminate:disabled:selected,
row:selected radio:indeterminate:disabled,
infobar radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-selected.png"), url("assets/radio-mixed-insensitive-selected@2.png"));
}

.radio:checked,
radio:checked,
treeview.radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked.png"), url("assets/radio-checked@2.png"));
}

.osd radio:checked,
filechooser actionbar radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
}

menuitem radio:checked:hover,
.view radio:checked:selected,
treeview.radio:checked:selected,
row:selected radio:checked,
infobar radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-selected.png"), url("assets/radio-checked-selected@2.png"));
}

.radio:checked:disabled,
radio:checked:disabled,
treeview.radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive.png"), url("assets/radio-checked-insensitive@2.png"));
}

.osd radio:checked:disabled,
filechooser actionbar radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
}

menuitem radio:checked:disabled:hover,
.view radio:checked:disabled:selected,
treeview.radio:checked:disabled:selected,
row:selected radio:checked:disabled,
infobar radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-selected.png"), url("assets/radio-checked-insensitive-selected@2.png"));
}

.view.content-view.check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png"));
  background-color: transparent;
}

.view.content-view.check:checked:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png"));
  background-color: transparent;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button:hover, radiobutton.text-button:hover {
  color: #0b0c0f;
}

checkbutton.text-button:disabled, radiobutton.text-button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

checkbutton label:not(:only-child):first-child, radiobutton label:not(:only-child):first-child {
  margin-left: 4px;
}

checkbutton label:not(:only-child):last-child, radiobutton label:not(:only-child):last-child {
  margin-right: 4px;
}

check,
radio {
  min-width: 16px;
  min-height: 16px;
  margin: 0 2px;
}

check:only-child, menu menuitem check,
radio:only-child, menu menuitem radio {
  margin: 0;
}

scale {
  min-height: 15px;
  min-width: 15px;
  padding: 3px;
}

scale.horizontal trough {
  padding: 0 4px;
}

scale.horizontal highlight, scale.horizontal fill {
  margin: 0 -4px;
}

scale.vertical trough {
  padding: 4px 0;
}

scale.vertical highlight, scale.vertical fill {
  margin: -4px 0;
}

scale.fine-tune slider {
  margin: -4px;
}

scale.fine-tune fill,
scale.fine-tune highlight,
scale.fine-tune trough {
  border-radius: 5px;
  -gtk-outline-radius: 7px;
}

scale trough, scale trough:hover, scale trough:focus, scale trough:backdrop, scale:hover trough, scale:hover trough:hover, scale:hover trough:focus, scale:hover trough:backdrop, scale:focus trough, scale:focus trough:hover, scale:focus trough:focus, scale:focus trough:backdrop {
  outline-offset: 2px;
  -gtk-outline-radius: 4.5px;
  border-radius: 2.5px;
  background-color: rgba(0, 0, 0, 0.15);
}

scale trough:disabled, scale trough:hover:disabled, scale trough:focus:disabled, scale trough:backdrop:disabled, scale:hover trough:disabled, scale:hover trough:hover:disabled, scale:hover trough:focus:disabled, scale:hover trough:backdrop:disabled, scale:focus trough:disabled, scale:focus trough:hover:disabled, scale:focus trough:focus:disabled, scale:focus trough:backdrop:disabled {
  background-color: rgba(0, 0, 0, 0.08);
}

.osd scale trough, .osd scale trough:hover, .osd scale trough:focus, .osd scale trough:backdrop, .osd scale:hover trough, .osd scale:hover trough:hover, .osd scale:hover trough:focus, .osd scale:hover trough:backdrop, .osd scale:focus trough, .osd scale:focus trough:hover, .osd scale:focus trough:focus, .osd scale:focus trough:backdrop {
  background-color: rgba(0, 0, 0, 0.15);
}

.osd scale trough:disabled, .osd scale trough:hover:disabled, .osd scale trough:focus:disabled, .osd scale trough:backdrop:disabled, .osd scale:hover trough:disabled, .osd scale:hover trough:hover:disabled, .osd scale:hover trough:focus:disabled, .osd scale:hover trough:backdrop:disabled, .osd scale:focus trough:disabled, .osd scale:focus trough:hover:disabled, .osd scale:focus trough:focus:disabled, .osd scale:focus trough:backdrop:disabled {
  background-color: rgba(0, 0, 0, 0.08);
}

.osd scale trough highlight, .osd scale trough:hover highlight, .osd scale trough:focus highlight, .osd scale trough:backdrop highlight, .osd scale:hover trough highlight, .osd scale:hover trough:hover highlight, .osd scale:hover trough:focus highlight, .osd scale:hover trough:backdrop highlight, .osd scale:focus trough highlight, .osd scale:focus trough:hover highlight, .osd scale:focus trough:focus highlight, .osd scale:focus trough:backdrop highlight {
  background-color: #3498db;
}

.osd scale trough highlight:disabled, .osd scale trough:hover highlight:disabled, .osd scale trough:focus highlight:disabled, .osd scale trough:backdrop highlight:disabled, .osd scale:hover trough highlight:disabled, .osd scale:hover trough:hover highlight:disabled, .osd scale:hover trough:focus highlight:disabled, .osd scale:hover trough:backdrop highlight:disabled, .osd scale:focus trough highlight:disabled, .osd scale:focus trough:hover highlight:disabled, .osd scale:focus trough:focus highlight:disabled, .osd scale:focus trough:backdrop highlight:disabled {
  background-color: rgba(52, 152, 219, 0.55);
}

scale highlight {
  border-radius: 2.5px;
}

scale highlight, scale highlight:hover, scale highlight:focus, scale highlight:backdrop {
  background-color: #3498db;
}

scale highlight:disabled, scale highlight:hover:disabled, scale highlight:focus:disabled, scale highlight:backdrop:disabled {
  background-color: rgba(52, 152, 219, 0.55);
}

scale fill {
  border-radius: 2.5px;
}

scale fill, scale fill:hover, scale fill:focus, scale fill:backdrop {
  background-color: rgba(52, 152, 219, 0.5);
}

scale fill:disabled, scale fill:hover:disabled, scale fill:focus:disabled, scale fill:backdrop:disabled {
  background-color: transparent;
}

scale slider {
  min-height: 15px;
  min-width: 15px;
  margin: -6px;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 100%;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border;
}

scale slider:hover {
  background-clip: border-box;
  background-color: #3498db;
  border-color: #2791d9;
}

scale slider:active {
  background-clip: border-box;
  background-color: #2791d9;
  border-color: #2489cc;
}

scale slider:disabled {
  background-color: #e6e6e6;
  border-color: rgba(0, 0, 0, 0.15);
}

scale value {
  color: alpha(currentColor,0.4);
}

scale marks {
  color: alpha(currentColor,0.4);
}

scale marks.top {
  margin-bottom: 1px;
  margin-top: -4px;
}

scale marks.bottom {
  margin-top: 1px;
  margin-bottom: -4px;
}

scale marks.top {
  margin-right: 1px;
  margin-left: -4px;
}

scale marks.bottom {
  margin-left: 1px;
  margin-right: -4px;
}

scale.fine-tune marks.top {
  margin-bottom: 0px;
  margin-top: -2px;
}

scale.fine-tune marks.bottom {
  margin-top: 0px;
  margin-bottom: -2px;
}

scale.fine-tune marks.top {
  margin-right: 0px;
  margin-left: -2px;
}

scale.fine-tune marks.bottom {
  margin-left: 0px;
  margin-right: -2px;
}

scale.horizontal indicator {
  min-height: 3px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 2px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 3px;
}

scale.vertical.fine-tune indicator {
  min-width: 2px;
}

infobar.info trough, infobar.question trough, infobar.warning trough, infobar.error trough, scale:selected trough {
  background-color: rgba(0, 0, 0, 0.2);
}

infobar.info trough highlight, infobar.question trough highlight, infobar.warning trough highlight, infobar.error trough highlight, scale:selected trough highlight {
  background-color: #4ea5e0;
}

infobar.info trough highlight:disabled, infobar.question trough highlight:disabled, infobar.warning trough highlight:disabled, infobar.error trough highlight:disabled, scale:selected trough highlight:disabled {
  background-color: #a4d1ef;
}

infobar.info trough:disabled, infobar.question trough:disabled, infobar.warning trough:disabled, infobar.error trough:disabled, scale:selected trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

progressbar {
  padding: 0;
  font-size: smaller;
  color: rgba(43, 47, 59, 0.7);
}

progressbar.osd {
  min-width: 3px;
  min-height: 3px;
  background-color: transparent;
}

progressbar.osd trough {
  border-style: none;
  background-color: transparent;
  box-shadow: none;
}

progressbar progress {
  background-color: #3498db;
  border: none;
  border-radius: 3px;
  box-shadow: none;
}

row:selected progressbar progress, infobar progressbar progress {
  background-color: #ffffff;
}

progressbar trough {
  border: none;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.15);
}

row:selected progressbar trough, infobar progressbar trough {
  background-color: rgba(0, 0, 0, 0.2);
}

levelbar block {
  min-width: 1px;
  min-height: 1px;
}

levelbar.vertical block {
  min-width: 1px;
  min-height: 1px;
}

levelbar trough {
  border: none;
  padding: 3px;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.15);
}

levelbar.horizontal.discrete block {
  margin: 0 1px;
}

levelbar.vertical.discrete block {
  margin: 1px 0;
}

levelbar block:not(.empty) {
  border: 1px solid #3498db;
  background-color: #3498db;
  border-radius: 2px;
}

levelbar block.low {
  border-color: #F27835;
  background-color: #F27835;
}

levelbar block.high {
  border-color: #3498db;
  background-color: #3498db;
}

levelbar block.full {
  border-color: #2eb398;
  background-color: #2eb398;
}

levelbar block.empty {
  background-color: rgba(43, 47, 59, 0.2);
  border-color: rgba(43, 47, 59, 0.2);
}

printdialog paper {
  border: 1px solid rgba(0, 0, 0, 0.15);
  background: #ffffff;
  padding: 0;
}

printdialog .dialog-action-box {
  margin: 12px;
}

frame > border,
.frame {
  margin: 0;
  padding: 0;
  border-radius: 2px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

frame.flat > border,
frame > border.flat,
.frame.flat {
  border-style: none;
}

scrolledwindow viewport.frame {
  border: none;
}

scrolledwindow viewport.frame > box.vertical list.content.view {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

scrolledwindow viewport.frame > box.vertical list.frame {
  border-radius: 2px;
  padding: 0;
}

scrolledwindow viewport.frame > box.vertical list.frame > row.activatable:first-child {
  border-radius: 2px 2px 0 0;
}

scrolledwindow viewport.frame > box.vertical list.frame > row.activatable:last-child {
  border-radius: 0 0 2px 2px;
}

scrolledwindow viewport.frame > box.vertical list.frame list {
  border: none;
  box-shadow: none;
  border-radius: 0;
  margin: 0;
  background: none;
}

scrolledwindow viewport.frame > box.vertical list.frame list > row.activatable, scrolledwindow viewport.frame > box.vertical list.frame list > row.activatable:first-child, scrolledwindow viewport.frame > box.vertical list.frame list > row.activatable:last-child {
  border-radius: 0;
}

scrolledwindow overshoot.top {
  background-image: radial-gradient(farthest-side at top, rgba(0, 0, 0, 0.15) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at top, rgba(43, 47, 59, 0.07), rgba(43, 47, 59, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, rgba(0, 0, 0, 0.15) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at bottom, rgba(43, 47, 59, 0.07), rgba(43, 47, 59, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.left {
  background-image: radial-gradient(farthest-side at left, rgba(0, 0, 0, 0.15) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at left, rgba(43, 47, 59, 0.07), rgba(43, 47, 59, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.right {
  background-image: radial-gradient(farthest-side at right, rgba(0, 0, 0, 0.15) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at right, rgba(43, 47, 59, 0.07), rgba(43, 47, 59, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.top {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top;
  border: none;
}

scrolledwindow undershoot.bottom {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom;
  border: none;
}

scrolledwindow undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
}

scrolledwindow undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
}

scrolledwindow junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15) 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: #fcfcfc;
}

scrolledwindow junction:dir(rtl) {
  border-image-slice: 0 1 0 0;
}

separator {
  background-color: rgba(0, 0, 0, 0.1);
  min-width: 1px;
  min-height: 1px;
}

list {
  background-color: #ffffff;
  border-color: rgba(0, 0, 0, 0.15);
}

list row {
  padding: 2px;
}

list.content:not(.conversation-listbox) {
  border-radius: 2px;
}

list.content:not(.conversation-listbox) > row:first-child {
  border-radius: 2px 2px 0 0;
}

list.content:not(.conversation-listbox) > row:last-child {
  border-radius: 0 0 2px 2px;
}

treeview.has-open-popup.view.sidebar.source-list, .panel popover .sidebar .has-open-popup.view, .budgie-popover.budgie-menu button.has-open-popup, .nemo-window .nemo-places-sidebar .has-open-popup.places-treeview, row.has-open-popup.activatable, treeview.view.sidebar.source-list:hover, .panel popover .sidebar .view:hover, .budgie-popover.budgie-menu button:hover, .nemo-window .nemo-places-sidebar .places-treeview:hover, row.activatable:hover {
  background-color: rgba(0, 0, 0, 0.05);
}

treeview.view.sidebar.source-list:active, .panel popover .sidebar .view:active, .budgie-popover.budgie-menu button:active, .nemo-window .nemo-places-sidebar .places-treeview:active, row.activatable:active {
  color: #2b2f3b;
}

treeview.view.sidebar.source-list:disabled, .panel popover .sidebar .view:disabled, .budgie-popover.budgie-menu button:disabled, .nemo-window .nemo-places-sidebar .places-treeview:disabled, row.activatable:disabled {
  color: rgba(43, 47, 59, 0.55);
}

treeview.view.sidebar.source-list:disabled image, .panel popover .sidebar .view:disabled image, .budgie-popover.budgie-menu button:disabled image, .nemo-window .nemo-places-sidebar .places-treeview:disabled image, row.activatable:disabled image {
  color: inherit;
}

treeview.view.sidebar.source-list:selected:active, .panel popover .sidebar .view:selected:active, .budgie-popover.budgie-menu button:selected:active, .nemo-window .nemo-places-sidebar .places-treeview:selected:active, row.activatable:selected:active {
  color: #ffffff;
}

treeview.view.sidebar.source-list:selected.has-open-popup, .panel popover .sidebar .view:selected.has-open-popup, .budgie-popover.budgie-menu button:selected.has-open-popup, .nemo-window .nemo-places-sidebar .places-treeview:selected.has-open-popup, row.activatable:selected.has-open-popup, treeview.view.sidebar.source-list:selected:hover, .panel popover .sidebar .view:selected:hover, .budgie-popover.budgie-menu button:selected:hover, .nemo-window .nemo-places-sidebar .places-treeview:selected:hover, row.activatable:selected:hover {
  background-color: #2f89c5;
}

row:not(:hover) {
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.app-notification {
  padding: 10px;
  color: #2e313d;
  background-color: alpha(rgba(255, 255, 255, 0.95),0.9);
  background-clip: border-box;
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
}

.app-notification border {
  border: none;
}

.app-notification button {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.95);
}

.app-notification button:hover {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(46, 49, 61, 0.1);
}

.app-notification button:active, .app-notification button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
  background-clip: padding-box;
}

.app-notification button:disabled {
  color: #c0c1c5;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

.app-notification button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
}

.app-notification .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0.3);
}

.app-notification .linked:not(.vertical) > entry.error + entry,
.app-notification .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.app-notification .linked:not(.vertical) > entry.warning + entry,
.app-notification .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.app-notification .linked:not(.vertical) > entry.error + entry.warning,
.app-notification .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.app-notification .linked:not(.vertical) > entry + entry:focus:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry:focus:last-child {
  border-left-color: #3498db;
}

.app-notification .linked:not(.vertical) > entry:focus:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry:focus:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #3498db;
}

.app-notification .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.app-notification .linked:not(.vertical) > entry + entry.warning:focus:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.app-notification .linked:not(.vertical) > entry.warning:focus:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry.warning:focus:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.app-notification .linked:not(.vertical) > entry + entry.error:focus:not(:last-child),
.app-notification .linked:not(.vertical) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.app-notification .linked:not(.vertical) > entry.error:focus:not(:only-child) + entry,
.app-notification .linked:not(.vertical) > entry.error:focus:not(:only-child) + button,
.app-notification .linked:not(.vertical) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.app-notification .linked:not(.vertical) > button:active + entry,
.app-notification .linked:not(.vertical) > button:checked + entry {
  border-left-color: #3498db;
}

.app-notification .linked:not(.vertical) > button + button {
  border-left-style: none;
}

.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.app-notification .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.app-notification .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.app-notification .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.app-notification .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child) {
  box-shadow: none;
}

expander arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander arrow:hover {
  color: #6c7694;
}

expander arrow:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

calendar {
  color: #2b2f3b;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  padding: 0 6px;
}

calendar:selected {
  border-radius: 3px;
}

calendar.header {
  color: #2b2f3b;
  border: none;
}

calendar.button {
  color: rgba(43, 47, 59, 0.45);
}

calendar.button:hover {
  color: #2b2f3b;
}

calendar.button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

calendar:indeterminate {
  color: alpha(currentColor,0.55);
}

calendar.highlight {
  color: #2b2f3b;
}

messagedialog.csd .titlebar {
  min-height: 20px;
  background-color: #f7f7f7;
  border: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

messagedialog .dialog-action-area.linked:not(.vertical) > button {
  padding: 5px 10px;
  border-radius: 0;
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:active, messagedialog .dialog-action-area.linked:not(.vertical) > button:checked {
  transition: background-color 0.00001s 0.2s;
  animation: ripple_effect 0.2s cubic-bezier(0, 0, 0.2, 1);
}

messagedialog .dialog-action-area.linked:not(.vertical) > button, messagedialog .dialog-action-area.linked:not(.vertical) > button:hover, messagedialog .dialog-action-area.linked:not(.vertical) > button:active, messagedialog .dialog-action-area.linked:not(.vertical) > button:checked, messagedialog .dialog-action-area.linked:not(.vertical) > button:disabled {
  border-radius: 0;
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:first-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:hover:first-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:active:first-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:checked:first-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:disabled:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:last-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:hover:last-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:active:last-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:checked:last-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:disabled:last-child {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:only-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:hover:only-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:active:only-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:checked:only-child, messagedialog .dialog-action-area.linked:not(.vertical) > button:disabled:only-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):hover {
  background-color: alpha(#2b2f3b,0.06);
}

messagedialog .dialog-action-area.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):active, messagedialog .dialog-action-area.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):checked {
  background-color: alpha(#2b2f3b,0.1);
  color: #2b2f3b;
}

messagedialog.csd.background {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border: none;
}

messagedialog.csd .dialog-action-area.linked:not(.vertical) > button {
  padding: 6px 10px 8px 10px;
}

messagedialog.csd .dialog-action-area.linked:not(.vertical) > button, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:hover, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:active, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:checked, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:disabled {
  border-radius: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-right: none;
  border-bottom: none;
}

messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:first-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:hover:first-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:active:first-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:checked:first-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:disabled:first-child {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 0;
  border-left: none;
  border-bottom: none;
}

messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:last-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:hover:last-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:active:last-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:checked:last-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:disabled:last-child {
  border-bottom-right-radius: 3px;
  border-top-right-radius: 0;
  border-right: none;
  border-bottom: none;
}

messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:only-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:hover:only-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:active:only-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:checked:only-child, messagedialog.csd .dialog-action-area.linked:not(.vertical) > button:disabled:only-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-left: none;
  border-right: none;
  border-bottom: none;
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.08);
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

.sidebar {
  border-style: none;
  background-color: #f7f7f7;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left {
  border-right: 1px solid #d1d1d1;
  border-left-style: none;
}

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list, .sidebar:dir(rtl), .sidebar.right {
  border-left: 1px solid #d1d1d1;
  border-right-style: none;
}

.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar row {
  padding: 4px 4px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar row.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

placessidebar row button.sidebar-button {
  min-width: 22px;
  min-height: 22px;
  margin-top: 2px;
  margin-bottom: 2px;
  padding: 0;
  border-radius: 100%;
  -gtk-outline-radius: 100%;
}

placessidebar row button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

placessidebar > viewport.frame {
  border-style: none;
}

placessidebar row {
  min-height: 28px;
  padding: 2px 2px 2px 10px;
}

placessidebar row > revealer {
  padding: 0 10px;
}

placessidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: linear-gradient(to bottom, #F08437, #F08437);
  background-clip: content-box;
}

placessidebar row.sidebar-new-bookmark-row {
  color: #3498db;
}

placessidebar row:drop(active):not(:disabled) {
  box-shadow: inset 0 1px #F08437, inset 0 -1px #F08437;
}

placessidebar row:drop(active):not(:disabled), placessidebar row:drop(active):not(:disabled) label, placessidebar row:drop(active):not(:disabled) image {
  color: #F08437;
}

placessidebar row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

placessidebar row:drop(active):not(:disabled):selected, placessidebar row:drop(active):not(:disabled):selected label, placessidebar row:drop(active):not(:disabled):selected image {
  color: #ffffff;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15));
  background-size: 1px 1px;
}

paned > separator:selected {
  background-image: linear-gradient(to bottom, #3498db, #3498db);
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
  background-color: #f7f7f7;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15)), linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15));
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

infobar {
  border-style: none;
}

infobar.info > revealer > box, infobar.info:backdrop > revealer > box {
  background-color: #3498db;
}

infobar.info > revealer > box selection, infobar.info:backdrop > revealer > box selection {
  color: #3498db;
}

infobar.question > revealer > box, infobar.question:backdrop > revealer > box {
  background-color: #3498db;
}

infobar.question > revealer > box selection, infobar.question:backdrop > revealer > box selection {
  color: #3498db;
}

infobar.warning > revealer > box, infobar.warning:backdrop > revealer > box {
  background-color: #F27835;
}

infobar.warning > revealer > box selection, infobar.warning:backdrop > revealer > box selection {
  color: #F27835;
}

infobar.error > revealer > box, infobar.error:backdrop > revealer > box {
  background-color: #FC4138;
}

infobar.error > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  color: #FC4138;
}

infobar.info > revealer > box, infobar.info:hover > revealer > box, infobar.info:backdrop > revealer > box, infobar.question > revealer > box, infobar.question:hover > revealer > box, infobar.question:backdrop > revealer > box, infobar.warning > revealer > box, infobar.warning:hover > revealer > box, infobar.warning:backdrop > revealer > box, infobar.error > revealer > box, infobar.error:hover > revealer > box, infobar.error:backdrop > revealer > box {
  color: #ffffff;
  caret-color: currentColor;
}

infobar.info > revealer > box button, infobar.info:hover > revealer > box button, infobar.info:backdrop > revealer > box button, infobar.question > revealer > box button, infobar.question:hover > revealer > box button, infobar.question:backdrop > revealer > box button, infobar.warning > revealer > box button, infobar.warning:hover > revealer > box button, infobar.warning:backdrop > revealer > box button, infobar.error > revealer > box button, infobar.error:hover > revealer > box button, infobar.error:backdrop > revealer > box button {
  min-height: 28px;
}

infobar.info > revealer > box selection, infobar.info:hover > revealer > box selection, infobar.info:backdrop > revealer > box selection, infobar.question > revealer > box selection, infobar.question:hover > revealer > box selection, infobar.question:backdrop > revealer > box selection, infobar.warning > revealer > box selection, infobar.warning:hover > revealer > box selection, infobar.warning:backdrop > revealer > box selection, infobar.error > revealer > box selection, infobar.error:hover > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  background-color: #ffffff;
}

.raven-mpris button.image-button, .nemo-window .floating-bar button, .nautilus-window .floating-bar button, row:selected button, infobar.info > revealer > box button, infobar.info:hover > revealer > box button, infobar.info:backdrop > revealer > box button, infobar.question > revealer > box button, infobar.question:hover > revealer > box button, infobar.question:backdrop > revealer > box button, infobar.warning > revealer > box button, infobar.warning:hover > revealer > box button, infobar.warning:backdrop > revealer > box button, infobar.error > revealer > box button, infobar.error:hover > revealer > box button, infobar.error:backdrop > revealer > box button {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.5);
}

.raven-mpris button.flat.image-button, .nemo-window .floating-bar button.flat, .nautilus-window .floating-bar button.flat, row:selected button.flat, infobar.info > revealer > box button.flat, infobar.question > revealer > box button.flat, infobar.warning > revealer > box button.flat, infobar.error > revealer > box button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

.raven-mpris button.flat.image-button:disabled, .nemo-window .floating-bar button.flat:disabled, .nautilus-window .floating-bar button.flat:disabled, row:selected button.flat:disabled, infobar.info > revealer > box button.flat:disabled, infobar.question > revealer > box button.flat:disabled, infobar.warning > revealer > box button.flat:disabled, infobar.error > revealer > box button.flat:disabled {
  color: rgba(255, 255, 255, 0.42);
}

.raven-mpris button.flat.image-button:disabled label, .nemo-window .floating-bar button.flat:disabled label, .nautilus-window .floating-bar button.flat:disabled label, row:selected button.flat:disabled label, infobar.info > revealer > box button.flat:disabled label, infobar.question > revealer > box button.flat:disabled label, infobar.warning > revealer > box button.flat:disabled label, infobar.error > revealer > box button.flat:disabled label {
  color: rgba(255, 255, 255, 0.42);
}

.raven-mpris button.image-button:hover, .nemo-window .floating-bar button:hover, .nautilus-window .floating-bar button:hover, row:selected button:hover, infobar.info > revealer > box button:hover, infobar.question > revealer > box button:hover, infobar.warning > revealer > box button:hover, infobar.error > revealer > box button:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.8);
}

.raven-mpris button.image-button:active, .nemo-window .floating-bar button:active, .nautilus-window .floating-bar button:active, row:selected button:active, infobar.info > revealer > box button:active, infobar.question > revealer > box button:active, infobar.warning > revealer > box button:active, infobar.error > revealer > box button:active, .raven-mpris button.image-button:checked, .nemo-window .floating-bar button:checked, .nautilus-window .floating-bar button:checked, row:selected button:checked, infobar.info > revealer > box button:checked, infobar.question > revealer > box button:checked, infobar.warning > revealer > box button:checked, infobar.error > revealer > box button:checked {
  color: #3498db;
  background-color: #ffffff;
  border-color: #ffffff;
}

.raven-mpris button.image-button:disabled, .nemo-window .floating-bar button:disabled, .nautilus-window .floating-bar button:disabled, row:selected button:disabled, infobar.info > revealer > box button:disabled, infobar.question > revealer > box button:disabled, infobar.warning > revealer > box button:disabled, infobar.error > revealer > box button:disabled {
  color: rgba(255, 255, 255, 0.5);
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.42);
}

.raven-mpris button.image-button:disabled label, .nemo-window .floating-bar button:disabled label, .nautilus-window .floating-bar button:disabled label, row:selected button:disabled label, infobar.info > revealer > box button:disabled label, infobar.question > revealer > box button:disabled label, infobar.warning > revealer > box button:disabled label, infobar.error > revealer > box button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

.raven-mpris button.image-button:disabled:active, .nemo-window .floating-bar button:disabled:active, .nautilus-window .floating-bar button:disabled:active, row:selected button:disabled:active, infobar.info > revealer > box button:disabled:active, infobar.question > revealer > box button:disabled:active, infobar.warning > revealer > box button:disabled:active, infobar.error > revealer > box button:disabled:active, .raven-mpris button.image-button:disabled:checked, .nemo-window .floating-bar button:disabled:checked, .nautilus-window .floating-bar button:disabled:checked, row:selected button:disabled:checked, infobar.info > revealer > box button:disabled:checked, infobar.question > revealer > box button:disabled:checked, infobar.warning > revealer > box button:disabled:checked, infobar.error > revealer > box button:disabled:checked {
  color: #3498db;
  background-color: rgba(255, 255, 255, 0.5);
  border-color: rgba(255, 255, 255, 0.42);
}

tooltip {
  border-radius: 2px;
  box-shadow: none;
}

tooltip.background {
  background-color: rgba(255, 255, 255, 0.95);
  background-clip: padding-box;
}

tooltip.background label {
  padding: 4px;
}

tooltip decoration {
  background-color: transparent;
}

tooltip * {
  background-color: transparent;
  color: #2e313d;
}

colorswatch, colorswatch:drop(active) {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 2.5px;
  border-top-right-radius: 2.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

colorswatch.bottom {
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 2.5px;
  border-bottom-left-radius: 2.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.dark overlay {
  color: rgba(255, 255, 255, 0.37);
}

colorswatch.dark overlay:hover {
  border-color: rgba(0, 0, 0, 0.5);
}

colorswatch.light overlay {
  color: rgba(0, 0, 0, 0.7);
}

colorswatch.light overlay:hover {
  border-color: rgba(0, 0, 0, 0.3);
}

colorswatch overlay {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

colorswatch overlay:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

colorswatch#add-color-button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

colorswatch#add-color-button overlay {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button.color {
  padding: 0;
}

button.color colorswatch:first-child:last-child, button.color colorswatch:first-child:last-child overlay {
  margin: 4px;
  border-radius: 0;
}

colorchooser .popover.osd {
  border-radius: 3px;
}

.content-view {
  background-color: #ffffff;
}

.content-view:hover {
  -gtk-icon-effect: highlight;
}

.scale-popup button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

.context-menu, popover.touch-selection, .csd popover.touch-selection,
popover.background.touch-selection, .csd popover.background.touch-selection {
  font: initial;
}

.monospace {
  font-family: Monospace;
}

.slate-notification-window button.image-button.close,
.budgie-notification-window button.image-button.close,
.budgie-switcher-window button.image-button.close,
.budgie-osd-window button.image-button.close, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable button.image-button, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button, button.nautilus-circular-button.image-button,
button.circular,
button.circular-button {
  min-width: 28px;
  min-height: 28px;
  padding: 2px;
  border-radius: 1000px;
  -gtk-outline-radius: 1000px;
}

.slate-notification-window button.image-button.close label,
.budgie-notification-window button.image-button.close label,
.budgie-switcher-window button.image-button.close label,
.budgie-osd-window button.image-button.close label, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable button.image-button label, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button label, button.nautilus-circular-button.image-button label,
button.circular label,
button.circular-button label {
  padding: 0;
}

.keycap {
  min-width: 16px;
  min-height: 20px;
  padding: 3px 6px 4px 6px;
  color: #2b2f3b;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2.5px;
  box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.05);
}

stackswitcher button.text-button {
  min-width: 80px;
}

stackswitcher button.circular {
  min-width: 0;
}

viewswitcher button > stack > box {
  padding: 6px 12px;
}

viewswitcher button > stack > box.narrow {
  font-size: 10px;
}

viewswitcher button:active, viewswitcher button:active:hover, viewswitcher button:checked {
  background-color: #dddddf;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-clip: border-box;
}

viewswitcher button:active + button, viewswitcher button:active:hover + button, viewswitcher button:checked + button {
  border-left-color: rgba(0, 0, 0, 0.2);
}

*:drop(active):focus,
*:drop(active) {
  box-shadow: inset 0 0 0 1px #F08437;
}

decoration {
  border-radius: 2px;
  border-width: 0;
  box-shadow: 0 3px 5px 0 rgba(0, 0, 0, 0.2), 0 8px 8px 0 rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.15);
  margin: 6px;
}

decoration:backdrop {
  box-shadow: 0 3px 5px 0 transparent, 0 8px 8px 0 transparent, 0 3px 3px 0 rgba(0, 0, 0, 0.16), 0 0 0 1px rgba(0, 0, 0, 0.15);
  transition: 200ms ease-out;
}

.fullscreen decoration, .tiled decoration {
  border-radius: 0;
  box-shadow: 0 3px 3px 0 rgba(0, 0, 0, 0.16);
}

.ssd decoration {
  border-radius: 4px 4px 0 0;
  box-shadow: 0 3px 5px 0 rgba(0, 0, 0, 0.25);
}

.ssd decoration.maximized {
  border-radius: 0;
}

.csd.popup decoration {
  border-radius: 2px;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.15);
}

tooltip.csd decoration {
  border-radius: 2px;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
}

messagedialog.csd decoration {
  border-radius: 3px;
}

.solid-csd decoration {
  border: 1px solid #f2f2f2;
  border-radius: 0;
  margin: 0;
  background-color: #f2f2f2;
  box-shadow: none;
}

headerbar button.titlebutton {
  margin: 0;
  padding: 0;
  min-width: 28px;
  min-height: 28px;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  background-color: rgba(242, 242, 242, 0);
}

headerbar button.titlebutton:hover {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.12);
}

headerbar button.titlebutton:active, headerbar button.titlebutton:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

headerbar button.titlebutton.close, headerbar button.titlebutton.maximize, headerbar button.titlebutton.minimize, headerbar button.titlebutton.restore {
  min-width: 30px;
  min-height: 28px;
  color: transparent;
  background-color: transparent;
  background-position: center;
  background-repeat: no-repeat;
  border-width: 0;
}

headerbar button.titlebutton.close:backdrop, headerbar button.titlebutton.maximize:backdrop, headerbar button.titlebutton.minimize:backdrop, headerbar button.titlebutton.restore:backdrop {
  opacity: 1;
}

headerbar button.titlebutton.close {
  background-image: -gtk-scaled(url("assets/titlebutton-close.png"), url("assets/titlebutton-close@2.png"));
}

headerbar button.titlebutton.close:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop.png"), url("assets/titlebutton-close-backdrop@2.png"));
}

headerbar button.titlebutton.close:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-close-hover.png"), url("assets/titlebutton-close-hover@2.png"));
}

headerbar button.titlebutton.close:active {
  background-image: -gtk-scaled(url("assets/titlebutton-close-active.png"), url("assets/titlebutton-close-active@2.png"));
}

headerbar button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize.png"), url("assets/titlebutton-maximize@2.png"));
}

headerbar button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop.png"), url("assets/titlebutton-maximize-backdrop@2.png"));
}

headerbar button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover.png"), url("assets/titlebutton-maximize-hover@2.png"));
}

headerbar button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-active.png"), url("assets/titlebutton-maximize-active@2.png"));
}

headerbar button.titlebutton.minimize {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize.png"), url("assets/titlebutton-minimize@2.png"));
}

headerbar button.titlebutton.minimize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop.png"), url("assets/titlebutton-minimize-backdrop@2.png"));
}

headerbar button.titlebutton.minimize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover.png"), url("assets/titlebutton-minimize-hover@2.png"));
}

headerbar button.titlebutton.minimize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-active.png"), url("assets/titlebutton-minimize-active@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize, .maximized headerbar button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-restore.png"), url("assets/titlebutton-restore@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:backdrop, .maximized headerbar button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop.png"), url("assets/titlebutton-restore-backdrop@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:hover, .maximized headerbar button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover.png"), url("assets/titlebutton-restore-hover@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:active, .maximized headerbar button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active.png"), url("assets/titlebutton-restore-active@2.png"));
}

filechooser placessidebar.sidebar row.sidebar-row.has-open-popup:selected, filechooser placessidebar.sidebar row.sidebar-row:selected, filechooser placessidebar.sidebar row.sidebar-row:selected:hover, filechooser placessidebar.sidebar row.sidebar-row:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover, .budgie-popover.budgie-menu button:checked, .atril-window scrolledwindow.frame > .view:selected, .atril-window scrolledwindow.frame > .view:active,
.xreader-window scrolledwindow.frame > .view:selected,
.xreader-window scrolledwindow.frame > .view:active, .caja-desktop > widget.entry:selected, .caja-desktop > widget.entry:focus:selected, #MozillaGtkWidget > widget > scrolledwindow > textview text:selected, #MozillaGtkWidget > widget > scrolledwindow > textview text:selected:focus,
#MozillaGtkWidget > widget > scrolledwindow > textview text selection, .nemo-window .nemo-window-pane widget.entry:selected:focus, .nemo-window .nemo-window-pane widget.entry:selected, .nemo-window .nemo-places-sidebar .places-treeview:selected, .nemo-window .nemo-places-sidebar .places-treeview:selected:hover, .emoji widget:hover, .view:selected, .view:selected:focus, textview text selection:focus, textview text selection, iconview:selected, iconview:selected:focus, flowbox flowboxchild:selected, entry selection:focus, entry selection, menuitem.button.flat:active, menuitem.button.flat:active arrow, menuitem.button.flat:selected, menuitem.button.flat:selected arrow,
modelbutton.flat:active,
modelbutton.flat:active arrow,
modelbutton.flat:selected,
modelbutton.flat:selected arrow, treeview.view:selected, treeview.view:selected:focus, row:selected, calendar:selected {
  background-color: #3498db;
  color: #ffffff;
}

filechooser placessidebar.sidebar row.sidebar-row:disabled:selected, filechooser placessidebar.sidebar row.sidebar-row:disabled:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled:active:hover, .budgie-popover.budgie-menu button:disabled:checked, .atril-window scrolledwindow.frame > .view:disabled:selected, .atril-window scrolledwindow.frame > .view:disabled:active,
.xreader-window scrolledwindow.frame > .view:disabled:selected,
.xreader-window scrolledwindow.frame > .view:disabled:active, .caja-desktop > widget.entry:disabled:selected, #MozillaGtkWidget > widget > scrolledwindow > textview text:disabled:selected,
#MozillaGtkWidget > widget > scrolledwindow > textview text selection:disabled, .nemo-window .nemo-window-pane widget.entry:disabled:selected, .nemo-window .nemo-places-sidebar .places-treeview:disabled:selected, .emoji widget:disabled:hover, .view:disabled:selected, textview text selection:disabled, iconview:disabled:selected, iconview:disabled:selected:focus, flowbox flowboxchild:disabled:selected, entry selection:disabled, menuitem.button.flat:disabled:active, menuitem.button.flat:active arrow:disabled, menuitem.button.flat:disabled:selected, menuitem.button.flat:selected arrow:disabled,
modelbutton.flat:disabled:active,
modelbutton.flat:active arrow:disabled,
modelbutton.flat:disabled:selected,
modelbutton.flat:selected arrow:disabled, row:disabled:selected, calendar:disabled:selected {
  color: #9acced;
}

row:selected label, label:selected {
  color: #ffffff;
}

row:selected label:disabled, label:disabled:selected {
  color: #9acced;
}

/*********
 * Emoji *
 *********/
popover.emoji-picker {
  padding: 0;
}

popover.emoji-picker entry {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px 2px 0 0;
  box-shadow: none;
  border-width: 0 0 1px 0;
  padding: 4px 12px;
}

popover.emoji-picker entry, popover.emoji-picker entry:focus {
  background-color: transparent;
}

popover.emoji-picker scrolledwindow {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

button.emoji-section {
  margin-top: -1px;
  padding: 4px 12px;
  border-radius: 0;
  outline-offset: -4px;
  box-shadow: none;
  border: none;
  transition-duration: 0ms;
}

button.emoji-section:first-child {
  border-radius: 0 0 0 2px;
}

button.emoji-section:last-child {
  border-radius: 0 0 2px 0;
}

.emoji {
  min-width: 3em;
  min-height: 3em;
  padding: 0;
  font-size: large;
}

.emoji widget {
  border-radius: 3px;
  transition: all 0.1s cubic-bezier(0, 0, 0.2, 1);
}

terminal-window.background.csd,
.mate-terminal.background.csd {
  border-radius: 0 0 0 0;
}

terminal-window decoration,
.mate-terminal decoration {
  border-radius: 2px 2px 0 0;
}

terminal-window notebook > header.top button,
.mate-terminal notebook > header.top button {
  padding: 0;
  min-width: 24px;
  min-height: 24px;
}

terminal-window notebook scrollbar,
.mate-terminal notebook scrollbar {
  background: none;
}

window.thunar toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button, window.thunar .inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button,
.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.image-button.text-button, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle {
  background-color: transparent;
  background-image: none;
  color: #2b2f3b;
  border-radius: 0;
  box-shadow: none;
  border: none;
  margin: 0 0 0 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 0%, transparent 0%) 0 0 0/0 0 0;
}

window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:hover, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:hover, .nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:hover,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:hover, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:hover, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:hover {
  background-color: transparent;
  box-shadow: inset 0 -2px rgba(52, 152, 219, 0.5);
}

window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked, .nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:checked, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:checked, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:checked, window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:active, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:active, .nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:active,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:active, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:active, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:active {
  color: #2b2f3b;
  background-color: transparent;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 100%, transparent 0%) 0 0 2/0 0 2px;
}

window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:disabled, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:disabled, .nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:disabled,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:disabled, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:disabled, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:disabled {
  color: rgba(43, 47, 59, 0.4);
  background-color: transparent;
}

window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked:disabled, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked:disabled, .nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button:checked:disabled,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:checked:disabled, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:checked:disabled, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:checked:disabled {
  color: rgba(43, 47, 59, 0.4);
  background-color: transparent;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(52, 152, 219, 0.4) 100%, transparent 0%) 0 0 2/0 0 2px;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar > button.popup {
  border-radius: 2px;
  border: none;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar > button.popup:hover {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.1);
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar > button.popup:active {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.2);
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:checked, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar > button.popup:checked {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.15);
}

.nautilus-window headerbar.titlebar .path-bar-box {
  margin: 6px 0 4px 0;
  border-radius: 3px;
  color: #2b2f3b;
  background-color: transparent;
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:hover, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:checked, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:active, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:disabled,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle:hover,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle:checked,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle:active,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle:disabled {
  margin-top: 0;
  margin-bottom: 0;
  padding: 0 6px 4px 6px;
  min-height: 24px;
  border-radius: 0;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:not(:only-child):last-child,
.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.image-button.text-button:not(:only-child):last-child {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 100%, transparent 0%) 0 0 2/0 0 2px;
}

.nautilus-window headerbar.titlebar .path-bar-box.width-maximized {
  border: 1px solid rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.06);
}

.nautilus-window headerbar.titlebar .path-bar-box.background.frame {
  border: none;
  background-color: transparent;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar {
  background-color: rgba(43, 47, 59, 0.06);
  border-radius: 2px;
  margin: 6px 0;
  border: none;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar > button.popup {
  margin-top: 0;
  margin-bottom: 0;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box {
  padding: 0;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button {
  margin: 0;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.dim-label, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .slate-notification .path-buttons-box > box > button > box > label.notification-body, .slate-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-notification .path-buttons-box > box > button > box > label.notification-body,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-switcher .path-buttons-box > box > button > box > label.notification-body,
.budgie-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body,
.budgie-switcher .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.separator, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.subtitle {
  color: rgba(43, 47, 59, 0.85);
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.dim-label:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .slate-notification .path-buttons-box > box > button > box > label.notification-body:hover, .slate-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:hover,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-notification .path-buttons-box > box > button > box > label.notification-body:hover,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-switcher .path-buttons-box > box > button > box > label.notification-body:hover,
.budgie-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:hover,
.budgie-switcher .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.separator:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.subtitle:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.dim-label:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .slate-notification .path-buttons-box > box > button > box > label.notification-body:active, .slate-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:active,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-notification .path-buttons-box > box > button > box > label.notification-body:active,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-switcher .path-buttons-box > box > button > box > label.notification-body:active,
.budgie-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:active,
.budgie-switcher .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.separator:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.subtitle:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.dim-label:checked, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .slate-notification .path-buttons-box > box > button > box > label.notification-body:checked, .slate-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:checked,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-notification .path-buttons-box > box > button > box > label.notification-body:checked,
.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .budgie-switcher .path-buttons-box > box > button > box > label.notification-body:checked,
.budgie-notification .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:checked,
.budgie-switcher .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.notification-body:checked, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.separator:checked, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button > box > label.subtitle:checked {
  color: #2b2f3b;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:hover {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.1);
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:active, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button:checked {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.2);
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button.current-dir {
  color: #2b2f3b;
}

.nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button.current-dir:hover, .nautilus-window headerbar.titlebar.windowhandle .linked.nautilus-path-bar .path-buttons-box > box > button.current-dir:active {
  background: none;
  box-shadow: none;
  border-image: none;
}

.nautilus-canvas-item, .caja-canvas-item {
  border-radius: 2px;
}

.caja-desktop.caja-canvas-item, .caja-desktop, .nemo-desktop.nemo-canvas-item,
.nautilus-desktop.nautilus-canvas-item,
.nautilus-desktop.caja-canvas-item {
  color: #ffffff;
  text-shadow: 1px 1px rgba(0, 0, 0, 0.6);
}

.caja-desktop:active, .nemo-desktop.nemo-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:active,
.nautilus-desktop.caja-canvas-item:active {
  color: #2b2f3b;
}

.caja-desktop:selected, .nemo-desktop.nemo-canvas-item:selected,
.nautilus-desktop.nautilus-canvas-item:selected,
.nautilus-desktop.caja-canvas-item:selected {
  color: #ffffff;
  text-shadow: none;
}

.nautilus-canvas-item.dim-label, .slate-notification .nautilus-canvas-item.notification-body,
.budgie-notification .nautilus-canvas-item.notification-body,
.budgie-switcher .nautilus-canvas-item.notification-body, .dim-label.caja-canvas-item, .slate-notification .caja-canvas-item.notification-body,
.budgie-notification .caja-canvas-item.notification-body,
.budgie-switcher .caja-canvas-item.notification-body, label.nautilus-canvas-item.separator, label.separator.caja-canvas-item, headerbar .nautilus-canvas-item.subtitle, headerbar .subtitle.caja-canvas-item,
.nautilus-list-dim-label,
.caja-list-dim-label {
  color: #919399;
}

.nautilus-canvas-item.dim-label:selected, .slate-notification .nautilus-canvas-item.notification-body:selected,
.budgie-notification .nautilus-canvas-item.notification-body:selected,
.budgie-switcher .nautilus-canvas-item.notification-body:selected, .dim-label.caja-canvas-item:selected, .slate-notification .caja-canvas-item.notification-body:selected,
.budgie-notification .caja-canvas-item.notification-body:selected,
.budgie-switcher .caja-canvas-item.notification-body:selected, label.nautilus-canvas-item.separator:selected, label.separator.caja-canvas-item:selected, headerbar .nautilus-canvas-item.subtitle:selected, headerbar .subtitle.caja-canvas-item:selected, .nautilus-canvas-item.dim-label:selected:focus,
.nautilus-list-dim-label:selected,
.caja-list-dim-label:selected,
.nautilus-list-dim-label:selected:focus {
  color: #d6eaf8;
}

.nautilus-window searchbar {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.nautilus-window .searchbar-container {
  margin-top: -1px;
}

.nautilus-window notebook,
.nautilus-window notebook > stack:not(:only-child) searchbar {
  background-color: #ffffff;
}

.disk-space-display {
  border-style: solid;
  border-width: 1px;
}

.disk-space-display.unknown {
  background-color: rgba(43, 47, 59, 0.5);
  border-color: rgba(22, 24, 30, 0.5);
}

.disk-space-display.used {
  background-color: rgba(52, 152, 219, 0.8);
  border-color: rgba(33, 125, 187, 0.8);
}

.disk-space-display.free {
  background-color: #efefef;
  border-color: #d6d6d6;
}

@keyframes needs_attention_keyframes {
  0% {
    color: #2b2f3b;
    border-color: rgba(0, 0, 0, 0.15);
    background-color: rgba(43, 47, 59, 0.12);
  }
  100% {
    color: #ffffff;
    border-color: #3498db;
    background-color: #3498db;
  }
}

.nautilus-operations-button-needs-attention {
  animation: needs_attention_keyframes 2s ease-in-out;
}

.nautilus-operations-button-needs-attention-multiple {
  animation: needs_attention_keyframes 3s ease-in-out;
  animation-iteration-count: 3;
}

.conflict-row.activatable, .conflict-row.activatable:active {
  color: white;
  background-color: #FC4138;
}

.conflict-row.activatable:hover {
  background-color: #fd716a;
}

.conflict-row.activatable:selected {
  color: #ffffff;
  background-color: #3498db;
}

.open-document-selector-treeview.view {
  padding: 3px 6px 3px 6px;
  border-color: #ffffff;
}

.open-document-selector-treeview.view:hover {
  background-color: #f0f0f1;
}

.open-document-selector-treeview.view:hover:selected {
  color: #ffffff;
  background-color: #3498db;
}

.open-document-selector-name-label {
  color: #2b2f3b;
}

.open-document-selector-path-label {
  color: #95979d;
  font-size: smaller;
}

.open-document-selector-path-label:selected {
  color: rgba(255, 255, 255, 0.9);
}

.gedit-document-panel row button {
  min-width: 22px;
  min-height: 22px;
  padding: 0;
  color: transparent;
  background: none;
  border: none;
  box-shadow: none;
}

.gedit-document-panel row button image {
  color: inherit;
}

.gedit-document-panel row:hover:not(:selected) button {
  color: #72757d;
}

.gedit-document-panel row:hover:not(:selected) button:hover {
  color: #ff4d4d;
}

.gedit-document-panel row:hover:not(:selected) button:active {
  color: #2b2f3b;
}

.gedit-document-panel row:hover:selected button:hover {
  color: #ff6666;
  background: none;
  border: none;
  box-shadow: none;
}

.gedit-document-panel row:hover:selected button:hover:active {
  color: #ffffff;
}

.gedit-document-panel-dragged-row {
  border: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #dedede;
  color: #2b2f3b;
}

.gedit-side-panel-paned statusbar {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #f7f7f7;
}

.gedit-search-slider {
  background-color: #fcfcfc;
  padding: 6px;
  border-color: rgba(0, 0, 0, 0.15);
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
}

.gedit-search-entry-occurrences-tag {
  color: rgba(43, 47, 59, 0.6);
  border: none;
  margin: 2px;
  padding: 2px;
}

.gedit-map-frame border {
  border-color: rgba(0, 0, 0, 0.3);
  border-width: 0;
}

.gedit-map-frame border:dir(ltr) {
  border-left-width: 1px;
}

.gedit-map-frame border:dir(rtl) {
  border-right-width: 1px;
}

.gedit-side-panel-paned.horizontal separator {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.24), rgba(0, 0, 0, 0.11) 2px, rgba(0, 0, 0, 0.05) 4px, rgba(0, 0, 0, 0.05));
  background-position: left top;
  background-repeat: no-repeat;
  background-size: 1px auto;
}

.gb-search-entry-occurrences-tag {
  background: none;
}

workbench.csd > stack.titlebar:not(headerbar) {
  padding: 0;
  background: none;
  border: none;
  box-shadow: none;
}

workbench.csd > stack.titlebar:not(headerbar) headerbar, workbench.csd > stack.titlebar:not(headerbar) headerbar:first-child, workbench.csd > stack.titlebar:not(headerbar) headerbar:last-child {
  border-radius: 2px 2px 0 0;
}

editortweak .linked > entry.search:focus + .gb-linked-scroller {
  border-top-color: #3498db;
}

layouttab {
  background-color: #ffffff;
}

layout {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

eggsearchbar box.search-bar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

pillbox {
  color: #ffffff;
  background-color: #3498db;
  border-radius: 3px;
}

pillbox:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

docktabstrip {
  padding: 0 6px;
  background-color: #f7f7f7;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

docktabstrip docktab {
  min-height: 28px;
  border: solid transparent;
  border-width: 0 1px;
}

docktabstrip docktab label {
  opacity: 0.5;
}

docktabstrip docktab:checked label, docktabstrip docktab:hover label {
  opacity: 1;
}

docktabstrip docktab:checked {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

dockbin {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

dockpaned {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

dockoverlayedge {
  background-color: #f7f7f7;
}

dockoverlayedge docktabstrip {
  padding: 0;
  border: none;
}

dockoverlayedge.left-edge tab:checked, dockoverlayedge.right-edge tab:checked {
  border-width: 1px 0;
}

popover.messagepopover.background {
  padding: 0;
}

popover.messagepopover .popover-content-area {
  margin: 16px;
}

popover.messagepopover .popover-action-area {
  margin: 8px;
}

popover.messagepopover .popover-action-area button:not(:first-child):not(:last-child) {
  margin: 0 4px;
}

popover.popover-selector {
  padding: 0;
}

popover.popover-selector list row {
  padding: 5px 0;
}

popover.popover-selector list row image {
  margin-left: 3px;
  margin-right: 10px;
}

button.dzlmenubuttonitem.check label {
  color: #2b2f3b;
}

button.dzlmenubuttonitem.check label.dim-label, button.dzlmenubuttonitem.check .slate-notification label.notification-body, .slate-notification button.dzlmenubuttonitem.check label.notification-body,
button.dzlmenubuttonitem.check .budgie-notification label.notification-body,
button.dzlmenubuttonitem.check .budgie-switcher label.notification-body,
.budgie-notification button.dzlmenubuttonitem.check label.notification-body,
.budgie-switcher button.dzlmenubuttonitem.check label.notification-body, button.dzlmenubuttonitem.check label.separator, button.dzlmenubuttonitem.check headerbar label.subtitle, headerbar button.dzlmenubuttonitem.check label.subtitle {
  color: #2b2f3b;
}

button.dzlmenubuttonitem.check box > image {
  opacity: 0.87;
}

entry.search.preferences-search {
  border: none;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
}

preferences stacksidebar.sidebar list {
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
}

preferences stacksidebar.sidebar list separator {
  background-color: transparent;
}

devhelppanel entry:focus,
symboltreepanel entry:focus {
  border-color: rgba(0, 0, 0, 0.15);
}

button.run-arrow-button {
  min-width: 12px;
}

omnibar.linked > entry:not(:only-child) {
  border-style: solid;
  border-radius: 3px;
  margin-left: 1px;
  margin-right: 1px;
}

gstyleslidein #scale_box button.toggle:checked,
gstyleslidein #strings_controls button.toggle:checked,
gstyleslidein #palette_controls button.toggle:checked,
gstyleslidein #components_controls button.toggle:checked {
  color: #2b2f3b;
}

configurationview entry.flat {
  background: none;
}

configurationview list {
  border-width: 0;
}

eog-thumb-nav scrolledwindow {
  border-top: none;
}

eog-thumb-nav button {
  border-radius: 2px;
}

.documents-scrolledwin.frame {
  border-width: 0;
}

button.documents-load-more {
  border-width: 1px 0 0;
  border-radius: 0;
}

.documents-icon-bg {
  background-color: #3498db;
  color: #ffffff;
  border-radius: 2px;
}

.documents-collection-icon, .photos-collection-icon {
  background-color: rgba(43, 47, 59, 0.3);
  border-radius: 2px;
}

button.documents-favorite:active,
button.documents-favorite:active:hover {
  color: #8bc4ea;
}

.documents-entry-tag, .photos-entry-tag {
  color: #ffffff;
  background: #3498db;
  border-radius: 2px;
  border-width: 0;
  margin: 2px;
  padding: 4px;
}

.documents-entry-tag:hover, .photos-entry-tag:hover {
  color: #ffffff;
  background: #45a1de;
}

.documents-entry-tag:active, .photos-entry-tag:active {
  color: #ffffff;
  background: #268fd5;
}

.documents-entry-tag.button, .button.photos-entry-tag {
  box-shadow: none;
  border: none;
  background-color: transparent;
}

.content-view.document-page {
  border-style: solid;
  border-width: 3px 3px 6px 4px;
  border-image: url("assets/thumbnail-frame.png") 3 3 6 4;
}

window.background.csd > headerbar.titlebar > box.horizontal > separator.sidebar,
window.background.csd > headerbar.titlebar > hdyleaflet > separator.sidebar,
window.background.csd > headerbar.titlebar > leaflet > separator.sidebar {
  border-right: none;
  background: none;
  min-width: 0;
}

box.horizontal > separator.sidebar,
hdyleaflet > separator.sidebar,
leaflet > separator.sidebar {
  background: none;
  min-width: 0;
}

window.background > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical > box.vertical > flowbox.horizontal > flowboxchild > overlay > button.osd.image-button.remove-button, window.background > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical > box.vertical > flowbox.horizontal > flowboxchild > overlay > button.osd.image-button.remove-button {
  padding-top: 0;
  padding-bottom: 0;
}

.photos-fade-in {
  opacity: 1.0;
  transition: opacity 0.2s ease-out;
}

.photos-fade-out {
  opacity: 0.0;
  transition: opacity 0.2s ease-out;
}

window.background.csd.unified {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

window.background.csd.unified > deck > deck > deck > box.vertical > headerbar.titlebar.windowhandle > viewswitchertitle > squeezer > viewswitcher > box.horizontal > button.radio {
  margin: 0;
  border-radius: 0;
}

window.background.org-gnome-Calendar event.color-light, window.background.org-gnome-Calendar event.color-light > stack > grid > label {
  color: rgba(0, 0, 0, 0.75);
}

window.background.org-gnome-Calendar event.color-dark, window.background.org-gnome-Calendar event.color-dark > stack > grid > label {
  color: white;
}

hdyviewswitcherbar > actionbar,
viewswitcherbar > actionbar {
  background: none;
  border: none;
}

.tweak-categories,
.tweak-category:not(:selected):not(:hover) {
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
}

.tweak-categories > separator {
  background: none;
}

row#Focus,
row#ClickMethod,
row#StaticWorkspaceTweak,
row#dynamic-workspaces,
row#PrimaryWorkspaceTweak,
row#workspaces-only-on-primary {
  padding: 0;
  margin: 0;
}

row#Focus.tweak > list,
row#ClickMethod.tweak > list,
row#StaticWorkspaceTweak.tweak > list,
row#dynamic-workspaces.tweak > list,
row#PrimaryWorkspaceTweak.tweak > list,
row#workspaces-only-on-primary.tweak > list {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

row#AutostartTitle.tweak {
  background-color: #ffffff;
}

list#AutostartListBoxTweakGroup.tweak-group-startup {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.main-window > stack > hdyleaflet > separator.sidebar {
  min-width: 1px;
  background-color: rgba(0, 0, 0, 0.15);
}

.tr-workarea undershoot,
.tr-workarea overshoot {
  border-color: transparent;
}

#gf-bubble, #gf-bubble.solid,
#gf-osd-window,
#gf-osd-window.solid,
#gf-input-source-popup,
#gf-input-source-popup.solid,
#gf-candidate-popup,
#gf-candidate-popup.solid {
  color: #3d4151;
  background-color: rgba(255, 255, 255, 0.95);
  border: 1px solid rgba(235, 235, 235, 0.95);
  border-radius: 2px;
}

#gf-bubble levelbar block.low, #gf-bubble levelbar block.high, #gf-bubble levelbar block.full,
#gf-osd-window levelbar block.low,
#gf-osd-window levelbar block.high,
#gf-osd-window levelbar block.full,
#gf-input-source-popup levelbar block.low,
#gf-input-source-popup levelbar block.high,
#gf-input-source-popup levelbar block.full,
#gf-candidate-popup levelbar block.low,
#gf-candidate-popup levelbar block.high,
#gf-candidate-popup levelbar block.full {
  background-color: #3498db;
  border-color: #3498db;
}

#gf-bubble levelbar block.empty,
#gf-osd-window levelbar block.empty,
#gf-input-source-popup levelbar block.empty,
#gf-candidate-popup levelbar block.empty {
  background-color: rgba(242, 242, 242, 0.95);
}

#gf-bubble levelbar trough,
#gf-osd-window levelbar trough,
#gf-input-source-popup levelbar trough,
#gf-candidate-popup levelbar trough {
  background: none;
}

#gf-input-source {
  min-height: 32px;
  min-width: 40px;
}

#gf-input-source:selected {
  color: #ffffff;
  background-color: #3498db;
  border-radius: 2px;
}

gf-candidate-box label {
  padding: 3px;
}

gf-candidate-box:hover, gf-candidate-box:selected {
  color: #ffffff;
  background-color: #3498db;
  border-radius: 2px;
}

stack grid.vertical scrolledwindow.frame,
stack grid.vertical scrolledwindow.frame.emptyGrid {
  border: none;
}

eog-thumb-nav scrolledwindow, eog-thumb-nav scrolledwindow.frame,
#eog-thumb-nav scrolledwindow,
#eog-thumb-nav scrolledwindow.frame {
  border-top: none;
}

eog-thumb-nav button,
#eog-thumb-nav button {
  border-radius: 2px;
  border-top: none;
}

window.background.csd overlay > grid.horizontal frame:dir(ltr) > border {
  border-top-width: 0;
  border-left-width: 0;
  border-bottom-width: 0;
}

window.background.csd > deck > box.vertical > leaflet > separator.sidebar {
  border-right: none;
}

window.background.csd list.content {
  border-radius: 2px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.selection-mode box.horizontal headerbar, .selection-mode hdyleaflet headerbar, .selection-mode leaflet.unfolded headerbar {
  color: #ffffff;
  background-color: rgba(52, 152, 219, 0.95);
  border-color: rgba(38, 143, 213, 0.95);
  box-shadow: none;
}

.selection-mode box.horizontal headerbar:backdrop, .selection-mode hdyleaflet headerbar:backdrop, .selection-mode leaflet.unfolded headerbar:backdrop {
  background-color: rgba(52, 152, 219, 0.95);
  color: rgba(255, 255, 255, 0.6);
}

frame.sidebar.chat-sidebar > border {
  border-right: none;
}

frame.sidebar.chat-sidebar frame.chat-status-area > border {
  border-style: none;
  border-top-style: solid;
}

widget#PROCESSOR list row, widget#MEMORY list row {
  margin: -1px;
  border: 1px solid #d1d1d1;
}

widget#PROCESSOR list row.max, widget#MEMORY list row.max {
  color: rgba(255, 255, 255, 0.95);
}

widget#PROCESSOR list separator.list, widget#MEMORY list separator.list {
  box-shadow: inset 0 0 0 1px #d1d1d1;
}

widget#STORAGE list {
  margin: -1px;
}

widget#STORAGE list row.activatable {
  color: rgba(43, 47, 59, 0.75);
}

widget#STORAGE list row.activatable:hover, widget#STORAGE list row.activatable:active {
  color: rgba(43, 47, 59, 0.75);
}

widget#STORAGE list separator.list {
  box-shadow: inset 0 0 0 1px #d1d1d1;
}

widget#PERFORMANCE searchbar {
  box-shadow: inset 0 -2px rgba(0, 0, 0, 0.15), inset 0 -1px #f7f7f7;
}

widget#PERFORMANCE searchbar entry, widget#PERFORMANCE searchbar button {
  margin-bottom: 2px;
}

graph-switcher-button.toggle {
  color: rgba(43, 47, 59, 0.75);
  font-weight: 500;
}

graph-switcher-button.toggle:hover {
  color: #2b2f3b;
  background-image: image(rgba(0, 0, 0, 0.05));
}

rg-graph.big {
  background-position: left top;
  background-origin: border-box;
  background-repeat: repeat;
}

box.speedometer-outter {
  opacity: 0.8;
}

box.speedometer-content-area {
  box-shadow: 0 0 0 4px rgba(52, 152, 219, 0.2);
}

headerbar > button.flat.popup.title-menu-button.toggle {
  border-radius: 2px;
}

headerbar > button.flat.popup.title-menu-button.toggle > grid .title {
  margin: -0.16875rem 0;
  padding: 0.08125rem 0.83125rem 0;
  font-size: 90%;
}

headerbar > button.flat.popup.title-menu-button.toggle > grid .subtitle {
  margin: -0.16875rem 0;
  padding: 0 0.83125rem 0.08125rem;
  font-size: 80%;
}

window.background > box.vertical box.horizontal list.categories {
  background-color: #f7f7f7;
  border: none;
  color: #2b2f3b;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category {
  color: #2b2f3b;
  background-color: transparent;
  font-weight: 500;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:hover {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.08);
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:selected {
  color: #ffffff;
  background-color: #3498db;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:selected label {
  color: #ffffff;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category > label {
  padding-left: 0;
  padding-right: 0;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list > separator {
  background-color: transparent;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list > separator.compressed-rows-group-separator {
  background-image: image(rgba(0, 0, 0, 0.15));
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable {
  color: #2b2f3b;
  transition-duration: 0.1s;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable:hover, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable:active {
  color: #2b2f3b;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable label.compressed-entries-label {
  background-image: image(#3498db);
  color: #ffffff;
  font-weight: 700;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row {
  background-image: image(#efefef);
  color: black;
  transition-property: opacity, border-image, background-image, box-shadow;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:hover {
  background-image: image(#ededee);
  color: #2b2f3b;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:active, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:active:focus {
  background-image: image(#e3e3e4);
  color: #2b2f3b;
  animation: none;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row.popover-activated-row {
  background-image: image(#3498db);
  color: #ffffff;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header {
  background-image: image(#ffffff);
  color: #3498db;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:hover {
  background-image: image(#f5fafd);
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:active, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:active:focus {
  background-image: image(#ebf5fb);
  color: #3498db;
  animation: none;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header label.compressed-entries-label {
  background-image: image(#3498db);
  color: #ffffff;
  transition-duration: 0s;
}

button.round-button {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
}

window.background > box.vertical > searchbar {
  box-shadow: none;
}

window.background > box.vertical > overlay > stack > widget > stack > box.vertical > scrolledwindow > viewport.frame > widget > list {
  background-color: #f7f7f7;
}

window.background > box.vertical > overlay > stack > widget > stack > box.vertical > scrolledwindow > viewport.frame > widget > list > separator {
  border-left: 100px solid transparent;
  border-right: 100px solid transparent;
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list {
  background-image: image(#f7f7f7);
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list > box.vertical > list {
  background-color: #f7f7f7;
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list separator {
  border-left: 100px solid transparent;
  border-right: 100px solid transparent;
}

.category_page_header_filter_box {
  background-image: image(#f7f7f7);
  border-image: linear-gradient(to bottom, #d1d1d1, #d1d1d1) 0 0 1 0/0 0 1px 0 stretch;
}

.category_page_header_filter_box button {
  color: rgba(43, 47, 59, 0.55);
  background-image: image(#f7f7f7);
}

.category_page_header_filter_box button:hover {
  color: rgba(43, 47, 59, 0.75);
}

.category_page_header_filter_box button:checked {
  color: #2b2f3b;
}

.category_page_header_filter_box button:disabled {
  color: rgba(43, 47, 59, 0.65);
}

.application-details-infobar {
  background-image: image(#ffffff);
  border-image: linear-gradient(to bottom, #d1d1d1, #d1d1d1) 1 1 1 1/1px 1px 1px 1px stretch;
}

headerbar.titlebar.incognito-mode entry {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

headerbar.titlebar.incognito-mode entry image, headerbar.titlebar.incognito-mode entry image:hover {
  color: inherit;
}

headerbar.titlebar.incognito-mode entry:focus {
  color: #565e76;
  border-color: #3498db;
  background-color: #ffffff;
}

headerbar.titlebar.incognito-mode entry:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

notebook > box > stack > box.vertical > paned.vertical > overlay > .floating-bar {
  color: rgba(43, 47, 59, 0.75);
}

.background headerbar entry.starred, .background headerbar entry.non-starred {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

.background headerbar entry.starred image, .background headerbar entry.starred image:hover, .background headerbar entry.non-starred image, .background headerbar entry.non-starred image:hover {
  color: inherit;
}

.background headerbar entry.starred:focus, .background headerbar entry.non-starred:focus {
  color: #565e76;
  border-color: #3498db;
  background-color: #ffffff;
}

.background headerbar entry.starred:disabled, .background headerbar entry.non-starred:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

.background headerbar entry.starred > image.right {
  color: #ccbb00;
}

.background headerbar entry.starred > image.right:hover, .background headerbar entry.starred > image.right:active, .background headerbar entry.starred > image.right:checked {
  color: #FFEA00;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background {
  background-color: transparent;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background > row.activatable {
  background-color: #f7f7f7;
  color: rgba(43, 47, 59, 0.85);
  border-radius: 2px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  margin: 2px;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background > row.activatable:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical {
  margin: 0;
  padding: 0;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row {
  background-color: rgba(255, 255, 255, 0.35);
  color: rgba(43, 47, 59, 0.85);
  border-bottom: 1px dashed rgba(0, 0, 0, 0.05);
  padding: 6px 0;
  margin: 0;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:hover, popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:active, popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:checked {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.05);
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row button.flat {
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  margin: 0 6px;
  border-radius: 100px;
}

flowboxchild.bookmark-tag-widget {
  color: #f7f7f7;
  font-weight: 500;
}

flowboxchild.bookmark-tag-widget label {
  margin-bottom: 2px;
}

flowboxchild.bookmark-tag-widget-selected {
  color: #ffffff;
}

tabbox {
  background-color: #f7f7f7;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

tabbox > tab {
  padding: 3px 16px 6px 16px;
  min-width: 16px;
  min-height: 16px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  color: rgba(43, 47, 59, 0.55);
}

tabbox > tab:not(:only-child):first-child {
  margin-left: 6px;
}

tabbox > tab:not(:only-child):last-child {
  margin-right: 6px;
}

tabbox > tab:hover {
  color: rgba(43, 47, 59, 0.775);
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  box-shadow: inset 0 -2px alpha(#3498db,0.6), 0 1px alpha(#3498db,0.6);
}

tabbox > tab:checked {
  color: #2b2f3b;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  box-shadow: inset 0 -2px #3498db, 0 1px #3498db;
}

tabbox > tab button {
  border-radius: 100%;
  min-height: 16px;
  min-width: 16px;
  border-radius: 3px;
  border: none;
  padding: 0;
  color: #72757d;
}

tabbox > tab button:hover {
  color: #ff4d4d;
  background-color: #eaeaea;
}

tabbox > tab button:active, tabbox > tab button:active:hover {
  color: #3498db;
  background-color: #e3e3e3;
}

.geary-main-window .geary-folder-frame treeview.view.sidebar {
  background-color: #f7f7f7;
  color: #2e313d;
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:hover {
  background-color: rgba(0, 0, 0, 0.05);
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:active {
  color: #2b2f3b;
  background-color: rgba(0, 0, 0, 0.1);
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:disabled {
  color: rgba(43, 47, 59, 0.55);
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:disabled image {
  color: inherit;
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:selected {
  color: #ffffff;
  background-color: #3498db;
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:selected:active {
  background-color: #2f89c5;
}

.geary-main-window .geary-folder-frame treeview.view.sidebar:selected:hover {
  background-color: #48a2df;
}

.geary-main-window headerbar.titlebar > leaflet > leaflet > separator.sidebar {
  border-right: none;
  background: none;
  min-width: 0;
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > separator.sidebar,
.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > separator.sidebar {
  min-width: 1px;
  background-color: #f2f2f2;
  border-right: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15), inset 0 1px rgba(255, 255, 255, 0.13);
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > box.vertical + separator.sidebar {
  background-color: rgba(0, 0, 0, 0.15);
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > box.vertical > .geary-conversation-frame > scrolledwindow {
  margin: -1px 0;
}

.geary-main-window > deck > overlay > .geary-main-layout .conversation-listbox {
  border: none;
}

.geary-main-window > deck > overlay > .geary-main-layout statusbar {
  padding: 0 6px;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content > row.activatable {
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-bottom-width: 0;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content > row.activatable:first-child {
  border-top-left-radius: 8px;
  border-top-right-radius: 8px;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.15);
  padding: 4px;
  background-color: #efefef;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button > widget > box > image {
  padding: 0;
}

.sidebar-paned scrolledwindow {
  border: none;
}

.sidebar-paned treeview.view.sidebar {
  background-color: #f7f7f7;
  color: #2e313d;
}

.sidebar-paned treeview.view.sidebar:hover {
  background-color: rgba(43, 47, 59, 0.06);
  color: #2b2f3b;
}

.sidebar-paned treeview.view.sidebar:active, .sidebar-paned treeview.view.sidebar:selected {
  background-color: #3498db;
  color: #ffffff;
}

.sidebar-paned separator {
  background-image: image(#d1d1d1);
}

window.csd > box.vertical > box.vertical > toolbar.horizontal, window.csd > box.vertical > box.vertical > .horizontal.inline-toolbar,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal,
window.solid-csd > box.vertical > box.vertical > .horizontal.inline-toolbar {
  margin: -1px 0;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: none;
  background-color: transparent;
}

window.csd > box.vertical > box.vertical > toolbar.horizontal button, window.csd > box.vertical > box.vertical > .horizontal.inline-toolbar button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal button,
window.solid-csd > box.vertical > box.vertical > .horizontal.inline-toolbar button {
  min-height: 36px;
  min-width: 36px;
  padding: 0;
  margin-top: 8px;
  margin-bottom: 8px;
}

window.csd > box.vertical > box.vertical > frame,
window.solid-csd > box.vertical > box.vertical > frame {
  margin: -1px 0;
  padding: 0;
}

window.csd > box.vertical > box.vertical > frame > border,
window.solid-csd > box.vertical > box.vertical > frame > border {
  border: none;
}

window.background > box.vertical > toolbar.primary-toolbar toolitem .linked > button.image-button.raised, window.background > box.vertical > .primary-toolbar.inline-toolbar toolitem .linked > button.image-button.raised {
  min-height: 36px;
  min-width: 36px;
  padding: 0;
  margin: 0;
}

window.background > box.vertical > toolbar.primary-toolbar toolitem .linked > button.image-button.raised > widget > box > image, window.background > box.vertical > .primary-toolbar.inline-toolbar toolitem .linked > button.image-button.raised > widget > box > image {
  padding: 0;
}

window.background > box.vertical > toolbar.primary-toolbar toolitem button.flat.scale, window.background > box.vertical > .primary-toolbar.inline-toolbar toolitem button.flat.scale {
  min-height: 24px;
  min-width: 36px;
  padding: 0;
  margin-top: 8px;
  margin-bottom: 8px;
}

window.background > box.vertical > toolbar.primary-toolbar toolitem > box.horizontal:not(.linked) > button.toggle, window.background > box.vertical > .primary-toolbar.inline-toolbar toolitem > box.horizontal:not(.linked) > button.toggle,
window.background > box.vertical > toolbar.primary-toolbar toolitem > .linked > button:not(.toggle):not(.raised):not(.flat),
window.background > box.vertical > .primary-toolbar.inline-toolbar toolitem > .linked > button:not(.toggle):not(.raised):not(.flat) {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
  margin: 0;
}

dialog.background.csd box.dialog-vbox grid.horizontal scrolledwindow.frame {
  border: none;
}

dialog.background.csd box.dialog-vbox grid.horizontal scrolledwindow.frame viewport.frame {
  border: none;
}

dialog.background.csd box.dialog-vbox grid.horizontal stack scrolledwindow.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.maps-popover button.radio.layer-radio-button:checked {
  box-shadow: 0 0 0 2px #3498db;
}

.nautilus-window .floating-bar {
  padding: 1px;
  background-color: #ffffff;
  color: #2b2f3b;
  border-radius: 2px 2px 0 0;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.nautilus-window .floating-bar.bottom.left {
  border-top-left-radius: 0;
  border-width: 1px 1px 0 0;
}

.nautilus-window .floating-bar.bottom.right {
  border-top-right-radius: 0;
  border-width: 1px 0 0 1px;
}

.nautilus-window .floating-bar button {
  border: none;
  border-radius: 100px;
  min-height: 0;
  min-width: 0;
  padding: 0;
  margin-right: 6px;
  -gtk-icon-shadow: none;
}

.nemo-window menubar > menuitem > window.background.popup > menu,
.nemo-window .menubar > menuitem > window.background.popup > menu {
  border-radius: 0 0 2px 2px;
}

.nemo-window paned.horizontal > separator {
  background-image: image(#d1d1d1);
}

.nemo-window .nemo-places-sidebar.frame {
  border-width: 0;
}

.nemo-window .nemo-places-sidebar .places-treeview {
  -NemoPlacesTreeView-disk-full-bg-color: #d8d9db;
  -NemoPlacesTreeView-disk-full-fg-color: #e99a9a;
  -NemoPlacesTreeView-disk-full-bar-width: 2px;
  -NemoPlacesTreeView-disk-full-bar-radius: 0;
  -NemoPlacesTreeView-disk-full-bottom-padding: 1px;
  -NemoPlacesTreeView-disk-full-max-length: 80px;
  background-color: #f7f7f7;
  padding-top: 3px;
  padding-bottom: 3px;
}

.nemo-window .nemo-places-sidebar .places-treeview:selected .sidebar-icon, .nemo-window .nemo-places-sidebar .places-treeview:selected:hover .sidebar-icon {
  color: inherit;
}

.nemo-window .NemoSidebar {
  background-color: #f7f7f7;
}

.nemo-window .NemoSidebar:selected, .nemo-window .NemoSidebar:selected:hover, .nemo-window .NemoSidebar:selected:focus {
  background-color: rgba(43, 47, 59, 0.15);
  color: #2b2f3b;
}

.nemo-window .NemoSidebar.expander:hover {
  color: #40444f;
}

.nemo-window .NemoSidebar.expander:selected, .nemo-window .NemoSidebar.expander:selected:hover {
  color: #555962;
}

.nemo-window notebook {
  background-color: #ffffff;
}

.nemo-window .nemo-window-pane widget.entry {
  border: 1px solid;
  border-radius: 3px;
  color: #2e313d;
  border-color: #3498db;
  background-color: #ffffff;
  outline: none;
}

.nemo-window .primary-toolbar {
  padding-top: 0;
  padding-bottom: 0;
  border: none;
  color: #2b2f3b;
  background-color: #f2f2f2;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error + entry,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.error,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning + entry,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.warning,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error + entry.warning,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning + entry.error {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry:focus:not(:last-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry:focus:last-child {
  border-left-color: #3498db;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button:hover,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry:drop(active):not(:last-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:not(:hover):not(:active):not(:checked),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button:hover,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.warning:focus:not(:last-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button:hover,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.error:focus:not(:last-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:not(:hover):not(:active):not(:checked),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:not(:hover):not(:active):not(:checked) {
  border-left-color: transparent;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button:hover,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo:hover {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:active + entry,
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:checked + entry {
  border-left-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button + button {
  border-left-style: solid;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: none;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: none;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) > button {
  margin-left: 1px;
  margin-right: 1px;
}

.nemo-window .primary-toolbar button {
  min-height: 20px;
  margin-top: 6px;
  margin-bottom: 6px;
}

.nemo-window .primary-toolbar entry {
  min-height: 22px;
  margin-top: 4px;
  margin-bottom: 4px;
}

.nemo-window .primary-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button {
  padding: 2px 4px 4px 4px;
  margin-top: 6px;
  margin-bottom: 6px;
}

.nemo-window .sidebar scrolledwindow.frame {
  border: none;
}

.nemo-window .floating-bar {
  padding: 2px;
  background-color: #3498db;
  color: #ffffff;
  border-radius: 0;
}

.nemo-window .floating-bar.bottom.left {
  border-top-right-radius: 2px;
}

.nemo-window .floating-bar.bottom.right {
  border-top-left-radius: 2px;
}

.nemo-window .floating-bar button {
  border: none;
  border-radius: 3px;
  min-height: 16px;
  min-width: 16px;
  -gtk-icon-shadow: none;
}

window.background:not(.csd) > widget > separator {
  color: rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > scrollbar {
  background-clip: border-box;
}

window.background:not(.csd) > widget > scrollbar,
window.background:not(.csd) > widget > frame > border {
  border-color: #d1d1d1;
}

window.background:not(.csd) > widget > entry,
window.background:not(.csd) > widget > button > button {
  border: 1px solid #d1d1d1;
  border-radius: 2px;
}

window.background:not(.csd) > widget > entry,
window.background:not(.csd) > widget .entry {
  border-radius: 2px;
  background-image: image(#ffffff);
  border: 1px solid #d1d1d1;
}

window.background:not(.csd) > widget > entry:focus,
window.background:not(.csd) > widget .entry:focus {
  border-color: #3498db;
}

window.background:not(.csd) > widget > spinbutton {
  background-image: image(#fcfcfc);
  border: 1px solid #d1d1d1;
}

window.background:not(.csd) > widget > spinbutton:active {
  background-image: image(#3498db);
}

window.background:not(.csd) > widget > spinbutton .entry {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

window.background:not(.csd) > menu > separator {
  color: rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > menu > menuitem > label:disabled {
  color: rgba(43, 47, 59, 0.55);
}

#MozillaGtkWidget {
  background-color: #f7f7f7;
}

#MozillaGtkWidget .background,
#MozillaGtkWidget frame,
#MozillaGtkWidget separator,
#MozillaGtkWidget scrolledwindow {
  background-color: #f7f7f7;
}

#MozillaGtkWidget > window.background > menu {
  background-color: #ffffff;
}

#MozillaGtkWidget > window.background > menu > separator {
  padding: 0;
  border: none;
  background-color: #d1d1d1;
}

#MozillaGtkWidget > widget border {
  border-color: #d1d1d1;
}

#MozillaGtkWidget > widget separator {
  background-color: #d1d1d1;
}

#MozillaGtkWidget > widget > scrolledwindow > textview {
  background-color: #ffffff;
}

#MozillaGtkWidget > widget > scrolledwindow > textview text {
  background-color: transparent;
  color: #242424;
}

window.background.chromium {
  background-color: #f7f7f7;
  color: #2b2f3b;
}

window.background.chromium headerbar.titlebar button.toggle {
  color: #2b2f3b;
  outline-offset: -3px;
  background-color: transparent;
  border-color: transparent;
}

window.background.chromium headerbar.titlebar button.toggle:hover {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.12);
}

window.background.chromium headerbar.titlebar button.toggle:checked, window.background.chromium headerbar.titlebar button.toggle:active {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

window.background.chromium headerbar.titlebar button.titlebutton {
  min-width: 16px;
  min-height: 16px;
  margin: 0 4px;
  padding: 0;
  color: transparent;
  background-color: transparent;
  border: none;
}

window.background.chromium button {
  border-width: 1px;
  border-style: solid;
  border-color: #d1d1d1;
  background-color: #f7f7f7;
  color: #2b2f3b;
}

window.background.chromium entry.chromium {
  border-image: none;
  border: 1px solid #d1d1d1;
  background-color: #f7f7f7;
  color: #2b2f3b;
}

window.background.chromium > textview.view {
  background-color: #f7f7f7;
  color: #2b2f3b;
}

window.background.chromium > textview {
  color: #2b2f3b;
  background-color: #f7f7f7;
}

window.background.chromium > textview text {
  color: #2b2f3b;
  background-color: #f7f7f7;
}

window.background.chromium > menubar {
  background-color: #f2f2f2;
  color: #2b2f3b;
}

window.background.chromium > menubar > menuitem {
  color: #2b2f3b;
}

window.background.chromium > menu {
  border: 1px solid #d1d1d1;
  background-color: #ffffff;
  color: #2b2f3b;
}

window.background.chromium > menu > separator {
  color: #ffffff;
  background-color: #ffffff;
}

window.background.chromium > menu > menuitem {
  color: #2b2f3b;
}

window.background.chromium > menu > menuitem:hover {
  color: #ffffff;
  background-color: #3498db;
}

window.background.chromium > menu > menuitem:disabled, window.background.chromium > menu > menuitem accelerator, window.background.chromium > menu > menuitem label:disabled {
  color: rgba(43, 47, 59, 0.45);
}

tooltip.background.chromium {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

overlay.window-overlay grid.horizontal stack paned.horizontal stack widget.view.frame,
overlay.window-overlay grid.horizontal stack paned.horizontal stack scrolledwindow.frame {
  border-left: none;
  border-right: none;
}

overlay.window-overlay grid.horizontal stack .sidebar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

/****************
 * Libre-Office *
 ****************/
window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal {
  background-color: #f2f2f2;
}

window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal > button.flat.small-button {
  color: #2b2f3b;
  border: none;
}

window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal > button.flat.small-button:hover {
  background-color: white;
  color: #363b4a;
}

window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal > button.flat.small-button:active, window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal > button.flat.small-button:checked {
  background-color: #3498db;
  color: #4b5267;
}

window.background:not(.csd):not(.solid-csd) > grid.horizontal > grid.horizontal > button.flat.small-button:disabled {
  color: alpha(#2b2f3b,0.6);
}

window.background:not(.solid-csd) > notebook:not(.frame) {
  border: 0 none transparent;
  background-color: #ffffff;
}

window.background:not(.solid-csd) > notebook:not(.frame) > stack {
  border: none;
  box-shadow: none;
}

widget > box.terminal-titlebar {
  padding: 0 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle {
  border: none;
  border-radius: 0;
  padding-top: 0;
  padding-bottom: 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 0%, transparent 0%) 0 0 0/0 0 0;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:dir(ltr) {
  padding-right: 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:dir(rtl) {
  padding-left: 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:hover {
  box-shadow: inset 0 -2px #3498db;
  background: none;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:checked, widget > box.terminal-titlebar > button.flat.popup.toggle:active {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 100%, transparent 0%) 0 0 2/0 0 2px;
  background-color: transparent;
  color: #2b2f3b;
}

widget > box.terminal-titlebar > button.image-button, widget > box.terminal-titlebar > button.image-button.toggle {
  margin: 2px 0;
  padding: 0;
  min-height: 24px;
  min-width: 24px;
  border-radius: 100px;
}

list.tilix-session-sidebar {
  background-image: image(rgba(248, 248, 248, 0.95));
}

list.tilix-session-sidebar button.tilix-sidebar-close-button {
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  border-radius: 100px;
  background-color: #db5b5b;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button, list.tilix-session-sidebar button.tilix-sidebar-close-button:hover, list.tilix-session-sidebar button.tilix-sidebar-close-button:active, list.tilix-session-sidebar button.tilix-sidebar-close-button:checked {
  color: white;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button:hover {
  background-color: #e48585;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button:active, list.tilix-session-sidebar button.tilix-sidebar-close-button:checked {
  background-image: image(#d23131);
}

window.background.csd > box.vertical > stack > box.horizontal > list {
  background-color: transparent;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

window.background.csd > box.vertical > stack > box.horizontal > box.vertical > stack > scrolledwindow.frame {
  border: none;
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > list {
  background-color: transparent;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list {
  background-color: transparent;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list {
  background-color: transparent;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

window#ValaPanel.background {
  background-color: #f7f7f7;
  border: none;
  color: #2b2f3b;
}

window#ValaPanel.background widget.-vala-panel-background > separator {
  background: none;
}

window#ValaPanel.background .unpinned button.flat.-panel-icon-button {
  border-radius: 0;
}

window#ValaPanel.background .unpinned button.flat.-panel-icon-button:hover, window#ValaPanel.background .unpinned button.flat.-panel-icon-button:active, window#ValaPanel.background .unpinned button.flat.-panel-icon-button:checked {
  box-shadow: inset 0 -2px #3498db;
  color: #ffffff;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running {
  border-radius: 0;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running > image {
  background-position: bottom center;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:hover, window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:active, window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:checked {
  box-shadow: inset 0 -2px #3498db;
  color: #ffffff;
}

.mate-panel-menu-bar menubar,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button,
menubar.-vala-panel-background,
menubar.-vala-panel-appmenu-private {
  background: none;
  border: none;
  box-shadow: none;
  padding: 0 0 0 0;
}

.mate-panel-menu-bar menubar > menuitem,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem,
menubar.-vala-panel-background > menuitem,
menubar.-vala-panel-appmenu-private > menuitem {
  border-radius: 0;
  color: #2b2f3b;
  font-weight: normal;
}

.mate-panel-menu-bar menubar > menuitem:hover,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem:hover,
menubar.-vala-panel-background > menuitem:hover,
menubar.-vala-panel-appmenu-private > menuitem:hover {
  color: #ffffff;
}

.mate-panel-menu-bar menubar > menuitem:disabled,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem:disabled,
menubar.-vala-panel-background > menuitem:disabled,
menubar.-vala-panel-appmenu-private > menuitem:disabled {
  color: rgba(43, 47, 59, 0.45);
}

.mate-panel-menu-bar menubar > menuitem > window.background.popup > menu,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem > window.background.popup > menu,
menubar.-vala-panel-background > menuitem > window.background.popup > menu,
menubar.-vala-panel-appmenu-private > menuitem > window.background.popup > menu {
  border-radius: 0 0 2px 2px;
}

/****************
 * Mate Desktop *
 ****************/
.atril-window .primary-toolbar toolbar, .atril-window .primary-toolbar .inline-toolbar {
  background: none;
}

MsdOsdWindow.background.osd {
  border-radius: 2px;
  border: 1px solid rgba(235, 235, 235, 0.95);
}

MsdOsdWindow.background.osd .progressbar {
  background-color: #3498db;
  border: none;
  border-radius: 5px;
}

MsdOsdWindow.background.osd .trough {
  background-color: rgba(242, 242, 242, 0.95);
  border: none;
  border-radius: 5px;
}

.mate-panel-menu-bar, .mate-panel-menu-bar menubar,
panel-toplevel.background,
panel-toplevel.background menubar {
  background-color: #f7f7f7;
}

.mate-panel-menu-bar button label, .mate-panel-menu-bar button image,
.mate-panel-menu-bar button#tasklist-button label,
.mate-panel-menu-bar button#tasklist-button image,
panel-toplevel.background button label,
panel-toplevel.background button image,
panel-toplevel.background button#tasklist-button label,
panel-toplevel.background button#tasklist-button image {
  color: inherit;
}

.mate-panel-menu-bar .wnck-pager,
panel-toplevel.background .wnck-pager {
  color: #16181e;
  background-color: #dedede;
}

.mate-panel-menu-bar .wnck-pager:hover,
panel-toplevel.background .wnck-pager:hover {
  background-color: white;
}

.mate-panel-menu-bar .wnck-pager:selected,
panel-toplevel.background .wnck-pager:selected {
  color: #8bc4ea;
  background-color: #3498db;
}

PanelToplevel.background {
  color: #2b2f3b;
  background-color: #f7f7f7;
}

#PanelWidget,
#PanelPlug,
#PanelApplet {
  color: #2b2f3b;
  background-color: #f7f7f7;
}

PanelSeparator {
  border-width: 0;
  background: none;
  background-image: none;
  color: white;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus {
  background-image: linear-gradient(to right, transparent 2px, rgba(255, 255, 255, 0.1) 2px, rgba(255, 255, 255, 0.1) 3px, transparent 3px, transparent 4px, rgba(255, 255, 255, 0.1) 4px, rgba(255, 255, 255, 0.1) 5px, transparent 5px, transparent 7px);
  background-repeat: no-repeat;
  background-size: 7px 14px;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus:dir(ltr) {
  background-position: left center;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus:dir(rtl) {
  background-position: right center;
}

PanelToplevel.vertical MatePanelAppletFrameDBus {
  background-image: linear-gradient(to bottom, transparent 2px, rgba(255, 255, 255, 0.1) 2px, rgba(255, 255, 255, 0.1) 3px, transparent 3px, transparent 4px, rgba(255, 255, 255, 0.1) 4px, rgba(255, 255, 255, 0.1) 5px, transparent 5px, transparent 7px);
  background-repeat: no-repeat;
  background-size: 14px 7px;
  background-position: center top;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button {
  min-height: 4px;
  min-width: 4px;
  padding: 0;
  border-radius: 0;
  border-style: solid;
  border-color: rgba(255, 255, 255, 0.1);
  background-color: transparent;
  color: #2b2f3b;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:active {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:disabled {
  color: rgba(43, 47, 59, 0.45);
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:checked {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button > image {
  padding: 0 4px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:first-child:dir(ltr) {
  border-width: 0 1px 0 0;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:first-child:dir(rtl) {
  border-width: 0 0 0 1px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:not(:first-child):dir(ltr) {
  border-width: 0 0 0 1px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:not(:first-child):dir(rtl) {
  border-width: 0 1px 0 0;
}

.mate-panel-menu-bar #clock-applet-button label {
  padding: 0 6px;
}

.mate-panel-menu-bar.vertical menubar > menuitem,
.mate-panel-menu-bar.vertical #PanelApplet-window-menu-applet-button > menuitem {
  padding: 4px 0;
}

.mate-panel-menu-bar.vertical menubar > menuitem:hover,
.mate-panel-menu-bar.vertical #PanelApplet-window-menu-applet-button > menuitem:hover {
  box-shadow: inset 2px 0 #3498db;
}

.mate-panel-menu-bar.vertical #tasklist-button:hover,
.mate-panel-menu-bar.vertical #clock-applet-button:hover,
.mate-panel-menu-bar.vertical #showdesktop-button:hover {
  box-shadow: inset 2px 0 rgba(52, 152, 219, 0.5);
}

.mate-panel-menu-bar.vertical #tasklist-button:checked, .mate-panel-menu-bar.vertical #tasklist-button:hover:checked,
.mate-panel-menu-bar.vertical #clock-applet-button:checked,
.mate-panel-menu-bar.vertical #clock-applet-button:hover:checked,
.mate-panel-menu-bar.vertical #showdesktop-button:checked,
.mate-panel-menu-bar.vertical #showdesktop-button:hover:checked {
  box-shadow: inset 2px 0 #3498db;
}

.mate-panel-menu-bar.vertical #clock-applet-button label {
  padding: 6px 0;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button {
  padding: 0 4px;
  border-radius: 0;
  background-image: none;
  background-color: transparent;
  color: #2b2f3b;
  font-weight: 700;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:hover {
  background-image: none;
  color: #ffffff;
  box-shadow: inset 0 -2px rgba(255, 255, 255, 0.1);
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:active {
  animation: none;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:checked {
  background-image: none;
  color: #ffffff;
  box-shadow: inset 0 -2px #3498db;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical {
  padding: 0;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical:hover {
  box-shadow: inset 2px 0 rgba(255, 255, 255, 0.1);
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical:checked {
  box-shadow: inset 2px 0 #3498db;
}

.brisk-menu entry {
  margin: 0.25rem;
}

.brisk-menu box.horizontal scrolledwindow:dir(ltr) {
  margin: 0.25rem 0.25rem 0.25rem 0;
}

.brisk-menu box.horizontal scrolledwindow:dir(rtl) {
  margin: 0.25rem 0 0.25rem 0.25rem;
}

.brisk-menu .categories-list:dir(ltr) {
  margin: 0.25rem 0 0.25rem 0.25rem;
}

.brisk-menu .categories-list:dir(rtl) {
  margin: 0.25rem 0.25rem 0.25rem 0;
}

.brisk-menu .categories-list button.flat {
  padding-top: unset;
  padding-bottom: unset;
  border-radius: 2px;
  font-weight: 500;
  transition-duration: 0.1s;
}

.brisk-menu .categories-list button.flat:checked {
  background-color: #3498db;
  color: #ffffff;
}

.brisk-menu .categories-list button.flat image {
  padding: 0.5rem 0;
}

.brisk-menu .categories-list button.flat label {
  padding-bottom: 0.04375rem;
}

.brisk-menu box.vertical > box.horizontal > box.vertical > separator.horizontal {
  min-height: 0;
  background-color: transparent;
}

.brisk-menu list.content-view.view {
  background-color: #ffffff;
}

.brisk-menu list.content-view.view row.activatable {
  padding: 0;
  background-image: none;
  transition-duration: 0s;
}

.brisk-menu list.content-view.view row.activatable > button.flat {
  padding-top: unset;
  padding-bottom: unset;
  border-radius: 0;
  font-weight: 400;
  transition-duration: 0s;
  border: none;
}

.brisk-menu list.content-view.view row.activatable > button.flat:hover {
  background-color: rgba(43, 47, 59, 0.06);
}

.brisk-menu list.content-view.view row.activatable > button.flat:active {
  background-color: rgba(43, 47, 59, 0.1);
  color: #2b2f3b;
}

.brisk-menu list.content-view.view row.activatable > button.flat > box.horizontal > image {
  padding: 0.33125rem 0;
}

.mate-panel-applet-slider {
  background-color: transparent;
}

.mate-panel-applet-slider > frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  background-color: #f7f7f7;
}

.mate-panel-applet-slider > frame > border {
  border: unset;
}

.caja-notebook {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.caja-side-pane .frame {
  border-width: 1px 0 0;
}

.caja-notebook .frame {
  border-width: 0 0 1px;
}

.caja-desktop > widget.entry, .caja-desktop > widget.entry:focus {
  transition: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar {
  background-color: #f2f2f2;
  color: #2b2f3b;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame {
  border: none;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame:dir(ltr) {
  border-left: 1px solid #d1d1d1;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame:dir(rtl) {
  border-right: 1px solid #d1d1d1;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame > widget.view {
  all: unset;
  background-color: #f7f7f7;
}

.background:not(.csd) > box.horizontal > notebook.frame {
  border: none;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack {
  border-width: 1px;
  border-style: solid;
  border-color: #f7f7f7;
  box-shadow: none;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack:dir(ltr) {
  border-left-color: #d1d1d1;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack:dir(rtl) {
  border-right-color: #d1d1d1;
}

.eom-window statusbar {
  margin: 0 -10px;
  padding: 0 0.41875rem;
  background-color: rgba(255, 255, 255, 0.95);
  color: #2e313d;
}

.pluma-window statusbar frame > border {
  border: none;
}

.pluma-window notebook > stack scrolledwindow {
  border-width: 0 0 1px 0;
}

#pluma-status-combo-button {
  min-height: 0;
  padding: 0;
  border-top: none;
  border-bottom: none;
  border-radius: 0;
}

.atril-window scrolledwindow.frame,
.xreader-window scrolledwindow.frame {
  border-style: solid none none;
}

.atril-window scrolledwindow.frame > .view,
.xreader-window scrolledwindow.frame > .view {
  transition: none;
}

.atril-window toolbar > toolbutton button.flat.image-button, .atril-window .inline-toolbar > toolbutton button.flat.image-button,
.xreader-window toolbar > toolbutton button.flat.image-button,
.xreader-window .inline-toolbar > toolbutton button.flat.image-button {
  border-radius: 2px;
}

.atril-window.fullscreen.background > box.vertical,
.xreader-window.fullscreen.background > box.vertical {
  background-color: black;
  transition-duration: 0s;
}

.atril-window.fullscreen.background > box.vertical > toolbar:not(.primary-toolbar).horizontal, .atril-window.fullscreen.background > box.vertical > .inline-toolbar:not(.primary-toolbar).horizontal,
.xreader-window.fullscreen.background > box.vertical > toolbar:not(.primary-toolbar).horizontal,
.xreader-window.fullscreen.background > box.vertical > .inline-toolbar:not(.primary-toolbar).horizontal {
  border-bottom-color: #d1d1d1;
}

.atril-window.fullscreen.background > box.vertical > paned.horizontal,
.xreader-window.fullscreen.background > box.vertical > paned.horizontal {
  background-color: #f7f7f7;
}

.background.osd {
  border-radius: 3px;
}

.background.osd image:selected {
  background-color: #3498db;
}

.slate-notification {
  border-radius: 2px;
}

.slate-notification-window .drop-shadow {
  margin: 4px 6px 10px;
  border-radius: 2px;
}

/******************
 * Budgie Desktop *
 ******************/
.drop-shadow button, .raven .raven-header:not(.top) button.image-button, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button) {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.drop-shadow button:hover, .raven .raven-header:not(.top) button.image-button:hover, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:hover, .budgie-popover:not(.budgie-menu) button.flat:hover:not(.image-button) {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 350ms;
}

.drop-shadow button:checked, .raven .raven-header:not(.top) button.image-button:checked, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:checked, .budgie-popover:not(.budgie-menu) button.flat:checked:not(.image-button), .drop-shadow button:active, .raven .raven-header:not(.top) button.image-button:active, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:active, .budgie-popover:not(.budgie-menu) button.flat:active:not(.image-button) {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.drop-shadow button:hover, .raven .raven-header:not(.top) button.image-button:hover, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:hover, .budgie-popover:not(.budgie-menu) button.flat:hover:not(.image-button) {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

.drop-shadow button:active, .raven .raven-header:not(.top) button.image-button:active, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:active, .budgie-popover:not(.budgie-menu) button.flat:active:not(.image-button) {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.drop-shadow button:checked, .raven .raven-header:not(.top) button.image-button:checked, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:checked, .budgie-popover:not(.budgie-menu) button.flat:checked:not(.image-button) {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.drop-shadow button:disabled, .raven .raven-header:not(.top) button.image-button:disabled, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:disabled, .budgie-popover:not(.budgie-menu) button.flat:disabled:not(.image-button) {
  border-color: transparent;
  background-color: transparent;
}

.drop-shadow button:disabled label, .raven .raven-header:not(.top) button.image-button:disabled label, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:disabled label, .budgie-popover:not(.budgie-menu) button.flat:disabled:not(.image-button) label, .drop-shadow button:disabled, .raven .raven-header:not(.top) button.image-button:disabled, .budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle:disabled, .budgie-popover:not(.budgie-menu) button.flat:disabled:not(.image-button) {
  color: rgba(43, 47, 59, 0.55);
}

.budgie-container {
  background-color: transparent;
}

.budgie-settings-window buttonbox.inline-toolbar {
  border-style: none none solid;
}

.budgie-popover {
  margin: 0;
  padding: 0;
  border-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  background-color: #ffffff;
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.25), 0 2px 3px 0 rgba(0, 0, 0, 0.25), 0 0 0 1px rgba(0, 0, 0, 0.15);
}

.budgie-popover .container {
  padding: 6px;
  margin: 0;
  border: none;
}

.budgie-popover .container .container {
  padding: 0;
}

.budgie-popover widget > separator {
  margin: 3px 0;
  background-color: rgba(0, 0, 0, 0.15);
}

.budgie-popover border {
  border: none;
}

.budgie-popover list {
  background-color: transparent;
}

.budgie-popover list.content-box row.activatable {
  padding: 0;
  background: 0;
  border: none;
  box-shadow: none;
}

.budgie-popover treeview.view.sidebar,
.budgie-popover scrolledwindow.sidebar {
  background: none;
  color: #2b2f3b;
  padding: 0;
}

.budgie-popover treeview.view.sidebar label,
.budgie-popover scrolledwindow.sidebar label {
  padding: 3px 8px;
}

.budgie-popover treeview.view.sidebar:hover,
.budgie-popover scrolledwindow.sidebar:hover {
  background-color: rgba(43, 47, 59, 0.05);
}

.budgie-popover treeview.view.sidebar:selected, .budgie-popover treeview.view.sidebar:selected:hover,
.budgie-popover scrolledwindow.sidebar:selected,
.budgie-popover scrolledwindow.sidebar:selected:hover {
  color: #ffffff;
  background-color: #3498db;
}

.budgie-popover scrolledwindow.sidebar:not(.categories) {
  border-right: none;
}

.budgie-popover > frame.container > grid.horizontal > grid.horizontal > widget > grid.horizontal > stack {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button) {
  min-height: 28px;
  padding: 0 8px;
  color: rgba(43, 47, 59, 0.85);
  font-weight: normal;
  border: none;
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):hover {
  background-color: rgba(43, 47, 59, 0.12);
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active {
  background-color: rgba(43, 47, 59, 0.22);
  color: #2b2f3b;
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):disabled {
  color: rgba(43, 47, 59, 0.55);
}

.budgie-popover.budgie-menu .container {
  padding: 0;
}

.budgie-popover.budgie-menu.background {
  padding: 0;
  background-color: #ffffff;
}

.budgie-popover.budgie-menu scrollbar,
.budgie-popover.budgie-menu entry.search {
  background-color: transparent;
}

.budgie-popover.budgie-menu entry.search {
  border: none;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
  box-shadow: none;
  font-size: 120%;
}

.budgie-popover.budgie-menu .categories:dir(ltr) {
  border-bottom-left-radius: 3px;
}

.budgie-popover.budgie-menu .categories:dir(rtl) {
  border-bottom-right-radius: 3px;
}

.budgie-popover.budgie-menu button {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 0;
  color: #2b2f3b;
  font-weight: normal;
  border: none;
}

.budgie-popover.budgie-menu button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

.budgie-popover.budgie-menu button:checked:disabled {
  background-color: #3498db;
}

.budgie-popover.budgie-menu row {
  padding: 0;
}

.budgie-popover.budgie-menu row:hover {
  box-shadow: none;
}

.budgie-popover.budgie-menu list.left-overlay-menu {
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.15), 0 3px 5px rgba(0, 0, 0, 0.08), 0 0 0 1px rgba(0, 0, 0, 0.15), inset 0 1px rgba(255, 255, 255, 0.13);
  background-color: #ffffff;
  padding: 6px;
  margin: 6px;
  border-radius: 2px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable {
  border-radius: 2px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable, .budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:hover, .budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:selected, .budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:active, .budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:active:hover {
  background-color: transparent;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:not(:last-child) {
  margin-bottom: 3px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:active {
  background-color: #3498db;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:active label, .budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:active button {
  color: #ffffff;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable button.menuitem {
  border-radius: 2px;
}

.budgie-popover.budgie-menu .budgie-menu-footer {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  padding: 6px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat {
  min-height: 16px;
  min-width: 16px;
  padding: 6px;
  border-radius: 2px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat.image-button {
  border-radius: 999px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat.image-button:not(.last-child) {
  margin-right: 6px;
}

.budgie-popover.user-menu .content-box {
  background-color: transparent;
}

.budgie-popover.user-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

.budgie-popover.sound-popover .container {
  padding: 0;
}

.budgie-popover.sound-popover buttonbox.linked > button {
  margin-top: 6px;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

.budgie-popover.sound-popover buttonbox.linked > button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

.budgie-popover.sound-popover buttonbox.linked > button:active, .budgie-popover.sound-popover buttonbox.linked > button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.budgie-popover.night-light-indicator .view-header {
  padding-left: 4px;
}

.budgie-popover.places-menu .name-button.text-button {
  padding-left: 8px;
  padding-right: 8px;
}

.budgie-popover.places-menu .name-button.text-button image:dir(ltr) {
  margin-right: 3px;
}

.budgie-popover.places-menu .name-button.text-button image:dir(rtl) {
  margin-left: 3px;
}

.budgie-popover.places-menu .places-section-header > image:dir(ltr) {
  margin: 0 -2px 0 5px;
}

.budgie-popover.places-menu .places-section-header > image:dir(rtl) {
  margin: 0 5px 0 -2px;
}

.budgie-popover.places-menu .places-list {
  margin-top: 4px;
  padding-top: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: transparent;
}

.budgie-popover.places-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

.budgie-popover.places-menu .places-list:not(.always-expand) {
  margin-top: 4px;
  padding-top: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover.places-menu .alternative-label {
  padding: 3px;
  font-size: 15px;
}

.budgie-popover.workspace-popover .container {
  padding: 2px 6px 6px;
}

.budgie-popover.workspace-popover flowboxchild {
  padding: 0;
}

.budgie-popover > frame > box.vertical > box.vertical > box.vertical {
  margin: 0 6px 9px;
}

.budgie-popover > frame > box.vertical > box.vertical > box.horizontal > button.image-button.toggle {
  margin-right: 6px;
}

.budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable {
  border-radius: 2px;
}

.budgie-popover > frame > box.vertical > box.vertical > scrolledwindow > viewport.frame > list > row.activatable button:active {
  color: #2b2f3b;
}

window.budgie-popover:not(.csd) > frame.container {
  margin: 0 -1px -1px;
}

.bottom window.budgie-popover:not(.csd) > frame.container {
  padding: 2px 0 2px;
}

window.budgie-popover:not(.csd) > frame.container,
window.budgie-popover:not(.csd) > frame.container > border {
  border-style: none;
}

.workspace-switcher .workspace-layout {
  border: 0 solid rgba(255, 255, 255, 0.12);
}

.top .workspace-switcher .workspace-layout:dir(ltr), .bottom .workspace-switcher .workspace-layout:dir(ltr) {
  border-left-width: 1px;
}

.top .workspace-switcher .workspace-layout:dir(rtl), .bottom .workspace-switcher .workspace-layout:dir(rtl) {
  border-right-width: 1px;
}

.left .workspace-switcher .workspace-layout, .right .workspace-switcher .workspace-layout {
  border-top-width: 1px;
}

.workspace-switcher .workspace-item,
.workspace-switcher .workspace-add-button {
  border: 0 solid rgba(255, 255, 255, 0.12);
}

.top .workspace-switcher .workspace-item:dir(ltr), .bottom .workspace-switcher .workspace-item:dir(ltr), .top .workspace-switcher .workspace-add-button:dir(ltr), .bottom .workspace-switcher .workspace-add-button:dir(ltr) {
  border-right-width: 1px;
}

.top .workspace-switcher .workspace-item:dir(rtl), .bottom .workspace-switcher .workspace-item:dir(rtl), .top .workspace-switcher .workspace-add-button:dir(rtl), .bottom .workspace-switcher .workspace-add-button:dir(rtl) {
  border-left-width: 1px;
}

.left .workspace-switcher .workspace-item, .right .workspace-switcher .workspace-item, .left .workspace-switcher .workspace-add-button, .right .workspace-switcher .workspace-add-button {
  border-bottom-width: 1px;
}

.workspace-switcher .workspace-item {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
}

.workspace-switcher .workspace-item.current-workspace {
  background-color: rgba(255, 255, 255, 0.12);
}

.workspace-switcher .workspace-add-button {
  background-color: transparent;
}

.workspace-switcher .workspace-add-button:hover {
  box-shadow: none;
}

.workspace-switcher .workspace-add-button:active {
  background-image: none;
}

.workspace-switcher .workspace-add-button:active image {
  margin: 1px 0 -1px;
}

.budgie-panel .workspace-switcher .workspace-icon-button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 2px;
}

.workspace-switcher button.raven-trigger {
  padding: 0 6px;
}

.budgie-panel {
  transition: background-color 0.2s cubic-bezier(0, 0, 0.2, 1);
  background-color: #f7f7f7;
  color: #2b2f3b;
  font-weight: 500;
}

.budgie-panel.transparent {
  background-color: rgba(247, 247, 247, 0.85);
}

.bottom .budgie-panel.dock-mode {
  border-radius: 3px 3px 0 0;
}

.bottom .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-left-radius: 3px;
}

.bottom .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-top-right-radius: 3px;
}

.left .budgie-panel.dock-mode {
  border-radius: 0 3px 3px 0;
}

.left .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-right-radius: 3px;
}

.left .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-bottom-right-radius: 3px;
}

.right .budgie-panel.dock-mode {
  border-radius: 3px 0 0 3px;
}

.right .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-left-radius: 3px;
}

.right .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-bottom-left-radius: 3px;
}

.budgie-panel button {
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  border-radius: 0;
  color: #2b2f3b;
  border: none;
  background: none;
}

.budgie-panel button:hover {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.15);
}

.budgie-panel button:active {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.1);
}

.budgie-panel button:checked {
  color: #2b2f3b;
  background-color: rgba(43, 47, 59, 0.12);
}

.budgie-panel button:checked:disabled {
  color: rgba(43, 47, 59, 0.5);
  background-color: rgba(43, 47, 59, 0.06);
}

.budgie-panel button:disabled {
  color: rgba(43, 47, 59, 0.35);
  background: none;
}

.budgie-panel.horizontal button {
  padding: 0 6px;
}

.budgie-panel.vertical button {
  padding: 6px 0;
}

.budgie-panel separator {
  background-color: rgba(0, 0, 0, 0.15);
}

.budgie-panel .alert {
  color: #db5b5b;
}

.budgie-panel.vertical #tasklist-button {
  min-height: 32px;
}

.budgie-panel button.flat.launcher {
  padding: 0;
}

.budgie-panel button.flat.launcher:not(:checked) {
  color: #2b2f3b;
}

.budgie-panel button.flat.launcher:not(:checked):hover, .budgie-panel button.flat.launcher:not(:checked):active {
  color: #ffffff;
}

.budgie-panel button.flat.launcher:not(:checked):disabled {
  color: rgba(43, 47, 59, 0.5);
}

#tasklist-button {
  padding: 0 6px;
}

.top .budgie-panel button.flat.launcher, .budgie-panel .top button.flat.launcher, .top #tasklist-button {
  border-image: radial-gradient(circle closest-corner at center calc(1px), #3498db 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.top .budgie-panel button.flat.launcher:checked, .budgie-panel .top button.flat.launcher:checked, .top #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(1px), #3498db 100%, transparent 0%) 3 0 0 0/3px 0 0 0;
}

.bottom .budgie-panel button.flat.launcher, .budgie-panel .bottom button.flat.launcher, .bottom #tasklist-button {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.bottom .budgie-panel button.flat.launcher:checked, .budgie-panel .bottom button.flat.launcher:checked, .bottom #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #3498db 100%, transparent 0%) 0 0 3 0/0 0 3px 0;
}

.left .budgie-panel button.flat.launcher, .budgie-panel .left button.flat.launcher, .left #tasklist-button {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, #3498db 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.left .budgie-panel button.flat.launcher:checked, .budgie-panel .left button.flat.launcher:checked, .left #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, #3498db 100%, transparent 0%) 0 0 0 3/0 0 0 3px;
}

.right .budgie-panel button.flat.launcher, .budgie-panel .right button.flat.launcher, .right #tasklist-button {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, #3498db 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.right .budgie-panel button.flat.launcher:checked, .budgie-panel .right button.flat.launcher:checked, .right #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, #3498db 100%, transparent 0%) 0 3 0 0/0 3px 0 0;
}

.budgie-panel button.flat.launcher {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  border-radius: 0;
  border: none;
  background-position: center center;
}

.budgie-panel button.flat.launcher > image {
  opacity: 0.87;
}

.budgie-panel button.flat.launcher:hover > image {
  opacity: 1.0;
}

.budgie-panel button.flat.launcher:active > image {
  opacity: 1.0;
}

.budgie-panel button.flat.launcher:checked > image {
  opacity: 1.0;
}


.unpinned button.flat.launcher > image,
.pinned button.flat.launcher.running > image,
.pinned button.launcher.running.sidebar-button > image {
  background-repeat: no-repeat;
  opacity: 1.0;
}


.unpinned button.flat.launcher:checked > image,
.pinned button.flat.launcher.running:checked > image,
.pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.top .budgie-panel .unpinned button.flat.launcher > image,
.top .budgie-panel .pinned button.flat.launcher.running > image,
.top .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 6px 3px;
  background-position: top center;
  background-image: image(#3498db);
}

.top .budgie-panel .unpinned button.flat.launcher:checked > image,
.top .budgie-panel .pinned button.flat.launcher.running:checked > image,
.top .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.bottom .budgie-panel .unpinned button.flat.launcher > image,
.bottom .budgie-panel .pinned button.flat.launcher.running > image,
.bottom .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 6px 3px;
  background-position: bottom center;
  background-image: image(#3498db);
}

.bottom .budgie-panel .unpinned button.flat.launcher:checked > image,
.bottom .budgie-panel .pinned button.flat.launcher.running:checked > image,
.bottom .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.left .budgie-panel .unpinned button.flat.launcher > image,
.left .budgie-panel .pinned button.flat.launcher.running > image,
.left .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 3px 6px;
  background-position: left center;
  background-image: image(#3498db);
}

.left .budgie-panel .unpinned button.flat.launcher:checked > image,
.left .budgie-panel .pinned button.flat.launcher.running:checked > image,
.left .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.right .budgie-panel .unpinned button.flat.launcher > image,
.right .budgie-panel .pinned button.flat.launcher.running > image,
.right .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 3px 6px;
  background-position: right center;
  background-image: image(#3498db);
}

.right .budgie-panel .unpinned button.flat.launcher:checked > image,
.right .budgie-panel .pinned button.flat.launcher.running:checked > image,
.right .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

box:not(.unpinned):not(.pinned) > revealer > button.flat.launcher {
  border-image: none;
}

frame.raven-frame > border {
  border: none;
  box-shadow: none;
}

.top .shadow-block {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.bottom .shadow-block {
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.left .shadow-block {
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.right .shadow-block {
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.raven {
  background-color: #f7f7f7;
}

.raven > box {
  margin-bottom: -10px;
}

.raven > stack {
  margin-bottom: -10px;
}

.raven .raven-header {
  min-height: 36px;
  padding: 3px;
}

.raven .raven-header:not(.top) {
  margin-top: -6px;
}

.raven .raven-header:not(.top) button.image-button {
  min-height: 28px;
  min-width: 28px;
  margin: 0;
  padding: 0;
}

.raven .raven-header:not(.top) button.image-button.image-button {
  border-radius: 100px;
}

.raven .raven-header.top {
  padding: 2px 12px;
  background-color: #f2f2f2;
  color: #2b2f3b;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

.raven .raven-header.top stackswitcher {
  padding: 0;
  margin: 0;
}

.raven .raven-header.top stackswitcher button {
  margin: 4px 0;
  padding: 2px 16px;
  min-height: 16px;
  background-color: white;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
}

.raven .raven-header.top stackswitcher button:hover {
  background-color: white;
  box-shadow: none;
}

.raven .raven-header.top stackswitcher button:active, .raven .raven-header.top stackswitcher button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

.raven .raven-header.top stackswitcher button:disabled {
  color: rgba(43, 47, 59, 0.4);
}

.raven .raven-header.top stackswitcher button:disabled label {
  color: rgba(43, 47, 59, 0.4);
}

.raven .raven-header.top button.image-button:dir(ltr) {
  margin-right: 2px;
}

.raven .raven-header.top button.image-button:dir(rtl) {
  margin-left: 2px;
}

.raven .raven-header.top > image {
  margin: 0 8px;
}

.raven .raven-header.top > label {
  margin: 0 -8px;
  font-weight: bold;
}

.raven .raven-header.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.raven viewport.frame .raven-header {
  margin-top: -8px;
}

.raven .expander-button {
  border-radius: 100px;
}

.raven .raven-background {
  border-style: solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

.raven .raven-background.middle {
  border-bottom-style: none;
}

.raven .raven-background.frame {
  border-style: solid none;
}

.raven .raven-background > overlay > widget > image {
  color: alpha(currentColor,0.12);
}

.raven .raven-background grid > label:first-child {
  min-height: 26px;
}

.raven .raven-background stackswitcher {
  padding: 6px;
}

.raven scrolledwindow.raven-background {
  border-bottom-style: none;
}

.raven .raven-header.top + .raven-background {
  border-style: none;
  background-color: #3498db;
  color: #ffffff;
}

.raven .raven-header.top + .raven-background stackswitcher button {
  margin: -4px 0;
}

.raven .powerstrip button.image-button {
  min-height: 28px;
  min-width: 28px;
  margin: 0 4px;
  padding: 6px;
}

.raven .option-subtitle {
  font-size: smaller;
}

calendar.raven-calendar {
  margin: 2px 0;
  padding: 2px;
  border-style: none;
  background-color: transparent;
}

calendar.raven-calendar:selected {
  border-radius: 3px;
  background-color: #3498db;
}

.raven-mpris {
  background-color: rgba(0, 0, 0, 0.5);
  color: #ffffff;
}

.raven-mpris label {
  min-height: 24px;
}

.raven-mpris button.image-button {
  padding: 8px 7px;
  border: none;
  border-radius: 100px;
}

image.raven-mpris {
  background-color: rgba(43, 47, 59, 0.1);
  color: #2e313d;
  border-radius: 3px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame list {
  background-color: transparent;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable {
  margin-left: -8px;
  margin-right: -2px;
  background-color: transparent;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable > grid > *,
box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable > box.vertical * {
  color: #2b2f3b;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable image {
  padding-left: 8px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button {
  margin: 8px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button image {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:active image, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:checked image {
  color: white;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list {
  border-radius: 2px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable:last-child {
  border-bottom: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable:selected {
  background-color: rgba(43, 47, 59, 0.06);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable label {
  padding: 0 16px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable button.image-button image {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected {
  background-color: rgba(52, 152, 219, 0.75);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected > grid > *,
box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected > box.vertical * {
  color: #ffffff;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button {
  border: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:hover {
  background-color: rgba(255, 255, 255, 0.25);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:active, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:checked {
  background-color: rgba(255, 255, 255, 0.35);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list {
  border: 1px solid rgba(255, 255, 255, 0.12);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable:last-child {
  border-bottom: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable:selected {
  background-color: rgba(52, 152, 219, 0.65);
}

.slate-notification-window,
.budgie-notification-window,
.budgie-switcher-window,
.budgie-osd-window {
  background-color: transparent;
  background-image: none;
  border-radius: 6px;
}

.slate-notification .notification-title,
.budgie-notification .notification-title,
.budgie-switcher .notification-title {
  font-size: 120%;
}

.budgie-osd .budgie-osd-text {
  font-size: 120%;
}

.drop-shadow {
  margin: 5px 9px;
  padding: 8px;
  border-radius: 6px;
  box-shadow: 0 5px 5px 0 transparent, 0 8px 15px 0 transparent, 0 3px 3px 0 rgba(0, 0, 0, 0.25), 0 0 0 1px rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
  color: #2b2f3b;
}

.drop-shadow .linked > button:not(:hover):not(:active) {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

.budgie-run-dialog, .budgie-session-dialog,
.budgie-polkit-dialog {
  background-color: #ffffff;
  color: #2b2f3b;
}

.background.csd.budgie-run-dialog, .background.csd.budgie-session-dialog,
.background.csd.budgie-polkit-dialog, .budgie-run-dialog > decoration, .budgie-session-dialog > decoration,
.budgie-polkit-dialog > decoration {
  border-radius: 3px;
}

.budgie-session-dialog buttonbox.linked.horizontal > button,
.budgie-polkit-dialog buttonbox.linked.horizontal > button {
  padding: 8px 16px;
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
}

.budgie-session-dialog buttonbox.linked.horizontal > button:active, .budgie-session-dialog buttonbox.linked.horizontal > button:checked,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:active,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:checked {
  transition: background-color 0.00001s 0.3s;
  animation: ripple_effect 0.3s cubic-bezier(0, 0, 0.2, 1);
}

.budgie-session-dialog buttonbox.linked.horizontal > button:first-child,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:first-child {
  border-bottom-left-radius: 3px;
}

.budgie-session-dialog buttonbox.linked.horizontal > button:last-child,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:last-child {
  border-bottom-right-radius: 3px;
}

.budgie-session-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):hover,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):hover {
  background-color: alpha(#2b2f3b,0.06);
  border-color: rgba(0, 0, 0, 0.15);
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.budgie-session-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):active, .budgie-session-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):checked,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):active,
.budgie-polkit-dialog buttonbox.linked.horizontal > button:not(.suggested-action):not(.destructive-action):checked {
  color: #2b2f3b;
  background-color: alpha(#2b2f3b,0.1);
  border-color: rgba(0, 0, 0, 0.15);
}

.budgie-polkit-dialog .message {
  color: alpha(currentColor,0.6);
}

.budgie-polkit-dialog .failure {
  color: #db5b5b;
}

.budgie-run-dialog {
  background-color: #ffffff;
}

.budgie-run-dialog entry.search {
  font-size: 120%;
  padding: 6px 12px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
  background-color: transparent;
}

.budgie-run-dialog list .dim-label, .budgie-run-dialog list label.separator, .budgie-run-dialog list headerbar .subtitle, headerbar .budgie-run-dialog list .subtitle, .budgie-run-dialog list .slate-notification .notification-body, .slate-notification .budgie-run-dialog list .notification-body,
.budgie-run-dialog list .budgie-notification .notification-body,
.budgie-notification .budgie-run-dialog list .notification-body,
.budgie-run-dialog list .budgie-switcher .notification-body,
.budgie-switcher .budgie-run-dialog list .notification-body {
  opacity: 1;
}

.budgie-run-dialog scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-panel box.titlebar {
  min-width: 20px;
  min-height: 20px;
  border-radius: 0;
  background: unset;
  box-shadow: none;
  border: none;
}

.budgie-panel box.titlebar > widget > label {
  color: #2b2f3b;
}

.budgie-panel box.titlebar.horizontal {
  padding: 0 3px;
}

.budgie-panel box.titlebar.horizontal > widget > label:dir(ltr) {
  padding-right: 3px;
}

.budgie-panel box.titlebar.horizontal > widget > label:dir(rtl) {
  padding-left: 3px;
}

.budgie-panel box.titlebar.horizontal > button.image-button.titlebutton {
  padding: 0 3px;
}

/*****************
 * Xfce4 Desktop *
 *****************/
.xfce4-panel button, .xfce4-panel button.flat, .xfce4-panel.panel button, .xfce4-panel.panel button.flat, window#ValaPanel.background button.flat.-panel-button,
window#ValaPanel.background button#tasklist-button.toggle.flat,
window#ValaPanel.background button.flat.-panel-icon-button, .mate-panel-menu-bar button,
.mate-panel-menu-bar button#tasklist-button,
panel-toplevel.background button,
panel-toplevel.background button#tasklist-button {
  color: #2b2f3b;
  border-radius: 0;
  border: none;
  background-color: transparent;
}

.xfce4-panel button:hover:not(:active):not(:checked), window#ValaPanel.background button.flat.-panel-button:hover:not(:active):not(:checked),
window#ValaPanel.background button#tasklist-button.toggle.flat:hover:not(:active):not(:checked),
window#ValaPanel.background button.flat.-panel-icon-button:hover:not(:active):not(:checked), .mate-panel-menu-bar button:hover:not(:active):not(:checked),
.mate-panel-menu-bar button#tasklist-button:hover:not(:active):not(:checked),
panel-toplevel.background button:hover:not(:active):not(:checked),
panel-toplevel.background button#tasklist-button:hover:not(:active):not(:checked) {
  color: black;
  box-shadow: inset 0 -2px rgba(52, 152, 219, 0.5);
}

.xfce4-panel button:checked, window#ValaPanel.background button.flat.-panel-button:checked,
window#ValaPanel.background button#tasklist-button.toggle.flat:checked,
window#ValaPanel.background button.flat.-panel-icon-button:checked, .mate-panel-menu-bar button:checked,
.mate-panel-menu-bar button#tasklist-button:checked,
panel-toplevel.background button:checked,
panel-toplevel.background button#tasklist-button:checked {
  color: #2b2f3b;
  box-shadow: inset 0 -2px #3498db;
}

.xfce4-panel button:checked label, window#ValaPanel.background button.flat.-panel-button:checked label,
window#ValaPanel.background button#tasklist-button.toggle.flat:checked label,
window#ValaPanel.background button.flat.-panel-icon-button:checked label, .mate-panel-menu-bar button:checked label,
.mate-panel-menu-bar button#tasklist-button:checked label,
panel-toplevel.background button:checked label,
panel-toplevel.background button#tasklist-button:checked label, .xfce4-panel button:checked image, window#ValaPanel.background button.flat.-panel-button:checked image,
window#ValaPanel.background button#tasklist-button.toggle.flat:checked image,
window#ValaPanel.background button.flat.-panel-icon-button:checked image, .mate-panel-menu-bar button:checked image,
.mate-panel-menu-bar button#tasklist-button:checked image,
panel-toplevel.background button:checked image,
panel-toplevel.background button#tasklist-button:checked image {
  color: inherit;
}

.xfce4-panel button:active, window#ValaPanel.background button.flat.-panel-button:active,
window#ValaPanel.background button#tasklist-button.toggle.flat:active,
window#ValaPanel.background button.flat.-panel-icon-button:active, .mate-panel-menu-bar button:active,
.mate-panel-menu-bar button#tasklist-button:active,
panel-toplevel.background button:active,
panel-toplevel.background button#tasklist-button:active {
  background-color: rgba(255, 255, 255, 0.12);
  color: #2b2f3b;
  box-shadow: inset 0 -2px #3498db;
}

.xfce4-panel.panel {
  background-color: #f7f7f7;
  text-shadow: none;
  -gtk-icon-shadow: none;
  border: none;
}

.XfceHeading {
  border: 0 none transparent;
  background-color: #f7f7f7;
  color: #2b2f3b;
}

.xfce4-panel {
  background-color: #f7f7f7;
  color: #2b2f3b;
  font-weight: 700;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.xfce4-panel,
.xfce4-panel frame > border {
  border: none;
}

.xfce4-panel#XfcePanelWindow {
  border: none;
}

.xfce4-panel#XfcePanelWindow, .xfce4-panel#XfcePanelWindow.marching-ants {
  transition: none;
}

.xfce4-panel button {
  font-weight: 700;
}

.xfce4-panel button#launcher-arrow:hover, .xfce4-panel button#launcher-arrow + button.toggle:hover {
  box-shadow: none;
}

.xfce4-panel button#launcher-arrow + button.toggle:checked {
  color: #3498db;
  box-shadow: none;
}

.xfce4-panel button#xfce4-notification-plugin {
  padding: 0 1px;
}

.xfce4-panel menu {
  font-weight: 400;
  text-shadow: none;
}

.xfce4-panel widget.tasklist > button.toggle {
  font-weight: 400;
}

window#XfcePanelWindow.background.panel.xfce4-panel {
  border: none;
}

window#XfcePanelWindow.background.panel.xfce4-panel > widget wnck-pager {
  background-color: rgba(255, 255, 255, 0.1);
  border: none;
  box-shadow: 0 0 0 1px rgba(255, 255, 255, 0.15);
}

window#XfcePanelWindow.background.panel.xfce4-panel > widget wnck-pager:hover {
  background-color: rgba(255, 255, 255, 0.25);
}

window#XfcePanelWindow.background.panel.xfce4-panel > widget wnck-pager:active, window#XfcePanelWindow.background.panel.xfce4-panel > widget wnck-pager:checked, window#XfcePanelWindow.background.panel.xfce4-panel > widget wnck-pager:selected {
  background-color: rgba(255, 255, 255, 0.35);
}

XfdesktopIconView.view {
  border-radius: 2px;
  background: transparent;
  color: #ffffff;
  text-shadow: 0 0 1px rgba(0, 0, 0, 0.26), 0 1px 2px rgba(0, 0, 0, 0.32), 0 2px 3px rgba(0, 0, 0, 0.12);
}

XfdesktopIconView.view:active, XfdesktopIconView.view:checked {
  background-color: #3498db;
  color: #ffffff;
  text-shadow: none;
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar {
  background-color: rgba(0, 0, 0, 0.15);
  border-color: #f2f2f2;
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  background-color: #2b2f3b;
  border: 1px solid rgba(0, 0, 0, 0.2);
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar slider {
  background-color: rgba(75, 82, 103, 0.65);
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar slider:hover {
  background-color: #565e76;
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar slider:hover:active {
  background-color: #3498db;
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar slider:disabled {
  background-color: transparent;
}

window#whiskermenu-window > frame > stack scrolledwindow scrollbar trough {
  background-color: rgba(0, 0, 0, 0.08);
}

window#whiskermenu-window {
  background-color: #f7f7f7;
  color: #2b2f3b;
}

window#whiskermenu-window > frame > border {
  border-radius: 0;
}

window#whiskermenu-window > frame > stack button {
  background-color: transparent;
  color: #2b2f3b;
  background-clip: padding-box;
}

window#whiskermenu-window > frame > stack button:hover {
  background-color: rgba(43, 47, 59, 0.12);
  color: black;
  border-color: rgba(0, 0, 0, 0.2);
}

window#whiskermenu-window > frame > stack button:checked, window#whiskermenu-window > frame > stack button:active {
  background-color: #3498db;
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.2);
  background-clip: border-box;
}

window#whiskermenu-window > frame > stack button:disabled {
  color: rgba(43, 47, 59, 0.45);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(247, 247, 247, 0.45);
}

window#whiskermenu-window > frame > stack entry {
  background-color: white;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.2);
}

window#whiskermenu-window > frame > stack entry image {
  color: #545761;
}

window#whiskermenu-window > frame > stack entry:focus {
  border-color: #3498db;
}

window#whiskermenu-window > frame > stack entry:focus image {
  color: #3498db;
}

window#whiskermenu-window > frame > stack entry:disabled {
  color: rgba(43, 47, 59, 0.45);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(247, 247, 247, 0.45);
}

window#whiskermenu-window > frame > stack entry:disabled image {
  color: rgba(43, 47, 59, 0.45);
}

window#whiskermenu-window > frame > stack scrolledwindow .view {
  background-color: white;
  color: #2b2f3b;
}

window#whiskermenu-window > frame > stack scrolledwindow .view:selected:hover {
  background-color: #dedede;
  color: #2b2f3b;
}

window.thunar paned.horizontal > separator {
  background-image: image(#d1d1d1);
}

window.thunar .sidebar {
  border: none;
}

window.thunar .sidebar treeview.view {
  background-color: #f7f7f7;
  color: #2e313d;
}

window.thunar .sidebar treeview.view:hover {
  background-color: #e3e3e4;
  box-shadow: none;
}

window.thunar .sidebar treeview.view:selected, window.thunar .sidebar treeview.view:selected:hover, window.thunar .sidebar treeview.view:active:hover {
  background-color: #d8d9db;
}

window.thunar toolbar, window.thunar .inline-toolbar {
  background-color: #f2f2f2;
  color: #2b2f3b;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

window.thunar toolbar entry, window.thunar .inline-toolbar entry {
  min-height: 0;
}

window.thunar toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button, window.thunar .inline-toolbar .linked:not(.vertical):not(.stack-switcher).path-bar button {
  margin: 0;
  padding: 2px 4px 4px 4px;
}

window.thunar notebook stack > scrolledwindow.frame.standard-view {
  border-top-width: 0;
  border-right-width: 0;
}

window.thunar notebook stack > scrolledwindow.frame.standard-view widget.view {
  border-radius: 2px;
}

window.thunar notebook header.top tab.reorderable-page > box > label {
  min-height: 0;
}

#pulseaudio-button menuitem:hover scale highlight, #xfce4-power-manager-plugin menuitem:hover scale highlight {
  background-color: #ffffff;
}

/**********************
 * Elementary Desktop *
 **********************/
.panel {
  background-color: #f7f7f7;
  transition: all 100ms ease-in-out;
  color: #2b2f3b;
  font-weight: bold;
}

.panel.maximized {
  background-color: black;
}

.panel.translucent {
  background-color: #f7f7f7;
}

menubar .panel, .panel menubar {
  box-shadow: none;
  border: none;
  background: none;
  color: #2b2f3b;
}

.panel-shadow {
  background-image: none;
  background-color: transparent;
}

.panel .menu {
  box-shadow: none;
}

.panel .menu .menuitem {
  font-weight: normal;
}

.panel .menubar > .menuitem {
  padding: 3px 6px;
}

.panel .menubar > .menuitem:hover {
  background-color: transparent;
}

.panel popover {
  padding: 2px 4px;
  font-weight: normal;
  border: 1px solid rgba(0, 0, 0, 0.25);
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.12), 0 3px 6px rgba(0, 0, 0, 0.08);
}

.panel popover button {
  font-weight: normal;
  background-color: transparent;
}

.panel popover button:active label, .panel popover button:checked label {
  color: white;
}

.panel popover .linked > button {
  border-color: rgba(0, 0, 0, 0.15);
}

.panel popover list {
  background-color: transparent;
}

.panel popover separator.horizontal {
  margin: 0 -4px;
}

.panel popover separator.vertical {
  background-image: image(rgba(0, 0, 0, 0.15));
  margin: 0 2px;
}

.panel popover .sidebar {
  border-style: none;
  background: none;
}

.panel popover .sidebar .view {
  background: none;
  border-radius: 2px;
}

.panel popover .sidebar .view:selected, .panel popover .sidebar .view:active, .panel popover .sidebar .view:checked, .panel popover .sidebar .view:active:backdrop, .panel popover .sidebar .view:checked:backdrop, .panel popover .sidebar .view:selected:backdrop {
  color: #ffffff;
  background-color: #3498db;
}

button.flat.toggle.switcher:hover image, button.flat.toggle.switcher:active image, button.flat.toggle.switcher:checked image, button.flat.toggle.switcher:selected image {
  color: #3498db;
}

.circular label:disabled {
  color: rgba(43, 47, 59, 0.55);
}

.circular.accent {
  color: #ffffff;
  background-color: #3498db;
}

.panel-app-button > GtkWidget > GtkWidget:first-child {
  padding: 0 2px 0 4px;
}

.panel .menu .spinner,
.menu .spinner {
  opacity: 1;
}

.composited-indicator {
  background-color: transparent;
  color: #2b2f3b;
  padding: 0 6px;
}

.composited-indicator > revealer label,
.composited-indicator > revealer image,
.composited-indicator > revealer spinner {
  color: #2b2f3b;
  font-weight: bold;
  text-shadow: none;
  transition: all 200ms ease-in-out;
}

.composited-indicator .keyboard {
  background-color: #fff;
  border-radius: 2px;
  box-shadow: none;
  color: #333;
  font-weight: 600;
  padding: 0 3px;
  text-shadow: none;
}

.composited-indicator > GtkWidget > GtkWidget:first-child {
  padding: 0 2px;
}

.composited-indicator .menuitem:active, .composited-indicator .menuitem:hover {
  border-style: none;
}

.composited-indicator > .popup > .menu {
  padding-top: 8px;
  padding-bottom: 8px;
}

BirdieWidgetsTweetList * {
  background-image: none;
  background-color: transparent;
}

MarlinViewWindow *:selected, MarlinViewWindow *:selected:focus {
  color: #ffffff;
  background-color: #3498db;
  outline-color: transparent;
}

MarlinViewWindow GtkIconView.view:selected, MarlinViewWindow GtkIconView.view:selected:focus, MarlinViewWindow GtkIconView.view:selected:hover, MarlinViewWindow GtkIconView.view:selected:focus:hover {
  background-color: transparent;
}

MarlinViewWindow FMListView, MarlinViewWindow FMColumnView {
  outline-color: transparent;
}

.marlin-pathbar.pathbar {
  border-radius: 3px;
  padding-left: 4px;
  padding-right: 4px;
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

.marlin-pathbar.pathbar image, .marlin-pathbar.pathbar image:hover {
  color: inherit;
}

.marlin-pathbar.pathbar:focus {
  color: #565e76;
  border-color: #3498db;
  background-color: #ffffff;
}

.marlin-pathbar.pathbar:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

.marlin-pathbar.pathbar:active, .marlin-pathbar.pathbar:checked {
  color: #3498db;
}

treeview.view.sidebar {
  color: #2e313d;
  background-color: rgba(248, 248, 248, 0.95);
}

treeview.view.sidebar.source-list {
  padding-top: 3px;
  padding-bottom: 3px;
}

treeview.view.sidebar.source-list.trough {
  color: #2b2f3b;
  background-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  border-width: 0;
}

treeview.view.sidebar.source-list.trough:selected, treeview.view.sidebar.source-list.trough:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  border-width: 0;
}

.dynamic-notebook notebook iconview.view.cell:selected {
  background-color: rgba(0, 0, 0, 0.1);
}

headerbar.titlebar entry.pathbar {
  min-height: 0;
}

headerbar.titlebar button.flat.image-button.toggle {
  min-height: 0;
  padding-top: 0;
  padding-bottom: 0;
  margin-top: 9px;
  margin-bottom: 10px;
}

headerbar.titlebar > grid.linked.horizontal.format-bar {
  background-image: image(#f2f2f2);
}

popover radiobutton.color-button.color-light, popover radiobutton.color-button.color-dark, popover radiobutton.color-button.color-white {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.gala-notification {
  border: 1px solid rgba(0, 0, 0, 0.35);
  border-radius: 3px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  background-image: linear-gradient(to bottom, white, white);
  background-color: transparent;
}

.gala-notification .title, .gala-notification .label {
  color: #5c616c;
}

actionbar.inline-toolbar {
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

actionbar.inline-toolbar button {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

actionbar.inline-toolbar button:first-child {
  border-right-style: solid;
}

actionbar.inline-toolbar button:last-child {
  border-left-style: solid;
}

scale.warmth trough {
  background-image: linear-gradient(to right, #3498db, #db5b5b);
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.25);
}

#panel_window {
  background-color: #f7f7f7;
  color: #2b2f3b;
  font-weight: bold;
  box-shadow: inset 0 -1px #e5e5e5;
}

#panel_window menubar {
  padding-left: 5px;
}

#panel_window menubar, #panel_window menubar > menuitem {
  background-color: transparent;
  color: #2b2f3b;
  font-weight: bold;
}

#panel_window menubar menuitem:disabled {
  color: rgba(43, 47, 59, 0.5);
}

#panel_window menubar menuitem:disabled label {
  color: inherit;
}

#panel_window menubar menu > menuitem {
  font-weight: normal;
}

#login_window,
#shutdown_dialog,
#restart_dialog {
  font-weight: normal;
  border-style: none;
  background-color: transparent;
  color: #2b2f3b;
}

#content_frame {
  padding-bottom: 14px;
  background-color: #f7f7f7;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 1px 1px 0 1px;
}

#content_frame button {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

#content_frame button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

#content_frame button:active, #content_frame button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

#content_frame button:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

#content_frame button:disabled label, #content_frame button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

#buttonbox_frame {
  padding-top: 20px;
  padding-bottom: 0px;
  border-style: none;
  background-color: rgba(255, 255, 255, 0.95);
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 0 1px 1px 1px;
  box-shadow: inset 0 1px rgba(210, 210, 210, 0.95);
}

#buttonbox_frame button {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.95);
}

#buttonbox_frame button:hover {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(46, 49, 61, 0.1);
}

#buttonbox_frame button:active, #buttonbox_frame button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

#buttonbox_frame button:disabled {
  color: #c0c1c5;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.85);
}

#login_window #user_combobox {
  color: #2b2f3b;
  font-size: 13px;
}

#login_window #user_combobox menu {
  font-weight: normal;
}

#user_image {
  padding: 3px;
  border-radius: 2px;
}

#shutdown_button.button {
  background-clip: border-box;
  color: green;
  background-color: #db5b5b;
  border-color: #db5b5b;
}

#shutdown_button.button:hover {
  background-clip: border-box;
  color: green;
  background-color: #e48585;
  border-color: #e48585;
}

#shutdown_button.button:active, #shutdown_button.button:checked {
  background-clip: border-box;
  color: green;
  background-color: #d23131;
  border-color: #d23131;
}

#restart_button.button {
  background-clip: border-box;
  color: green;
  background-color: #3498db;
  border-color: #3498db;
}

#restart_button.button:hover {
  background-clip: border-box;
  color: green;
  background-color: #5faee3;
  border-color: #5faee3;
}

#restart_button.button:active, #restart_button.button:checked {
  background-clip: border-box;
  color: green;
  background-color: #217dbb;
  border-color: #217dbb;
}

#greeter_infobar {
  border-bottom-width: 0;
  font-weight: bold;
}

.overlay-bar {
  background-color: #3498db;
  border-color: #3498db;
  border-radius: 2px;
  padding: 3px 6px;
  margin: 3px;
}

.overlay-bar label {
  color: #ffffff;
}

GraniteWidgetsThinPaned {
  background-color: transparent;
  background-image: none;
  margin: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.15);
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

GraniteWidgetsPopOver .frame,
GraniteWidgetsStaticNotebook .frame {
  border: none;
}

.help_button {
  border-radius: 100px;
  padding: 3px 9px;
}

toolbar.secondary-toolbar, .secondary-toolbar.inline-toolbar {
  padding: 3px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

toolbar.secondary-toolbar button, .secondary-toolbar.inline-toolbar button {
  padding: 0 3px 0 3px;
}

toolbar.bottom-toolbar, .bottom-toolbar.inline-toolbar {
  padding: 5px;
  border-width: 1px 0 0 0;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #f7f7f7;
}

toolbar.bottom-toolbar button, .bottom-toolbar.inline-toolbar button {
  padding: 2px 3px 2px 3px;
}

.source-list {
  -GtkTreeView-horizontal-separator: 1px;
  -GtkTreeView-vertical-separator: 6px;
}

.source-list,
.source-list.view {
  background-color: #f7f7f7;
  color: #2b2f3b;
  -gtk-icon-style: regular;
}

.source-list.category-expander {
  color: transparent;
}

.source-list.view:hover {
  background-color: white;
}

.source-list.view:selected,
.source-list.view:hover:selected,
.source-list.view:selected:focus,
.source-list.category-expander:hover {
  color: #ffffff;
  background-color: #3498db;
}

.source-list scrollbar,
.source-list junction {
  border-image: none;
  border-color: transparent;
  background-color: #f7f7f7;
  background-image: none;
}

.source-list.badge,
.source-list.badge:hover,
.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
  background-image: none;
  background-color: #3498db;
  color: #ffffff;
  border-radius: 10px;
  padding: 0 6px;
  margin: 0 3px;
  border-width: 0;
}

.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
  background-color: #ffffff;
  color: #3498db;
}

.source-list.category-expander {
  color: #2b2f3b;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  -GtkTreeView-expander-size: 16;
}

.source-list.category-expander,
.source-list.category-expander:backdrop {
  color: transparent;
  border: none;
}

.source-list.category-expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

GraniteWidgetsWelcome {
  background-color: #ffffff;
}

GraniteWidgetsWelcome label {
  color: #919399;
  font-size: 11px;
  text-shadow: none;
}

GraniteWidgetsWelcome .h1,
GraniteWidgetsWelcome .h3 {
  color: rgba(43, 47, 59, 0.8);
}

.help_button {
  border-radius: 0;
}

GraniteWidgetsPopOver {
  -GraniteWidgetsPopOver-arrow-width: 21;
  -GraniteWidgetsPopOver-arrow-height: 10;
  -GraniteWidgetsPopOver-border-radius: 2px;
  -GraniteWidgetsPopOver-border-width: 1;
  -GraniteWidgetsPopOver-shadow-size: 12;
  border: 1px solid rgba(0, 0, 0, 0.3);
  margin: 0;
}

.popover_bg {
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
  border: 1px solid rgba(0, 0, 0, 0.3);
}

GraniteWidgetsPopOver .sidebar.view,
GraniteWidgetsPopOver * {
  background-color: transparent;
}

GraniteWidgetsXsEntry entry {
  padding: 4px;
}

.h1 {
  font-size: 24px;
}

.h2 {
  font-size: 18px;
}

.h3 {
  font-size: 11px;
}

.h4,
.category-label {
  color: #6a6c75;
  font-weight: 600;
}

.h4 {
  padding-bottom: 6px;
  padding-top: 6px;
}

GtkListBox .h4 {
  padding-left: 6px;
}

filechooser paned > separator,
.nautilus-window paned > separator {
  background-image: linear-gradient(to bottom, rgba(210, 210, 210, 0.95), rgba(210, 210, 210, 0.95));
}

filechooser.csd.background, filechooser placessidebar list,
.nautilus-window.csd.background,
.nautilus-window placessidebar list {
  background-color: transparent;
}

filechooser placessidebar.sidebar,
.nautilus-window placessidebar.sidebar {
  background-color: rgba(248, 248, 248, 0.95);
}

filechooser placessidebar.sidebar row.sidebar-row,
.nautilus-window placessidebar.sidebar row.sidebar-row {
  margin: 0 0;
  border: none;
  border-radius: 0;
  color: #2e313d;
}

filechooser placessidebar.sidebar row.sidebar-row .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row .sidebar-icon {
  color: rgba(46, 49, 61, 0.6);
}

filechooser placessidebar.sidebar row.sidebar-row.has-open-popup, filechooser placessidebar.sidebar row.sidebar-row:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup,
.nautilus-window placessidebar.sidebar row.sidebar-row:hover {
  border-radius: 0;
  background-color: rgba(46, 49, 61, 0.15);
  box-shadow: inset 3px 0 #5faee3;
}

filechooser placessidebar.sidebar row.sidebar-row:disabled, filechooser placessidebar.sidebar row.sidebar-row:disabled label, filechooser placessidebar.sidebar row.sidebar-row:disabled image,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled label,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled image {
  color: rgba(46, 49, 61, 0.45);
}

filechooser placessidebar.sidebar row.sidebar-row:selected.has-open-popup, filechooser placessidebar.sidebar row.sidebar-row:selected, filechooser placessidebar.sidebar row.sidebar-row:selected:hover, filechooser placessidebar.sidebar row.sidebar-row:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected.has-open-popup,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover {
  border-radius: 0;
}

filechooser placessidebar.sidebar row.sidebar-row:selected.has-open-popup label, filechooser placessidebar.sidebar row.sidebar-row:selected label, filechooser placessidebar.sidebar row.sidebar-row:selected:hover label, filechooser placessidebar.sidebar row.sidebar-row:active:hover label,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected.has-open-popup label,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected label,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover label,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover label {
  color: #ffffff;
}

filechooser placessidebar.sidebar row.sidebar-row:selected.has-open-popup .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:selected .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:active:hover .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected.has-open-popup .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover .sidebar-icon {
  color: inherit;
}

filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button {
  color: #2e313d;
}

filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:hover {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(43, 47, 59, 0.12);
}

filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:active,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:active {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

filechooser placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row,
.nautilus-window placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row {
  color: #3498db;
}

filechooser placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row .sidebar-icon {
  color: inherit;
}

filechooser placessidebar.sidebar row.sidebar-row:backdrop,
.nautilus-window placessidebar.sidebar row.sidebar-row:backdrop {
  opacity: 0.75;
}

filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled), filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled),
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon {
  color: #F08437;
}

filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon {
  color: #ffffff;
}

filechooser placessidebar.sidebar separator,
.nautilus-window placessidebar.sidebar separator {
  background-color: transparent;
}

filechooser.maximized placessidebar.sidebar,
.nautilus-window.maximized placessidebar.sidebar {
  background-color: #f8f8f8;
}

filechooser actionbar {
  color: #2b2f3b;
  background-color: #f7f7f7;
  border-color: rgba(0, 0, 0, 0.15);
}

filechooser actionbar button {
  color: #2b2f3b;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fcfcfc;
}

filechooser actionbar button:hover {
  color: #0b0c0f;
  border-color: rgba(0, 0, 0, 0.25);
  background-color: white;
}

filechooser actionbar button:active, filechooser actionbar button:checked {
  color: #ffffff;
  border-color: #3498db;
  background-color: #3498db;
}

filechooser actionbar button:disabled {
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(252, 252, 252, 0.55);
}

filechooser actionbar button:disabled label, filechooser actionbar button:disabled {
  color: rgba(43, 47, 59, 0.55);
}

filechooser actionbar entry {
  color: #2e313d;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
  outline: none;
}

filechooser actionbar entry:focus {
  color: #2e313d;
  border-color: #3498db;
  background-color: #ffffff;
  outline: none;
}

filechooser actionbar entry:disabled {
  color: rgba(43, 47, 59, 0.55);
  border-color: rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.55);
}

filechooser actionbar label, filechooser actionbar combobox {
  color: #2b2f3b;
}

.gedit-bottom-panel-paned {
  background-color: #ffffff;
}

.gedit-side-panel-paned > separator {
  background-image: linear-gradient(to bottom, rgba(210, 210, 210, 0.95), rgba(210, 210, 210, 0.95));
}

.gedit-bottom-panel-paned > separator {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15));
}

.gedit-document-panel {
  background-color: rgba(248, 248, 248, 0.95);
}

.maximized .gedit-document-panel {
  background-color: #f8f8f8;
}

.gedit-document-panel row {
  color: #2e313d;
  background-color: rgba(46, 49, 61, 0);
}

.gedit-document-panel row:hover {
  background-color: rgba(46, 49, 61, 0.15);
}

.gedit-document-panel row:active {
  color: #ffffff;
  background-color: #3498db;
}

.gedit-document-panel row:active button {
  color: #ffffff;
}

.gedit-document-panel row:selected, .gedit-document-panel row:selected:hover {
  color: #ffffff;
  background-color: #3498db;
}

.gedit-document-panel row:hover:not(:selected) button:active {
  color: #2e313d;
}

filechooser placessidebar.sidebar scrollbar,
.nautilus-window placessidebar.sidebar scrollbar {
  border-color: rgba(235, 235, 235, 0.95);
}

filechooser placessidebar.sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider,
.nautilus-window placessidebar.sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  background-color: #4f5469;
  border: 1px solid rgba(0, 0, 0, 0.3);
}

filechooser placessidebar.sidebar scrollbar slider,
.nautilus-window placessidebar.sidebar scrollbar slider {
  background-color: rgba(79, 84, 105, 0.7);
}

filechooser placessidebar.sidebar scrollbar slider:hover,
.nautilus-window placessidebar.sidebar scrollbar slider:hover {
  background-color: #5a6077;
}

filechooser placessidebar.sidebar scrollbar slider:hover:active,
.nautilus-window placessidebar.sidebar scrollbar slider:hover:active {
  background-color: #3498db;
}

filechooser placessidebar.sidebar scrollbar slider:disabled,
.nautilus-window placessidebar.sidebar scrollbar slider:disabled {
  background-color: transparent;
}

filechooser placessidebar.sidebar scrollbar trough,
.nautilus-window placessidebar.sidebar scrollbar trough {
  background-color: rgba(235, 235, 235, 0.95);
}

@define-color theme_fg_color #2b2f3b;
@define-color theme_text_color #2e313d;
@define-color theme_bg_color #f7f7f7;
@define-color theme_base_color #ffffff;
@define-color theme_selected_bg_color #3498db;
@define-color theme_selected_fg_color #ffffff;
@define-color fg_color #2b2f3b;
@define-color text_color #2e313d;
@define-color bg_color #f7f7f7;
@define-color base_color #ffffff;
@define-color selected_bg_color #3498db;
@define-color selected_fg_color #ffffff;
@define-color insensitive_bg_color #fcfcfc;
@define-color insensitive_fg_color alpha(rgba(43, 47, 59, 0.55), 0.5);
@define-color insensitive_base_color #ffffff;
@define-color theme_unfocused_fg_color #2b2f3b;
@define-color theme_unfocused_text_color #2e313d;
@define-color theme_unfocused_bg_color #f7f7f7;
@define-color theme_unfocused_base_color #ffffff;
@define-color borders rgba(0, 0, 0, 0.15);
@define-color unfocused_borders rgba(0, 0, 0, 0.15);
@define-color warning_color #F27835;
@define-color error_color #FC4138;
@define-color success_color #2eb398;
@define-color placeholder_text_color #A8A8A8;
@define-color link_color #217dbb;
@define-color content_view_bg #ffffff;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #ffffff;
@define-color wm_title alpha(#2b2f3b, 0.8);
@define-color wm_unfocused_title alpha(#2b2f3b, 0.5);
@define-color wm_bg #f2f2f2;
@define-color wm_bg_unfocused white;
@define-color wm_highlight #fafafa;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_button_close_bg #f46067;
@define-color wm_button_close_hover_bg #f68086;
@define-color wm_button_close_active_bg #f13039;
@define-color wm_icon_close_bg #f2f2f2;
@define-color wm_button_hover_bg #d9d9d9;
@define-color wm_button_active_bg #3498db;
@define-color wm_button_hover_border rgba(0, 0, 0, 0.15);
@define-color wm_icon_bg #2b2f3b;
@define-color wm_icon_unfocused_bg #a7adbf;
@define-color wm_icon_hover_bg #2b2f3b;
@define-color wm_icon_active_bg #ffffff;
@define-color budgie_tasklist_indicator_color #3498db;
@define-color budgie_tasklist_indicator_color_active #3498db;
@define-color budgie_tasklist_indicator_color_active_window #8ec4e8;
@define-color budgie_tasklist_indicator_color_attention #F27835;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
